@@ -67,15 +67,26 @@ def split_file_projects_branches(path):
 
 
 class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
-
     """
     Poll a Subversion repository for changes and submit them to the change
     master.
     """
 
-    compare_attrs = ("repourl", "split_file", "svnuser", "svnpasswd", "project", "pollInterval",
-                     "histmax", "svnbin", "category", "cachepath", "pollAtLaunch",
-                     "pollRandomDelayMin", "pollRandomDelayMax")
+    compare_attrs = (
+        "repourl",
+        "split_file",
+        "svnuser",
+        "svnpasswd",
+        "project",
+        "pollInterval",
+        "histmax",
+        "svnbin",
+        "category",
+        "cachepath",
+        "pollAtLaunch",
+        "pollRandomDelayMin",
+        "pollRandomDelayMax",
+    )
     secrets = ("svnuser", "svnpasswd")
     parent = None  # filled in when we're added
     last_change = None
@@ -87,34 +98,56 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
             kwargs['name'] = repourl
         super().__init__(repourl, **kwargs)
 
-    def checkConfig(self, repourl, split_file=None, svnuser=None, svnpasswd=None,
-                    pollInterval=10 * 60, histmax=100, svnbin="svn", revlinktmpl="",
-                    category=None, project="", cachepath=None, pollinterval=-2,
-                    extra_args=None, name=None, pollAtLaunch=False, pollRandomDelayMin=0,
-                    pollRandomDelayMax=0):
-
-        # for backward compatibility; the parameter used to be spelled with 'i'
-        if pollinterval != -2:
-            pollInterval = pollinterval
-
+    def checkConfig(
+        self,
+        repourl,
+        split_file=None,
+        svnuser=None,
+        svnpasswd=None,
+        pollInterval=10 * 60,
+        histmax=100,
+        svnbin="svn",
+        revlinktmpl="",
+        category=None,
+        project="",
+        cachepath=None,
+        extra_args=None,
+        name=None,
+        pollAtLaunch=False,
+        pollRandomDelayMin=0,
+        pollRandomDelayMax=0,
+    ):
         if name is None:
             name = repourl
 
-        super().checkConfig(name=name, pollInterval=pollInterval, pollAtLaunch=pollAtLaunch,
-                            pollRandomDelayMin=pollRandomDelayMin,
-                            pollRandomDelayMax=pollRandomDelayMax)
+        super().checkConfig(
+            name=name,
+            pollInterval=pollInterval,
+            pollAtLaunch=pollAtLaunch,
+            pollRandomDelayMin=pollRandomDelayMin,
+            pollRandomDelayMax=pollRandomDelayMax,
+        )
 
     @defer.inlineCallbacks
-    def reconfigService(self, repourl, split_file=None, svnuser=None, svnpasswd=None,
-                        pollInterval=10 * 60, histmax=100, svnbin="svn", revlinktmpl="",
-                        category=None, project="", cachepath=None, pollinterval=-2,
-                        extra_args=None, name=None, pollAtLaunch=False, pollRandomDelayMin=0,
-                        pollRandomDelayMax=0):
-
-        # for backward compatibility; the parameter used to be spelled with 'i'
-        if pollinterval != -2:
-            pollInterval = pollinterval
-
+    def reconfigService(
+        self,
+        repourl,
+        split_file=None,
+        svnuser=None,
+        svnpasswd=None,
+        pollInterval=10 * 60,
+        histmax=100,
+        svnbin="svn",
+        revlinktmpl="",
+        category=None,
+        project="",
+        cachepath=None,
+        extra_args=None,
+        name=None,
+        pollAtLaunch=False,
+        pollRandomDelayMin=0,
+        pollRandomDelayMax=0,
+    ):
         if name is None:
             name = repourl
 
@@ -134,8 +167,7 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
         self.svnbin = svnbin
         self.histmax = histmax
         self._prefix = None
-        self.category = category if callable(
-            category) else util.bytes2unicode(category)
+        self.category = category if callable(category) else util.bytes2unicode(category)
         self.project = util.bytes2unicode(project)
 
         self.cachepath = cachepath
@@ -143,21 +175,30 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
             try:
                 with open(self.cachepath, "r", encoding='utf-8') as f:
                     self.last_change = int(f.read().strip())
-                    log.msg(f"SVNPoller: SVNPoller({self.repourl}) setting last_change "
-                            f"to {self.last_change}")
+                    log.msg(
+                        f"SVNPoller: SVNPoller({self.repourl}) setting last_change "
+                        f"to {self.last_change}"
+                    )
                 # try writing it, too
                 with open(self.cachepath, "w", encoding='utf-8') as f:
                     f.write(str(self.last_change))
             except Exception:
                 self.cachepath = None
-                log.msg(("SVNPoller: SVNPoller({}) cache file corrupt or unwriteable; " +
-                         "skipping and not using").format(self.repourl))
+                log.msg(
+                    (
+                        "SVNPoller: SVNPoller({}) cache file corrupt or unwriteable; "
+                        + "skipping and not using"
+                    ).format(self.repourl)
+                )
                 log.err()
 
-        yield super().reconfigService(name=name, pollInterval=pollInterval,
-                                      pollAtLaunch=pollAtLaunch,
-                                      pollRandomDelayMin=pollRandomDelayMin,
-                                      pollRandomDelayMax=pollRandomDelayMax)
+        yield super().reconfigService(
+            name=name,
+            pollInterval=pollInterval,
+            pollAtLaunch=pollAtLaunch,
+            pollRandomDelayMin=pollRandomDelayMin,
+            pollRandomDelayMax=pollRandomDelayMax,
+        )
 
     def describe(self):
         return f"SVNPoller: watching {self.repourl}"
@@ -226,8 +267,13 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
             command.append(f"--password={self.svnpasswd}")
         if self.extra_args:
             command.extend(self.extra_args)
-        rc, output = yield runprocess.run_process(self.master.reactor, command, env=self.environ,
-                                                  collect_stderr=False, stderr_is_error=True)
+        rc, output = yield runprocess.run_process(
+            self.master.reactor,
+            command,
+            env=self.environ,
+            collect_stderr=False,
+            stderr_is_error=True,
+        )
 
         if rc != 0:
             raise EnvironmentError(f'{self}: Got error when retrieving svn prefix')
@@ -247,11 +293,14 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
         root = "".join([c.data for c in rootnode.childNodes])
         # root will be a unicode string
         if not self.repourl.startswith(root):
-            log.msg(format="Got root %(root)r from `svn info`, but it is "
-                           "not a prefix of the configured repourl",
-                    repourl=self.repourl, root=root)
+            log.msg(
+                format="Got root %(root)r from `svn info`, but it is "
+                "not a prefix of the configured repourl",
+                repourl=self.repourl,
+                root=root,
+            )
             raise RuntimeError("Configured repourl doesn't match svn root")
-        prefix = self.repourl[len(root):]
+        prefix = self.repourl[len(root) :]
         if prefix.startswith("/"):
             prefix = prefix[1:]
         log.msg(f"SVNPoller: repourl={self.repourl}, root={root}, so prefix={prefix}")
@@ -268,8 +317,13 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
             command.extend(self.extra_args)
         command.extend([f"--limit={(self.histmax)}", self.repourl])
 
-        rc, output = yield runprocess.run_process(self.master.reactor, command, env=self.environ,
-                                                  collect_stderr=False, stderr_is_error=True)
+        rc, output = yield runprocess.run_process(
+            self.master.reactor,
+            command,
+            env=self.environ,
+            collect_stderr=False,
+            stderr_is_error=True,
+        )
 
         if rc != 0:
             raise EnvironmentError(f'{self}: Got error when retrieving svn logs')
@@ -327,11 +381,14 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
 
     def _transform_path(self, path):
         if not path.startswith(self._prefix):
-            log.msg(format="SVNPoller: ignoring path '%(path)s' which doesn't"
-                    "start with prefix '%(prefix)s'",
-                    path=path, prefix=self._prefix)
+            log.msg(
+                format="SVNPoller: ignoring path '%(path)s' which doesn't"
+                "start with prefix '%(prefix)s'",
+                path=path,
+                prefix=self._prefix,
+            )
             return None
-        relative_path = path[len(self._prefix):]
+        relative_path = path[len(self._prefix) :]
         if relative_path.startswith("/"):
             relative_path = relative_path[1:]
         where = self.split_file(relative_path)
@@ -385,8 +442,7 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
                     branch = where.get("branch", None)
                     filename = where["path"]
                     if branch not in branches:
-                        branches[branch] = {
-                            'files': [], 'number_of_directories': 0}
+                        branches[branch] = {'files': [], 'number_of_directories': 0}
                     if filename == "":
                         # root directory of branch
                         branches[branch]['files'].append(filename)
@@ -412,8 +468,12 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
                 number_of_directories_changed = info['number_of_directories']
                 number_of_files_changed = len(files)
 
-                if (action == 'D' and number_of_directories_changed == 1 and
-                        number_of_files_changed == 1 and files[0] == ''):
+                if (
+                    action == 'D'
+                    and number_of_directories_changed == 1
+                    and number_of_files_changed == 1
+                    and files[0] == ''
+                ):
                     log.msg(f"Ignoring deletion of branch '{branch}'")
                 else:
                     chdict = {
@@ -428,7 +488,7 @@ class SVNPoller(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
                         "category": self.category,
                         "repository": util.bytes2unicode(info.get('repository', self.repourl)),
                         "project": util.bytes2unicode(info.get('project', self.project)),
-                        "codebase": util.bytes2unicode(info.get('codebase', None))
+                        "codebase": util.bytes2unicode(info.get('codebase', None)),
                     }
                     changes.append(chdict)
 
