@@ -39,7 +39,6 @@ from buildbot.util import ComparableMixin
 from buildbot.util import identifiers as util_identifiers
 from buildbot.util import service as util_service
 from buildbot.warnings import ConfigWarning
-from buildbot.warnings import warn_deprecated
 from buildbot.www import auth
 from buildbot.www import avatar
 from buildbot.www.authz import authz
@@ -89,18 +88,22 @@ def loadConfigDict(basedir, configFileName):
         except SyntaxError:
             error(
                 f"encountered a SyntaxError while parsing config file:\n{traceback.format_exc()} ",
-                always_raise=True)
+                always_raise=True,
+            )
         except Exception:
             log.err(failure.Failure(), 'error while parsing config file:')
-            error(f"error while parsing config file: {sys.exc_info()[1]} (traceback in logfile)",
-                  always_raise=True)
+            error(
+                f"error while parsing config file: {sys.exc_info()[1]} (traceback in logfile)",
+                always_raise=True,
+            )
     finally:
         sys.path[:] = old_sys_path
 
     if 'BuildmasterConfig' not in localDict:
-        error(f"Configuration file {repr(filename)} does not define 'BuildmasterConfig'",
-              always_raise=True,
-              )
+        error(
+            f"Configuration file {repr(filename)} does not define 'BuildmasterConfig'",
+            always_raise=True,
+        )
 
     return filename, localDict['BuildmasterConfig']
 
@@ -124,7 +127,6 @@ class FileLoader(ComparableMixin):
 
 
 class MasterConfig(util.ComparableMixin):
-
     def __init__(self):
         # local import to avoid circular imports
         from buildbot.process import properties
@@ -144,6 +146,7 @@ class MasterConfig(util.ComparableMixin):
         self.collapseRequests = None
         self.codebaseGenerator = None
         self.prioritizeBuilders = None
+        self.select_next_worker = None
         self.multiMaster = False
         self.manhole = None
         self.protocols = {}
@@ -205,13 +208,12 @@ class MasterConfig(util.ComparableMixin):
         "multiMaster",
         "prioritizeBuilders",
         "projects",
-        "projectName",
-        "projectURL",
         "properties",
         "protocols",
         "revlink",
         "schedulers",
         "secretsProviders",
+        "select_next_worker",
         "services",
         "title",
         "titleURL",
@@ -235,7 +237,7 @@ class MasterConfig(util.ComparableMixin):
             'properties': kwargs.get('properties', {}),
             'repository': kwargs.get('repository', ''),
             'project': kwargs.get('project', ''),
-            'codebase': kwargs.get('codebase', None)
+            'codebase': kwargs.get('codebase', None),
         }
 
     @classmethod
@@ -290,49 +292,47 @@ class MasterConfig(util.ComparableMixin):
             interfaces.IConfigurator(configurator).configure(config_dict)
 
     def load_global(self, filename, config_dict):
-        def copy_param(name, alt_key=None,
-                       check_type=None, check_type_name=None, can_be_callable=False):
+        def copy_param(name, check_type=None, check_type_name=None, can_be_callable=False):
             if name in config_dict:
                 v = config_dict[name]
-            elif alt_key and alt_key in config_dict:
-                warn_deprecated(
-                    "3.9.0",
-                    f"Configuration dictionary key {alt_key} is deprecated. Use {name} instead."
-                )
-                v = config_dict[alt_key]
             else:
                 return
-            if v is not None and check_type and not (
-                    isinstance(v, check_type) or (can_be_callable and callable(v))):
+            if (
+                v is not None
+                and check_type
+                and not (isinstance(v, check_type) or (can_be_callable and callable(v)))
+            ):
                 error(f"c['{name}'] must be {check_type_name}")
             else:
                 setattr(self, name, v)
 
-        def copy_int_param(name, alt_key=None):
-            copy_param(name, alt_key=alt_key,
-                       check_type=int, check_type_name='an int')
+        def copy_int_param(name):
+            copy_param(name, check_type=int, check_type_name='an int')
 
-        def copy_str_param(name, alt_key=None):
-            copy_param(name, alt_key=alt_key,
-                       check_type=(str,), check_type_name='a string')
+        def copy_str_param(name):
+            copy_param(name, check_type=(str,), check_type_name='a string')
 
-        copy_str_param('title', alt_key='projectName')
+        copy_str_param('title')
 
         max_title_len = 18
         if len(self.title) > max_title_len:
             # Warn if the title length limiting logic in www/base/src/app/app.route.js
             # would hide the title.
-            warnings.warn('WARNING: Title is too long to be displayed. ' +
-                          '"Buildbot" will be used instead.',
-                          category=ConfigWarning)
+            warnings.warn(
+                'WARNING: Title is too long to be displayed. ' + '"Buildbot" will be used instead.',
+                category=ConfigWarning,
+            )
 
-        copy_str_param('titleURL', alt_key='projectURL')
+        copy_str_param('titleURL')
         copy_str_param('buildbotURL')
 
-        def copy_str_or_callable_param(name, alt_key=None):
-            copy_param(name, alt_key=alt_key,
-                       check_type=(str,), check_type_name='a string or callable',
-                       can_be_callable=True)
+        def copy_str_or_callable_param(name):
+            copy_param(
+                name,
+                check_type=(str,),
+                check_type_name='a string or callable',
+                can_be_callable=True,
+            )
 
         if "buildbotNetUsageData" not in config_dict:
             if get_is_in_unit_tests():
@@ -346,25 +346,27 @@ class MasterConfig(util.ComparableMixin):
                     'Only installation software version info and plugin usage is sent.\n'
                     'You can `opt-out` by setting this variable to None.\n'
                     'Or `opt-in` for more information by setting it to "full".\n',
-                    category=ConfigWarning)
+                    category=ConfigWarning,
+                )
         copy_str_or_callable_param('buildbotNetUsageData')
 
         copy_int_param('changeHorizon')
         copy_int_param('logCompressionLimit')
 
-        self.logCompressionMethod = config_dict.get(
-            'logCompressionMethod', 'gz')
+        self.logCompressionMethod = config_dict.get('logCompressionMethod', 'gz')
         if self.logCompressionMethod not in ('raw', 'bz2', 'gz', 'lz4'):
-            error(
-                "c['logCompressionMethod'] must be 'raw', 'bz2', 'gz' or 'lz4'")
+            error("c['logCompressionMethod'] must be 'raw', 'bz2', 'gz' or 'lz4'")
 
         if self.logCompressionMethod == "lz4":
             try:
                 import lz4  # pylint: disable=import-outside-toplevel
+
                 [lz4]
             except ImportError:
-                error("To set c['logCompressionMethod'] to 'lz4' "
-                      "you must install the lz4 library ('pip install lz4')")
+                error(
+                    "To set c['logCompressionMethod'] to 'lz4' "
+                    "you must install the lz4 library ('pip install lz4')"
+                )
 
         copy_int_param('logMaxSize')
         copy_int_param('logMaxTailSize')
@@ -377,17 +379,14 @@ class MasterConfig(util.ComparableMixin):
             self.properties.update(properties, filename)
 
         collapseRequests = config_dict.get('collapseRequests')
-        if (collapseRequests not in (None, True, False)
-                and not callable(collapseRequests)):
+        if collapseRequests not in (None, True, False) and not callable(collapseRequests):
             error("collapseRequests must be a callable, True, or False")
         else:
             self.collapseRequests = collapseRequests
 
         codebaseGenerator = config_dict.get('codebaseGenerator')
-        if (codebaseGenerator is not None and
-                not callable(codebaseGenerator)):
-            error(
-                "codebaseGenerator must be a callable accepting a dict and returning a str")
+        if codebaseGenerator is not None and not callable(codebaseGenerator):
+            error("codebaseGenerator must be a callable accepting a dict and returning a str")
         else:
             self.codebaseGenerator = codebaseGenerator
 
@@ -397,6 +396,12 @@ class MasterConfig(util.ComparableMixin):
         else:
             self.prioritizeBuilders = prioritizeBuilders
 
+        select_next_worker = config_dict.get("select_next_worker")
+        if select_next_worker is not None and not callable(select_next_worker):
+            error("select_next_worker must be a callable")
+        else:
+            self.select_next_worker = select_next_worker
+
         protocols = config_dict.get('protocols', {})
         if isinstance(protocols, dict):
             for proto, options in protocols.items():
@@ -416,8 +421,10 @@ class MasterConfig(util.ComparableMixin):
             self.multiMaster = config_dict["multiMaster"]
 
         if 'debugPassword' in config_dict:
-            log.msg("the 'debugPassword' parameter is unused and "
-                    "can be removed from the configuration file")
+            log.msg(
+                "the 'debugPassword' parameter is unused and "
+                "can be removed from the configuration file"
+            )
 
         if 'manhole' in config_dict:
             # we don't check that this is a manhole instance, since that
@@ -437,8 +444,7 @@ class MasterConfig(util.ComparableMixin):
         if not isinstance(validation, dict):
             error("c['validation'] must be a dictionary")
         else:
-            unknown_keys = (
-                set(validation.keys()) - set(self.validation.keys()))
+            unknown_keys = set(validation.keys()) - set(self.validation.keys())
             if unknown_keys:
                 error(f"unrecognized validation key(s): {', '.join(unknown_keys)}")
             else:
@@ -446,7 +452,6 @@ class MasterConfig(util.ComparableMixin):
 
     @staticmethod
     def getDbUrlFromConfig(config_dict, throwErrors=True):
-
         if 'db' in config_dict:
             db = config_dict['db']
             if set(db.keys()) - set(['db_url']) and throwErrors:
@@ -466,6 +471,7 @@ class MasterConfig(util.ComparableMixin):
 
     def load_mq(self, filename, config_dict):
         from buildbot.mq import connector  # avoid circular imports
+
         if 'mq' in config_dict:
             self.mq.update(config_dict['mq'])
 
@@ -505,7 +511,7 @@ class MasterConfig(util.ComparableMixin):
             if not isinstance(caches, dict):
                 error("c['caches'] must be a dictionary")
             else:
-                for (name, value) in caches.items():
+                for name, value in caches.items():
                     if not isinstance(value, int):
                         error(f"value for cache size '{name}' must be an integer")
                         return
@@ -563,6 +569,7 @@ class MasterConfig(util.ComparableMixin):
                 return p
             error(f"{repr(p)} is not a project config (in c['projects']")
             return None
+
         self.projects = [mapper(p) for p in projects]
 
     def load_builders(self, filename, config_dict):
@@ -583,13 +590,16 @@ class MasterConfig(util.ComparableMixin):
             else:
                 error(f"{repr(b)} is not a builder config (in c['builders']")
             return None
+
         builders = [mapper(b) for b in builders]
 
         for builder in builders:
             if builder and os.path.isabs(builder.builddir):
                 warnings.warn(
-                    (f"Absolute path '{builder.builddir}' for builder may cause mayhem. "
-                     "Perhaps you meant to specify workerbuilddir instead."),
+                    (
+                        f"Absolute path '{builder.builddir}' for builder may cause mayhem. "
+                        "Perhaps you meant to specify workerbuilddir instead."
+                    ),
                     category=ConfigWarning,
                 )
 
@@ -709,6 +719,7 @@ class MasterConfig(util.ComparableMixin):
             'ws_ping_interval',
             'project_widgets',
             'graphql',
+            'theme',
         }
         unknown = set(list(www_cfg)) - allowed
 
@@ -732,8 +743,10 @@ class MasterConfig(util.ComparableMixin):
         cookie_expiration_time = www_cfg.get('cookie_expiration_time')
         if cookie_expiration_time is not None:
             if not isinstance(cookie_expiration_time, datetime.timedelta):
-                error('Invalid www["cookie_expiration_time"] configuration should '
-                      'be a datetime.timedelta')
+                error(
+                    'Invalid www["cookie_expiration_time"] configuration should '
+                    'be a datetime.timedelta'
+                )
 
         self.www.update(www_cfg)
 
@@ -743,8 +756,10 @@ class MasterConfig(util.ComparableMixin):
         self.services = {}
         for _service in config_dict['services']:
             if not isinstance(_service, util_service.BuildbotService):
-                error(f"{type(_service)} object should be an instance of "
-                      "buildbot.util.service.BuildbotService")
+                error(
+                    f"{type(_service)} object should be an instance of "
+                    "buildbot.util.service.BuildbotService"
+                )
 
                 continue
 
@@ -838,8 +853,10 @@ class MasterConfig(util.ComparableMixin):
         for b in self.builders:
             unknowns = set(b.workernames) - workernames
             if unknowns:
-                error(f"builder '{b.name}' uses unknown workers "
-                      f"{', '.join(repr(u) for u in unknowns)}")
+                error(
+                    f"builder '{b.name}' uses unknown workers "
+                    f"{', '.join(repr(u) for u in unknowns)}"
+                )
             if b.name in seen_names:
                 error(f"duplicate builder name '{b.name}'")
             seen_names.add(b.name)
