@@ -19,12 +19,10 @@ from buildbot.data import base
 from buildbot.data import types
 from buildbot.db.buildrequests import AlreadyClaimedError
 from buildbot.db.buildrequests import NotClaimedError
-from buildbot.process import results
 from buildbot.process.results import RETRY
 
 
 class Db2DataMixin:
-
     def _generate_filtered_properties(self, props, filters):
         """
         This method returns Build's properties according to property filters.
@@ -34,9 +32,11 @@ class Db2DataMixin:
         """
         # by default no properties are returned
         if props and filters:
-            return (props
-                    if '*' in filters
-                    else dict(((k, v) for k, v in props.items() if k in filters)))
+            return (
+                props
+                if '*' in filters
+                else dict(((k, v) for k, v in props.items() if k in filters))
+            )
         return None
 
     @defer.inlineCallbacks
@@ -66,6 +66,7 @@ class Db2DataMixin:
             'properties': dbdict.get('properties'),
         }
         return defer.succeed(data)
+
     fieldMapping = {
         'buildrequestid': 'buildrequests.id',
         'buildsetid': 'buildrequests.buildsetid',
@@ -83,8 +84,7 @@ class Db2DataMixin:
 
 
 class BuildRequestEndpoint(Db2DataMixin, base.Endpoint):
-
-    isCollection = False
+    kind = base.EndpointKind.SINGLE
     pathPatterns = """
         /buildrequests/n:buildrequestid
     """
@@ -99,48 +99,29 @@ class BuildRequestEndpoint(Db2DataMixin, base.Endpoint):
             return (yield self.db2data(buildrequest))
         return None
 
+    @defer.inlineCallbacks
+    def set_request_priority(self, brid, args, kwargs):
+        priority = args['priority']
+        yield self.master.db.buildrequests.set_build_requests_priority(
+            brids=[brid], priority=priority
+        )
+
     @defer.inlineCallbacks
     def control(self, action, args, kwargs):
-        if action != "cancel":
-            raise ValueError(f"action: {action} is not supported")
         brid = kwargs['buildrequestid']
-        # first, try to claim the request; if this fails, then it's too late to
-        # cancel the build anyway
-        try:
-            b = yield self.master.db.buildrequests.claimBuildRequests(brids=[brid])
-        except AlreadyClaimedError:
-            # XXX race condition
-            # - After a buildrequest was claimed, and
-            # - Before creating a build,
-            # the claiming master still
-            # needs to do some processing, (send a message to the message queue,
-            # call maybeStartBuild on the related builder).
-            # In that case we won't have the related builds here. We don't have
-            # an alternative to letting them run without stopping them for now.
-            builds = yield self.master.data.get(("buildrequests", brid, "builds"))
-
-            # Don't call the data API here, as the buildrequests might have been
-            # taken by another master. We just send the stop message and forget
-            # about those.
-            mqArgs = {'reason': args.get('reason', 'no reason')}
-            for b in builds:
-                self.master.mq.produce(("control", "builds", str(b['buildid']), "stop"),
-                                       mqArgs)
-            return None
-
-        # then complete it with 'CANCELLED'; this is the closest we can get to
-        # cancelling a request without running into trouble with dangling
-        # references.
-        yield self.master.data.updates.completeBuildRequests([brid],
-                                                             results.CANCELLED)
-        brdict = yield self.master.db.buildrequests.getBuildRequest(brid)
-        self.master.mq.produce(('buildrequests', str(brid), 'cancel'), brdict)
-        return None
+        if action == "cancel":
+            self.master.mq.produce(
+                ('control', 'buildrequests', str(brid), 'cancel'),
+                {'reason': args.get('reason', 'no reason')},
+            )
+        elif action == "set_priority":
+            yield self.set_request_priority(brid, args, kwargs)
+        else:
+            raise ValueError(f"action: {action} is not supported")
 
 
 class BuildRequestsEndpoint(Db2DataMixin, base.Endpoint):
-
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = """
         /buildrequests
         /builders/n:builderid/buildrequests
@@ -151,8 +132,7 @@ class BuildRequestsEndpoint(Db2DataMixin, base.Endpoint):
     def get(self, resultSpec, kwargs):
         builderid = kwargs.get("builderid", None)
         complete = resultSpec.popBooleanFilter('complete')
-        claimed_by_masterid = resultSpec.popBooleanFilter(
-            'claimed_by_masterid')
+        claimed_by_masterid = resultSpec.popBooleanFilter('claimed_by_masterid')
         if claimed_by_masterid:
             # claimed_by_masterid takes precedence over 'claimed' filter
             # (no need to check consistency with 'claimed' filter even if
@@ -168,7 +148,8 @@ class BuildRequestsEndpoint(Db2DataMixin, base.Endpoint):
             complete=complete,
             claimed=claimed,
             bsid=bsid,
-            resultSpec=resultSpec)
+            resultSpec=resultSpec,
+        )
         results = []
         filters = resultSpec.popProperties() if hasattr(resultSpec, 'popProperties') else []
         for br in buildrequests:
@@ -178,7 +159,6 @@ class BuildRequestsEndpoint(Db2DataMixin, base.Endpoint):
 
 
 class BuildRequest(base.ResourceType):
-
     name = "buildrequest"
     plural = "buildrequests"
     endpoints = [BuildRequestEndpoint, BuildRequestsEndpoint]
@@ -205,6 +185,7 @@ class BuildRequest(base.ResourceType):
         complete_at = types.NoneOk(types.DateTime())
         waited_for = types.Boolean()
         properties = types.NoneOk(types.SourcedProperties())
+
     entityType = EntityType(name, 'Buildrequest')
 
     @defer.inlineCallbacks
@@ -231,10 +212,12 @@ class BuildRequest(base.ResourceType):
 
     @base.updateMethod
     def claimBuildRequests(self, brids, claimed_at=None):
-        return self.callDbBuildRequests(brids,
-                                        self.master.db.buildrequests.claimBuildRequests,
-                                        event="claimed",
-                                        claimed_at=claimed_at)
+        return self.callDbBuildRequests(
+            brids,
+            self.master.db.buildrequests.claimBuildRequests,
+            event="claimed",
+            claimed_at=claimed_at,
+        )
 
     @base.updateMethod
     @defer.inlineCallbacks
@@ -252,9 +235,8 @@ class BuildRequest(base.ResourceType):
             return True
         try:
             yield self.master.db.buildrequests.completeBuildRequests(
-                brids,
-                results,
-                complete_at=complete_at)
+                brids, results, complete_at=complete_at
+            )
         except NotClaimedError:
             # the db layer returned a NotClaimedError exception, usually
             # because one of the buildrequests has been claimed by another
@@ -280,17 +262,38 @@ class BuildRequest(base.ResourceType):
     @base.updateMethod
     @defer.inlineCallbacks
     def rebuildBuildrequest(self, buildrequest):
-
         # goal is to make a copy of the original buildset
         buildset = yield self.master.data.get(('buildsets', buildrequest['buildsetid']))
-        properties = yield self.master.data.get(('buildsets', buildrequest['buildsetid'],
-                                                 'properties'))
+        properties = yield self.master.data.get((
+            'buildsets',
+            buildrequest['buildsetid'],
+            'properties',
+        ))
+        # use original build id: after rebuild, it is saved in new buildset `rebuilt_buildid` column
+        builds = yield self.master.data.get((
+            'buildrequests',
+            buildrequest['buildrequestid'],
+            'builds',
+        ))
+        # if already rebuilt build of the same initial build is rebuilt again only save the build
+        # id of the initial build
+        if len(builds) != 0 and buildset['rebuilt_buildid'] is None:
+            print("Length = ", len(builds))
+            rebuilt_buildid = builds[0]['buildid']
+        else:
+            rebuilt_buildid = buildset['rebuilt_buildid']
+
         ssids = [ss['ssid'] for ss in buildset['sourcestamps']]
         res = yield self.master.data.updates.addBuildset(
-                waited_for=False, scheduler='rebuild', sourcestamps=ssids, reason='rebuild',
-                properties=properties,
-                builderids=[buildrequest['builderid']],
-                external_idstring=buildset['external_idstring'],
-                parent_buildid=buildset['parent_buildid'],
-                parent_relationship=buildset['parent_relationship'])
+            waited_for=False,
+            scheduler='rebuild',
+            sourcestamps=ssids,
+            reason='rebuild',
+            properties=properties,
+            builderids=[buildrequest['builderid']],
+            external_idstring=buildset['external_idstring'],
+            rebuilt_buildid=rebuilt_buildid,
+            parent_buildid=buildset['parent_buildid'],
+            parent_relationship=buildset['parent_relationship'],
+        )
         return res
