@@ -30,13 +30,23 @@ from buildbot.util import epoch2datetime
 
 
 class Db2DataMixin:
-
     @defer.inlineCallbacks
     def db2data(self, bsdict):
         if not bsdict:
             return None
 
-        buildset = bsdict.copy()
+        buildset = {
+            "bsid": bsdict["bsid"],
+            "external_idstring": bsdict["external_idstring"],
+            "reason": bsdict["reason"],
+            "rebuilt_buildid": bsdict["rebuilt_buildid"],
+            "submitted_at": datetime2epoch(bsdict["submitted_at"]),
+            "complete": bsdict["complete"],
+            "complete_at": datetime2epoch(bsdict["complete_at"]),
+            "results": bsdict["results"],
+            "parent_buildid": bsdict["parent_buildid"],
+            "parent_relationship": bsdict["parent_relationship"],
+        }
 
         # gather the actual sourcestamps, in parallel
         sourcestamps = []
@@ -45,33 +55,30 @@ class Db2DataMixin:
         def getSs(ssid):
             ss = yield self.master.data.get(('sourcestamps', str(ssid)))
             sourcestamps.append(ss)
-        yield defer.DeferredList([getSs(id)
-                                  for id in buildset['sourcestamps']],
-                                 fireOnOneErrback=True, consumeErrors=True)
+
+        yield defer.DeferredList(
+            [getSs(id) for id in bsdict['sourcestamps']], fireOnOneErrback=True, consumeErrors=True
+        )
+
         buildset['sourcestamps'] = sourcestamps
-
-        # minor modifications
-        buildset['submitted_at'] = datetime2epoch(buildset['submitted_at'])
-        buildset['complete_at'] = datetime2epoch(buildset['complete_at'])
-
         return buildset
 
     fieldMapping = {
         'bsid': 'buildsets.id',
         'external_idstring': 'buildsets.external_idstring',
         'reason': 'buildsets.reason',
+        'rebuilt_buildid': 'buildsets.rebuilt_buildid',
         'submitted_at': 'buildsets.submitted_at',
         'complete': 'buildsets.complete',
         'complete_at': 'buildsets.complete_at',
         'results': 'buildsets.results',
         'parent_buildid': 'buildsets.parent_buildid',
-        'parent_relationship': 'buildsets.parent_relationship'
+        'parent_relationship': 'buildsets.parent_relationship',
     }
 
 
 class BuildsetEndpoint(Db2DataMixin, base.Endpoint):
-
-    isCollection = False
+    kind = base.EndpointKind.SINGLE
     pathPatterns = """
         /buildsets/n:bsid
     """
@@ -84,33 +91,28 @@ class BuildsetEndpoint(Db2DataMixin, base.Endpoint):
 
 
 class BuildsetsEndpoint(Db2DataMixin, base.Endpoint):
-
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = """
         /buildsets
     """
     rootLinkName = 'buildsets'
 
+    @defer.inlineCallbacks
     def get(self, resultSpec, kwargs):
         complete = resultSpec.popBooleanFilter('complete')
         resultSpec.fieldMapping = self.fieldMapping
-        d = self.master.db.buildsets.getBuildsets(
-            complete=complete, resultSpec=resultSpec)
+        buildsets = yield self.master.db.buildsets.getBuildsets(
+            complete=complete, resultSpec=resultSpec
+        )
 
-        @d.addCallback
-        def db2data(buildsets):
-            d = defer.DeferredList([self.db2data(bs) for bs in buildsets],
-                                   fireOnOneErrback=True, consumeErrors=True)
+        buildsets = yield defer.gatherResults(
+            [self.db2data(bs) for bs in buildsets], consumeErrors=True
+        )
 
-            @d.addCallback
-            def getResults(res):
-                return [r[1] for r in res]
-            return d
-        return d
+        return buildsets
 
 
 class Buildset(base.ResourceType):
-
     name = "buildset"
     plural = "buildsets"
     endpoints = [BuildsetEndpoint, BuildsetsEndpoint]
@@ -123,22 +125,34 @@ class Buildset(base.ResourceType):
         bsid = types.Integer()
         external_idstring = types.NoneOk(types.String())
         reason = types.String()
+        rebuilt_buildid = types.NoneOk(types.Integer())
         submitted_at = types.Integer()
         complete = types.Boolean()
         complete_at = types.NoneOk(types.Integer())
         results = types.NoneOk(types.Integer())
-        sourcestamps = types.List(
-            of=sourcestampsapi.SourceStamp.entityType)
+        sourcestamps = types.List(of=sourcestampsapi.SourceStamp.entityType)
         parent_buildid = types.NoneOk(types.Integer())
         parent_relationship = types.NoneOk(types.String())
+
     entityType = EntityType(name, 'Buildset')
     subresources = ["Property"]
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def addBuildset(self, waited_for, scheduler=None, sourcestamps=None, reason='',
-                    properties=None, builderids=None, external_idstring=None,
-                    parent_buildid=None, parent_relationship=None, priority=0):
+    def addBuildset(
+        self,
+        waited_for,
+        scheduler=None,
+        sourcestamps=None,
+        reason='',
+        properties=None,
+        builderids=None,
+        external_idstring=None,
+        rebuilt_buildid=None,
+        parent_buildid=None,
+        parent_relationship=None,
+        priority=0,
+    ):
         if sourcestamps is None:
             sourcestamps = []
         if properties is None:
@@ -147,12 +161,18 @@ class Buildset(base.ResourceType):
             builderids = []
         submitted_at = int(self.master.reactor.seconds())
         bsid, brids = yield self.master.db.buildsets.addBuildset(
-            sourcestamps=sourcestamps, reason=reason,
-            properties=properties, builderids=builderids,
-            waited_for=waited_for, external_idstring=external_idstring,
+            sourcestamps=sourcestamps,
+            reason=reason,
+            rebuilt_buildid=rebuilt_buildid,
+            properties=properties,
+            builderids=builderids,
+            waited_for=waited_for,
+            external_idstring=external_idstring,
             submitted_at=epoch2datetime(submitted_at),
-            parent_buildid=parent_buildid, parent_relationship=parent_relationship,
-            priority=priority)
+            parent_buildid=parent_buildid,
+            parent_relationship=parent_relationship,
+            priority=priority,
+        )
 
         yield BuildRequestCollapser(self.master, list(brids.values())).collapse()
 
@@ -160,9 +180,7 @@ class Buildset(base.ResourceType):
         bsdict = yield self.master.db.buildsets.getBuildset(bsid)
         sourcestamps = []
         for ssid in bsdict['sourcestamps']:
-            sourcestamps.append(
-                (yield self.master.data.get(('sourcestamps', str(ssid)))).copy()
-            )
+            sourcestamps.append((yield self.master.data.get(('sourcestamps', str(ssid)))).copy())
 
         # notify about the component build requests
         brResource = self.master.data.getResourceType("buildrequest")
@@ -173,12 +191,14 @@ class Buildset(base.ResourceType):
             "bsid": bsid,
             "external_idstring": external_idstring,
             "reason": reason,
+            "parent_buildid": parent_buildid,
+            "rebuilt_buildid": rebuilt_buildid,
             "submitted_at": submitted_at,
             "complete": False,
             "complete_at": None,
             "results": None,
             "scheduler": scheduler,
-            "sourcestamps": sourcestamps
+            "sourcestamps": sourcestamps,
         }
         # TODO: properties=properties)
         self.produceEvent(msg, "new")
@@ -195,8 +215,7 @@ class Buildset(base.ResourceType):
     @base.updateMethod
     @defer.inlineCallbacks
     def maybeBuildsetComplete(self, bsid):
-        brdicts = yield self.master.db.buildrequests.getBuildRequests(
-            bsid=bsid, complete=False)
+        brdicts = yield self.master.db.buildrequests.getBuildRequests(bsid=bsid, complete=False)
 
         # if there are incomplete buildrequests, bail out
         if brdicts:
@@ -207,8 +226,7 @@ class Buildset(base.ResourceType):
         # figure out the overall results of the buildset:
         cumulative_results = SUCCESS
         for brdict in brdicts:
-            cumulative_results = worst_status(
-                cumulative_results, brdict['results'])
+            cumulative_results = worst_status(cumulative_results, brdict['results'])
 
         # get a copy of the buildset
         bsdict = yield self.master.db.buildsets.getBuildset(bsid)
@@ -225,8 +243,9 @@ class Buildset(base.ResourceType):
         # mark it as completed in the database
         complete_at = epoch2datetime(int(self.master.reactor.seconds()))
         try:
-            yield self.master.db.buildsets.completeBuildset(bsid, cumulative_results,
-                                                            complete_at=complete_at)
+            yield self.master.db.buildsets.completeBuildset(
+                bsid, cumulative_results, complete_at=complete_at
+            )
         except AlreadyCompleteError:
             return
         # get the sourcestamps for the message
@@ -235,20 +254,21 @@ class Buildset(base.ResourceType):
         sourcestamps = []
         for ssid in bsdict['sourcestamps']:
             sourcestamps.append(
-                copy.deepcopy(
-                    (yield self.master.data.get(('sourcestamps', str(ssid))))
-                )
+                copy.deepcopy((yield self.master.data.get(('sourcestamps', str(ssid)))))
             )
 
         msg = {
             "bsid": bsid,
             "external_idstring": bsdict['external_idstring'],
             "reason": bsdict['reason'],
+            "rebuilt_buildid": bsdict['rebuilt_buildid'],
             "sourcestamps": sourcestamps,
             "submitted_at": bsdict['submitted_at'],
             "complete": True,
             "complete_at": complete_at,
-            "results": cumulative_results
+            "results": cumulative_results,
+            "parent_buildid": bsdict["parent_buildid"],
+            "parent_relationship": bsdict["parent_relationship"],
         }
         # TODO: properties=properties)
         self.produceEvent(msg, "complete")
