@@ -14,6 +14,7 @@
 # Copyright Buildbot Team Members
 
 import copy
+import json
 
 from twisted.internet import defer
 from twisted.python import log
@@ -28,39 +29,54 @@ from buildbot.util import epoch2datetime
 
 
 class FixerMixin:
-
     @defer.inlineCallbacks
-    def _fixChange(self, change):
+    def _fixChange(self, change, is_graphql):
         # TODO: make these mods in the DB API
         if change:
             change = change.copy()
             change['when_timestamp'] = datetime2epoch(change['when_timestamp'])
-
-            sskey = ('sourcestamps', str(change['sourcestampid']))
-            change['sourcestamp'] = yield self.master.data.get(sskey)
-            del change['sourcestampid']
+            if is_graphql:
+                props = change['properties']
+                change['properties'] = [
+                    {'name': k, 'source': v[1], 'value': json.dumps(v[0])} for k, v in props.items()
+                ]
+            else:
+                sskey = ('sourcestamps', str(change['sourcestampid']))
+                change['sourcestamp'] = yield self.master.data.get(sskey)
+                del change['sourcestampid']
         return change
+
     fieldMapping = {
+        'author': 'changes.author',
+        'branch': 'changes.branch',
+        'category': 'changes.category',
         'changeid': 'changes.changeid',
+        'codebase': 'changes.codebase',
+        'comments': 'changes.comments',
+        'committer': 'changes.committer',
+        'project': 'changes.project',
+        'repository': 'changes.repository',
+        'revision': 'changes.revision',
+        'revlink': 'changes.revlink',
+        'sourcestampid': 'changes.sourcestampid',
+        'when_timestamp': 'changes.when_timestamp',
     }
 
 
 class ChangeEndpoint(FixerMixin, base.Endpoint):
-
-    isCollection = False
+    kind = base.EndpointKind.SINGLE
     pathPatterns = """
         /changes/n:changeid
     """
 
     def get(self, resultSpec, kwargs):
         d = self.master.db.changes.getChange(kwargs['changeid'])
-        d.addCallback(self._fixChange)
+        d.addCallback(self._fixChange, is_graphql='graphql' in kwargs)
         return d
 
 
 class ChangesEndpoint(FixerMixin, base.BuildNestingMixin, base.Endpoint):
-
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = """
         /changes
         /builders/n:builderid/builds/n:build_number/changes
@@ -89,18 +105,19 @@ class ChangesEndpoint(FixerMixin, base.BuildNestingMixin, base.Endpoint):
                 changes = yield self.master.db.changes.getChanges(resultSpec=resultSpec)
         results = []
         for ch in changes:
-            results.append((yield self._fixChange(ch)))
+            results.append((yield self._fixChange(ch, is_graphql='graphql' in kwargs)))
         return results
 
 
 class Change(base.ResourceType):
-
     name = "change"
     plural = "changes"
     endpoints = [ChangeEndpoint, ChangesEndpoint]
     eventPathPatterns = """
         /changes/:changeid
     """
+    keyField = "changeid"
+    subresources = ["Build", "Property"]
 
     class EntityType(types.Entity):
         changeid = types.Integer()
@@ -119,14 +136,28 @@ class Change(base.ResourceType):
         project = types.String()
         codebase = types.String()
         sourcestamp = sourcestamps.SourceStamp.entityType
-    entityType = EntityType(name)
+
+    entityType = EntityType(name, 'Change')
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def addChange(self, files=None, comments=None, author=None, committer=None, revision=None,
-                  when_timestamp=None, branch=None, category=None, revlink='',
-                  properties=None, repository='', codebase=None, project='',
-                  src=None):
+    def addChange(
+        self,
+        files=None,
+        comments=None,
+        author=None,
+        committer=None,
+        revision=None,
+        when_timestamp=None,
+        branch=None,
+        category=None,
+        revlink='',
+        properties=None,
+        repository='',
+        codebase=None,
+        project='',
+        src=None,
+    ):
         metrics.MetricCountEvent.log("added_changes", 1)
 
         if properties is None:
@@ -138,8 +169,7 @@ class Change(base.ResourceType):
         # get a user id
         if src:
             # create user object, returning a corresponding uid
-            uid = yield users.createUserObject(self.master,
-                                               author, src)
+            uid = yield users.createUserObject(self.master, author, src)
         else:
             uid = None
 
@@ -148,34 +178,37 @@ class Change(base.ResourceType):
             revlink = self.master.config.revlink(revision, repository) or ''
 
         if callable(category):
-            pre_change = self.master.config.preChangeGenerator(author=author,
-                                                               committer=committer,
-                                                               files=files,
-                                                               comments=comments,
-                                                               revision=revision,
-                                                               when_timestamp=when_timestamp,
-                                                               branch=branch,
-                                                               revlink=revlink,
-                                                               properties=properties,
-                                                               repository=repository,
-                                                               project=project)
+            pre_change = self.master.config.preChangeGenerator(
+                author=author,
+                committer=committer,
+                files=files,
+                comments=comments,
+                revision=revision,
+                when_timestamp=when_timestamp,
+                branch=branch,
+                revlink=revlink,
+                properties=properties,
+                repository=repository,
+                project=project,
+            )
             category = category(pre_change)
 
         # set the codebase, either the default, supplied, or generated
-        if codebase is None \
-                and self.master.config.codebaseGenerator is not None:
-            pre_change = self.master.config.preChangeGenerator(author=author,
-                                                               committer=committer,
-                                                               files=files,
-                                                               comments=comments,
-                                                               revision=revision,
-                                                               when_timestamp=when_timestamp,
-                                                               branch=branch,
-                                                               category=category,
-                                                               revlink=revlink,
-                                                               properties=properties,
-                                                               repository=repository,
-                                                               project=project)
+        if codebase is None and self.master.config.codebaseGenerator is not None:
+            pre_change = self.master.config.preChangeGenerator(
+                author=author,
+                committer=committer,
+                files=files,
+                comments=comments,
+                revision=revision,
+                when_timestamp=when_timestamp,
+                branch=branch,
+                category=category,
+                revlink=revlink,
+                properties=properties,
+                repository=repository,
+                project=project,
+            )
             codebase = self.master.config.codebaseGenerator(pre_change)
             codebase = str(codebase)
         else:
@@ -196,7 +229,8 @@ class Change(base.ResourceType):
             repository=repository,
             codebase=codebase,
             project=project,
-            uid=uid)
+            uid=uid,
+        )
 
         # get the change and munge the result for the notification
         change = yield self.master.data.get(('changes', str(changeid)))
@@ -204,7 +238,7 @@ class Change(base.ResourceType):
         self.produceEvent(change, 'new')
 
         # log, being careful to handle funny characters
-        msg = "added change with revision {} to database".format(revision)
+        msg = f"added change with revision {revision} to database"
         log.msg(msg.encode('utf-8', 'replace'))
 
         return changeid
