@@ -21,7 +21,6 @@ from buildbot.data import types
 
 
 class Db2DataMixin:
-
     def db2data(self, dbdict):
         data = {
             'stepid': dbdict['id'],
@@ -29,6 +28,7 @@ class Db2DataMixin:
             'name': dbdict['name'],
             'buildid': dbdict['buildid'],
             'started_at': dbdict['started_at'],
+            "locks_acquired_at": dbdict["locks_acquired_at"],
             'complete': dbdict['complete_at'] is not None,
             'complete_at': dbdict['complete_at'],
             'state_string': dbdict['state_string'],
@@ -40,8 +40,7 @@ class Db2DataMixin:
 
 
 class StepEndpoint(Db2DataMixin, base.BuildNestingMixin, base.Endpoint):
-
-    isCollection = False
+    kind = base.EndpointKind.SINGLE
     pathPatterns = """
         /steps/n:stepid
         /builds/n:buildid/steps/i:step_name
@@ -61,15 +60,13 @@ class StepEndpoint(Db2DataMixin, base.BuildNestingMixin, base.Endpoint):
         if buildid is None:
             return None
         dbdict = yield self.master.db.steps.getStep(
-            buildid=buildid,
-            number=kwargs.get('step_number'),
-            name=kwargs.get('step_name'))
+            buildid=buildid, number=kwargs.get('step_number'), name=kwargs.get('step_name')
+        )
         return (yield self.db2data(dbdict)) if dbdict else None
 
 
 class StepsEndpoint(Db2DataMixin, base.BuildNestingMixin, base.Endpoint):
-
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = """
         /builds/n:buildid/steps
         /builders/n:builderid/builds/n:build_number/steps
@@ -97,15 +94,15 @@ class UrlEntityType(types.Entity):
 
 
 class Step(base.ResourceType):
-
     name = "step"
     plural = "steps"
     endpoints = [StepEndpoint, StepsEndpoint]
-    keyFields = ['builderid', 'stepid']
+    keyField = 'stepid'
     eventPathPatterns = """
         /builds/:buildid/steps/:stepid
         /steps/:stepid
     """
+    subresources = ["Log"]
 
     class EntityType(types.Entity):
         stepid = types.Integer()
@@ -113,14 +110,15 @@ class Step(base.ResourceType):
         name = types.Identifier(50)
         buildid = types.Integer()
         started_at = types.NoneOk(types.DateTime())
+        locks_acquired_at = types.NoneOk(types.DateTime())
         complete = types.Boolean()
         complete_at = types.NoneOk(types.DateTime())
         results = types.NoneOk(types.Integer())
         state_string = types.String()
-        urls = types.List(
-            of=UrlEntityType("Url"))
+        urls = types.List(of=UrlEntityType("Url", "Url"))
         hidden = types.Boolean()
-    entityType = EntityType(name)
+
+    entityType = EntityType(name, 'Step')
 
     @defer.inlineCallbacks
     def generateEvent(self, stepid, event):
@@ -131,33 +129,46 @@ class Step(base.ResourceType):
     @defer.inlineCallbacks
     def addStep(self, buildid, name):
         stepid, num, name = yield self.master.db.steps.addStep(
-            buildid=buildid, name=name, state_string='pending')
+            buildid=buildid, name=name, state_string='pending'
+        )
         yield self.generateEvent(stepid, 'new')
         return (stepid, num, name)
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def startStep(self, stepid):
-        yield self.master.db.steps.startStep(stepid=stepid)
+    def startStep(self, stepid, started_at=None, locks_acquired=False):
+        if started_at is None:
+            started_at = int(self.master.reactor.seconds())
+        yield self.master.db.steps.startStep(
+            stepid=stepid, started_at=started_at, locks_acquired=locks_acquired
+        )
         yield self.generateEvent(stepid, 'started')
 
+    @base.updateMethod
+    @defer.inlineCallbacks
+    def set_step_locks_acquired_at(self, stepid, locks_acquired_at=None):
+        if locks_acquired_at is None:
+            locks_acquired_at = int(self.master.reactor.seconds())
+
+        yield self.master.db.steps.set_step_locks_acquired_at(
+            stepid=stepid, locks_acquired_at=locks_acquired_at
+        )
+        yield self.generateEvent(stepid, 'updated')
+
     @base.updateMethod
     @defer.inlineCallbacks
     def setStepStateString(self, stepid, state_string):
-        yield self.master.db.steps.setStepStateString(
-            stepid=stepid, state_string=state_string)
+        yield self.master.db.steps.setStepStateString(stepid=stepid, state_string=state_string)
         yield self.generateEvent(stepid, 'updated')
 
     @base.updateMethod
     @defer.inlineCallbacks
     def addStepURL(self, stepid, name, url):
-        yield self.master.db.steps.addURL(
-            stepid=stepid, name=name, url=url)
+        yield self.master.db.steps.addURL(stepid=stepid, name=name, url=url)
         yield self.generateEvent(stepid, 'updated')
 
     @base.updateMethod
     @defer.inlineCallbacks
     def finishStep(self, stepid, results, hidden):
-        yield self.master.db.steps.finishStep(
-            stepid=stepid, results=results, hidden=hidden)
+        yield self.master.db.steps.finishStep(stepid=stepid, results=results, hidden=hidden)
         yield self.generateEvent(stepid, 'finished')
