@@ -27,7 +27,6 @@ def capitalize(word):
 
 
 class Type:
-
     name = None
     doc = None
     graphQLType = "unknown"
@@ -55,7 +54,7 @@ class Type:
         raise NotImplementedError
 
     def getSpec(self):
-        r = dict(name=self.name)
+        r = {"name": self.name}
         if self.doc is not None:
             r["doc"] = self.doc
         return r
@@ -74,7 +73,6 @@ class Type:
 
 
 class NoneOk(Type):
-
     def __init__(self, nestedType):
         assert isinstance(nestedType, Type)
         self.nestedType = nestedType
@@ -93,8 +91,7 @@ class NoneOk(Type):
     def validate(self, name, object):
         if object is None:
             return
-        for msg in self.nestedType.validate(name, object):
-            yield msg
+        yield from self.nestedType.validate(name, object)
 
     def getSpec(self):
         r = self.nestedType.getSpec()
@@ -118,7 +115,6 @@ class NoneOk(Type):
 
 
 class Instance(Type):
-
     types = ()
     ramlType = "unknown"
     graphQLType = "unknown"
@@ -139,7 +135,6 @@ class Instance(Type):
 
 
 class Integer(Instance):
-
     name = "integer"
     types = (int,)
     ramlType = "integer"
@@ -150,7 +145,6 @@ class Integer(Instance):
 
 
 class DateTime(Instance):
-
     name = "datetime"
     types = (datetime.datetime,)
     ramlType = "date"
@@ -173,7 +167,6 @@ class DateTime(Instance):
 
 
 class String(Instance):
-
     name = "string"
     types = (str,)
     ramlType = "string"
@@ -185,7 +178,6 @@ class String(Instance):
 
 
 class Binary(Instance):
-
     name = "binary"
     types = (bytes,)
     ramlType = "string"
@@ -196,7 +188,6 @@ class Binary(Instance):
 
 
 class Boolean(Instance):
-
     name = "boolean"
     types = (bool,)
     ramlType = "boolean"
@@ -207,7 +198,6 @@ class Boolean(Instance):
 
 
 class Identifier(Type):
-
     name = "identifier"
     identRe = re.compile('^[a-zA-Z_-][a-zA-Z0-9._-]*$')
     ramlType = "string"
@@ -234,12 +224,10 @@ class Identifier(Type):
             yield f"{name} - {repr(object)} - is longer than {self.len} characters"
 
     def toRaml(self):
-        return {'type': self.ramlType,
-                'pattern': self.identRe.pattern}
+        return {'type': self.ramlType, 'pattern': self.identRe.pattern}
 
 
 class List(Type):
-
     name = "list"
     ramlType = "list"
 
@@ -257,8 +245,7 @@ class List(Type):
             return
 
         for idx, elt in enumerate(object):
-            for msg in self.of.validate(f"{name}[{idx}]", elt):
-                yield msg
+            yield from self.of.validate(f"{name}[{idx}]", elt)
 
     def valueFromString(self, arg):
         # valueFromString is used to process URL args, which come one at
@@ -266,8 +253,7 @@ class List(Type):
         return self.of.valueFromString(arg)
 
     def getSpec(self):
-        return dict(type=self.name,
-                    of=self.of.getSpec())
+        return {"type": self.name, "of": self.of.getSpec()}
 
     def toRaml(self):
         return {'type': 'array', 'items': self.of.name}
@@ -294,7 +280,6 @@ def ramlMaybeNoneOrList(k, v):
 
 
 class SourcedProperties(Type):
-
     name = "sourcedproperties"
 
     def validate(self, name, object):
@@ -316,14 +301,15 @@ class SourcedProperties(Type):
                 yield f"{name}[{repr(k)}] value is not JSON-able"
 
     def toRaml(self):
-        return {'type': "object",
-                'properties':
-                {'[]': {'type': 'object',
-                        'properties': {
-                            1: 'string',
-                            2: 'integer | string | object | array | boolean'
-                        }
-                        }}}
+        return {
+            'type': "object",
+            'properties': {
+                '[]': {
+                    'type': 'object',
+                    'properties': {1: 'string', 2: 'integer | string | object | array | boolean'},
+                }
+            },
+        }
 
     def toGraphQL(self):
         return "[Property]!"
@@ -357,7 +343,6 @@ class JsonObject(Type):
 
 
 class Entity(Type):
-
     # NOTE: this type is defined by subclassing it in each resource type class.
     # Instances are generally accessed at e.g.,
     #  * buildsets.Buildset.entityType or
@@ -396,32 +381,37 @@ class Entity(Type):
 
         for k in gotNames & self.fieldNames:
             f = self.fields[k]
-            for msg in f.validate(f"{name}[{repr(k)}]", object[k]):
-                yield msg
+            yield from f.validate(f"{name}[{repr(k)}]", object[k])
 
     def getSpec(self):
-        return dict(type=self.name,
-                    fields=[dict(name=k,
-                                 type=v.name,
-                                 type_spec=v.getSpec())
-                            for k, v in self.fields.items()
-                            ])
+        return {
+            "type": self.name,
+            "fields": [
+                {"name": k, "type": v.name, "type_spec": v.getSpec()}
+                for k, v in self.fields.items()
+            ],
+        }
 
     def toRaml(self):
-        return {'type': "object",
-                'properties': {
-                    ramlMaybeNoneOrList(k, v): {'type': v.ramlname, 'description': ''}
-                    for k, v in self.fields.items()}}
+        return {
+            'type': "object",
+            'properties': {
+                ramlMaybeNoneOrList(k, v): {'type': v.ramlname, 'description': ''}
+                for k, v in self.fields.items()
+            },
+        }
 
     def toGraphQL(self):
-        return dict(type=self.graphql_name,
-                    fields=[dict(name=k,
-                                 type=v.toGraphQL())
-                            for k, v in self.fields.items()
-                            # in graphql, we handle properties as queriable sub resources
-                            # instead of hardcoded attributes like in rest api
-                            if k != "properties"
-                            ])
+        return {
+            "type": self.graphql_name,
+            "fields": [
+                {"name": k, "type": v.toGraphQL()}
+                for k, v in self.fields.items()
+                # in graphql, we handle properties as queriable sub resources
+                # instead of hardcoded attributes like in rest api
+                if k != "properties"
+            ],
+        }
 
     def toGraphQLTypeName(self):
         return self.graphql_name
