@@ -47,7 +47,6 @@ class DBConnectorComponent:
     _isCheckLengthNecessary = None
 
     def checkLength(self, col, value):
-
         if not self._isCheckLengthNecessary:
             if self.db.pool.engine.dialect.name == 'mysql':
                 self._isCheckLengthNecessary = True
@@ -56,47 +55,67 @@ class DBConnectorComponent:
                 self.checkLength = lambda col, value: None
                 return
 
-        assert col.type.length, "column %s does not have a length" % (col,)
+        assert col.type.length, f"column {col} does not have a length"
         if value and len(value) > col.type.length:
             raise RuntimeError(
-                "value for column %s is greater than max of %d characters: %s"
-                % (col, col.type.length, value))
+                f"value for column {col} is greater than max of {col.type.length} "
+                f"characters: {value}"
+            )
 
     def ensureLength(self, col, value):
-        assert col.type.length, "column %s does not have a length" % (col,)
+        assert col.type.length, f"column {col} does not have a length"
         if value and len(value) > col.type.length:
-            value = value[:col.type.length // 2] + hashlib.sha1(unicode2bytes(value)).hexdigest()[:col.type.length // 2]
+            value = (
+                value[: col.type.length // 2]
+                + hashlib.sha1(unicode2bytes(value)).hexdigest()[: col.type.length // 2]
+            )
         return value
 
     # returns a Deferred that returns a value
-    def findSomethingId(self, tbl, whereclause, insert_values,
-                        _race_hook=None, autoCreate=True):
+    def findSomethingId(self, tbl, whereclause, insert_values, _race_hook=None, autoCreate=True):
+        d = self.findOrCreateSomethingId(tbl, whereclause, insert_values, _race_hook, autoCreate)
+        d.addCallback(lambda pair: pair[0])
+        return d
+
+    def findOrCreateSomethingId(
+        self, tbl, whereclause, insert_values, _race_hook=None, autoCreate=True
+    ):
+        """
+        Find a matching row and if one cannot be found optionally create it.
+        Returns a deferred which resolves to the pair (id, found) where
+        id is the primary key of the matching row and `found` is True if
+        a match was found. `found` will be false if a new row was created.
+        """
+
         def thd(conn, no_recurse=False):
             # try to find the master
-            q = sa.select([tbl.c.id],
-                          whereclause=whereclause)
+            q = sa.select(tbl.c.id)
+            if whereclause is not None:
+                q = q.where(whereclause)
             r = conn.execute(q)
             row = r.fetchone()
             r.close()
 
             # found it!
             if row:
-                return row.id
+                return row.id, True
 
             if not autoCreate:
-                return None
+                return None, False
 
-            _race_hook and _race_hook(conn)
+            if _race_hook is not None:
+                _race_hook(conn)
 
             try:
                 r = conn.execute(tbl.insert(), [insert_values])
-                return r.inserted_primary_key[0]
+                return r.inserted_primary_key[0], False
             except (sa.exc.IntegrityError, sa.exc.ProgrammingError):
                 # try it all over again, in case there was an overlapping,
                 # identical call, but only retry once.
                 if no_recurse:
                     raise
                 return thd(conn, no_recurse=True)
+
         return self.db.pool.do(thd)
 
     def hashColumns(self, *args):
@@ -119,7 +138,6 @@ class DBConnectorComponent:
 
 
 class CachedMethod:
-
     def __init__(self, cache_name, method):
         self.cache_name = cache_name
         self.method = method
@@ -128,13 +146,15 @@ class CachedMethod:
         meth = self.method
 
         meth_name = meth.__name__
-        cache = component.db.master.caches.get_cache(self.cache_name,
-                                                     lambda key: meth(component, key))
+        cache = component.db.master.caches.get_cache(
+            self.cache_name, lambda key: meth(component, key)
+        )
 
         def wrap(key, no_cache=0):
             if no_cache:
                 return meth(component, key)
             return cache.get(key)
+
         wrap.__name__ = meth_name + " (wrapped)"
         wrap.__module__ = meth.__module__
         wrap.__doc__ = meth.__doc__
