@@ -19,7 +19,6 @@ Support for buildsets in the database
 import json
 
 import sqlalchemy as sa
-
 from twisted.internet import defer
 
 from buildbot.db import NULL
@@ -37,11 +36,21 @@ class AlreadyCompleteError(RuntimeError):
 
 
 class BuildsetsConnectorComponent(base.DBConnectorComponent):
-
     @defer.inlineCallbacks
-    def addBuildset(self, sourcestamps, reason, properties, builderids,
-                    waited_for, external_idstring=None, submitted_at=None,
-                    parent_buildid=None, parent_relationship=None, priority=0):
+    def addBuildset(
+        self,
+        sourcestamps,
+        reason,
+        properties,
+        builderids,
+        waited_for,
+        external_idstring=None,
+        submitted_at=None,
+        rebuilt_buildid=None,
+        parent_buildid=None,
+        parent_relationship=None,
+        priority=0,
+    ):
         if submitted_at is not None:
             submitted_at = datetime2epoch(submitted_at)
         else:
@@ -53,31 +62,35 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
                 return defer.succeed(sourcestamp)
             ssConnector = self.master.db.sourcestamps
             return ssConnector.findSourceStampId(**sourcestamp)
+
         sourcestamps = yield defer.DeferredList(
-            [toSsid(ss) for ss in sourcestamps],
-            fireOnOneErrback=True, consumeErrors=True)
+            [toSsid(ss) for ss in sourcestamps], fireOnOneErrback=True, consumeErrors=True
+        )
         sourcestampids = [r[1] for r in sourcestamps]
 
         def thd(conn):
             buildsets_tbl = self.db.model.buildsets
 
             self.checkLength(buildsets_tbl.c.reason, reason)
-            self.checkLength(buildsets_tbl.c.external_idstring,
-                             external_idstring)
+            self.checkLength(buildsets_tbl.c.external_idstring, external_idstring)
 
             transaction = conn.begin()
 
             # insert the buildset itself
-            r = conn.execute(buildsets_tbl.insert(), {
-                "submitted_at": submitted_at,
-                "reason": reason,
-                "complete": 0,
-                "complete_at": None,
-                "results": -1,
-                "external_idstring": external_idstring,
-                "parent_buildid": parent_buildid,
-                "parent_relationship": parent_relationship
-            })
+            r = conn.execute(
+                buildsets_tbl.insert(),
+                {
+                    "submitted_at": submitted_at,
+                    "reason": reason,
+                    "rebuilt_buildid": rebuilt_buildid,
+                    "complete": 0,
+                    "complete_at": None,
+                    "results": -1,
+                    "external_idstring": external_idstring,
+                    "parent_buildid": parent_buildid,
+                    "parent_relationship": parent_relationship,
+                },
+            )
             bsid = r.inserted_primary_key[0]
 
             # add any properties
@@ -86,17 +99,18 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
 
                 inserts = [
                     {"buildsetid": bsid, "property_name": k, "property_value": json.dumps([v, s])}
-                    for k, (v, s) in properties.items()]
+                    for k, (v, s) in properties.items()
+                ]
                 for i in inserts:
-                    self.checkLength(bs_props_tbl.c.property_name,
-                                     i['property_name'])
+                    self.checkLength(bs_props_tbl.c.property_name, i['property_name'])
 
                 conn.execute(bs_props_tbl.insert(), inserts)
 
             # add sourcestamp ids
-            r = conn.execute(self.db.model.buildset_sourcestamps.insert(),
-                             [{"buildsetid": bsid, "sourcestampid": ssid}
-                              for ssid in sourcestampids])
+            r = conn.execute(
+                self.db.model.buildset_sourcestamps.insert(),
+                [{"buildsetid": bsid, "sourcestampid": ssid} for ssid in sourcestampids],
+            )
 
             # and finish with a build request for each builder.  Note that
             # sqlalchemy and the Python DBAPI do not provide a way to recover
@@ -106,19 +120,22 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
             br_tbl = self.db.model.buildrequests
             ins = br_tbl.insert()
             for builderid in builderids:
-                r = conn.execute(ins, {
-                    "buildsetid": bsid,
-                    "builderid": builderid,
-                    "priority": priority,
-                    "claimed_at": 0,
-                    "claimed_by_name": None,
-                    "claimed_by_incarnation": None,
-                    "complete": 0,
-                    "results": -1,
-                    "submitted_at": submitted_at,
-                    "complete_at": None,
-                    "waited_for": 1 if waited_for else 0
-                })
+                r = conn.execute(
+                    ins,
+                    {
+                        "buildsetid": bsid,
+                        "builderid": builderid,
+                        "priority": priority,
+                        "claimed_at": 0,
+                        "claimed_by_name": None,
+                        "claimed_by_incarnation": None,
+                        "complete": 0,
+                        "results": -1,
+                        "submitted_at": submitted_at,
+                        "complete_at": None,
+                        "waited_for": 1 if waited_for else 0,
+                    },
+                )
 
                 brids[builderid] = r.inserted_primary_key[0]
 
@@ -143,29 +160,28 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
         def thd(conn):
             tbl = self.db.model.buildsets
 
-            q = tbl.update(whereclause=(
-                (tbl.c.id == bsid) &
-                ((tbl.c.complete == NULL) | (tbl.c.complete != 1))))
-            res = conn.execute(q,
-                               complete=1,
-                               results=results,
-                               complete_at=complete_at)
+            q = tbl.update().where(
+                (tbl.c.id == bsid) & ((tbl.c.complete == NULL) | (tbl.c.complete != 1))
+            )
+            res = conn.execute(q.values(complete=1, results=results, complete_at=complete_at))
 
             if res.rowcount != 1:
                 # happens when two buildrequests finish at the same time
                 raise AlreadyCompleteError()
+
         yield self.db.pool.do(thd)
 
     # returns a Deferred that returns a value
     def getBuildset(self, bsid):
         def thd(conn):
             bs_tbl = self.db.model.buildsets
-            q = bs_tbl.select(whereclause=bs_tbl.c.id == bsid)
+            q = bs_tbl.select().where(bs_tbl.c.id == bsid)
             res = conn.execute(q)
             row = res.fetchone()
             if not row:
                 return None
             return self._thd_row2dict(conn, row)
+
         return self.db.pool.do(thd)
 
     @defer.inlineCallbacks
@@ -177,26 +193,24 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
                 if complete:
                     q = q.where(bs_tbl.c.complete != 0)
                 else:
-                    q = q.where((bs_tbl.c.complete == 0) |
-                                (bs_tbl.c.complete == NULL))
+                    q = q.where((bs_tbl.c.complete == 0) | (bs_tbl.c.complete == NULL))
             if resultSpec is not None:
                 return resultSpec.thd_execute(conn, q, lambda x: self._thd_row2dict(conn, x))
             res = conn.execute(q)
             return [self._thd_row2dict(conn, row) for row in res.fetchall()]
+
         res = yield self.db.pool.do(thd)
         return res
 
     # returns a Deferred that returns a value
-    def getRecentBuildsets(self, count=None, branch=None, repository=None,
-                           complete=None):
+    def getRecentBuildsets(self, count=None, branch=None, repository=None, complete=None):
         def thd(conn):
             bs_tbl = self.db.model.buildsets
             ss_tbl = self.db.model.sourcestamps
             j = self.db.model.buildsets
             j = j.join(self.db.model.buildset_sourcestamps)
             j = j.join(self.db.model.sourcestamps)
-            q = sa.select(columns=[bs_tbl], from_obj=[j],
-                          distinct=True)
+            q = sa.select(bs_tbl).select_from(j).distinct()
             q = q.order_by(sa.desc(bs_tbl.c.submitted_at))
             q = q.limit(count)
 
@@ -204,15 +218,14 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
                 if complete:
                     q = q.where(bs_tbl.c.complete != 0)
                 else:
-                    q = q.where((bs_tbl.c.complete == 0) |
-                                (bs_tbl.c.complete == NULL))
+                    q = q.where((bs_tbl.c.complete == 0) | (bs_tbl.c.complete == NULL))
             if branch:
                 q = q.where(ss_tbl.c.branch == branch)
             if repository:
                 q = q.where(ss_tbl.c.repository == repository)
             res = conn.execute(q)
-            return list(reversed([self._thd_row2dict(conn, row)
-                                  for row in res.fetchall()]))
+            return list(reversed([self._thd_row2dict(conn, row) for row in res.fetchall()]))
+
         return self.db.pool.do(thd)
 
     # returns a Deferred that returns a value
@@ -221,25 +234,29 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
         def thd(conn):
             bsp_tbl = self.db.model.buildset_properties
             q = sa.select(
-                [bsp_tbl.c.property_name, bsp_tbl.c.property_value],
-                whereclause=bsp_tbl.c.buildsetid == bsid)
+                bsp_tbl.c.property_name,
+                bsp_tbl.c.property_value,
+            ).where(bsp_tbl.c.buildsetid == bsid)
             ret = []
             for row in conn.execute(q):
                 try:
                     properties = json.loads(row.property_value)
-                    ret.append((row.property_name,
-                              tuple(properties)))
+                    ret.append((row.property_name, tuple(properties)))
                 except ValueError:
                     pass
             return BsProps(ret)
+
         return self.db.pool.do(thd)
 
     def _thd_row2dict(self, conn, row):
         # get sourcestamps
         tbl = self.db.model.buildset_sourcestamps
-        sourcestamps = [r.sourcestampid for r in
-                        conn.execute(sa.select([tbl.c.sourcestampid],
-                                               (tbl.c.buildsetid == row.id))).fetchall()]
+        sourcestamps = [
+            r.sourcestampid
+            for r in conn.execute(
+                sa.select(tbl.c.sourcestampid).where(tbl.c.buildsetid == row.id)
+            ).fetchall()
+        ]
 
         return {
             "external_idstring": row.external_idstring,
@@ -247,9 +264,10 @@ class BuildsetsConnectorComponent(base.DBConnectorComponent):
             "submitted_at": epoch2datetime(row.submitted_at),
             "complete": bool(row.complete),
             "complete_at": epoch2datetime(row.complete_at),
+            "rebuilt_buildid": row.rebuilt_buildid,
             "results": row.results,
             "bsid": row.id,
             "sourcestamps": sourcestamps,
             "parent_buildid": row.parent_buildid,
-            "parent_relationship": row.parent_relationship
+            "parent_relationship": row.parent_relationship,
         }
