@@ -20,7 +20,6 @@ import time
 import traceback
 
 import sqlalchemy as sa
-
 from twisted.internet import defer
 from twisted.internet import threads
 from twisted.python import log
@@ -29,6 +28,7 @@ from twisted.python import threadpool
 from buildbot.db.buildrequests import AlreadyClaimedError
 from buildbot.db.buildsets import AlreadyCompleteError
 from buildbot.db.changesources import ChangeSourceAlreadyClaimedError
+from buildbot.db.logs import LogSlugExistsError
 from buildbot.db.schedulers import SchedulerAlreadyClaimedError
 from buildbot.process import metrics
 
@@ -43,6 +43,7 @@ _debug_id = 1
 def timed_do_fn(f):
     """Decorate a do function to log before, after, and elapsed time,
     with the name of the calling function.  This is not speedy!"""
+
     def wrap(callable, *args, **kwargs):
         global _debug_id
 
@@ -75,6 +76,7 @@ def timed_do_fn(f):
                 return callable(*args, **kwargs)
             finally:
                 log.msg(f"{descr} - thd end")
+
         d = f(callable_wrap, *args, **kwargs)
 
         @d.addBoth
@@ -83,14 +85,15 @@ def timed_do_fn(f):
             elapsed = (end_time - start_time) * 1000
             log.msg(f"{descr} - after ({elapsed:0.2f} ms elapsed)")
             return x
+
         return d
+
     wrap.__name__ = f.__name__
     wrap.__doc__ = f.__doc__
     return wrap
 
 
 class DBThreadPool:
-
     running = False
 
     def __init__(self, engine, reactor, verbose=False):
@@ -98,8 +101,10 @@ class DBThreadPool:
         # messages about versions and other warnings
         log_msg = log.msg
         if verbose:
+
             def _log_msg(m):
                 print(m)
+
             log_msg = _log_msg
 
         self.reactor = reactor
@@ -113,21 +118,20 @@ class DBThreadPool:
         if hasattr(engine, 'optimal_thread_pool_size'):
             pool_size = engine.optimal_thread_pool_size
 
-        self._pool = threadpool.ThreadPool(minthreads=1,
-                                           maxthreads=pool_size,
-                                           name='DBThreadPool')
+        self._pool = threadpool.ThreadPool(minthreads=1, maxthreads=pool_size, name='DBThreadPool')
 
         self.engine = engine
         if engine.dialect.name == 'sqlite':
             vers = self.get_sqlite_version()
             if vers < (3, 7):
                 log_msg(f"Using SQLite Version {vers}")
-                log_msg("NOTE: this old version of SQLite does not support "
-                        "WAL journal mode; a busy master may encounter "
-                        "'Database is locked' errors.  Consider upgrading.")
+                log_msg(
+                    "NOTE: this old version of SQLite does not support "
+                    "WAL journal mode; a busy master may encounter "
+                    "'Database is locked' errors.  Consider upgrading."
+                )
                 if vers < (3, 6, 19):
-                    log_msg("NOTE: this old version of SQLite is not "
-                            "supported.")
+                    log_msg("NOTE: this old version of SQLite is not supported.")
                     raise RuntimeError("unsupported SQLite version")
         self._start_evt = self.reactor.callWhenRunning(self._start)
 
@@ -141,12 +145,14 @@ class DBThreadPool:
     def get_sqlalchemy_result_type(self):
         try:
             from sqlalchemy.engine import ResultProxy  # sqlalchemy 1.x - 1.3
+
             return ResultProxy
         except ImportError:
             pass
 
         try:
             from sqlalchemy.engine import Result  # sqlalchemy 1.4 and newer
+
             return Result
         except ImportError:
             pass
@@ -158,7 +164,8 @@ class DBThreadPool:
         if not self.running:
             self._pool.start()
             self._stop_evt = self.reactor.addSystemEventTrigger(
-                'during', 'shutdown', self._stop_nowait)
+                'during', 'shutdown', self._stop_nowait
+            )
             self.running = True
 
     def _stop_nowait(self):
@@ -206,20 +213,23 @@ class DBThreadPool:
             try:
                 try:
                     rv = callable(arg, *args, **kwargs)
-                    assert not isinstance(rv, self.forbidded_callable_return_type), \
-                        "do not return ResultProxy objects!"
+                    assert not isinstance(
+                        rv, self.forbidded_callable_return_type
+                    ), "do not return ResultProxy objects!"
                 except sa.exc.OperationalError as e:
                     if not self.engine.should_retry(e):
                         log.err(e, 'Got fatal OperationalError on DB')
                         raise
                     elapsed = time.time() - start
                     if elapsed > self.MAX_OPERATIONALERROR_TIME:
-                        log.err(e, f'Raising due to {self.MAX_OPERATIONALERROR_TIME} '
-                                'seconds delay on DB query retries')
+                        log.err(
+                            e,
+                            f'Raising due to {self.MAX_OPERATIONALERROR_TIME} '
+                            'seconds delay on DB query retries',
+                        )
                         raise
 
-                    metrics.MetricCountEvent.log(
-                        "DBThreadPool.retry-on-OperationalError")
+                    metrics.MetricCountEvent.log("DBThreadPool.retry-on-OperationalError")
                     # sleep (remember, we're in a thread..)
                     time.sleep(backoff)
                     backoff *= self.BACKOFF_MULT
@@ -229,9 +239,16 @@ class DBThreadPool:
                 except Exception as e:
                     # AlreadyClaimedError are normal especially in a multimaster
                     # configuration
-                    if not isinstance(e,
-                        (AlreadyClaimedError, ChangeSourceAlreadyClaimedError,
-                         SchedulerAlreadyClaimedError, AlreadyCompleteError)):
+                    if not isinstance(
+                        e,
+                        (
+                            AlreadyClaimedError,
+                            ChangeSourceAlreadyClaimedError,
+                            SchedulerAlreadyClaimedError,
+                            AlreadyCompleteError,
+                            LogSlugExistsError,
+                        ),
+                    ):
                         log.err(e, 'Got fatal Exception on DB')
                     raise
             finally:
@@ -242,16 +259,16 @@ class DBThreadPool:
 
     @defer.inlineCallbacks
     def do(self, callable, *args, **kwargs):
-        ret = yield threads.deferToThreadPool(self.reactor, self._pool,
-                                              self.__thd, False, callable,
-                                              args, kwargs)
+        ret = yield threads.deferToThreadPool(
+            self.reactor, self._pool, self.__thd, False, callable, args, kwargs
+        )
         return ret
 
     @defer.inlineCallbacks
     def do_with_engine(self, callable, *args, **kwargs):
-        ret = yield threads.deferToThreadPool(self.reactor, self._pool,
-                                              self.__thd, True, callable,
-                                              args, kwargs)
+        ret = yield threads.deferToThreadPool(
+            self.reactor, self._pool, self.__thd, True, callable, args, kwargs
+        )
         return ret
 
     def get_sqlite_version(self):
