@@ -15,7 +15,6 @@
 
 
 import sqlalchemy as sa
-from sqlalchemy.sql.expression import and_
 
 from buildbot.db import base
 from buildbot.util import identifiers
@@ -26,7 +25,6 @@ class UsDict(dict):
 
 
 class UsersConnectorComponent(base.DBConnectorComponent):
-
     # returns a Deferred that returns a value
     def findUserByAttr(self, identifier, attr_type, attr_data, _race_hook=None):
         # note that since this involves two tables, self.findSomethingId is not
@@ -40,9 +38,9 @@ class UsersConnectorComponent(base.DBConnectorComponent):
             self.checkLength(tbl_info.c.attr_data, attr_data)
 
             # try to find the user
-            q = sa.select([tbl_info.c.uid],
-                          whereclause=and_(tbl_info.c.attr_type == attr_type,
-                                           tbl_info.c.attr_data == attr_data))
+            q = sa.select(
+                tbl_info.c.uid,
+            ).where(tbl_info.c.attr_type == attr_type, tbl_info.c.attr_data == attr_data)
             rows = conn.execute(q).fetchall()
 
             if rows:
@@ -61,8 +59,9 @@ class UsersConnectorComponent(base.DBConnectorComponent):
                 uid = r.inserted_primary_key[0]
                 inserted_user = True
 
-                conn.execute(tbl_info.insert(),
-                             {"uid": uid, "attr_type": attr_type, "attr_data": attr_data})
+                conn.execute(
+                    tbl_info.insert(), {"uid": uid, "attr_type": attr_type, "attr_data": attr_data}
+                )
 
                 transaction.commit()
             except (sa.exc.IntegrityError, sa.exc.ProgrammingError):
@@ -77,14 +76,14 @@ class UsersConnectorComponent(base.DBConnectorComponent):
                 # if we failed to insert the user, then it's because the
                 # identifier wasn't unique
                 if not inserted_user:
-                    identifier = identifiers.incrementIdentifier(
-                        256, identifier)
+                    identifier = identifiers.incrementIdentifier(256, identifier)
                 else:
                     no_recurse = True
 
                 return thd(conn, no_recurse=no_recurse, identifier=identifier)
 
             return uid
+
         return self.db.pool.do(thd)
 
     # returns a Deferred that returns a value
@@ -94,17 +93,18 @@ class UsersConnectorComponent(base.DBConnectorComponent):
             tbl = self.db.model.users
             tbl_info = self.db.model.users_info
 
-            q = tbl.select(whereclause=tbl.c.uid == uid)
+            q = tbl.select().where(tbl.c.uid == uid)
             users_row = conn.execute(q).fetchone()
 
             if not users_row:
                 return None
 
             # gather all attr_type and attr_data entries from users_info table
-            q = tbl_info.select(whereclause=tbl_info.c.uid == uid)
+            q = tbl_info.select().where(tbl_info.c.uid == uid)
             rows = conn.execute(q).fetchall()
 
             return self.thd_createUsDict(users_row, rows)
+
         return self.db.pool.do(thd)
 
     def thd_createUsDict(self, users_row, rows):
@@ -128,17 +128,18 @@ class UsersConnectorComponent(base.DBConnectorComponent):
             tbl = self.db.model.users
             tbl_info = self.db.model.users_info
 
-            q = tbl.select(whereclause=tbl.c.bb_username == username)
+            q = tbl.select().where(tbl.c.bb_username == username)
             users_row = conn.execute(q).fetchone()
 
             if not users_row:
                 return None
 
             # gather all attr_type and attr_data entries from users_info table
-            q = tbl_info.select(whereclause=tbl_info.c.uid == users_row.uid)
+            q = tbl_info.select().where(tbl_info.c.uid == users_row.uid)
             rows = conn.execute(q).fetchall()
 
             return self.thd_createUsDict(users_row, rows)
+
         return self.db.pool.do(thd)
 
     # returns a Deferred that returns a value
@@ -153,12 +154,20 @@ class UsersConnectorComponent(base.DBConnectorComponent):
                     ud = {"uid": row.uid, "identifier": row.identifier}
                     dicts.append(ud)
             return dicts
+
         return self.db.pool.do(thd)
 
     # returns a Deferred that returns None
-    def updateUser(self, uid=None, identifier=None, bb_username=None,
-                   bb_password=None, attr_type=None, attr_data=None,
-                   _race_hook=None):
+    def updateUser(
+        self,
+        uid=None,
+        identifier=None,
+        bb_username=None,
+        bb_password=None,
+        attr_type=None,
+        attr_data=None,
+        _race_hook=None,
+    ):
         def thd(conn):
             transaction = conn.begin()
             tbl = self.db.model.users
@@ -180,7 +189,7 @@ class UsersConnectorComponent(base.DBConnectorComponent):
 
             # update the users table if it needs to be updated
             if update_dict:
-                q = tbl.update(whereclause=tbl.c.uid == uid)
+                q = tbl.update().where(tbl.c.uid == uid)
                 res = conn.execute(q, update_dict)
 
             # then, update the attributes, carefully handling the potential
@@ -192,10 +201,11 @@ class UsersConnectorComponent(base.DBConnectorComponent):
                 self.checkLength(tbl_info.c.attr_data, attr_data)
 
                 # first update, then insert
-                q = tbl_info.update(
-                    whereclause=(tbl_info.c.uid == uid)
-                    & (tbl_info.c.attr_type == attr_type))
-                res = conn.execute(q, attr_data=attr_data)
+                q = tbl_info.update().where(
+                    tbl_info.c.uid == uid,
+                    tbl_info.c.attr_type == attr_type,
+                )
+                res = conn.execute(q.values(attr_data=attr_data))
                 if res.rowcount == 0:
                     if _race_hook is not None:
                         _race_hook(conn)
@@ -203,10 +213,9 @@ class UsersConnectorComponent(base.DBConnectorComponent):
                     # the update hit 0 rows, so try inserting a new one
                     try:
                         q = tbl_info.insert()
-                        res = conn.execute(q,
-                                           uid=uid,
-                                           attr_type=attr_type,
-                                           attr_data=attr_data)
+                        res = conn.execute(
+                            q.values(uid=uid, attr_type=attr_type, attr_data=attr_data)
+                        )
                     except (sa.exc.IntegrityError, sa.exc.ProgrammingError):
                         # someone else beat us to the punch inserting this row;
                         # let them win.
@@ -214,6 +223,7 @@ class UsersConnectorComponent(base.DBConnectorComponent):
                         return
 
             transaction.commit()
+
         return self.db.pool.do(thd)
 
     # returns a Deferred that returns None
@@ -221,11 +231,12 @@ class UsersConnectorComponent(base.DBConnectorComponent):
         def thd(conn):
             # delete from dependent tables first, followed by 'users'
             for tbl in [
-                    self.db.model.change_users,
-                    self.db.model.users_info,
-                    self.db.model.users,
+                self.db.model.change_users,
+                self.db.model.users_info,
+                self.db.model.users,
             ]:
-                conn.execute(tbl.delete(whereclause=tbl.c.uid == uid))
+                conn.execute(tbl.delete().where(tbl.c.uid == uid))
+
         return self.db.pool.do(thd)
 
     # returns a Deferred that returns a value
@@ -233,10 +244,11 @@ class UsersConnectorComponent(base.DBConnectorComponent):
         def thd(conn):
             tbl = self.db.model.users
 
-            q = tbl.select(whereclause=tbl.c.identifier == identifier)
+            q = tbl.select().where(tbl.c.identifier == identifier)
             row = conn.execute(q).fetchone()
             if not row:
                 return None
 
             return row.uid
+
         return self.db.pool.do(thd)
