@@ -29,7 +29,6 @@ else:
 
 
 class BaseLock:
-
     """
     Class handling claiming and releasing of L{self}, and keeping track of
     current and waiting owners.
@@ -38,6 +37,7 @@ class BaseLock:
     in the queue behind exclusive waiters cannot acquire the lock. This ensures
     that exclusive waiters are not starved.
     """
+
     description = "<BaseLock>"
 
     def __init__(self, name, maxCount=1):
@@ -45,9 +45,9 @@ class BaseLock:
 
         # Name of the lock
         self.lockName = name
-        # Current queue, tuples (waiter, LockAccess, deferred)
+        # Current queue, tuples (waiter_id, LockAccess, deferred)
         self.waiting = []
-        # Current owners, tuples (owner, LockAccess)
+        # Current owners, tuples (owner_id, LockAccess)
         self.owners = []
         # maximal number of counting owners
         self.maxCount = maxCount
@@ -77,12 +77,12 @@ class BaseLock:
 
     def _find_waiting(self, requester):
         for idx, waiter in enumerate(self.waiting):
-            if waiter[0] is requester:
+            if waiter[0] == id(requester):
                 return idx
         return None
 
     def isAvailable(self, requester, access):
-        """ Return a boolean whether the lock is available for claiming """
+        """Return a boolean whether the lock is available for claiming"""
         debuglog(f"{self} isAvailable({requester}, {access}): self.owners={repr(self.owners)}")
         num_excl = self._claimed_excl
         num_counting = self._claimed_counting
@@ -98,26 +98,29 @@ class BaseLock:
 
         if access.mode == 'counting':
             # Wants counting access
-            return not num_excl \
-                and num_counting + len(ahead) + access.count <= self.maxCount \
+            return (
+                not num_excl
+                and num_counting + len(ahead) + access.count <= self.maxCount
                 and all(w[1].mode == 'counting' for w in ahead)
+            )
         # else Wants exclusive access
         return not num_excl and not num_counting and not ahead
 
     def _addOwner(self, owner, access):
-        self.owners.append((owner, access))
+        self.owners.append((id(owner), access))
         if access.mode == 'counting':
             self._claimed_counting += access.count
         else:
             self._claimed_excl += 1
 
-        assert (self._claimed_excl and not self._claimed_counting) \
-            or (not self._claimed_excl and self._claimed_excl <= self.maxCount)
+        assert (self._claimed_excl and not self._claimed_counting) or (
+            not self._claimed_excl and self._claimed_excl <= self.maxCount
+        )
 
     def _removeOwner(self, owner, access):
         # returns True if owner removed, False if the lock has been already
         # released
-        entry = (owner, access)
+        entry = (id(owner), access)
         if entry not in self.owners:
             return False
 
@@ -129,7 +132,7 @@ class BaseLock:
         return True
 
     def claim(self, owner, access):
-        """ Claim the lock (lock must be available) """
+        """Claim the lock (lock must be available)"""
         debuglog(f"{self} claim({owner}, {access.mode})")
         assert owner is not None
         assert self.isAvailable(owner, access), "ask for isAvailable() first"
@@ -144,7 +147,7 @@ class BaseLock:
         if not access.count:
             return
 
-        self.waiting = [w for w in self.waiting if w[0] is not owner]
+        self.waiting = [w for w in self.waiting if w[0] != id(owner)]
         self._addOwner(owner, access)
 
         debuglog(f" {self} is claimed '{access.mode}', {access.count} units")
@@ -155,7 +158,7 @@ class BaseLock:
         return self.release_subs.subscribe(callback)
 
     def release(self, owner, access):
-        """ Release the lock """
+        """Release the lock"""
         assert isinstance(access, LockAccess)
 
         if not access.count:
@@ -176,7 +179,7 @@ class BaseLock:
         # Break out of the loop when the first waiting client should not be
         # awakened.
         num_excl, num_counting = self._claimed_excl, self._claimed_counting
-        for i, (w_owner, w_access, d) in enumerate(self.waiting):
+        for i, (w_owner_id, w_access, d) in enumerate(self.waiting):
             if w_access.mode == 'counting':
                 if num_excl > 0 or num_counting >= self.maxCount:
                     break
@@ -190,7 +193,7 @@ class BaseLock:
             # If the waiter has a deferred, wake it up and clear the deferred
             # from the wait queue entry to indicate that it has been woken.
             if d:
-                self.waiting[i] = (w_owner, w_access, None)
+                self.waiting[i] = (w_owner_id, w_access, None)
                 eventually(d.callback, self)
 
     def waitUntilMaybeAvailable(self, owner, access):
@@ -216,17 +219,19 @@ class BaseLock:
         w_index = self._find_waiting(owner)
         if w_index is not None:
             _, _, old_d = self.waiting[w_index]
-            assert old_d is None, "waitUntilMaybeAvailable() must not be called again before the " \
-                                  "previous deferred fired"
-            self.waiting[w_index] = (owner, access, d)
+            assert old_d is None, (
+                "waitUntilMaybeAvailable() must not be called again before the "
+                "previous deferred fired"
+            )
+            self.waiting[w_index] = (id(owner), access, d)
         else:
-            self.waiting.append((owner, access, d))
+            self.waiting.append((id(owner), access, d))
         return d
 
     def stopWaitingUntilAvailable(self, owner, access, d):
-        """ Stop waiting for lock to become available. `d` must be the result of a previous call
-            to `waitUntilMaybeAvailable()`. If `d` has not been woken up already by calling its
-            callback, it will be done as part of this function
+        """Stop waiting for lock to become available. `d` must be the result of a previous call
+        to `waitUntilMaybeAvailable()`. If `d` has not been woken up already by calling its
+        callback, it will be done as part of this function
         """
         debuglog(f"{self} stopWaitingUntilAvailable({owner})")
         assert isinstance(access, LockAccess)
@@ -246,11 +251,10 @@ class BaseLock:
             self._tryWakeUp()
 
     def isOwner(self, owner, access):
-        return (owner, access) in self.owners
+        return (id(owner), access) in self.owners
 
 
 class RealMasterLock(BaseLock, service.SharedService):
-
     def __init__(self, name):
         # the caller will want to call updateFromLockId after initialization
         super().__init__(name, 0)
@@ -273,7 +277,6 @@ class RealMasterLock(BaseLock, service.SharedService):
 
 
 class RealWorkerLock(service.SharedService):
-
     def __init__(self, name):
         super().__init__()
 
@@ -290,20 +293,21 @@ class RealWorkerLock(service.SharedService):
 
     def getLockForWorker(self, workername):
         if workername not in self.locks:
-            maxCount = self.maxCountForWorker.get(workername,
-                                                  self.maxCount)
+            maxCount = self.maxCountForWorker.get(workername, self.maxCount)
             lock = self.locks[workername] = BaseLock(self.lockName, maxCount)
             self._updateDescriptionForLock(lock, workername)
             self.locks[workername] = lock
         return self.locks[workername]
 
     def _updateDescription(self):
-        self.description = \
+        self.description = (
             f"<WorkerLock({self.lockName}, {self.maxCount}, {self.maxCountForWorker})>"
+        )
 
     def _updateDescriptionForLock(self, lock, workername):
-        lock.description = \
+        lock.description = (
             f"<WorkerLock({lock.lockName}, {lock.maxCount})[{workername}] {id(lock)}>"
+        )
 
     def updateFromLockId(self, lockid, config_version):
         assert self.lockName == lockid.name
@@ -323,8 +327,7 @@ class RealWorkerLock(service.SharedService):
 
 
 class LockAccess(util.ComparableMixin):
-
-    """ I am an object representing a way to access a lock.
+    """I am an object representing a way to access a lock.
 
     @param lockid: LockId instance that should be accessed.
     @type  lockid: A MasterLock or WorkerLock instance.
@@ -354,8 +357,7 @@ class LockAccess(util.ComparableMixin):
 
 
 class BaseLockId(util.ComparableMixin):
-
-    """ Abstract base class for LockId classes.
+    """Abstract base class for LockId classes.
 
     Sets up the 'access()' function for the LockId's available to the user
     (MasterLock and WorkerLock classes).
@@ -367,15 +369,15 @@ class BaseLockId(util.ComparableMixin):
     """
 
     def access(self, mode, count=1):
-        """ Express how the lock should be accessed """
+        """Express how the lock should be accessed"""
         assert mode in ['counting', 'exclusive']
         assert isinstance(count, int)
         assert count >= 0
         return LockAccess(self, mode, count)
 
     def defaultAccess(self):
-        """ For buildbot 0.7.7 compatibility: When user doesn't specify an access
-            mode, this one is chosen.
+        """For buildbot 0.7.7 compatibility: When user doesn't specify an access
+        mode, this one is chosen.
         """
         return self.access('counting')
 
@@ -384,7 +386,6 @@ class BaseLockId(util.ComparableMixin):
 # classes. They are identifiers that will be turned into real Locks later,
 # via the BotMaster.getLockByID method.
 class MasterLock(BaseLockId):
-
     """I am a semaphore that limits the number of simultaneous actions.
 
     Builds and BuildSteps can declare that they wish to claim me as they run.
@@ -406,7 +407,6 @@ class MasterLock(BaseLockId):
 
 
 class WorkerLock(BaseLockId):
-
     """I am a semaphore that limits simultaneous actions on each worker.
 
     Builds and BuildSteps can declare that they wish to claim me as they run.
@@ -437,5 +437,4 @@ class WorkerLock(BaseLockId):
         self.maxCountForWorker = maxCountForWorker
         # for comparison purposes, turn this dictionary into a stably-sorted
         # list of tuples
-        self._maxCountForWorkerList = tuple(
-            sorted(self.maxCountForWorker.items()))
+        self._maxCountForWorkerList = tuple(sorted(self.maxCountForWorker.items()))
