@@ -26,12 +26,14 @@ from twisted.python import failure
 from twisted.python import log
 
 import buildbot
-import buildbot.pbmanager
 from buildbot import config
 from buildbot import monkeypatches
 from buildbot.buildbot_net_usage_data import sendBuildbotNetUsageData
 from buildbot.changes.manager import ChangeManager
+from buildbot.config.master import FileLoader
+from buildbot.config.master import MasterConfig
 from buildbot.data import connector as dataconnector
+from buildbot.data import graphql
 from buildbot.db import connector as dbconnector
 from buildbot.db import exceptions
 from buildbot.machine.manager import MachineManager
@@ -48,18 +50,18 @@ from buildbot.util import service
 from buildbot.util.eventual import eventually
 from buildbot.wamp import connector as wampconnector
 from buildbot.worker import manager as workermanager
+from buildbot.worker.protocols.manager.msgpack import MsgManager
+from buildbot.worker.protocols.manager.pb import PBManager
 from buildbot.www import service as wwwservice
 
 
 class LogRotation:
-
     def __init__(self):
         self.rotateLength = 1 * 1000 * 1000
         self.maxRotatedFiles = 10
 
 
 class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
-
     # multiplier on RECLAIM_BUILD_INTERVAL at which a build is considered
     # unclaimed; this should be at least 2 to avoid false positives
     UNCLAIMED_BUILD_FACTOR = 6
@@ -86,7 +88,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         if config_loader is None:
             if configFileName is None:
                 configFileName = 'master.cfg'
-            config_loader = config.FileLoader(self.basedir, configFileName)
+            config_loader = FileLoader(self.basedir, configFileName)
         self.config_loader = config_loader
         self.configFileName = configFileName
 
@@ -101,7 +103,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.configured_db_url = None
 
         # configuration / reconfiguration handling
-        self.config = config.MasterConfig()
+        self.config = MasterConfig()
         self.config_version = 0  # increased by one on each reconfig
         self.reconfig_active = False
         self.reconfig_requested = False
@@ -114,6 +116,8 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         # local cache for this master's object ID
         self._object_id = None
 
+        self._got_sigterm = False
+
         # Check environment is sensible
         check_functional_environment(self.config)
 
@@ -124,7 +128,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             self.hostname = socket.getfqdn()
 
         # public attributes
-        self.name = ("{}:{}".format(self.hostname, os.path.abspath(self.basedir or '.')))
+        self.name = f"{self.hostname}:{os.path.abspath(self.basedir or '.')}"
         if isinstance(self.name, bytes):
             self.name = self.name.decode('ascii', 'replace')
         self.masterid = None
@@ -140,9 +144,12 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.caches = cache.CacheManager()
         yield self.caches.setServiceParent(self)
 
-        self.pbmanager = buildbot.pbmanager.PBManager()
+        self.pbmanager = PBManager()
         yield self.pbmanager.setServiceParent(self)
 
+        self.msgmanager = MsgManager()
+        yield self.msgmanager.setServiceParent(self)
+
         self.workers = workermanager.WorkerManager(self)
         yield self.workers.setServiceParent(self)
 
@@ -173,6 +180,9 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.data = dataconnector.DataConnector()
         yield self.data.setServiceParent(self)
 
+        self.graphql = graphql.GraphQLConnector()
+        yield self.graphql.setServiceParent(self)
+
         self.www = wwwservice.WWWService()
         yield self.www.setServiceParent(self)
 
@@ -192,9 +202,9 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         @defer.inlineCallbacks
         def heartbeat():
             if self.masterid is not None:
-                yield self.data.updates.masterActive(name=self.name,
-                                                     masterid=self.masterid)
+                yield self.data.updates.masterActive(name=self.name, masterid=self.masterid)
             yield self.data.updates.expireMasters()
+
         self.masterHeartbeatService = internet.TimerService(60, heartbeat)
         self.masterHeartbeatService.clock = self.reactor
         # we do setServiceParent only when the master is configured
@@ -215,7 +225,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             yield self._services_d
             self._services_d = None
 
-        log.msg("Starting BuildMaster -- buildbot.version: {}".format(buildbot.version))
+        log.msg(f"Starting BuildMaster -- buildbot.version: {buildbot.version}")
 
         # Set umask
         if self.umask is not None:
@@ -238,8 +248,8 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
                 # run the master.cfg in thread, so that it can use blocking
                 # code
                 self.config = yield threads.deferToThreadPool(
-                    self.reactor, self.reactor.getThreadPool(),
-                    self.config_loader.loadConfig)
+                    self.reactor, self.reactor.getThreadPool(), self.config_loader.loadConfig
+                )
 
             except config.ConfigErrors as e:
                 log.msg("Configuration Errors:")
@@ -266,26 +276,28 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
 
             # the buildbot scripts send the SIGHUP signal to reconfig master
             if hasattr(signal, "SIGHUP"):
+
                 def sighup(*args):
                     eventually(self.reconfig)
+
                 signal.signal(signal.SIGHUP, sighup)
 
             # the buildbot scripts send the SIGUSR1 signal to stop master
             if hasattr(signal, "SIGUSR1"):
+
                 def sigusr1(*args):
                     eventually(self.botmaster.cleanShutdown)
+
                 signal.signal(signal.SIGUSR1, sigusr1)
 
             # get the masterid so other services can use it in
             # startup/reconfig.  This goes directly to the DB since the data
             # API isn't initialized yet, and anyway, this method is aware of
             # the DB API since it just called its setup function
-            self.masterid = yield self.db.masters.findMasterId(
-                name=self.name)
+            self.masterid = yield self.db.masters.findMasterId(name=self.name)
 
             # mark this master as stopped, in case it crashed before
-            yield self.data.updates.masterStopped(name=self.name,
-                                                  masterid=self.masterid)
+            yield self.data.updates.masterStopped(name=self.name, masterid=self.masterid)
 
             # call the parent method
             yield super().startService()
@@ -300,8 +312,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             yield self.reconfigServiceWithBuildbotConfig(self.config)
 
             # Mark the master as active now that mq is running
-            yield self.data.updates.masterActive(name=self.name,
-                                                 masterid=self.masterid)
+            yield self.data.updates.masterActive(name=self.name, masterid=self.masterid)
 
             # Start the heartbeat timer
             yield self.masterHeartbeatService.setServiceParent(self)
@@ -315,6 +326,17 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             self.reactor.stop()
 
         finally:
+
+            @defer.inlineCallbacks
+            def call_after_signal(sig_num, stack):
+                if not self._got_sigterm:
+                    self._got_sigterm = True
+                    yield self.disownServiceParent()
+                    self.reactor.stop()
+                else:
+                    log.msg('Ignoring SIGTERM, master is already shutting down.')
+
+            signal.signal(signal.SIGTERM, call_after_signal)
             if startup_succeed:
                 log.msg("BuildMaster is running")
             else:
@@ -325,8 +347,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
 
     def sendBuildbotNetUsageData(self):
         if "TRIAL_PYTHONPATH" in os.environ and self.config.buildbotNetUsageData is not None:
-            raise RuntimeError(
-                "Should not enable buildbotNetUsageData in trial tests!")
+            raise RuntimeError("Should not enable buildbotNetUsageData in trial tests!")
         sendBuildbotNetUsageData(self)
 
     @defer.inlineCallbacks
@@ -342,8 +363,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             # complete, so this may make state inconsistent if done while the builds are still
             # running.
             if self.masterid is not None:
-                yield self.data.updates.masterStopped(
-                    name=self.name, masterid=self.masterid)
+                yield self.data.updates.masterStopped(name=self.name, masterid=self.masterid)
 
             if self.running:
                 yield super().stopService()
@@ -368,8 +388,10 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         # notify every 10 seconds that the reconfig is still going on, the duration of reconfigs is
         # longer on larger installations and may take a while.
         self.reconfig_notifier = task.LoopingCall(
-            lambda: log.msg("reconfig is ongoing for {:.3f} s".format(self.reactor.seconds() -
-                                                                      self.reconfig_active)))
+            lambda: log.msg(
+                "reconfig is ongoing for " f"{self.reactor.seconds() - self.reconfig_active:.3f} s"
+            )
+        )
         self.reconfig_notifier.start(10, now=False)
 
         timer = metrics.Timer("BuildMaster.reconfig")
@@ -398,8 +420,8 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             yield self.initLock.acquire()
             # Run the master.cfg in thread, so that it can use blocking code
             new_config = yield threads.deferToThreadPool(
-                self.reactor, self.reactor.getThreadPool(),
-                self.config_loader.loadConfig)
+                self.reactor, self.reactor.getThreadPool(), self.config_loader.loadConfig
+            )
             changes_made = True
             self.config_version += 1
             self.config = new_config
@@ -426,12 +448,12 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         else:
             msg = "configuration update complete"
 
-        log.msg("{} (took {:.3f} seconds)".format(msg, self.reactor.seconds() - time_started))
+        log.msg(f"{msg} (took {(self.reactor.seconds() - time_started):.3f} seconds)")
 
     def reconfigServiceWithBuildbotConfig(self, new_config):
         if self.configured_db_url is None:
             self.configured_db_url = new_config.db['db_url']
-        elif (self.configured_db_url != new_config.db['db_url']):
+        elif self.configured_db_url != new_config.db['db_url']:
             config.error(
                 "Cannot change c['db']['db_url'] after the master has started",
             )
@@ -462,13 +484,13 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         # failing that, get it from the DB; multiple calls to this function
         # at the same time will not hurt
 
-        d = self.db.state.getObjectId(self.name,
-                                      "buildbot.master.BuildMaster")
+        d = self.db.state.getObjectId(self.name, "buildbot.master.BuildMaster")
 
         @d.addCallback
         def keep(id):
             self._object_id = id
             return id
+
         return d
 
     def _getState(self, name, default=None):
@@ -478,6 +500,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         @d.addCallback
         def get(objectid):
             return self.db.state.getState(objectid, name, default)
+
         return d
 
     def _setState(self, name, value):
@@ -487,4 +510,5 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         @d.addCallback
         def set(objectid):
             return self.db.state.setState(objectid, name, value)
+
         return d
