@@ -17,26 +17,40 @@
 
 import traceback
 import warnings
-from pkg_resources import iter_entry_points
+from importlib.metadata import distributions
+from importlib.metadata import entry_points
 
 from zope.interface import Invalid
 from zope.interface.verify import verifyClass
 
 from buildbot.errors import PluginDBError
 from buildbot.interfaces import IPlugin
+from buildbot.util.importlib_compat import entry_points_get
 
 # Base namespace for Buildbot specific plugins
 _NAMESPACE_BASE = 'buildbot'
 
 
-class _PluginEntry:
+def find_distribution_info(entry_point_name, entry_point_group):
+    for distribution in distributions():
+        # each distribution can have many entry points
+        try:
+            for ep in entry_points_get(distribution.entry_points, entry_point_group):
+                if ep.name == entry_point_name:
+                    return (distribution.metadata['Name'], distribution.metadata['Version'])
+        except KeyError as exc:
+            raise PluginDBError("Plugin info was found, but it is invalid.") from exc
+    raise PluginDBError("Plugin info not found.")
 
+
+class _PluginEntry:
     def __init__(self, group, entry, loader):
         self._group = group
         self._entry = entry
         self._value = None
         self._loader = loader
         self._load_warnings = []
+        self._info = None
 
     def load(self):
         if self._value is None:
@@ -55,11 +69,15 @@ class _PluginEntry:
 
     @property
     def info(self):
-        dist = self._entry.dist
-        return (dist.project_name, dist.version)
+        if self._info is None:
+            self._info = find_distribution_info(self._entry.name, self._group)
+        return self._info
+
+    def __eq__(self, other):
+        return self.info == other.info
 
     def __ne__(self, other):
-        return self.info != other.info
+        return not self.__eq__(other)
 
     @property
     def value(self):
@@ -70,7 +88,6 @@ class _PluginEntry:
 
 
 class _PluginEntryProxy(_PluginEntry):
-
     """Proxy for specific entry with custom group name.
 
     Used to provided access to the same entry from different namespaces.
@@ -128,7 +145,8 @@ class _NSNode:
                     raise PluginDBError(
                         f'Duplicate entry point for "{child.group}:{child.name}".\n'
                         f'  Previous definition {child.info}\n'
-                        f'  This definition {entry.info}')
+                        f'  This definition {entry.info}'
+                    )
             else:
                 self._children[key] = entry
         else:
@@ -179,8 +197,7 @@ class _NSNode:
                 result.append((key, child.info))
             else:
                 result.extend([
-                    (f'{key}.{name}', value)
-                    for name, value in child.info_all().items()
+                    (f'{key}.{name}', value) for name, value in child.info_all().items()
                 ])
         return result
 
@@ -189,30 +206,21 @@ class _NSNode:
 
 
 class _Plugins:
-
     """
     represent plugins within a namespace
     """
 
-    def __init__(self, namespace, interface=None, check_extras=True):
+    def __init__(self, namespace, interface=None):
         if interface is not None:
             assert interface.isOrExtends(IPlugin)
 
         self._group = f'{_NAMESPACE_BASE}.{namespace}'
 
         self._interface = interface
-        self._check_extras = check_extras
-
         self._real_tree = None
 
     def _load_entry(self, entry):
         # pylint: disable=W0703
-        if self._check_extras:
-            try:
-                entry.require()
-            except Exception as e:
-                raise PluginDBError('Requirements are not satisfied '
-                                    f'for {self._group}:{entry.name}: {str(e)}') from e
         try:
             result = entry.load()
         except Exception as e:
@@ -225,17 +233,17 @@ class _Plugins:
             except Invalid as e:
                 raise PluginDBError(
                     f'Plugin {self._group}:{entry.name} does not implement '
-                    f'{self._interface.__name__}: {str(e)}') from e
+                    f'{self._interface.__name__}: {str(e)}'
+                ) from e
         return result
 
     @property
     def _tree(self):
         if self._real_tree is None:
             self._real_tree = _NSNode()
-            for entry in iter_entry_points(self._group):
-                self._real_tree.add(entry.name,
-                                    _PluginEntry(self._group, entry,
-                                                 self._load_entry))
+            entries = entry_points_get(entry_points(), self._group)
+            for entry in entries:
+                self._real_tree.add(entry.name, _PluginEntry(self._group, entry, self._load_entry))
         return self._real_tree
 
     def load(self):
@@ -281,7 +289,6 @@ class _Plugins:
 
 
 class _PluginDB:
-
     """
     Plugin infrastructure support for Buildbot
     """
@@ -289,8 +296,7 @@ class _PluginDB:
     def __init__(self):
         self._namespaces = {}
 
-    def add_namespace(self, namespace, interface=None, check_extras=True,
-                      load_now=False):
+    def add_namespace(self, namespace, interface=None, load_now=False):
         """
         register given namespace in global database of plugins
 
@@ -299,7 +305,7 @@ class _PluginDB:
         tempo = self._namespaces.get(namespace)
 
         if tempo is None:
-            tempo = _Plugins(namespace, interface, check_extras)
+            tempo = _Plugins(namespace, interface)
             self._namespaces[namespace] = tempo
 
         if load_now:
@@ -349,8 +355,8 @@ def info():
     return _DB.info()
 
 
-def get_plugins(namespace, interface=None, check_extras=True, load_now=False):
+def get_plugins(namespace, interface=None, load_now=False):
     """
     helper to get a direct interface to _Plugins
     """
-    return _DB.add_namespace(namespace, interface, check_extras, load_now)
+    return _DB.add_namespace(namespace, interface, load_now)
