@@ -81,12 +81,10 @@ class BuildChooserBase:
         # the self.unclaimedBrdicts to None before calling."""
         if self.unclaimedBrdicts is None:
             # TODO: use order of the DATA API
-            brdicts = yield self.master.data.get(('builders',
-                                                  (yield self.bldr.getBuilderId()),
-                                                  'buildrequests'),
-                                                 [resultspec.Filter('claimed',
-                                                                    'eq',
-                                                                    [False])])
+            brdicts = yield self.master.data.get(
+                ('builders', (yield self.bldr.getBuilderId()), 'buildrequests'),
+                [resultspec.Filter('claimed', 'eq', [False])],
+            )
             # sort by buildrequestid, so the first is the oldest
             brdicts.sort(key=lambda brd: brd['buildrequestid'])
             self.unclaimedBrdicts = brdicts
@@ -134,8 +132,8 @@ class BuildChooserBase:
     def _getUnclaimedBuildRequests(self):
         # Retrieve the list of BuildRequest objects for all unclaimed builds
         return defer.gatherResults([
-            self._getBuildRequestForBrdict(brdict)
-            for brdict in self.unclaimedBrdicts])
+            self._getBuildRequestForBrdict(brdict) for brdict in self.unclaimedBrdicts
+        ])
 
 
 class BasicBuildChooser(BuildChooserBase):
@@ -159,8 +157,9 @@ class BasicBuildChooser(BuildChooserBase):
 
         self.nextWorker = self.bldr.config.nextWorker
         if not self.nextWorker:
-            self.nextWorker = lambda _, workers, __: random.choice(
-                workers) if workers else None
+            self.nextWorker = self.master.config.select_next_worker
+        if not self.nextWorker:
+            self.nextWorker = lambda _, workers, __: random.choice(workers) if workers else None
 
         self.workerpool = self.bldr.getAvailableWorkers()
 
@@ -226,13 +225,13 @@ class BasicBuildChooser(BuildChooserBase):
                 if nextBreq not in breqs:
                     nextBreq = None
             except Exception:
-                log.err(Failure(),
-                        f"from _getNextUnclaimedBuildRequest for builder '{self.bldr}'")
+                log.err(Failure(), f"from _getNextUnclaimedBuildRequest for builder '{self.bldr}'")
                 nextBreq = None
         else:
             # otherwise just return the build with highest priority
-            brdict = sorted(self.unclaimedBrdicts.data,
-                            key=lambda b: b['priority'], reverse=True)[0]
+            brdict = sorted(self.unclaimedBrdicts.data, key=lambda b: b['priority'], reverse=True)[
+                0
+            ]
             nextBreq = yield self._getBuildRequestForBrdict(brdict)
 
         return nextBreq
@@ -248,8 +247,7 @@ class BasicBuildChooser(BuildChooserBase):
             try:
                 worker = yield self.nextWorker(self.bldr, self.workerpool, buildrequest)
             except Exception:
-                log.err(Failure(),
-                        f"from nextWorker for builder '{self.bldr}'")
+                log.err(Failure(), f"from nextWorker for builder '{self.bldr}'")
                 worker = None
 
             if not worker or worker not in self.workerpool:
@@ -270,7 +268,6 @@ class BasicBuildChooser(BuildChooserBase):
 
 
 class BuildRequestDistributor(service.AsyncMultiService):
-
     """
     Special-purpose class to handle distributing build requests to builders by
     calling their C{maybeStartBuild} method.
@@ -350,9 +347,9 @@ class BuildRequestDistributor(service.AsyncMultiService):
                 existing_pending = set(self._pending_builders)
 
                 # then sort the new, expanded set of builders
-                self._pending_builders = \
-                    yield self._sortBuilders(
-                        list(existing_pending | new_builders))
+                self._pending_builders = yield self._sortBuilders(
+                    list(existing_pending | new_builders)
+                )
 
                 # start the activity loop, if we aren't already
                 # working on that.
@@ -361,8 +358,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
             except Exception:  # pragma: no cover
                 log.err(Failure(), f"while attempting to start builds on {self.name}")
 
-        yield self.pending_builders_lock.run(
-            resetPendingBuildersList, new_builders)
+        yield self.pending_builders_lock.run(resetPendingBuildersList, new_builders)
         return None
 
     @defer.inlineCallbacks
@@ -400,9 +396,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
 
         # convert builder names to builders
         builders_dict = self.botmaster.builders
-        builders = [builders_dict.get(n)
-                    for n in buildernames
-                    if n in builders_dict]
+        builders = [builders_dict.get(n) for n in buildernames if n in builders_dict]
 
         # find a sorting function
         sorter = self.master.config.prioritizeBuilders
@@ -479,8 +473,11 @@ class BuildRequestDistributor(service.AsyncMultiService):
             brids = [br.id for br in breqs]
             claimed_at_epoch = self.master.reactor.seconds()
             claimed_at = epoch2datetime(claimed_at_epoch)
-            if not (yield self.master.data.updates.claimBuildRequests(
-                    brids, claimed_at=claimed_at)):
+
+            self._add_in_progress_brids(brids)
+            if not (
+                yield self.master.data.updates.claimBuildRequests(brids, claimed_at=claimed_at)
+            ):
                 # some brids were already claimed, so start over
                 bc = self.createBuildChooser(bldr, self.master)
                 continue
@@ -488,10 +485,20 @@ class BuildRequestDistributor(service.AsyncMultiService):
             buildStarted = yield bldr.maybeStartBuild(worker, breqs)
             if not buildStarted:
                 yield self.master.data.updates.unclaimBuildRequests(brids)
+                self._remove_in_progress_brids(brids)
+
                 # try starting builds again.  If we still have a working worker,
                 # then this may re-claim the same buildrequests
                 self.botmaster.maybeStartBuildsForBuilder(self.name)
 
+    def _add_in_progress_brids(self, brids):
+        for brid in brids:
+            self.master.botmaster.add_in_progress_buildrequest(brid)
+
+    def _remove_in_progress_brids(self, brids):
+        for brid in brids:
+            self.master.botmaster.remove_in_progress_buildrequest(brid)
+
     def createBuildChooser(self, bldr, master):
         # just instantiate the build chooser requested
         return self.BuildChooser(bldr, master)
