@@ -13,33 +13,39 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
 import inspect
 import sys
+from typing import TYPE_CHECKING
 
 from twisted.internet import defer
 from twisted.internet import error
 from twisted.python import deprecate
 from twisted.python import log
 from twisted.python import versions
-from twisted.python.deprecate import deprecatedModuleAttribute
 from twisted.python.failure import Failure
 from twisted.python.reflect import accumulateClassList
-from twisted.python.versions import Version
 from twisted.web.util import formatFailure
 from zope.interface import implementer
 
 from buildbot import config
 from buildbot import interfaces
 from buildbot import util
+from buildbot.config.checks import check_param_bool
 from buildbot.config.checks import check_param_length
+from buildbot.config.checks import check_param_number_none
+from buildbot.config.checks import check_param_str
+from buildbot.config.checks import check_param_str_none
 from buildbot.db.model import Model
 from buildbot.interfaces import IRenderable
 from buildbot.interfaces import WorkerSetupError
 from buildbot.process import log as plog
-from buildbot.process import logobserver
 from buildbot.process import properties
 from buildbot.process import remotecommand
 from buildbot.process import results
+from buildbot.process.locks import get_real_locks_from_accesses
+
 # (WithProperties used to be available in this module)
 from buildbot.process.properties import WithProperties
 from buildbot.process.results import ALL_RESULTS
@@ -53,9 +59,13 @@ from buildbot.process.results import WARNINGS
 from buildbot.process.results import statusToString
 from buildbot.util import bytes2unicode
 from buildbot.util import debounce
+from buildbot.util import deferwaiter
 from buildbot.util import flatten
 from buildbot.util.test_result_submitter import TestResultSubmitter
-from buildbot.warnings import warn_deprecated
+
+if TYPE_CHECKING:
+    from buildbot.process.build import Build
+    from buildbot.worker.base import AbstractWorker
 
 
 class BuildStepFailed(Exception):
@@ -72,77 +82,32 @@ class CallableAttributeError(Exception):
     pass
 
 
-# old import paths for these classes
-RemoteCommand = remotecommand.RemoteCommand
-deprecatedModuleAttribute(
-    Version("buildbot", 2, 10, 1),
-    message="Use buildbot.process.remotecommand.RemoteCommand instead.",
-    moduleName="buildbot.process.buildstep",
-    name="RemoteCommand",
-)
-
-LoggedRemoteCommand = remotecommand.LoggedRemoteCommand
-deprecatedModuleAttribute(
-    Version("buildbot", 2, 10, 1),
-    message="Use buildbot.process.remotecommand.LoggedRemoteCommand instead.",
-    moduleName="buildbot.process.buildstep",
-    name="LoggedRemoteCommand",
-)
-
-RemoteShellCommand = remotecommand.RemoteShellCommand
-deprecatedModuleAttribute(
-    Version("buildbot", 2, 10, 1),
-    message="Use buildbot.process.remotecommand.RemoteShellCommand instead.",
-    moduleName="buildbot.process.buildstep",
-    name="RemoteShellCommand",
-)
-
-LogObserver = logobserver.LogObserver
-deprecatedModuleAttribute(
-    Version("buildbot", 2, 10, 1),
-    message="Use buildbot.process.logobserver.LogObserver instead.",
-    moduleName="buildbot.process.buildstep",
-    name="LogObserver",
-)
-
-LogLineObserver = logobserver.LogLineObserver
-deprecatedModuleAttribute(
-    Version("buildbot", 2, 10, 1),
-    message="Use buildbot.util.LogLineObserver instead.",
-    moduleName="buildbot.process.buildstep",
-    name="LogLineObserver",
-)
-
-OutputProgressObserver = logobserver.OutputProgressObserver
-deprecatedModuleAttribute(
-    Version("buildbot", 2, 10, 1),
-    message="Use buildbot.process.logobserver.OutputProgressObserver instead.",
-    moduleName="buildbot.process.buildstep",
-    name="OutputProgressObserver",
-)
-
-
 @implementer(interfaces.IBuildStepFactory)
 class _BuildStepFactory(util.ComparableMixin):
-
     """
     This is a wrapper to record the arguments passed to as BuildStep subclass.
     We use an instance of this class, rather than a closure mostly to make it
     easier to test that the right factories are getting created.
     """
+
     compare_attrs = ('factory', 'args', 'kwargs')
 
-    def __init__(self, factory, *args, **kwargs):
-        self.factory = factory
+    def __init__(self, step_class, *args, **kwargs):
+        self.step_class = step_class
         self.args = args
         self.kwargs = kwargs
 
     def buildStep(self):
         try:
-            return self.factory(*self.args, **self.kwargs)
+            step = object.__new__(self.step_class)
+            step._factory = self
+            step.__init__(*self.args, **self.kwargs)  # noqa pylint: disable=unnecessary-dunder-call
+            return step
         except Exception:
-            log.msg(f"error while creating step, factory={self.factory}, args={self.args}, "
-                    f"kwargs={self.kwargs}")
+            log.msg(
+                f"error while creating step, step_class={self.step_class}, args={self.args}, "
+                f"kwargs={self.kwargs}"
+            )
             raise
 
 
@@ -164,10 +129,42 @@ def create_step_from_step_or_factory(step_or_factory):
     return get_factory_from_step_or_factory(step_or_factory).buildStep()
 
 
+class BuildStepWrapperMixin:
+    __init_completed = False
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.__init_completed = True
+
+    def __setattr__(self, name, value):
+        if self.__init_completed:
+            config.error(
+                "Changes to attributes of a BuildStep instance are ignored, this is a bug. "
+                "Use set_step_arg(name, value) for that."
+            )
+        super().__setattr__(name, value)
+
+
+# This is also needed for comparisons to work because ComparableMixin requires type(x) and
+# x.__class__ to be equal in order to perform comparison at all.
+_buildstep_wrapper_cache = {}
+
+
+def _create_buildstep_wrapper_class(klass):
+    class_id = id(klass)
+    cached = _buildstep_wrapper_cache.get(class_id, None)
+    if cached is not None:
+        return cached
+
+    wrapper = type(klass.__qualname__, (BuildStepWrapperMixin, klass), {})
+    _buildstep_wrapper_cache[class_id] = wrapper
+    return wrapper
+
+
 @implementer(interfaces.IBuildStep)
-class BuildStep(results.ResultComputingConfigMixin,
-                properties.PropertiesMixin,
-                util.ComparableMixin):
+class BuildStep(
+    results.ResultComputingConfigMixin, properties.PropertiesMixin, util.ComparableMixin
+):
     # Note that the BuildStep is at the same time a template from which per-build steps are
     # constructed. This works by creating a new IBuildStepFactory in __new__, retrieving it via
     # get_step_factory() and then calling buildStep() on that factory.
@@ -189,43 +186,46 @@ class BuildStep(results.ResultComputingConfigMixin,
         'workdir',
     ]
 
-    # 'parms' holds a list of all the parameters we care about, to allow
+    # '_params_names' holds a list of all the parameters we care about, to allow
     # users to instantiate a subclass of BuildStep with a mixture of
     # arguments, some of which are for us, some of which are for the subclass
     # (or a delegate of the subclass, like how ShellCommand delivers many
     # arguments to the RemoteShellCommand that it creates). Such delegating
     # subclasses will use this list to figure out which arguments are meant
     # for us and which should be given to someone else.
-    parms = [
-        'alwaysRun',
-        'description',
-        'descriptionDone',
-        'descriptionSuffix',
-        'doStepIf',
-        'flunkOnFailure',
-        'flunkOnWarnings',
-        'haltOnFailure',
-        'updateBuildSummaryPolicy',
-        'hideStepIf',
-        'locks',
-        'logEncoding',
-        'name',
-        'progressMetrics',
-        'useProgress',
-        'warnOnFailure',
-        'warnOnWarnings',
-        'workdir',
+    _params_config = [
+        ('alwaysRun', check_param_bool),
+        ('description', None),
+        ('descriptionDone', None),
+        ('descriptionSuffix', None),
+        ('doStepIf', None),
+        ('flunkOnFailure', check_param_bool),
+        ('flunkOnWarnings', check_param_bool),
+        ('haltOnFailure', check_param_bool),
+        ('updateBuildSummaryPolicy', None),
+        ('hideStepIf', None),
+        ('locks', None),
+        ('logEncoding', None),
+        ('name', check_param_str),
+        ('progressMetrics', None),
+        ('useProgress', None),
+        ('warnOnFailure', check_param_bool),
+        ('warnOnWarnings', check_param_bool),
+        ('workdir', check_param_str_none),
     ]
 
+    _params_names = [arg for arg, _ in _params_config]
+
     name = "generic"
     description = None  # set this to a list of short strings to override
     descriptionDone = None  # alternate description when the step is complete
     descriptionSuffix = None  # extra information to append to suffix
     updateBuildSummaryPolicy = None
     locks = []
+    _locks_to_acquire = []
     progressMetrics = ()  # 'time' is implicit
     useProgress = True  # set to False if step is really unpredictable
-    build = None
+    build: Build | None = None
     step_status = None
     progress = None
     logEncoding = None
@@ -237,21 +237,22 @@ class BuildStep(results.ResultComputingConfigMixin,
     def __init__(self, **kwargs):
         self.worker = None
 
-        for p in self.__class__.parms:
+        for p, check in self.__class__._params_config:
             if p in kwargs:
-                setattr(self, p, kwargs.pop(p))
+                value = kwargs.pop(p)
+                if check is not None and not IRenderable.providedBy(value):
+                    check(value, self.__class__, p)
+                setattr(self, p, value)
 
         if kwargs:
-            config.error(f"{self.__class__}.__init__ got unexpected keyword argument(s) "
-                         f"{list(kwargs)}")
+            config.error(
+                f"{self.__class__}.__init__ got unexpected keyword argument(s) {list(kwargs)}"
+            )
         self._pendingLogObservers = []
 
-        if not isinstance(self.name, str) and not IRenderable.providedBy(self.name):
-            config.error(f"BuildStep name must be a string or a renderable object: "
-                         f"{repr(self.name)}")
-
-        check_param_length(self.name, f'Step {self.__class__.__name__} name',
-                           Model.steps.c.name.type.length)
+        check_param_length(
+            self.name, f'Step {self.__class__.__name__} name', Model.steps.c.name.type.length
+        )
 
         if isinstance(self.description, str):
             self.description = [self.description]
@@ -272,11 +273,14 @@ class BuildStep(results.ResultComputingConfigMixin,
         if self.updateBuildSummaryPolicy is True:
             self.updateBuildSummaryPolicy = ALL_RESULTS
         if not isinstance(self.updateBuildSummaryPolicy, list):
-            config.error("BuildStep updateBuildSummaryPolicy must be "
-                         "a list of result ids or boolean but it is "
-                         f"{repr(self.updateBuildSummaryPolicy)}")
+            config.error(
+                "BuildStep updateBuildSummaryPolicy must be "
+                "a list of result ids or boolean but it is "
+                f"{repr(self.updateBuildSummaryPolicy)}"
+            )
         self._acquiringLocks = []
         self.stopped = False
+        self.timed_out = False
         self.master = None
         self.statistics = {}
         self.logs = {}
@@ -284,26 +288,45 @@ class BuildStep(results.ResultComputingConfigMixin,
         self.stepid = None
         self.results = None
         self._start_unhandled_deferreds = None
+        self._interrupt_deferwaiter = deferwaiter.DeferWaiter()
+        self._update_summary_debouncer = debounce.Debouncer(
+            1.0, self._update_summary_impl, lambda: self.master.reactor
+        )
         self._test_result_submitters = {}
 
     def __new__(klass, *args, **kwargs):
-        self = object.__new__(klass)
+        # The following code prevents changing BuildStep attributes after an instance
+        # is created during config time. Such attribute changes don't affect the factory,
+        # so they will be lost when actual build step is created.
+        #
+        # This is implemented by dynamically creating a subclass that disallows attribute
+        # writes after __init__ completes.
+        self = object.__new__(_create_buildstep_wrapper_class(klass))
         self._factory = _BuildStepFactory(klass, *args, **kwargs)
         return self
 
+    def is_exact_step_class(self, klass):
+        # Due to wrapping BuildStep in __new__, it's not possible to compare self.__class__ to
+        # check if self is an instance of some class (but not subclass).
+        if self.__class__ is klass:
+            return True
+        mro = self.__class__.mro()
+        if len(mro) >= 3 and mro[1] is BuildStepWrapperMixin and mro[2] is klass:
+            return True
+        return False
+
     def __str__(self):
         args = [repr(x) for x in self._factory.args]
-        args.extend([str(k) + "=" + repr(v)
-                     for k, v in self._factory.kwargs.items()])
+        args.extend([str(k) + "=" + repr(v) for k, v in self._factory.kwargs.items()])
         return f'{self.__class__.__name__}({", ".join(args)})'
 
     __repr__ = __str__
 
-    def setBuild(self, build):
+    def setBuild(self, build: Build) -> None:
         self.build = build
         self.master = self.build.master
 
-    def setWorker(self, worker):
+    def setWorker(self, worker: AbstractWorker):
         self.worker = worker
 
     @deprecate.deprecated(versions.Version("buildbot", 0, 9, 0))
@@ -344,6 +367,15 @@ class BuildStep(results.ResultComputingConfigMixin,
     def get_step_factory(self):
         return self._factory
 
+    def set_step_arg(self, name, value):
+        self._factory.kwargs[name] = value
+        # check if buildstep can still be constructed with the new arguments
+        try:
+            self._factory.buildStep()
+        except Exception:
+            log.msg(f"Cannot set step factory attribute {name} to {value}: step creation fails")
+            raise
+
     def setupProgress(self):
         # this function temporarily does nothing
         pass
@@ -371,43 +403,54 @@ class BuildStep(results.ResultComputingConfigMixin,
 
         if self.results != SUCCESS:
             stepsumm += f' ({statusToString(self.results)})'
+            if self.timed_out:
+                stepsumm += " (timed out)"
 
         return {'step': stepsumm}
 
     @defer.inlineCallbacks
     def getBuildResultSummary(self):
         summary = yield self.getResultSummary()
-        if self.results in self.updateBuildSummaryPolicy and \
-                'build' not in summary and 'step' in summary:
+        if (
+            self.results in self.updateBuildSummaryPolicy
+            and 'build' not in summary
+            and 'step' in summary
+        ):
             summary['build'] = summary['step']
         return summary
 
-    @debounce.method(wait=1)
-    @defer.inlineCallbacks
     def updateSummary(self):
+        self._update_summary_debouncer()
+
+    @defer.inlineCallbacks
+    def _update_summary_impl(self):
         def methodInfo(m):
             lines = inspect.getsourcelines(m)
-            return "\nat {}:{}:\n {}".format(inspect.getsourcefile(m), lines[1],
-                                             "\n".join(lines[0]))
+            return "\nat {}:{}:\n {}".format(
+                inspect.getsourcefile(m), lines[1], "\n".join(lines[0])
+            )
+
         if not self._running:
             summary = yield self.getResultSummary()
             if not isinstance(summary, dict):
-                raise TypeError('getResultSummary must return a dictionary: ' +
-                                methodInfo(self.getResultSummary))
+                raise TypeError(
+                    'getResultSummary must return a dictionary: '
+                    + methodInfo(self.getResultSummary)
+                )
         else:
             summary = yield self.getCurrentSummary()
             if not isinstance(summary, dict):
-                raise TypeError('getCurrentSummary must return a dictionary: ' +
-                                methodInfo(self.getCurrentSummary))
+                raise TypeError(
+                    'getCurrentSummary must return a dictionary: '
+                    + methodInfo(self.getCurrentSummary)
+                )
 
         stepResult = summary.get('step', 'finished')
         if not isinstance(stepResult, str):
             raise TypeError(f"step result string must be unicode (got {repr(stepResult)})")
         if self.stepid is not None:
-            stepResult = self.build.properties.cleanupTextFromSecrets(
-                stepResult)
-            yield self.master.data.updates.setStepStateString(self.stepid,
-                                                              stepResult)
+            stepResult = self.build.properties.cleanupTextFromSecrets(stepResult)
+            yield self.master.data.updates.setStepStateString(self.stepid, stepResult)
 
         if not self._running:
             buildResult = summary.get('build', None)
@@ -421,54 +464,19 @@ class BuildStep(results.ResultComputingConfigMixin,
         self.name = yield self.build.render(self.name)
         self.build.setUniqueStepName(self)
         self.stepid, self.number, self.name = yield self.master.data.updates.addStep(
-            buildid=self.build.buildid,
-            name=util.bytes2unicode(self.name))
-        yield self.master.data.updates.startStep(self.stepid)
+            buildid=self.build.buildid, name=util.bytes2unicode(self.name)
+        )
 
     @defer.inlineCallbacks
     def startStep(self, remote):
         self.remote = remote
 
         yield self.addStep()
-        self.locks = yield self.build.render(self.locks)
-
-        # convert all locks into their real form
-        botmaster = self.build.builder.botmaster
-        self.locks = yield botmaster.getLockFromLockAccesses(self.locks, self.build.config_version)
-
-        # then narrow WorkerLocks down to the worker that this build is being
-        # run on
-        self.locks = [(l.getLockForWorker(self.build.workerforbuilder.worker.workername),
-                       la)
-                      for l, la in self.locks]
-
-        for l, _ in self.locks:
-            if l in self.build.locks:
-                log.msg(f"Hey, lock {l} is claimed by both a Step ({self}) and the"
-                        f" parent Build ({self.build})")
-                raise RuntimeError("lock claimed by both Step and Build")
+        started_at = int(self.master.reactor.seconds())
+        yield self.master.data.updates.startStep(self.stepid, started_at=started_at)
 
         try:
-            # set up locks
-            yield self.acquireLocks()
-
-            if self.stopped:
-                raise BuildStepCancelled
-
-            # render renderables in parallel
-            renderables = []
-            accumulateClassList(self.__class__, 'renderables', renderables)
-
-            def setRenderable(res, attr):
-                setattr(self, attr, res)
-
-            dl = []
-            for renderable in renderables:
-                d = self.build.render(getattr(self, renderable))
-                d.addCallback(setRenderable, renderable)
-                dl.append(d)
-            yield defer.gatherResults(dl)
-            self.rendered = True
+            yield self._render_renderables()
             # we describe ourselves only when renderables are interpolated
             self.updateSummary()
 
@@ -478,8 +486,33 @@ class BuildStep(results.ResultComputingConfigMixin,
             else:
                 doStep = yield self.doStepIf(self)
 
-            # run -- or skip -- the step
             if doStep:
+                yield self._setup_locks()
+
+                # set up locks
+                if self._locks_to_acquire:
+                    yield self.acquireLocks()
+
+                    if self.stopped:
+                        raise BuildStepCancelled
+
+                    locks_acquired_at = int(self.master.reactor.seconds())
+                    yield defer.DeferredList([
+                        self.master.data.updates.set_step_locks_acquired_at(
+                            self.stepid, locks_acquired_at=locks_acquired_at
+                        ),
+                        self.master.data.updates.add_build_locks_duration(
+                            self.build.buildid, duration_s=locks_acquired_at - started_at
+                        ),
+                    ])
+                else:
+                    yield self.master.data.updates.set_step_locks_acquired_at(
+                        self.stepid, locks_acquired_at=started_at
+                    )
+
+                    if self.stopped:
+                        raise BuildStepCancelled
+
                 yield self.addTestResultSets()
                 try:
                     self._running = True
@@ -535,28 +568,62 @@ class BuildStep(results.ResultComputingConfigMixin,
         # update the summary one last time, make sure that completes,
         # and then don't update it any more.
         self.updateSummary()
-        yield self.updateSummary.stop()
+        yield self._update_summary_debouncer.stop()
 
         for sub in self._test_result_submitters.values():
             yield sub.finish()
 
         self.releaseLocks()
 
-        yield self.master.data.updates.finishStep(self.stepid, self.results,
-                                                  hidden)
+        yield self.master.data.updates.finishStep(self.stepid, self.results, hidden)
 
         return self.results
 
+    @defer.inlineCallbacks
+    def _setup_locks(self):
+        self._locks_to_acquire = yield get_real_locks_from_accesses(self.locks, self.build)
+
+        if self.build._locks_to_acquire:
+            build_locks = [l for l, _ in self.build._locks_to_acquire]
+            for l, _ in self._locks_to_acquire:
+                if l in build_locks:
+                    log.err(
+                        f"{self}: lock {l} is claimed by both a Step ({self}) and the"
+                        f" parent Build ({self.build})"
+                    )
+                    raise RuntimeError(f"lock claimed by both Step and Build ({l})")
+
+    @defer.inlineCallbacks
+    def _render_renderables(self):
+        # render renderables in parallel
+        renderables = []
+        accumulateClassList(self.__class__, 'renderables', renderables)
+
+        def setRenderable(res, attr):
+            setattr(self, attr, res)
+
+        dl = []
+        for renderable in renderables:
+            d = self.build.render(getattr(self, renderable))
+            d.addCallback(setRenderable, renderable)
+            dl.append(d)
+        yield defer.gatherResults(dl)
+        self.rendered = True
+
     def setBuildData(self, name, value, source):
         # returns a Deferred that yields nothing
         return self.master.data.updates.setBuildData(self.build.buildid, name, value, source)
 
     @defer.inlineCallbacks
     def _cleanup_logs(self):
+        # Wait until any in-progress interrupt() to finish (that function may add new logs)
+        yield self._interrupt_deferwaiter.wait()
+
         all_success = True
         not_finished_logs = [v for (k, v) in self.logs.items() if not v.finished]
-        finish_logs = yield defer.DeferredList([v.finish() for v in not_finished_logs],
-                                               consumeErrors=True)
+        finish_logs = yield defer.DeferredList(
+            [v.finish() for v in not_finished_logs], consumeErrors=True
+        )
         for success, res in finish_logs:
             if not success:
                 log.err(res, "when trying to finish a log")
@@ -579,19 +646,24 @@ class BuildStep(results.ResultComputingConfigMixin,
         self._test_result_submitters[setid] = sub
         return setid
 
-    def addTestResult(self, setid, value, test_name=None, test_code_path=None, line=None,
-                      duration_ns=None):
-        self._test_result_submitters[setid].add_test_result(value, test_name=test_name,
-                                                            test_code_path=test_code_path,
-                                                            line=line, duration_ns=duration_ns)
+    def addTestResult(
+        self, setid, value, test_name=None, test_code_path=None, line=None, duration_ns=None
+    ):
+        self._test_result_submitters[setid].add_test_result(
+            value,
+            test_name=test_name,
+            test_code_path=test_code_path,
+            line=line,
+            duration_ns=duration_ns,
+        )
 
     def acquireLocks(self, res=None):
-        if not self.locks:
+        if not self._locks_to_acquire:
             return defer.succeed(None)
         if self.stopped:
             return defer.succeed(None)
-        log.msg(f"acquireLocks(step {self}, locks {self.locks})")
-        for lock, access in self.locks:
+        log.msg(f"acquireLocks(step {self}, locks {self._locks_to_acquire})")
+        for lock, access in self._locks_to_acquire:
             for waited_lock, _, _ in self._acquiringLocks:
                 if lock is waited_lock:
                     continue
@@ -604,7 +676,7 @@ class BuildStep(results.ResultComputingConfigMixin,
                 d.addCallback(self.acquireLocks)
                 return d
         # all locks are available, claim them all
-        for lock, access in self.locks:
+        for lock, access in self._locks_to_acquire:
             lock.claim(self, access)
         self._acquiringLocks = []
         self._waitingForLocks = False
@@ -613,10 +685,6 @@ class BuildStep(results.ResultComputingConfigMixin,
     def run(self):
         raise NotImplementedError("A custom build step must implement run()")
 
-    def isNewStyle(self):
-        warn_deprecated('3.0.0', 'BuildStep.isNewStyle() always returns True')
-        return True
-
     @defer.inlineCallbacks
     def _maybe_interrupt_cmd(self, reason):
         if not self.cmd:
@@ -627,8 +695,13 @@ class BuildStep(results.ResultComputingConfigMixin,
         except Exception as e:
             log.err(e, 'while cancelling command')
 
-    @defer.inlineCallbacks
     def interrupt(self, reason):
+        # Note that this method may be run outside usual step lifecycle (e.g. after run() has
+        # already completed), so extra care needs to be taken to prevent race conditions.
+        return self._interrupt_deferwaiter.add(self._interrupt_impl(reason))
+
+    @defer.inlineCallbacks
+    def _interrupt_impl(self, reason):
         if self.stopped:
             # If we are in the process of interruption and connection is lost then we must tell
             # the command not to wait for the interruption to complete.
@@ -638,21 +711,17 @@ class BuildStep(results.ResultComputingConfigMixin,
 
         self.stopped = True
         if self._acquiringLocks:
-            for (lock, access, d) in self._acquiringLocks:
+            for lock, access, d in self._acquiringLocks:
                 lock.stopWaitingUntilAvailable(self, access, d)
             self._acquiringLocks = []
 
-        if self._waitingForLocks:
-            yield self.addCompleteLog(
-                'cancelled while waiting for locks', str(reason))
-        else:
-            yield self.addCompleteLog('cancelled', str(reason))
-
+        log_name = "cancelled while waiting for locks" if self._waitingForLocks else "cancelled"
+        yield self.addCompleteLog(log_name, str(reason))
         yield self._maybe_interrupt_cmd(reason)
 
     def releaseLocks(self):
-        log.msg(f"releaseLocks({self}): {self.locks}")
-        for lock, access in self.locks:
+        log.msg(f"releaseLocks({self}): {self._locks_to_acquire}")
+        for lock, access in self._locks_to_acquire:
             if lock.isOwner(self, access):
                 lock.release(self, access)
             else:
@@ -683,13 +752,12 @@ class BuildStep(results.ResultComputingConfigMixin,
     def addLog(self, name, type='s', logEncoding=None):
         if self.stepid is None:
             raise BuildStepCancelled
-        d = self.master.data.updates.addLog(self.stepid,
-                                            util.bytes2unicode(name),
-                                            str(type))
+        d = self.master.data.updates.addLog(self.stepid, util.bytes2unicode(name), str(type))
 
         @d.addCallback
         def newLog(logid):
             return self._newLog(name, type, logid, logEncoding)
+
         return d
 
     def getLog(self, name):
@@ -699,8 +767,7 @@ class BuildStep(results.ResultComputingConfigMixin,
     def addCompleteLog(self, name, text):
         if self.stepid is None:
             raise BuildStepCancelled
-        logid = yield self.master.data.updates.addLog(self.stepid,
-                                                      util.bytes2unicode(name), 't')
+        logid = yield self.master.data.updates.addLog(self.stepid, util.bytes2unicode(name), 't')
         _log = self._newLog(name, 't', logid)
         yield _log.addContent(text)
         yield _log.finish()
@@ -709,8 +776,7 @@ class BuildStep(results.ResultComputingConfigMixin,
     def addHTMLLog(self, name, html):
         if self.stepid is None:
             raise BuildStepCancelled
-        logid = yield self.master.data.updates.addLog(self.stepid,
-                                                      util.bytes2unicode(name), 'h')
+        logid = yield self.master.data.updates.addLog(self.stepid, util.bytes2unicode(name), 'h')
         _log = self._newLog(name, 'h', logid)
         html = bytes2unicode(html)
         yield _log.addContent(html)
@@ -764,6 +830,8 @@ class BuildStep(results.ResultComputingConfigMixin,
         command.worker = self.worker
         try:
             res = yield command.run(self, self.remote, self.build.builder.name)
+            if command.remote_failure_reason in ("timeout", "timeout_without_output"):
+                self.timed_out = True
         finally:
             self.cmd = None
         return res
@@ -782,7 +850,6 @@ class BuildStep(results.ResultComputingConfigMixin,
 
 
 class CommandMixin:
-
     @defer.inlineCallbacks
     def _runRemoteCommand(self, cmd, abandonOnFailure, args, makeResult=None):
         cmd = remotecommand.RemoteCommand(cmd, args)
@@ -800,25 +867,24 @@ class CommandMixin:
             return not cmd.didFail()
 
     def runRmdir(self, dir, log=None, abandonOnFailure=True):
-        return self._runRemoteCommand('rmdir', abandonOnFailure,
-                                      {'dir': dir, 'logEnviron': False})
+        return self._runRemoteCommand('rmdir', abandonOnFailure, {'dir': dir, 'logEnviron': False})
 
     def pathExists(self, path, log=None):
-        return self._runRemoteCommand('stat', False,
-                                      {'file': path, 'logEnviron': False})
+        return self._runRemoteCommand('stat', False, {'file': path, 'logEnviron': False})
 
     def runMkdir(self, dir, log=None, abandonOnFailure=True):
-        return self._runRemoteCommand('mkdir', abandonOnFailure,
-                                      {'dir': dir, 'logEnviron': False})
+        return self._runRemoteCommand('mkdir', abandonOnFailure, {'dir': dir, 'logEnviron': False})
 
     def runGlob(self, path):
         return self._runRemoteCommand(
-            'glob', True, {'path': path, 'logEnviron': False},
-            makeResult=lambda cmd: cmd.updates['files'][0])
+            'glob',
+            True,
+            {'path': path, 'logEnviron': False},
+            makeResult=lambda cmd: cmd.updates['files'][0],
+        )
 
 
 class ShellMixin:
-
     command = None
     env = {}
     want_stdout = True
@@ -834,24 +900,24 @@ class ShellMixin:
     initialStdin = None
     decodeRC = {0: SUCCESS}
 
-    _shellMixinArgs = [
-        'command',
-        'workdir',
-        'env',
-        'want_stdout',
-        'want_stderr',
-        'usePTY',
-        'logfiles',
-        'lazylogfiles',
-        'timeout',
-        'maxTime',
-        'logEnviron',
-        'interruptSignal',
-        'sigtermTime',
-        'initialStdin',
-        'decodeRC',
+    _shell_mixin_arg_config = [
+        ('command', None),
+        ('workdir', check_param_str),
+        ('env', None),
+        ('want_stdout', check_param_bool),
+        ('want_stderr', check_param_bool),
+        ('usePTY', check_param_bool),
+        ('logfiles', None),
+        ('lazylogfiles', check_param_bool),
+        ('timeout', check_param_number_none),
+        ('maxTime', check_param_number_none),
+        ('logEnviron', check_param_bool),
+        ('interruptSignal', check_param_str_none),
+        ('sigtermTime', check_param_number_none),
+        ('initialStdin', check_param_str_none),
+        ('decodeRC', None),
     ]
-    renderables = _shellMixinArgs
+    renderables = [arg for arg, _ in _shell_mixin_arg_config]
 
     def setupShellMixin(self, constructorArgs, prohibitArgs=None):
         constructorArgs = constructorArgs.copy()
@@ -861,26 +927,30 @@ class ShellMixin:
 
         def bad(arg):
             config.error(f"invalid {self.__class__.__name__} argument {arg}")
-        for arg in self._shellMixinArgs:
+
+        for arg, check in self._shell_mixin_arg_config:
             if arg not in constructorArgs:
                 continue
             if arg in prohibitArgs:
                 bad(arg)
             else:
+                value = constructorArgs[arg]
+                if check is not None and not IRenderable.providedBy(value):
+                    check(value, self.__class__, arg)
+
                 setattr(self, arg, constructorArgs[arg])
             del constructorArgs[arg]
         for arg in list(constructorArgs):
-            if arg not in BuildStep.parms:
+            if arg not in BuildStep._params_names:
                 bad(arg)
                 del constructorArgs[arg]
         return constructorArgs
 
     @defer.inlineCallbacks
-    def makeRemoteShellCommand(self, collectStdout=False, collectStderr=False,
-                               stdioLogName='stdio',
-                               **overrides):
-        kwargs = {arg: getattr(self, arg)
-                  for arg in self._shellMixinArgs}
+    def makeRemoteShellCommand(
+        self, collectStdout=False, collectStderr=False, stdioLogName='stdio', **overrides
+    ):
+        kwargs = {arg: getattr(self, arg) for arg, _ in self._shell_mixin_arg_config}
         kwargs.update(overrides)
         stdio = None
         if stdioLogName is not None:
@@ -899,15 +969,15 @@ class ShellMixin:
         if kwargs['usePTY'] is not None:
             if self.workerVersionIsOlderThan("shell", "2.7"):
                 if stdio is not None:
-                    yield stdio.addHeader(
-                        "NOTE: worker does not allow master to override usePTY\n")
+                    yield stdio.addHeader("NOTE: worker does not allow master to override usePTY\n")
                 del kwargs['usePTY']
 
         # check for the interruptSignal flag
         if kwargs["interruptSignal"] and self.workerVersionIsOlderThan("shell", "2.15"):
             if stdio is not None:
                 yield stdio.addHeader(
-                    "NOTE: worker does not allow master to specify interruptSignal\n")
+                    "NOTE: worker does not allow master to specify interruptSignal\n"
+                )
             del kwargs['interruptSignal']
 
         # lazylogfiles are handled below
@@ -930,9 +1000,7 @@ class ShellMixin:
 
         # the rest of the args go to RemoteShellCommand
         cmd = remotecommand.RemoteShellCommand(
-            collectStdout=collectStdout,
-            collectStderr=collectStderr,
-            **kwargs
+            collectStdout=collectStdout, collectStderr=collectStderr, **kwargs
         )
 
         # set up logging
@@ -943,6 +1011,7 @@ class ShellMixin:
                 # it's OK if this does, or does not, return a Deferred
                 def callback(cmd_arg, local_logname=logname):
                     return self.addLog(local_logname)
+
                 cmd.useLogDelayed(logname, callback, True)
             else:
                 # add a LogFile
@@ -959,6 +1028,8 @@ class ShellMixin:
         if summary:
             if self.results != SUCCESS:
                 summary += f' ({statusToString(self.results)})'
+                if self.timed_out:
+                    summary += " (timed out)"
             return {'step': summary}
         return super().getResultSummary()
 
