@@ -49,20 +49,19 @@ from buildbot.util import service as util_service
 # Make use of the resource module if we can
 try:
     import resource
+
     assert resource
 except ImportError:
     resource = None
 
 
 class MetricEvent:
-
     @classmethod
     def log(cls, *args, **kwargs):
         log.msg(metric=cls(*args, **kwargs))
 
 
 class MetricCountEvent(MetricEvent):
-
     def __init__(self, counter, count=1, absolute=False):
         self.counter = counter
         self.count = count
@@ -70,7 +69,6 @@ class MetricCountEvent(MetricEvent):
 
 
 class MetricTimeEvent(MetricEvent):
-
     def __init__(self, timer, elapsed):
         self.timer = timer
         self.elapsed = elapsed
@@ -81,7 +79,6 @@ ALARM_TEXT = ["OK", "WARN", "CRIT"]
 
 
 class MetricAlarmEvent(MetricEvent):
-
     def __init__(self, alarm, msg=None, level=ALARM_OK):
         self.alarm = alarm
         self.level = level
@@ -93,7 +90,9 @@ def countMethod(counter):
         def wrapper(*args, **kwargs):
             MetricCountEvent.log(counter=counter)
             return func(*args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
@@ -109,6 +108,7 @@ class Timer:
         def wrapper(*args, **kwargs):
             self.start()
             return func(*args, **kwargs)
+
         return wrapper
 
     def stopTimer(self, func):
@@ -117,6 +117,7 @@ class Timer:
                 return func(*args, **kwargs)
             finally:
                 self.stop()
+
         return wrapper
 
     def start(self):
@@ -140,12 +141,13 @@ def timeMethod(name, _reactor=None):
                 return func(*args, **kwargs)
             finally:
                 t.stop()
+
         return wrapper
+
     return decorator
 
 
 class FiniteList(deque):
-
     def __init__(self, maxlen=10):
         self._maxlen = maxlen
         super().__init__()
@@ -157,7 +159,6 @@ class FiniteList(deque):
 
 
 class AveragingFiniteList(FiniteList):
-
     def __init__(self, maxlen=10):
         super().__init__(maxlen)
         self.average = 0
@@ -176,7 +177,6 @@ class AveragingFiniteList(FiniteList):
 
 
 class MetricHandler:
-
     def __init__(self, metrics):
         self.metrics = metrics
         self.watchers = []
@@ -230,14 +230,14 @@ class MetricCountHandler(MetricHandler):
     def report(self):
         retval = []
         for counter in sorted(self.keys()):
-            retval.append("Counter %s: %i" % (counter, self.get(counter)))
+            retval.append(f"Counter {counter}: {self.get(counter)}")
         return "\n".join(retval)
 
     def asDict(self):
         retval = {}
         for counter in sorted(self.keys()):
             retval[counter] = self.get(counter)
-        return dict(counters=retval)
+        return {"counters": retval}
 
 
 class MetricTimeHandler(MetricHandler):
@@ -258,14 +258,14 @@ class MetricTimeHandler(MetricHandler):
     def report(self):
         retval = []
         for timer in sorted(self.keys()):
-            retval.append("Timer %s: %.3g" % (timer, self.get(timer)))
+            retval.append(f"Timer {timer}: {self.get(timer):.3g}")
         return "\n".join(retval)
 
     def asDict(self):
         retval = {}
         for timer in sorted(self.keys()):
             retval[timer] = self.get(timer)
-        return dict(timers=retval)
+        return {"timers": retval}
 
 
 class MetricAlarmHandler(MetricHandler):
@@ -281,20 +281,19 @@ class MetricAlarmHandler(MetricHandler):
         retval = []
         for alarm, (level, msg) in sorted(self._alarms.items()):
             if msg:
-                retval.append("{} {}: {}".format(ALARM_TEXT[level], alarm, msg))
+                retval.append(f"{ALARM_TEXT[level]} {alarm}: {msg}")
             else:
-                retval.append("{} {}".format(ALARM_TEXT[level], alarm))
+                retval.append(f"{ALARM_TEXT[level]} {alarm}")
         return "\n".join(retval)
 
     def asDict(self):
         retval = {}
         for alarm, (level, msg) in sorted(self._alarms.items()):
             retval[alarm] = (ALARM_TEXT[level], msg)
-        return dict(alarms=retval)
+        return {"alarms": retval}
 
 
 class AttachedWorkersWatcher:
-
     def __init__(self, metrics):
         self.metrics = metrics
 
@@ -304,9 +303,11 @@ class AttachedWorkersWatcher:
         h = self.metrics.getHandler(MetricCountEvent)
         if not h:
             log.msg("Couldn't get MetricCountEvent handler")
-            MetricAlarmEvent.log('AttachedWorkersWatcher',
-                                 msg="Coudln't get MetricCountEvent handler",
-                                 level=ALARM_WARN)
+            MetricAlarmEvent.log(
+                'AttachedWorkersWatcher',
+                msg="Coudln't get MetricCountEvent handler",
+                level=ALARM_WARN,
+            )
             return
         botmaster_count = h.get('BotMaster.attached_workers')
         worker_count = h.get('AbstractWorker.attached_workers')
@@ -318,14 +319,15 @@ class AttachedWorkersWatcher:
         else:
             level = ALARM_OK
 
-        MetricAlarmEvent.log('attached_workers', msg='{} {}'.format(botmaster_count, worker_count),
-                             level=level)
+        MetricAlarmEvent.log(
+            'attached_workers', msg=f'{botmaster_count} {worker_count}', level=level
+        )
 
 
 def _get_rss():
     if sys.platform == 'linux':
         try:
-            with open("/proc/%i/statm" % os.getpid()) as f:
+            with open(f"/proc/{os.getpid()}/statm", encoding='utf-8') as f:
                 return int(f.read().split()[1])
         except Exception:
             return 0
@@ -345,19 +347,32 @@ def periodicCheck(_reactor=reactor):
 
         if resource:
             r = resource.getrusage(resource.RUSAGE_SELF)
-            attrs = ['ru_utime', 'ru_stime', 'ru_maxrss', 'ru_ixrss', 'ru_idrss',
-                     'ru_isrss', 'ru_minflt', 'ru_majflt', 'ru_nswap',
-                     'ru_inblock', 'ru_oublock', 'ru_msgsnd', 'ru_msgrcv',
-                     'ru_nsignals', 'ru_nvcsw', 'ru_nivcsw']
+            attrs = [
+                'ru_utime',
+                'ru_stime',
+                'ru_maxrss',
+                'ru_ixrss',
+                'ru_idrss',
+                'ru_isrss',
+                'ru_minflt',
+                'ru_majflt',
+                'ru_nswap',
+                'ru_inblock',
+                'ru_oublock',
+                'ru_msgsnd',
+                'ru_msgrcv',
+                'ru_nsignals',
+                'ru_nvcsw',
+                'ru_nivcsw',
+            ]
             for i, a in enumerate(attrs):
                 # Linux versions prior to 2.6.32 didn't report this value, but we
                 # can calculate it from /proc/<pid>/statm
                 v = r[i]
                 if a == 'ru_maxrss' and v == 0:
                     v = _get_rss() * resource.getpagesize() / 1024
-                MetricCountEvent.log('resource.{}'.format(a), v, absolute=True)
-            MetricCountEvent.log(
-                'resource.pagesize', resource.getpagesize(), absolute=True)
+                MetricCountEvent.log(f'resource.{a}', v, absolute=True)
+            MetricCountEvent.log('resource.pagesize', resource.getpagesize(), absolute=True)
         # Measure the reactor delay
         then = util.now(_reactor)
         dt = 0.1
@@ -366,13 +381,13 @@ def periodicCheck(_reactor=reactor):
             now = util.now(_reactor)
             delay = (now - then) - dt
             MetricTimeEvent.log("reactorDelay", delay)
+
         _reactor.callLater(dt, cb)
     except Exception:
         log.err(None, "while collecting VM metrics")
 
 
-class MetricLogObserver(util_service.ReconfigurableServiceMixin,
-                        service.MultiService):
+class MetricLogObserver(util_service.ReconfigurableServiceMixin, service.MultiService):
     _reactor = reactor
 
     def __init__(self):
@@ -393,8 +408,7 @@ class MetricLogObserver(util_service.ReconfigurableServiceMixin,
         self.registerHandler(MetricTimeEvent, MetricTimeHandler(self))
         self.registerHandler(MetricAlarmEvent, MetricAlarmHandler(self))
 
-        self.getHandler(MetricCountEvent).addWatcher(
-            AttachedWorkersWatcher(self))
+        self.getHandler(MetricCountEvent).addWatcher(AttachedWorkersWatcher(self))
 
     def reconfigServiceWithBuildbotConfig(self, new_config):
         # first, enable or disable
@@ -423,8 +437,7 @@ class MetricLogObserver(util_service.ReconfigurableServiceMixin,
                     self.periodic_task.stop()
                     self.periodic_task = None
                 if periodic_interval:
-                    self.periodic_task = LoopingCall(periodicCheck,
-                                                     self._reactor)
+                    self.periodic_task = LoopingCall(periodicCheck, self._reactor)
                     self.periodic_task.clock = self._reactor
                     self.periodic_task.start(periodic_interval)
 
@@ -480,13 +493,13 @@ class MetricLogObserver(util_service.ReconfigurableServiceMixin,
 
     def asDict(self):
         retval = {}
-        for interface, handler in self.handlers.items():
+        for _, handler in self.handlers.items():
             retval.update(handler.asDict())
         return retval
 
     def report(self):
         try:
-            for interface, handler in self.handlers.items():
+            for handler in self.handlers.values():
                 report = handler.report()
                 if not report:
                     continue
