@@ -25,6 +25,7 @@ from buildbot.process import metrics
 from buildbot.process.results import CANCELLED
 from buildbot.process.results import FAILURE
 from buildbot.process.results import SUCCESS
+from buildbot.util import lineboundaries
 from buildbot.util.eventual import eventually
 from buildbot.worker.protocols import base
 
@@ -34,7 +35,6 @@ class RemoteException(Exception):
 
 
 class RemoteCommand(base.RemoteCommandImpl):
-
     # class-level unique identifier generator for command ids
     _commandCounter = 0
 
@@ -42,9 +42,16 @@ class RemoteCommand(base.RemoteCommandImpl):
     rc = None
     debug = False
 
-    def __init__(self, remote_command, args, ignore_updates=False,
-                 collectStdout=False, collectStderr=False, decodeRC=None,
-                 stdioLogName='stdio'):
+    def __init__(
+        self,
+        remote_command,
+        args,
+        ignore_updates=False,
+        collectStdout=False,
+        collectStderr=False,
+        decodeRC=None,
+        stdioLogName='stdio',
+    ):
         if decodeRC is None:
             decodeRC = {0: SUCCESS}
         self.logs = {}
@@ -58,6 +65,7 @@ class RemoteCommand(base.RemoteCommandImpl):
         self.stdioLogName = stdioLogName
         self._startTime = None
         self._remoteElapsed = None
+        self.remote_failure_reason = None
         self.remote_command = remote_command
         self.args = args
         self.ignore_updates = ignore_updates
@@ -74,10 +82,22 @@ class RemoteCommand(base.RemoteCommandImpl):
         # This is really only a problem with old-style steps, which do not
         # wait for the Deferred from one method before invoking the next.
         self.loglock = defer.DeferredLock()
+        self._line_boundary_finders = {}
 
     def __repr__(self):
         return f"<RemoteCommand '{self.remote_command}' at {id(self)}>"
 
+    @classmethod
+    def generate_new_command_id(cls):
+        cmd_id = cls._commandCounter
+        cls._commandCounter += 1
+        return f"{cmd_id}"
+
+    @classmethod
+    def get_last_generated_command_id(cls):
+        cmd_id = cls._commandCounter - 1
+        return f"{cmd_id}"
+
     def run(self, step, conn, builder_name):
         self.active = True
         self.step = step
@@ -87,10 +107,7 @@ class RemoteCommand(base.RemoteCommandImpl):
         # This probably could be solved in a cleaner way.
         self._is_conn_test_fake = hasattr(self.conn, 'is_fake_test_connection')
 
-        # generate a new command id
-        cmd_id = RemoteCommand._commandCounter
-        RemoteCommand._commandCounter += 1
-        self.commandID = f"{cmd_id}"
+        self.commandID = RemoteCommand.generate_new_command_id()
 
         log.msg(f"{self}: RemoteCommand.run [{self.commandID}]")
         self.deferred = defer.Deferred()
@@ -130,9 +147,9 @@ class RemoteCommand(base.RemoteCommandImpl):
         # We will receive remote_update messages as the command runs.
         # We will get a single remote_complete when it finishes.
         # We should fire self.deferred when the command is done.
-        d = self.conn.remoteStartCommand(self, self.builder_name,
-                                         self.commandID, self.remote_command,
-                                         self.args)
+        d = self.conn.remoteStartCommand(
+            self, self.builder_name, self.commandID, self.remote_command, self.args
+        )
         return d
 
     @defer.inlineCallbacks
@@ -149,7 +166,7 @@ class RemoteCommand(base.RemoteCommandImpl):
         if not self._is_conn_test_fake:
             timeout = 10
             while self.rc is None and timeout > 0:
-                yield util.asyncSleep(.1)
+                yield util.asyncSleep(0.1)
                 timeout -= 1
 
         try:
@@ -182,12 +199,34 @@ class RemoteCommand(base.RemoteCommandImpl):
         # when the interrupt command has been delivered.
 
         try:
-            yield self.conn.remoteInterruptCommand(self.builder_name,
-                                                   self.commandID, str(why))
+            yield self.conn.remoteInterruptCommand(self.builder_name, self.commandID, str(why))
             # the worker may not have remote_interruptCommand
         except Exception as e:
             log.msg("RemoteCommand.interrupt failed", self, e)
 
+    def remote_update_msgpack(self, updates):
+        self.worker.messageReceivedFromWorker()
+        try:
+            for key, value in updates:
+                if self.active and not self.ignore_updates:
+                    if key in ['stdout', 'stderr', 'header']:
+                        self.remoteUpdate(key, value[0], False)
+                    elif key == "log":
+                        logname, data = value
+                        self.remoteUpdate(key, (logname, data[0]), False)
+                    else:
+                        self.remoteUpdate(key, value, False)
+        except Exception:
+            # log failure, terminate build, let worker retire the update
+            self._finished(Failure())
+
+    def split_line(self, stream, text):
+        try:
+            return self._line_boundary_finders[stream].append(text)
+        except KeyError:
+            lbf = self._line_boundary_finders[stream] = lineboundaries.LineBoundaryFinder()
+            return lbf.append(text)
+
     def remote_update(self, updates):
         """
         I am called by the worker's
@@ -200,18 +239,30 @@ class RemoteCommand(base.RemoteCommandImpl):
         updates = decode(updates)
         self.worker.messageReceivedFromWorker()
         max_updatenum = 0
-        for (update, num) in updates:
+        for update, num in updates:  # noqa pylint: disable=too-many-nested-blocks
             # log.msg("update[%d]:" % num)
             try:
                 if self.active and not self.ignore_updates:
-                    self.remoteUpdate(update)
+                    for key, value in update.items():
+                        if key in ['stdout', 'stderr', 'header']:
+                            whole_line = self.split_line(key, value)
+                            if whole_line is not None:
+                                self.remoteUpdate(key, whole_line, False)
+                        elif key == "log":
+                            logname, data = value
+                            whole_line = self.split_line(logname, data)
+                            value = (logname, whole_line)
+                            if whole_line is not None:
+                                self.remoteUpdate(key, value, False)
+                        else:
+                            self.remoteUpdate(key, value, False)
+
             except Exception:
                 # log failure, terminate build, let worker retire the update
                 self._finished(Failure())
                 # TODO: what if multiple updates arrive? should
                 # skip the rest but ack them all
-            if num > max_updatenum:
-                max_updatenum = num
+            max_updatenum = max(max_updatenum, num)
         return max_updatenum
 
     def remote_complete(self, failure=None):
@@ -239,6 +290,16 @@ class RemoteCommand(base.RemoteCommandImpl):
             self.logs[self.stdioLogName].addStdout(data)
         return defer.succeed(None)
 
+    @util.deferredLocked('loglock')
+    def add_stdout_lines(self, data, is_flushed):
+        if self.collectStdout:
+            if is_flushed:
+                data = data[:-1]
+            self.stdout += data
+        if self.stdioLogName is not None and self.stdioLogName in self.logs:
+            self.logs[self.stdioLogName].add_stdout_lines(data)
+        return defer.succeed(None)
+
     @util.deferredLocked('loglock')
     def addStderr(self, data):
         if self.collectStderr:
@@ -247,12 +308,28 @@ class RemoteCommand(base.RemoteCommandImpl):
             self.logs[self.stdioLogName].addStderr(data)
         return defer.succeed(None)
 
+    @util.deferredLocked('loglock')
+    def add_stderr_lines(self, data, is_flushed):
+        if self.collectStderr:
+            if is_flushed:
+                data = data[:-1]
+            self.stderr += data
+        if self.stdioLogName is not None and self.stdioLogName in self.logs:
+            self.logs[self.stdioLogName].add_stderr_lines(data)
+        return defer.succeed(None)
+
     @util.deferredLocked('loglock')
     def addHeader(self, data):
         if self.stdioLogName is not None and self.stdioLogName in self.logs:
             self.logs[self.stdioLogName].addHeader(data)
         return defer.succeed(None)
 
+    @util.deferredLocked('loglock')
+    def add_header_lines(self, data):
+        if self.stdioLogName is not None and self.stdioLogName in self.logs:
+            self.logs[self.stdioLogName].add_header_lines(data)
+        return defer.succeed(None)
+
     @util.deferredLocked('loglock')
     @defer.inlineCallbacks
     def addToLog(self, logname, data):
@@ -265,62 +342,74 @@ class RemoteCommand(base.RemoteCommandImpl):
             self._closeWhenFinished[logname] = closeWhenFinished
 
         if logname in self.logs:
-            yield self.logs[logname].addStdout(data)
+            yield self.logs[logname].add_stdout_lines(data)
         else:
             log.msg(f"{self}.addToLog: no such log {logname}")
 
     @metrics.countMethod('RemoteCommand.remoteUpdate()')
     @defer.inlineCallbacks
-    def remoteUpdate(self, update):
+    def remoteUpdate(self, key, value, is_flushed):
         def cleanup(data):
             if self.step is None:
                 return data
             return self.step.build.properties.cleanupTextFromSecrets(data)
 
         if self.debug:
-            for k, v in update.items():
-                log.msg(f"Update[{k}]: {v}")
-        if "stdout" in update:
-            # 'stdout': data
-            yield self.addStdout(cleanup(update['stdout']))
-        if "stderr" in update:
-            # 'stderr': data
-            yield self.addStderr(cleanup(update['stderr']))
-        if "header" in update:
-            # 'header': data
-            yield self.addHeader(cleanup(update['header']))
-        if "log" in update:
-            # 'log': (logname, data)
-            logname, data = update['log']
+            log.msg(f"Update[{key}]: {value}")
+        if key == "stdout":
+            yield self.add_stdout_lines(cleanup(value), is_flushed)
+        if key == "stderr":
+            yield self.add_stderr_lines(cleanup(value), is_flushed)
+        if key == "header":
+            yield self.add_header_lines(cleanup(value))
+        if key == "log":
+            logname, data = value
             yield self.addToLog(logname, cleanup(data))
-        if "rc" in update:
-            rc = self.rc = update['rc']
+        if key == "rc":
+            rc = self.rc = value
             log.msg(f"{self} rc={rc}")
-            yield self.addHeader(f"program finished with exit code {rc}\n")
-        if "elapsed" in update:
-            self._remoteElapsed = update['elapsed']
+            yield self.add_header_lines(f"program finished with exit code {rc}\n")
+        if key == "elapsed":
+            self._remoteElapsed = value
+        if key == "failure_reason":
+            self.remote_failure_reason = value
 
         # TODO: these should be handled at the RemoteCommand level
-        for k in update:
-            if k not in ('stdout', 'stderr', 'header', 'rc'):
-                if k not in self.updates:
-                    self.updates[k] = []
-                self.updates[k].append(update[k])
+        if key not in ('stdout', 'stderr', 'header', 'rc', "failure_reason"):
+            if key not in self.updates:
+                self.updates[key] = []
+            self.updates[key].append(value)
 
-    @util.deferredLocked('loglock')
     @defer.inlineCallbacks
     def remoteComplete(self, maybeFailure):
         if self._startTime and self._remoteElapsed:
             delta = (util.now() - self._startTime) - self._remoteElapsed
             metrics.MetricTimeEvent.log("RemoteCommand.overhead", delta)
 
-        for name, loog in self.logs.items():
-            if self._closeWhenFinished[name]:
-                if maybeFailure:
-                    yield loog.addHeader(f"\nremoteFailed: {maybeFailure}")
-                else:
-                    log.msg(f"closing log {loog}")
-                yield loog.finish()
+        for key, lbf in self._line_boundary_finders.items():
+            if key in ['stdout', 'stderr', 'header']:
+                whole_line = lbf.flush()
+                if whole_line is not None:
+                    yield self.remoteUpdate(key, whole_line, True)
+            else:
+                logname = key
+                whole_line = lbf.flush()
+                value = (logname, whole_line)
+                if whole_line is not None:
+                    yield self.remoteUpdate("log", value, True)
+
+        try:
+            yield self.loglock.acquire()
+            for name, loog in self.logs.items():
+                if self._closeWhenFinished[name]:
+                    if maybeFailure:
+                        yield loog.addHeader(f"\nremoteFailed: {maybeFailure}")
+                    else:
+                        log.msg(f"closing log {loog}")
+                    yield loog.finish()
+        finally:
+            yield self.loglock.release()
+
         if maybeFailure:
             # Message Pack protocol can not send an exception object back to the master, so
             # exception information is sent as a string
@@ -330,8 +419,9 @@ class RemoteCommand(base.RemoteCommandImpl):
             # workaround http://twistedmatrix.com/trac/ticket/5507
             # CopiedFailure cannot be raised back, this make debug difficult
             if isinstance(maybeFailure, pb.CopiedFailure):
-                maybeFailure.value = RemoteException(f"{maybeFailure.type}: {maybeFailure.value}"
-                                                     f"\n{maybeFailure.traceback}")
+                maybeFailure.value = RemoteException(
+                    f"{maybeFailure.type}: {maybeFailure.value}\n{maybeFailure.traceback}"
+                )
                 maybeFailure.type = RemoteException
             maybeFailure.raiseException()
 
@@ -350,15 +440,26 @@ LoggedRemoteCommand = RemoteCommand
 
 
 class RemoteShellCommand(RemoteCommand):
-
-    def __init__(self, workdir, command, env=None,
-                 want_stdout=1, want_stderr=1,
-                 timeout=20 * 60, maxTime=None, sigtermTime=None,
-                 logfiles=None, usePTY=None, logEnviron=True,
-                 collectStdout=False, collectStderr=False,
-                 interruptSignal=None,
-                 initialStdin=None, decodeRC=None,
-                 stdioLogName='stdio'):
+    def __init__(
+        self,
+        workdir,
+        command,
+        env=None,
+        want_stdout=1,
+        want_stderr=1,
+        timeout=20 * 60,
+        maxTime=None,
+        sigtermTime=None,
+        logfiles=None,
+        usePTY=None,
+        logEnviron=True,
+        collectStdout=False,
+        collectStderr=False,
+        interruptSignal=None,
+        initialStdin=None,
+        decodeRC=None,
+        stdioLogName='stdio',
+    ):
         if logfiles is None:
             logfiles = {}
         if decodeRC is None:
@@ -373,6 +474,7 @@ class RemoteShellCommand(RemoteCommand):
                 if isinstance(arg, tuple) and len(arg) == 3 and arg[0] == 'obfuscated':
                     return arg[2]
                 return arg
+
             self.fake_command = [obfuscate(c) for c in self.command]
 
         if env is not None:
@@ -381,24 +483,29 @@ class RemoteShellCommand(RemoteCommand):
             # able to modify the original.
             env = env.copy()
 
-        args = {'workdir': workdir,
-                'env': env,
-                'want_stdout': want_stdout,
-                'want_stderr': want_stderr,
-                'logfiles': logfiles,
-                'timeout': timeout,
-                'maxTime': maxTime,
-                'sigtermTime': sigtermTime,
-                'usePTY': usePTY,
-                'logEnviron': logEnviron,
-                'initial_stdin': initialStdin
-                }
+        args = {
+            'workdir': workdir,
+            'env': env,
+            'want_stdout': want_stdout,
+            'want_stderr': want_stderr,
+            'logfiles': logfiles,
+            'timeout': timeout,
+            'maxTime': maxTime,
+            'sigtermTime': sigtermTime,
+            'usePTY': usePTY,
+            'logEnviron': logEnviron,
+            'initial_stdin': initialStdin,
+        }
         if interruptSignal is not None:
             args['interruptSignal'] = interruptSignal
-        super().__init__("shell", args, collectStdout=collectStdout,
-                         collectStderr=collectStderr,
-                         decodeRC=decodeRC,
-                         stdioLogName=stdioLogName)
+        super().__init__(
+            "shell",
+            args,
+            collectStdout=collectStdout,
+            collectStderr=collectStderr,
+            decodeRC=decodeRC,
+            stdioLogName=stdioLogName,
+        )
 
     def _start(self):
         if self.args['usePTY'] is None:
