@@ -67,8 +67,9 @@ class ReporterBase(service.BuildbotService):
         # Add consumers for new keys
         for key in sorted(list(wanted_event_keys)):
             if key not in self._event_consumers:
-                self._event_consumers[key] = \
-                    yield self.master.mq.startConsuming(self._got_event, key)
+                self._event_consumers[key] = yield self.master.mq.startConsuming(
+                    self._got_event, key
+                )
 
     @defer.inlineCallbacks
     def stopService(self):
@@ -76,8 +77,7 @@ class ReporterBase(service.BuildbotService):
             yield consumer.stopConsuming()
         self._event_consumers = {}
 
-        for pending_call in list(self._pending_got_event_calls.values()):
-            yield pending_call
+        yield from list(self._pending_got_event_calls.values())
         self._pending_got_event_calls = {}
 
         yield super().stopService()
@@ -114,8 +114,11 @@ class ReporterBase(service.BuildbotService):
                         if report is not None:
                             reports.append(report)
                     except Exception as e:
-                        log.err(e, "Got exception when handling reporter events: "
-                                f"key: {key} generator: {g}")
+                        log.err(
+                            e,
+                            "Got exception when handling reporter events: "
+                            f"key: {key} generator: {g}",
+                        )
 
             if reports:
                 yield self.sendMessage(reports)
