@@ -20,14 +20,12 @@ import time
 import warnings
 
 from packaging.version import parse as parse_version
-
 from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.internet.protocol import ProcessProtocol
 from twisted.python import log
 from zope.interface import implementer
 
-from buildbot import config
 from buildbot import interfaces
 from buildbot.process.results import EXCEPTION
 from buildbot.process.results import FAILURE
@@ -38,7 +36,6 @@ from buildbot.process.results import Results
 from buildbot.reporters import utils
 from buildbot.reporters.base import ReporterBase
 from buildbot.util import bytes2unicode
-from buildbot.warnings import warn_deprecated
 
 # Cache the version that the gerrit server is running for this many seconds
 GERRIT_VERSION_CACHE_TIMEOUT = 600
@@ -54,28 +51,14 @@ def makeReviewResult(message, *labels):
     return {"message": message, "labels": dict(labels)}
 
 
-def _handleLegacyResult(result):
-    """
-    make sure the result is backward compatible
-    """
-    if not isinstance(result, dict):
-        warnings.warn('The Gerrit status callback uses the old way to '
-                      'communicate results.  The outcome might be not what is '
-                      'expected.')
-        message, verified, reviewed = result
-        result = makeReviewResult(message,
-                                  (GERRIT_LABEL_VERIFIED, verified),
-                                  (GERRIT_LABEL_REVIEWED, reviewed))
-    return result
-
-
 def _old_add_label(label, value):
     if label == GERRIT_LABEL_VERIFIED:
         return [f"--verified {int(value)}"]
     elif label == GERRIT_LABEL_REVIEWED:
         return [f"--code-review {int(value)}"]
-    warnings.warn('Gerrit older than 2.6 does not support custom labels. '
-                  f'Setting {label} is ignored.')
+    warnings.warn(
+        'Gerrit older than 2.6 does not support custom labels. ' f'Setting {label} is ignored.'
+    )
     return []
 
 
@@ -91,8 +74,7 @@ def defaultReviewCB(builderName, build, result, master, arg):
     message += f"on configuration: {builderName}\n"
     message += f"The result is: {Results[result].upper()}\n"
 
-    return makeReviewResult(message,
-                            (GERRIT_LABEL_VERIFIED, result == SUCCESS or -1))
+    return makeReviewResult(message, (GERRIT_LABEL_VERIFIED, result == SUCCESS or -1))
 
 
 def defaultSummaryCB(buildInfoList, results, master, arg):
@@ -171,9 +153,9 @@ def extract_project_revision(master, report):
         project = get_property(props, "event.change.project")
         codebase = get_property(props, "codebase")
         revision = (
-            get_property(props, "event.patchSet.revision") or
-            get_property(props, "got_revision") or
-            get_property(props, "revision")
+            get_property(props, "event.patchSet.revision")
+            or get_property(props, "got_revision")
+            or get_property(props, "revision")
         )
 
         if isinstance(revision, dict):
@@ -190,7 +172,6 @@ def extract_project_revision(master, report):
 
 
 class GerritStatusGeneratorBase:
-
     def __init__(self, callback, callback_arg, builders, want_steps, want_logs):
         self.callback = callback
         self.callback_arg = callback_arg
@@ -206,11 +187,7 @@ class GerritStatusGeneratorBase:
         br = yield master.data.get(("buildrequests", build["buildrequestid"]))
         buildset = yield master.data.get(("buildsets", br["buildsetid"]))
         yield utils.getDetailsForBuilds(
-            master,
-            buildset,
-            [build],
-            want_properties=True,
-            want_steps=self.want_steps
+            master, buildset, [build], want_properties=True, want_steps=self.want_steps
         )
 
 
@@ -232,7 +209,7 @@ class GerritBuildSetStatusGenerator(GerritStatusGeneratorBase):
             want_properties=True,
             want_steps=self.want_steps,
             want_logs=self.want_logs,
-            want_logs_content=self.want_logs
+            want_logs_content=self.want_logs,
         )
 
         builds = res["builds"]
@@ -256,12 +233,8 @@ class GerritBuildSetStatusGenerator(GerritStatusGeneratorBase):
                 "result": result,
                 "resultText": resultText,
                 "text": build["state_string"],
-                "url": utils.getURLForBuild(
-                    master,
-                    build["builder"]["builderid"],
-                    build["number"]
-                ),
-                "build": build
+                "url": utils.getURLForBuild(master, build["builder"]["builderid"], build["number"]),
+                "build": build,
             }
 
         build_info_list = sorted(
@@ -269,14 +242,9 @@ class GerritBuildSetStatusGenerator(GerritStatusGeneratorBase):
         )
 
         result = yield self.callback(
-            build_info_list,
-            Results[buildset["results"]],
-            master,
-            self.callback_arg
+            build_info_list, Results[buildset["results"]], master, self.callback_arg
         )
 
-        result = _handleLegacyResult(result)
-
         return {
             "body": result.get("message", None),
             "extra_info": {
@@ -305,8 +273,6 @@ class GerritBuildStartStatusGenerator(GerritStatusGeneratorBase):
 
         result = yield self.callback(build["builder"]["name"], build, self.callback_arg)
 
-        result = _handleLegacyResult(result)
-
         return {
             "body": result.get("message", None),
             "extra_info": {
@@ -334,15 +300,9 @@ class GerritBuildEndStatusGenerator(GerritStatusGeneratorBase):
             return None
 
         result = yield self.callback(
-            build['builder']['name'],
-            build,
-            build['results'],
-            master,
-            self.callback_arg
+            build['builder']['name'], build, build['results'], master, self.callback_arg
         )
 
-        result = _handleLegacyResult(result)
-
         return {
             "body": result.get("message", None),
             "extra_info": {
@@ -354,8 +314,8 @@ class GerritBuildEndStatusGenerator(GerritStatusGeneratorBase):
 
 
 class GerritStatusPush(ReporterBase):
-
     """Event streamer to a gerrit ssh server."""
+
     name = "GerritStatusPush"
     gerrit_server = None
     gerrit_username = None
@@ -369,57 +329,22 @@ class GerritStatusPush(ReporterBase):
         self,
         server,
         username,
-        reviewCB=DEFAULT_REVIEW,
-        startCB=None,
         port=29418,
-        reviewArg=None,
-        startArg=None,
-        summaryCB=DEFAULT_SUMMARY,
-        summaryArg=None,
         identity_file=None,
-        builders=None,
         notify=None,
-        wantSteps=False,
-        wantLogs=False,
         generators=None,
-        **kwargs
+        **kwargs,
     ):
-        old_arg_names = {
-            "reviewCB": reviewCB is not DEFAULT_REVIEW,
-            "startCB": startCB is not None,
-            "reviewArg": reviewArg is not None,
-            "startArg": startArg is not None,
-            "summaryCB": summaryCB is not DEFAULT_SUMMARY,
-            "summaryArg": summaryArg is not None,
-            "builders": builders is not None,
-            "wantSteps": wantSteps is not False,
-            "wantLogs": wantLogs is not False,
-        }
-
-        passed_old_arg_names = [k for k, v in old_arg_names.items() if v]
-
-        if passed_old_arg_names:
-            old_arg_names_msg = ', '.join(passed_old_arg_names)
-            if generators is not None:
-                config.error("can't specify generators and deprecated GerritStatusPush "
-                             f"arguments ({old_arg_names_msg}) at the same time")
-            warn_deprecated(
-                "3.11.0",
-                f"The arguments {old_arg_names_msg} passed to {self.__class__.__name__} "
-                "have been deprecated. Use generators instead"
-            )
-
         if generators is None:
-            generators = self._create_generators_from_old_args(
-                reviewCB,
-                startCB,
-                reviewArg,
-                startArg,
-                summaryCB,
-                summaryArg,
-                builders,
-                wantSteps,
-                wantLogs
+            generators = []
+            generators.append(
+                GerritBuildSetStatusGenerator(
+                    callback=defaultSummaryCB,
+                    callback_arg=None,
+                    builders=None,
+                    want_steps=False,
+                    want_logs=False,
+                )
             )
 
         super().checkConfig(generators=generators, **kwargs)
@@ -428,20 +353,11 @@ class GerritStatusPush(ReporterBase):
         self,
         server,
         username,
-        reviewCB=DEFAULT_REVIEW,
-        startCB=None,
         port=29418,
-        reviewArg=None,
-        startArg=None,
-        summaryCB=DEFAULT_SUMMARY,
-        summaryArg=None,
         identity_file=None,
-        builders=None,
         notify=None,
-        wantSteps=False,
-        wantLogs=False,
         generators=None,
-        **kwargs
+        **kwargs,
     ):
         self.gerrit_server = server
         self.gerrit_username = username
@@ -452,97 +368,40 @@ class GerritStatusPush(ReporterBase):
         self._gerrit_notify = notify
 
         if generators is None:
-            generators = self._create_generators_from_old_args(
-                reviewCB,
-                startCB,
-                reviewArg,
-                startArg,
-                summaryCB,
-                summaryArg,
-                builders,
-                wantSteps,
-                wantLogs
+            generators = []
+            generators.append(
+                GerritBuildSetStatusGenerator(
+                    callback=defaultSummaryCB,
+                    callback_arg=None,
+                    builders=None,
+                    want_steps=False,
+                    want_logs=False,
+                )
             )
 
         super().reconfigService(generators=generators, **kwargs)
 
-    def _create_generators_from_old_args(
-        self,
-        reviewCB,
-        startCB,
-        reviewArg,
-        startArg,
-        summaryCB,
-        summaryArg,
-        builders,
-        wantSteps,
-        wantLogs
-    ):
-        # If neither reviewCB nor summaryCB were specified, default to sending
-        # out "summary" reviews. But if we were given a reviewCB and only a
-        # reviewCB, disable the "summary" reviews, so we don't send out both
-        # by default.
-        if reviewCB is DEFAULT_REVIEW and summaryCB is DEFAULT_SUMMARY:
-            reviewCB = None
-            summaryCB = defaultSummaryCB
-        if reviewCB is DEFAULT_REVIEW:
-            reviewCB = None
-        if summaryCB is DEFAULT_SUMMARY:
-            summaryCB = None
-
-        generators = []
-
-        if startCB is not None:
-            generators.append(
-                GerritBuildStartStatusGenerator(
-                    callback=startCB,
-                    callback_arg=startArg,
-                    builders=builders,
-                    want_steps=wantSteps,
-                    want_logs=wantLogs
-                )
-            )
-
-        if reviewCB is not None:
-            generators.append(
-                GerritBuildEndStatusGenerator(
-                    callback=reviewCB,
-                    callback_arg=reviewArg,
-                    builders=builders,
-                    want_steps=wantSteps,
-                    want_logs=wantLogs
-                )
-            )
-
-        if summaryCB is not None:
-            generators.append(
-                GerritBuildSetStatusGenerator(
-                    callback=summaryCB,
-                    callback_arg=summaryArg,
-                    builders=builders,
-                    want_steps=wantSteps,
-                    want_logs=wantLogs
-                )
-            )
-
-        return generators
-
     def _gerritCmd(self, *args):
-        '''Construct a command as a list of strings suitable for
+        """Construct a command as a list of strings suitable for
         :func:`subprocess.call`.
-        '''
+        """
         if self.gerrit_identity_file is not None:
             options = ['-i', self.gerrit_identity_file]
         else:
             options = []
-        return ['ssh', '-o', 'BatchMode=yes'] + options + [
-            '@'.join((self.gerrit_username, self.gerrit_server)),
-            '-p', str(self.gerrit_port),
-            'gerrit'
-        ] + list(args)
+        return (
+            ['ssh', '-o', 'BatchMode=yes']
+            + options
+            + [
+                '@'.join((self.gerrit_username, self.gerrit_server)),
+                '-p',
+                str(self.gerrit_port),
+                'gerrit',
+            ]
+            + list(args)
+        )
 
     class VersionPP(ProcessProtocol):
-
         def __init__(self, func):
             self.func = func
             self.gerrit_version = None
@@ -552,7 +411,7 @@ class GerritStatusPush(ReporterBase):
             if not data.startswith(vstr):
                 log.msg(b"Error: Cannot interpret gerrit version info: " + data)
                 return
-            vers = data[len(vstr):].strip()
+            vers = data[len(vstr) :].strip()
             log.msg(b"gerrit version: " + vers)
             self.gerrit_version = parse_version(bytes2unicode(vers))
 
@@ -588,7 +447,6 @@ class GerritStatusPush(ReporterBase):
         self.spawnProcess(self.VersionPP(callback), command[0], command, env=None)
 
     class LocalPP(ProcessProtocol):
-
         def __init__(self, status):
             self.status = status
 
