@@ -45,7 +45,6 @@ from buildbot.util import unicode2bytes
 
 
 class TelegramChannel(Channel):
-
     def __init__(self, bot, channel):
         assert isinstance(channel, dict), "channel must be a dict provided by Telegram API"
         super().__init__(bot, channel['id'])
@@ -69,7 +68,6 @@ def collect_fields(fields):
 
 
 class TelegramContact(Contact):
-
     def __init__(self, user, channel=None):
         assert isinstance(user, dict), "user must be a dict provided by Telegram API"
         self.user_info = user
@@ -82,8 +80,10 @@ class TelegramContact(Contact):
 
     @property
     def user_full_name(self):
-        fullname = " ".join((self.user_info['first_name'],
-                             self.user_info.get('last_name', ''))).strip()
+        fullname = " ".join((
+            self.user_info['first_name'],
+            self.user_info.get('last_name', ''),
+        )).strip()
         return fullname
 
     @property
@@ -106,7 +106,7 @@ class TelegramContact(Contact):
 
     ACCESS_DENIED_MESSAGES = [
         "🧙‍♂️ You shall not pass! 👹",
-        "😨 Oh NO! You are simply not allowed to to this! 😢",
+        "😨 Oh NO! You are simply not allowed to this! 😢",
         "⛔ You cannot do this. Better go outside and relax... 🌳",
         "⛔ ACCESS DENIED! This incident has ben reported to NSA, KGB, and George Soros! 🕵",
         "🚫 Unauthorized access detected! Your device will explode in 3... 2... 1... 💣",
@@ -115,7 +115,8 @@ class TelegramContact(Contact):
 
     def access_denied(self, *args, tmessage, **kwargs):
         self.send(
-            random.choice(self.ACCESS_DENIED_MESSAGES), reply_to_message_id=tmessage['message_id'])
+            random.choice(self.ACCESS_DENIED_MESSAGES), reply_to_message_id=tmessage['message_id']
+        )
 
     def query_button(self, caption, payload):
         if isinstance(payload, str) and len(payload) < 64:
@@ -133,8 +134,10 @@ class TelegramContact(Contact):
 
     @defer.inlineCallbacks
     def command_START(self, args, **kwargs):
-        self.bot.post('/setChatMenuButton', json={'chat_id': self.channel.id,
-                                                  'menu_button': {'type': 'commands'}})
+        self.bot.post(
+            '/setChatMenuButton',
+            json={'chat_id': self.channel.id, 'menu_button': {'type': 'commands'}},
+        )
         yield self.command_HELLO(args)
         reactor.callLater(0.2, self.command_HELP, '')
 
@@ -143,12 +146,12 @@ class TelegramContact(Contact):
         replied_message = tmessage.get('reply_to_message')
         if replied_message:
             if 'reply_markup' in replied_message:
-                self.bot.edit_keyboard(self.channel.id,
-                                       replied_message['message_id'])
+                self.bot.edit_keyboard(self.channel.id, replied_message['message_id'])
         if self.is_private_chat:
             self.send("Never mind...")
         else:
             self.send(f"Never mind, {self.user_name}...")
+
     command_NAY.usage = "nay - never mind the command we are currently discussing"
 
     @classmethod
@@ -187,8 +190,10 @@ class TelegramContact(Contact):
         else:
             yield self.send(f"{self.user_name}, your ID is `{self.user_id}`.")
             self.send(f'This {self.channel.chat_info.get("type", "group")} ID is `{self.chat_id}`.')
-    command_GETID.usage = "getid - get user and chat ID that can be put in the master " \
-                          "configuration file"
+
+    command_GETID.usage = (
+        "getid - get user and chat ID that can be put in the master configuration file"
+    )
 
     @defer.inlineCallbacks
     @Contact.overrideCommand
@@ -196,14 +201,17 @@ class TelegramContact(Contact):
         args = self.splitArgs(args)
         if not args:
             keyboard = [
-                [self.query_button("👷️ Builders", '/list builders'),
-                 self.query_button("👷️ (including old ones)", '/list all builders')],
-                [self.query_button("⚙ Workers", '/list workers'),
-                 self.query_button("⚙ (including old ones)", '/list all workers')],
+                [
+                    self.query_button("👷️ Builders", '/list builders'),
+                    self.query_button("👷️ (including old ones)", '/list all builders'),
+                ],
+                [
+                    self.query_button("⚙ Workers", '/list workers'),
+                    self.query_button("⚙ (including old ones)", '/list all workers'),
+                ],
                 [self.query_button("📄 Changes (last 10)", '/list changes')],
             ]
-            self.send("What do you want to list?",
-                      reply_markup={'inline_keyboard': keyboard})
+            self.send("What do you want to list?", reply_markup={'inline_keyboard': keyboard})
             return
 
         all = False
@@ -219,8 +227,9 @@ class TelegramContact(Contact):
             pass
 
         if not args:
-            raise UsageError("Try '" + self.bot.commandPrefix +
-                             "list [all|N] builders|workers|changes'.")
+            raise UsageError(
+                "Try '" + self.bot.commandPrefix + "list [all|N] builders|workers|changes'."
+            )
 
         if args[0] == 'builders':
             bdicts = yield self.bot.getAllBuilders()
@@ -248,7 +257,6 @@ class TelegramContact(Contact):
             self.send('\n'.join(response))
 
         elif args[0] == 'changes':
-
             wait_message = yield self.send("⏳ Getting your changes...")
 
             if all:
@@ -257,12 +265,17 @@ class TelegramContact(Contact):
                 num = len(changes)
                 if num > 50:
                     keyboard = [
-                        [self.query_button("‼ Yes, flood me with all of them!",
-                                           f'/list {num} changes')],
-                        [self.query_button("✅ No, just show last 50", '/list 50 changes')]
+                        [
+                            self.query_button(
+                                "‼ Yes, flood me with all of them!", f'/list {num} changes'
+                            )
+                        ],
+                        [self.query_button("✅ No, just show last 50", '/list 50 changes')],
                     ]
-                    self.send(f"I found {num} changes. Do you really want me to list them all?",
-                              reply_markup={'inline_keyboard': keyboard})
+                    self.send(
+                        f"I found {num} changes. Do you really want me to list them all?",
+                        reply_markup={'inline_keyboard': keyboard},
+                    )
                     return
 
             else:
@@ -280,7 +293,8 @@ class TelegramContact(Contact):
                     f"_Date_: {change['date']}\n"
                     f"_Repository_: {change['repository']}\n"
                     f"_Branch_: {change['branch']}\n"
-                    f"_Revision_: {change['revision']}\n")
+                    f"_Revision_: {change['revision']}\n"
+                )
             self.send('\n'.join(response))
 
     @defer.inlineCallbacks
@@ -299,12 +313,11 @@ class TelegramContact(Contact):
         else:
             builders = yield self.get_running_builders()
             if builders:
-                keyboard = [
-                    [self.query_button("🔎 " + b, f'/watch {b}')]
-                    for b in builders
-                ]
-                self.send("Which builder do you want to watch?",
-                          reply_markup={'inline_keyboard': keyboard})
+                keyboard = [[self.query_button("🔎 " + b, f'/watch {b}')] for b in builders]
+                self.send(
+                    "Which builder do you want to watch?",
+                    reply_markup={'inline_keyboard': keyboard},
+                )
             else:
                 self.send("There are no currently running builds.")
 
@@ -324,19 +337,28 @@ class TelegramContact(Contact):
             [
                 self.query_button(
                     f"{e.capitalize()} {'🔔' if e in self.channel.notify_events else '🔕'}",
-                    f"/notify {'off' if e in self.channel.notify_events else 'on'}-quiet {e}")
+                    f"/notify {'off' if e in self.channel.notify_events else 'on'}-quiet {e}",
+                )
                 for e in evs
             ]
-            for evs in (('started', 'finished'), ('success', 'failure'), ('warnings', 'exception'),
-                        ('problem', 'recovery'), ('worse', 'better'), ('cancelled', 'worker'))
+            for evs in (
+                ('started', 'finished'),
+                ('success', 'failure'),
+                ('warnings', 'exception'),
+                ('problem', 'recovery'),
+                ('worse', 'better'),
+                ('cancelled', 'worker'),
+            )
         ] + [[self.query_button("Hide...", '/notify list')]]
 
         if tquery:
             self.bot.edit_keyboard(self.chat_id, tquery['message']['message_id'], keyboard)
         else:
-            self.send("Here are available notifications and their current state. "
-                      "Click to turn them on/off.",
-                      reply_markup={'inline_keyboard': keyboard})
+            self.send(
+                "Here are available notifications and their current state. "
+                "Click to turn them on/off.",
+                reply_markup={'inline_keyboard': keyboard},
+            )
 
     def ask_for_reply(self, prompt, greeting='Ok'):
         kwargs = {}
@@ -347,10 +369,7 @@ class TelegramContact(Contact):
                     prompt = f"{greeting} @{username}, now {prompt}..."
                 else:
                     prompt = f"@{username}, now {prompt}..."
-                kwargs['reply_markup'] = {
-                    'force_reply': True,
-                    'selective': True
-                }
+                kwargs['reply_markup'] = {'force_reply': True, 'selective': True}
             else:
                 if greeting:
                     prompt = f"{greeting}, now reply to this message and {prompt}..."
@@ -372,20 +391,15 @@ class TelegramContact(Contact):
     @Contact.overrideCommand
     def command_STOP(self, args, **kwargs):
         argv = self.splitArgs(args)
-        if len(argv) >= 3 or \
-                argv and argv[0] != 'build':
+        if len(argv) >= 3 or argv and argv[0] != 'build':
             super().command_STOP(args)
             return
         argv = argv[1:]
         if not argv:
             builders = yield self.get_running_builders()
             if builders:
-                keyboard = [
-                    [self.query_button("🚫 " + b, f'/stop build {b}')]
-                    for b in builders
-                ]
-                self.send("Select builder to stop...",
-                          reply_markup={'inline_keyboard': keyboard})
+                keyboard = [[self.query_button("🚫 " + b, f'/stop build {b}')] for b in builders]
+                self.send("Select builder to stop...", reply_markup={'inline_keyboard': keyboard})
         else:  # len(argv) == 1
             self.template = '/stop ' + args + ' {}'
             self.ask_for_reply(f"give me the reason to stop build on `{argv[0]}`")
@@ -395,19 +409,22 @@ class TelegramContact(Contact):
         if args:
             return super().command_SHUTDOWN(args)
         if self.master.botmaster.shuttingDown:
-            keyboard = [[
-                 self.query_button("🔙 Stop Shutdown", '/shutdown stop'),
-                 self.query_button("‼️ Shutdown Now", '/shutdown now')
-            ]]
+            keyboard = [
+                [
+                    self.query_button("🔙 Stop Shutdown", '/shutdown stop'),
+                    self.query_button("‼️ Shutdown Now", '/shutdown now'),
+                ]
+            ]
             text = "Buildbot is currently shutting down.\n\n"
         else:
-            keyboard = [[
-                 self.query_button("↘️ Begin Shutdown", '/shutdown start'),
-                 self.query_button("‼️ Shutdown Now", '/shutdown now')
-            ]]
+            keyboard = [
+                [
+                    self.query_button("↘️ Begin Shutdown", '/shutdown start'),
+                    self.query_button("‼️ Shutdown Now", '/shutdown now'),
+                ]
+            ]
             text = ""
-        self.send(text + "What do you want to do?",
-                  reply_markup={'inline_keyboard': keyboard})
+        self.send(text + "What do you want to do?", reply_markup={'inline_keyboard': keyboard})
         return None
 
     @defer.inlineCallbacks
@@ -436,8 +453,10 @@ class TelegramContact(Contact):
                     [self.query_button(s['label'], f"/force {s['name']}")]
                     for s in forceschedulers.values()
                 ]
-                self.send("Which force scheduler do you want to activate?",
-                          reply_markup={'inline_keyboard': keyboard})
+                self.send(
+                    "Which force scheduler do you want to activate?",
+                    reply_markup={'inline_keyboard': keyboard},
+                )
                 return
         else:
             if sched in forceschedulers:
@@ -445,8 +464,9 @@ class TelegramContact(Contact):
             elif len(forceschedulers) == 1:
                 sched = next(iter(forceschedulers))
             else:
-                raise UsageError("Try '/force' and follow the instructions"
-                                 f" (no force scheduler {sched})")
+                raise UsageError(
+                    "Try '/force' and follow the instructions" f" (no force scheduler {sched})"
+                )
         scheduler = forceschedulers[sched]
 
         try:
@@ -462,8 +482,9 @@ class TelegramContact(Contact):
                 [self.query_button(b, f'/force {sched} {task} {b}')]
                 for b in scheduler['builder_names']
             ]
-            self.send("Which builder do you want to start?",
-                      reply_markup={'inline_keyboard': keyboard})
+            self.send(
+                "Which builder do you want to start?", reply_markup={'inline_keyboard': keyboard}
+            )
             return
 
         if task == 'ask':
@@ -476,8 +497,10 @@ class TelegramContact(Contact):
 
         bldr = argv.pop(0)
         if bldr not in scheduler['builder_names']:
-            raise UsageError("Try '/force' and follow the instructions "
-                             f"(`{bldr}` not configured for _{scheduler['label']}_ scheduler)")
+            raise UsageError(
+                "Try '/force' and follow the instructions "
+                f"(`{bldr}` not configured for _{scheduler['label']}_ scheduler)"
+            )
 
         try:
             params = dict(arg.split('=', 1) for arg in argv)
@@ -485,8 +508,11 @@ class TelegramContact(Contact):
             raise UsageError(f"Try '/force' and follow the instructions ({e})") from e
 
         all_fields = list(collect_fields(scheduler['all_fields']))
-        required_params = [f['fullName'] for f in all_fields
-                           if f['required'] and f['fullName'] not in ('username', 'owner')]
+        required_params = [
+            f['fullName']
+            for f in all_fields
+            if f['required'] and f['fullName'] not in ('username', 'owner')
+        ]
         missing_params = [p for p in required_params if p not in params]
 
         if task == 'build':
@@ -498,10 +524,13 @@ class TelegramContact(Contact):
                     # raise UsageError
                     task = 'config'
                 else:
-                    params.update(dict(
-                        (f['fullName'], f['default']) for f in all_fields
-                        if f['type'] == 'fixed' and f['fullName'] not in ('username', 'owner')
-                    ))
+                    params.update(
+                        dict(
+                            (f['fullName'], f['default'])
+                            for f in all_fields
+                            if f['type'] == 'fixed' and f['fullName'] not in ('username', 'owner')
+                        )
+                    )
 
                     builder = yield self.bot.getBuilder(buildername=bldr)
                     for scheduler in self.master.allSchedulers():
@@ -510,9 +539,9 @@ class TelegramContact(Contact):
                     else:
                         raise ValueError(f"There is no force scheduler '{sched}'")
                     try:
-                        yield scheduler.force(builderid=builder['builderid'],
-                                              owner=self.describeUser(),
-                                              **params)
+                        yield scheduler.force(
+                            builderid=builder['builderid'], owner=self.describeUser(), **params
+                        )
                     except CollectedValidationError as e:
                         raise ValueError(e.errors) from e
                     self.send("Force build successfully requested.")
@@ -522,14 +551,16 @@ class TelegramContact(Contact):
                 raise UsageError(f"Try '/force' and follow the instructions ({e})") from e
 
         if task == 'config':
-
             msg = f"{self.user_full_name}, you are about to start a new build on `{bldr}`!"
 
             keyboard = []
             args = ' '.join(shlex.quote(f"{p[0]}={p[1]}") for p in params.items())
 
-            fields = [f for f in all_fields if f['type'] != 'fixed'
-                      and f['fullName'] not in ('username', 'owner')]
+            fields = [
+                f
+                for f in all_fields
+                if f['type'] != 'fixed' and f['fullName'] not in ('username', 'owner')
+            ]
 
             if fields:
                 msg += "\n\nThe current build parameters are:"
@@ -550,10 +581,9 @@ class TelegramContact(Contact):
                         if field_name in missing_params:
                             key = "⚠️ " + key
                             msg += " ⚠️"
-                        keyboard.append(
-                            [self.query_button(key,
-                                f'/force {sched} ask {field_name} {bldr} {args}')]
-                        )
+                        keyboard.append([
+                            self.query_button(key, f'/force {sched} ask {field_name} {bldr} {args}')
+                        ])
 
             msg += "\n\nWhat do you want to do?"
             if missing_params:
@@ -568,8 +598,7 @@ class TelegramContact(Contact):
 
         elif task == 'ask':
             prompt = "enter the new value for the " + what.replace('_', ' ').lower()
-            args = ' '.join(shlex.quote(f"{p[0]}={p[1]}") for p in params.items()
-                            if p[0] != what)
+            args = ' '.join(shlex.quote(f"{p[0]}={p[1]}") for p in params.items() if p[0] != what)
             self.template = f'/force {sched} config {bldr} {args} {what}={{}}'
             self.ask_for_reply(prompt, '')
 
@@ -580,7 +609,6 @@ class TelegramContact(Contact):
 
 
 class TelegramStatusBot(StatusBot):
-
     contactClass = TelegramContact
     channelClass = TelegramChannel
     commandPrefix = '/'
@@ -615,8 +643,10 @@ class TelegramStatusBot(StatusBot):
             channel = self.getChannel(c)
             channel.add_notification_events(self.notify_events)
         yield self.loadState()
-        commands = [{'command': command, 'description': doc}
-                    for command, doc in TelegramContact.get_commands()]
+        commands = [
+            {'command': command, 'description': doc}
+            for command, doc in TelegramContact.get_commands()
+        ]
         self.post('/setMyCommands', json={'commands': commands})
 
     results_emoji = {
@@ -633,11 +663,10 @@ class TelegramStatusBot(StatusBot):
         if short:
             return self.results_emoji[br]
         else:
-            return self.results_descriptions[br] + \
-                   self.results_emoji[br]
+            return self.results_descriptions[br] + self.results_emoji[br]
 
     def getContact(self, user, channel):
-        """ get a Contact instance for ``user`` on ``channel`` """
+        """get a Contact instance for ``user`` on ``channel``"""
         assert isinstance(user, dict), "user must be a dict provided by Telegram API"
         assert isinstance(channel, dict), "channel must be a dict provided by Telegram API"
 
@@ -647,8 +676,7 @@ class TelegramStatusBot(StatusBot):
             contact = self.contacts[(cid, uid)]
         except KeyError:
             valid = self.isValidUser(uid)
-            contact = self.contactClass(user=user,
-                                        channel=self.getChannel(channel, valid))
+            contact = self.contactClass(user=user, channel=self.getChannel(channel, valid))
             if valid:
                 self.contacts[(cid, uid)] = contact
         else:
@@ -696,8 +724,8 @@ class TelegramStatusBot(StatusBot):
                 if original_message:
                     try:
                         self.edit_keyboard(
-                            original_message['chat']['id'],
-                            original_message['message_id'])
+                            original_message['chat']['id'], original_message['message_id']
+                        )
                     except KeyError:
                         pass
             else:
@@ -763,8 +791,10 @@ class TelegramStatusBot(StatusBot):
             else:
                 ans = yield res.json()
                 if not ans.get('ok'):
-                    self.log(f"ERROR: cannot send Telegram request {path}: "
-                             f"[{res.code}] {ans.get('description')}")
+                    self.log(
+                        f"ERROR: cannot send Telegram request {path}: "
+                        f"[{res.code}] {ans.get('description')}"
+                    )
                     return None
                 return ans.get('result', True)
 
@@ -782,9 +812,15 @@ class TelegramStatusBot(StatusBot):
         return (yield self.post('/answerCallbackQuery', json=params))
 
     @defer.inlineCallbacks
-    def send_message(self, chat, message, parse_mode='Markdown',
-                     reply_to_message_id=None, reply_markup=None,
-                     **kwargs):
+    def send_message(
+        self,
+        chat,
+        message,
+        parse_mode='Markdown',
+        reply_to_message_id=None,
+        reply_markup=None,
+        **kwargs,
+    ):
         result = None
 
         message = message.strip()
@@ -867,8 +903,7 @@ class TelegramWebhookBot(TelegramStatusBot):
         content = bytes2unicode(content)
         content_type = request.getHeader(b'Content-Type')
         content_type = bytes2unicode(content_type)
-        if content_type is not None and \
-                content_type.startswith('application/json'):
+        if content_type is not None and content_type.startswith('application/json'):
             update = json.loads(content)
         else:
             raise ValueError(f'Unknown content type: {content_type}')
@@ -882,8 +917,7 @@ class TelegramWebhookBot(TelegramStatusBot):
         else:
             self.log(f"Setting up webhook to: {url} (custom certificate)")
             certificate = io.BytesIO(unicode2bytes(certificate))
-            yield self.post('/setWebhook', data={"url": url},
-                            files={"certificate": certificate})
+            yield self.post('/setWebhook', data={"url": url}, files={"certificate": certificate})
 
 
 class TelegramPollingBot(TelegramStatusBot):
@@ -915,9 +949,9 @@ class TelegramPollingBot(TelegramStatusBot):
             if offset:
                 kwargs['json']['offset'] = offset
             try:
-                res = yield self.http_client.post('/getUpdates',
-                                                  timeout=self.poll_timeout + 2,
-                                                  **kwargs)
+                res = yield self.http_client.post(
+                    '/getUpdates', timeout=self.poll_timeout + 2, **kwargs
+                )
                 ans = yield res.json()
                 if not ans.get('ok'):
                     raise ValueError(f"[{res.code}] {ans.get('description')}")
@@ -945,11 +979,19 @@ class TelegramBot(service.BuildbotService):
 
     in_test_harness = False
 
-    compare_attrs = ["bot_token", "chat_ids", "authz",
-                     "tags", "notify_events",
-                     "showBlameList", "useRevisions",
-                     "certificate", "useWebhook",
-                     "pollTimeout", "retryDelay"]
+    compare_attrs = [
+        "bot_token",
+        "chat_ids",
+        "authz",
+        "tags",
+        "notify_events",
+        "showBlameList",
+        "useRevisions",
+        "certificate",
+        "useWebhook",
+        "pollTimeout",
+        "retryDelay",
+    ]
     secrets = ["bot_token"]
 
     def __init__(self, *args, **kwargs):
@@ -958,14 +1000,23 @@ class TelegramBot(service.BuildbotService):
 
     def _get_http(self, bot_token):
         base_url = "https://api.telegram.org/bot" + bot_token
-        return httpclientservice.HTTPClientService.getService(
-            self.master, base_url)
+        return httpclientservice.HTTPClientService.getService(self.master, base_url)
 
-    def checkConfig(self, bot_token, chat_ids=None, authz=None,
-                    bot_username=None, tags=None, notify_events=None,
-                    showBlameList=True, useRevisions=False,
-                    useWebhook=False, certificate=None,
-                    pollTimeout=120, retryDelay=30):
+    def checkConfig(
+        self,
+        bot_token,
+        chat_ids=None,
+        authz=None,
+        bot_username=None,
+        tags=None,
+        notify_events=None,
+        showBlameList=True,
+        useRevisions=False,
+        useWebhook=False,
+        certificate=None,
+        pollTimeout=120,
+        retryDelay=30,
+    ):
         super().checkConfig(self.name)
 
         if authz is not None:
@@ -977,11 +1028,21 @@ class TelegramBot(service.BuildbotService):
             config.error("certificate file must be open in binary mode")
 
     @defer.inlineCallbacks
-    def reconfigService(self, bot_token, chat_ids=None, authz=None,
-                        bot_username=None, tags=None, notify_events=None,
-                        showBlameList=True, useRevisions=False,
-                        useWebhook=False, certificate=None,
-                        pollTimeout=120, retryDelay=30):
+    def reconfigService(
+        self,
+        bot_token,
+        chat_ids=None,
+        authz=None,
+        bot_username=None,
+        tags=None,
+        notify_events=None,
+        showBlameList=True,
+        useRevisions=False,
+        useWebhook=False,
+        certificate=None,
+        pollTimeout=120,
+        retryDelay=30,
+    ):
         # need to stash these so we can detect changes later
         self.bot_token = bot_token
         if chat_ids is None:
@@ -1008,19 +1069,31 @@ class TelegramBot(service.BuildbotService):
             self.removeService(self.bot)
 
         if not useWebhook:
-            self.bot = TelegramPollingBot(bot_token, http, chat_ids, authz,
-                                          tags=tags, notify_events=notify_events,
-                                          useRevisions=useRevisions,
-                                          showBlameList=showBlameList,
-                                          poll_timeout=self.pollTimeout,
-                                          retry_delay=self.retryDelay)
+            self.bot = TelegramPollingBot(
+                bot_token,
+                http,
+                chat_ids,
+                authz,
+                tags=tags,
+                notify_events=notify_events,
+                useRevisions=useRevisions,
+                showBlameList=showBlameList,
+                poll_timeout=self.pollTimeout,
+                retry_delay=self.retryDelay,
+            )
         else:
-            self.bot = TelegramWebhookBot(bot_token, http, chat_ids, authz,
-                                          tags=tags, notify_events=notify_events,
-                                          useRevisions=useRevisions,
-                                          showBlameList=showBlameList,
-                                          retry_delay=self.retryDelay,
-                                          certificate=self.certificate)
+            self.bot = TelegramWebhookBot(
+                bot_token,
+                http,
+                chat_ids,
+                authz,
+                tags=tags,
+                notify_events=notify_events,
+                useRevisions=useRevisions,
+                showBlameList=showBlameList,
+                retry_delay=self.retryDelay,
+                certificate=self.certificate,
+            )
         if bot_username is not None:
             self.bot.nickname = bot_username
         else:
