@@ -40,39 +40,62 @@ def getPreviousBuild(master, build):
 
 
 @defer.inlineCallbacks
-def getDetailsForBuildset(master, bsid, want_properties=False, want_steps=False,
-                          want_previous_build=False, want_logs=False, want_logs_content=False):
+def getDetailsForBuildset(
+    master,
+    bsid,
+    want_properties=False,
+    want_steps=False,
+    want_previous_build=False,
+    want_logs=False,
+    want_logs_content=False,
+):
     # Here we will do a bunch of data api calls on behalf of the reporters
     # We do try to make *some* calls in parallel with the help of gatherResults, but don't commit
     # to much in that. The idea is to do parallelism while keeping the code readable
     # and maintainable.
 
     # first, just get the buildset and all build requests for our buildset id
-    dl = [master.data.get(("buildsets", bsid)),
-          master.data.get(('buildrequests', ),
-                          filters=[resultspec.Filter('buildsetid', 'eq', [bsid])])]
+    dl = [
+        master.data.get(("buildsets", bsid)),
+        master.data.get(
+            ('buildrequests',), filters=[resultspec.Filter('buildsetid', 'eq', [bsid])]
+        ),
+    ]
     (buildset, breqs) = yield defer.gatherResults(dl)
     # next, get the bdictlist for each build request
-    dl = [master.data.get(("buildrequests", breq['buildrequestid'], 'builds'))
-          for breq in breqs]
+    dl = [master.data.get(("buildrequests", breq['buildrequestid'], 'builds')) for breq in breqs]
 
     builds = yield defer.gatherResults(dl)
     builds = flatten(builds, types=(list, UserList))
     if builds:
-        yield getDetailsForBuilds(master, buildset, builds, want_properties=want_properties,
-                                  want_steps=want_steps, want_previous_build=want_previous_build,
-                                  want_logs=want_logs,
-                                  want_logs_content=want_logs_content)
+        yield getDetailsForBuilds(
+            master,
+            buildset,
+            builds,
+            want_properties=want_properties,
+            want_steps=want_steps,
+            want_previous_build=want_previous_build,
+            want_logs=want_logs,
+            want_logs_content=want_logs_content,
+        )
 
     return {"buildset": buildset, "builds": builds}
 
 
 @defer.inlineCallbacks
-def getDetailsForBuild(master, build, want_properties=False, want_steps=False,
-                       want_previous_build=False, want_logs=False, want_logs_content=False):
+def getDetailsForBuild(
+    master,
+    build,
+    want_properties=False,
+    want_steps=False,
+    want_previous_build=False,
+    want_logs=False,
+    want_logs_content=False,
+):
     buildrequest = yield master.data.get(("buildrequests", build['buildrequestid']))
     buildset = yield master.data.get(("buildsets", buildrequest['buildsetid']))
-    build['buildrequest'], build['buildset'] = buildrequest, buildset
+    build['buildrequest'] = buildrequest
+    build['buildset'] = buildset
 
     parentbuild = None
     parentbuilder = None
@@ -82,11 +105,16 @@ def getDetailsForBuild(master, build, want_properties=False, want_steps=False,
     build['parentbuild'] = parentbuild
     build['parentbuilder'] = parentbuilder
 
-    ret = yield getDetailsForBuilds(master, buildset, [build],
-                                    want_properties=want_properties, want_steps=want_steps,
-                                    want_previous_build=want_previous_build,
-                                    want_logs=want_logs,
-                                    want_logs_content=want_logs_content)
+    ret = yield getDetailsForBuilds(
+        master,
+        buildset,
+        [build],
+        want_properties=want_properties,
+        want_steps=want_steps,
+        want_previous_build=want_previous_build,
+        want_logs=want_logs,
+        want_logs_content=want_logs_content,
+    )
     return ret
 
 
@@ -105,27 +133,33 @@ def get_details_for_buildrequest(master, buildrequest, build):
 
 
 @defer.inlineCallbacks
-def getDetailsForBuilds(master, buildset, builds, want_properties=False, want_steps=False,
-                        want_previous_build=False, want_logs=False, want_logs_content=False):
-
+def getDetailsForBuilds(
+    master,
+    buildset,
+    builds,
+    want_properties=False,
+    want_steps=False,
+    want_previous_build=False,
+    want_logs=False,
+    want_logs_content=False,
+):
     builderids = {build['builderid'] for build in builds}
 
-    builders = yield defer.gatherResults([master.data.get(("builders", _id))
-                                          for _id in builderids])
+    builders = yield defer.gatherResults([master.data.get(("builders", _id)) for _id in builderids])
 
-    buildersbyid = {builder['builderid']: builder
-                    for builder in builders}
+    buildersbyid = {builder['builderid']: builder for builder in builders}
 
     if want_properties:
-        buildproperties = yield defer.gatherResults(
-            [master.data.get(("builds", build['buildid'], 'properties'))
-             for build in builds])
+        buildproperties = yield defer.gatherResults([
+            master.data.get(("builds", build['buildid'], 'properties')) for build in builds
+        ])
     else:  # we still need a list for the big zip
         buildproperties = list(range(len(builds)))
 
     if want_previous_build:
-        prev_builds = yield defer.gatherResults(
-            [getPreviousBuild(master, build) for build in builds])
+        prev_builds = yield defer.gatherResults([
+            getPreviousBuild(master, build) for build in builds
+        ])
     else:  # we still need a list for the big zip
         prev_builds = list(range(len(builds)))
 
@@ -135,17 +169,18 @@ def getDetailsForBuilds(master, buildset, builds, want_properties=False, want_st
         want_steps = True
 
     if want_steps:  # pylint: disable=too-many-nested-blocks
-        buildsteps = yield defer.gatherResults(
-            [master.data.get(("builds", build['buildid'], 'steps'))
-             for build in builds])
+        buildsteps = yield defer.gatherResults([
+            master.data.get(("builds", build['buildid'], 'steps')) for build in builds
+        ])
         if want_logs:
             for build, build_steps in zip(builds, buildsteps):
                 for s in build_steps:
                     logs = yield master.data.get(("steps", s['stepid'], 'logs'))
                     s['logs'] = list(logs)
                     for l in s['logs']:
-                        l['url'] = get_url_for_log(master, build['builderid'], build['number'],
-                                                   s['number'], l['slug'])
+                        l['url'] = get_url_for_log(
+                            master, build['builderid'], build['number'], s['number'], l['slug']
+                        )
                         if want_logs_content:
                             l['content'] = yield master.data.get(("logs", l['logid'], 'contents'))
 
@@ -156,8 +191,7 @@ def getDetailsForBuilds(master, buildset, builds, want_properties=False, want_st
     for build, properties, steps, prev in zip(builds, buildproperties, buildsteps, prev_builds):
         build['builder'] = buildersbyid[build['builderid']]
         build['buildset'] = buildset
-        build['url'] = getURLForBuild(
-            master, build['builderid'], build['number'])
+        build['url'] = getURLForBuild(master, build['builderid'], build['number'])
 
         if want_properties:
             build['properties'] = properties
@@ -192,7 +226,7 @@ def getResponsibleUsersForSourceStamp(master, sourcestampid):
 def getResponsibleUsersForBuild(master, buildid):
     dl = [
         master.data.get(("builds", buildid, "changes")),
-        master.data.get(("builds", buildid, 'properties'))
+        master.data.get(("builds", buildid, 'properties')),
     ]
     changes, properties = yield defer.gatherResults(dl)
     blamelist = set()
@@ -208,8 +242,7 @@ def getResponsibleUsersForBuild(master, buildid):
             blamelist.add(owner)
         else:
             blamelist.update(owner)
-            log.msg(
-                f"Warning: owner property is a list for buildid {buildid}. ")
+            log.msg(f"Warning: owner property is a list for buildid {buildid}. ")
             log.msg(f"Please report a bug: changes: {changes}. properties: {properties}")
 
     # add owner from properties
@@ -221,6 +254,20 @@ def getResponsibleUsersForBuild(master, buildid):
     return blamelist
 
 
+# perhaps we need data api for users with buildsets/:id/users
+@defer.inlineCallbacks
+def get_responsible_users_for_buildset(master, buildsetid):
+    props = yield master.data.get(("buildsets", buildsetid, "properties"))
+
+    # TODO: This currently does not track what changes were in the buildset. getChangesForBuild()
+    # would walk the change graph until it finds last successful build and uses the authors of
+    # the changes as blame list. Probably this needs to be done here too
+    owner = props.get("owner", None)
+    if owner:
+        return [owner[0]]
+    return []
+
+
 def getURLForBuild(master, builderid, build_number):
     prefix = master.config.buildbotURL
     return prefix + f"#/builders/{builderid}/builds/{build_number}"
@@ -233,8 +280,10 @@ def getURLForBuildrequest(master, buildrequestid):
 
 def get_url_for_log(master, builderid, build_number, step_number, log_slug):
     prefix = master.config.buildbotURL
-    return f"{prefix}#/builders/{builderid}/builds/{build_number}/" + \
-        f"steps/{step_number}/logs/{log_slug}"
+    return (
+        f"{prefix}#/builders/{builderid}/builds/{build_number}/"
+        + f"steps/{step_number}/logs/{log_slug}"
+    )
 
 
 @renderer
