@@ -47,26 +47,110 @@ from buildbot.util import unicode2bytes
 # Used in command_HELLO and it's test. 'Hi' in 100 languages.
 
 GREETINGS = [
-    "ږغ كول ، هركلى كول ږغ، هركلى", "Goeie dag", "Tungjatjeta",
-    "Yatasay", "Ahlan bik", "Voghdzuyin", "hola", "kaixo", "Horas",
-    "Pryvitańnie", "Nomoskar", "Oki", "Selam", "Dez-mat", "Zdrávejte",
-    "Mingala ba", "Hola", "Hafa dai", "Oh-see-YOH", "Nín hao", "Bonjou",
-    "Zdravo", "Nazdar", "Hallo", "Hallo", "Iiti", "Kotáka", "Saluton", "Tere",
-    "Hallo", "Hallo", "Bula", "Helo", "Hei", "Goede morgen", "Bonjour", "Hoi",
-    "Ola", "Gamardžoba", "Guten Tag", "Mauri", "Geia!", "Inuugujoq", "Kem cho",
-    "Sannu", "Aloha", "Shalóm", "Namasté", "Szia", "Halló", "Hai", "Kiana",
-    "Dia is muire dhuit", "Buongiorno", "Kónnichi wa", "Salam",
-    "Annyeonghaseyo", "Na", "Sabai dii", "Ave", "Es mīlu tevi", "Labas.",
-    "Selamat petang", "Ni hao", "Kia ora", "Yokwe", "Kwe", "sain baina uu",
-    "niltze", "Yá'át'ééh", "Namaste", "Hallo.", "Salâm", "Witajcie", "Olá",
-    "Kâils", "Aroha", "Salut", "Privét", "Talofa", "Namo namah", "ćao",
-    "Nazdar", "Zdravo", "Hola", "Jambo", "Hej", "Sälü", "Halo", "Selam",
-    "Sàwàtdee kráp", "Dumela", "Merhaba", "Pryvít", "Adaab arz hai", "Chào",
-    "Glidis", "Helo", "Sawubona", "Hoi"]
+    "ږغ كول ، هركلى كول ږغ، هركلى",
+    "Goeie dag",
+    "Tungjatjeta",
+    "Yatasay",
+    "Ahlan bik",
+    "Voghdzuyin",
+    "hola",
+    "kaixo",
+    "Horas",
+    "Pryvitańnie",
+    "Nomoskar",
+    "Oki",
+    "Selam",
+    "Dez-mat",
+    "Zdrávejte",
+    "Mingala ba",
+    "Hola",
+    "Hafa dai",
+    "Oh-see-YOH",
+    "Nín hao",
+    "Bonjou",
+    "Zdravo",
+    "Nazdar",
+    "Hallo",
+    "Hallo",
+    "Iiti",
+    "Kotáka",
+    "Saluton",
+    "Tere",
+    "Hallo",
+    "Hallo",
+    "Bula",
+    "Helo",
+    "Hei",
+    "Goede morgen",
+    "Bonjour",
+    "Hoi",
+    "Ola",
+    "Gamardžoba",
+    "Guten Tag",
+    "Mauri",
+    "Geia!",
+    "Inuugujoq",
+    "Kem cho",
+    "Sannu",
+    "Aloha",
+    "Shalóm",
+    "Namasté",
+    "Szia",
+    "Halló",
+    "Hai",
+    "Kiana",
+    "Dia is muire dhuit",
+    "Buongiorno",
+    "Kónnichi wa",
+    "Salam",
+    "Annyeonghaseyo",
+    "Na",
+    "Sabai dii",
+    "Ave",
+    "Es mīlu tevi",
+    "Labas.",
+    "Selamat petang",
+    "Ni hao",
+    "Kia ora",
+    "Yokwe",
+    "Kwe",
+    "sain baina uu",
+    "niltze",
+    "Yá'át'ééh",
+    "Namaste",
+    "Hallo.",
+    "Salâm",
+    "Witajcie",
+    "Olá",
+    "Kâils",
+    "Aroha",
+    "Salut",
+    "Privét",
+    "Talofa",
+    "Namo namah",
+    "ćao",
+    "Nazdar",
+    "Zdravo",
+    "Hola",
+    "Jambo",
+    "Hej",
+    "Sälü",
+    "Halo",
+    "Selam",
+    "Sàwàtdee kráp",
+    "Dumela",
+    "Merhaba",
+    "Pryvít",
+    "Adaab arz hai",
+    "Chào",
+    "Glidis",
+    "Helo",
+    "Sawubona",
+    "Hoi",
+]
 
 
 class UsageError(ValueError):
-
     # pylint: disable=useless-super-delegation
     def __init__(self, string="Invalid usage", *more):
         # This is not useless as we change the default value of an argument.
@@ -84,10 +168,14 @@ class ForceOptions(usage.Options):
         ["revision", None, "HEAD", "which revision to build"],
         ["project", None, "", "which project to build"],
         ["reason", None, None, "the reason for starting the build"],
-        ["props", None, None,
-         "A set of properties made available in the build environment, "
-         "format is --properties=prop1=value1,prop2=value2,.. "
-         "option can be specified multiple times."],
+        [
+            "props",
+            None,
+            None,
+            "A set of properties made available in the build environment, "
+            "format is --properties=prop1=value1,prop2=value2,.. "
+            "option can be specified multiple times.",
+        ],
     ]
 
     def parseArgs(self, *args):
@@ -140,18 +228,22 @@ class Channel(service.AsyncService):
             yield self.unsubscribe_from_build_events()
 
     def validate_notification_event(self, event):
-        if not re.compile("^(started|finished|success|warnings|failure|exception|"
-                          "cancelled|problem|recovery|worse|better|worker|"
-                          # this is deprecated list
-                          "(success|warnings|failure|exception)To"
-                          "(Success|Warnings|Failure|Exception))$").match(event):
+        if not re.compile(
+            "^(started|finished|success|warnings|failure|exception|"
+            "cancelled|problem|recovery|worse|better|worker|"
+            # this is deprecated list
+            "(success|warnings|failure|exception)To"
+            "(Success|Warnings|Failure|Exception))$"
+        ).match(event):
             raise UsageError("Try '" + self.bot.commandPrefix + "notify on|off _EVENT_'.")
 
     @defer.inlineCallbacks
     def list_notified_events(self):
         if self.notify_events:
-            yield self.send('The following events are being notified: '
-                            f'{", ".join(sorted(self.notify_events))}.')
+            yield self.send(
+                'The following events are being notified: '
+                f'{", ".join(sorted(self.notify_events))}.'
+            )
         else:
             yield self.send("No events are being notified.")
 
@@ -178,8 +270,10 @@ class Channel(service.AsyncService):
                 return self.workerConnected(msg)
             return None
 
-        for e, f in (("new", buildStarted),             # BuilderStarted
-                     ("finished", buildFinished)):      # BuilderFinished
+        for e, f in (
+            ("new", buildStarted),  # BuilderStarted
+            ("finished", buildFinished),
+        ):  # BuilderFinished
             handle = yield startConsuming(f, ('builders', None, 'builds', None, e))
             self.subscribed.append(handle)
 
@@ -243,8 +337,7 @@ class Channel(service.AsyncService):
         log.msg(f"[Contact] Builder {builder['name']} started")
 
         # only notify about builders we are interested in
-        if (self.bot.tags is not None and
-                not self.builderMatchesAnyTag(builder.get('tags', []))):
+        if self.bot.tags is not None and not self.builderMatchesAnyTag(builder.get('tags', [])):
             log.msg('Not notifying for a build that does not match any tags')
             return
 
@@ -275,8 +368,7 @@ class Channel(service.AsyncService):
         buildNumber = build['number']
 
         # only notify about builders we are interested in
-        if (self.bot.tags is not None and
-                not self.bot.builderMatchesAnyTag(builder.get('tags', []))):
+        if self.bot.tags is not None and not self.bot.builderMatchesAnyTag(builder.get('tags', [])):
             log.msg('Not notifying for a build that does not match any tags')
             return
 
@@ -290,11 +382,15 @@ class Channel(service.AsyncService):
 
         if self.useRevisions:
             revisions = yield self.getRevisionsForBuild(build)
-            r = (f"Build on `{builderName}` containing revision(s) {','.join(revisions)} "
-                 f"{self.bot.format_build_status(build)}")
+            r = (
+                f"Build on `{builderName}` containing revision(s) {','.join(revisions)} "
+                f"{self.bot.format_build_status(build)}"
+            )
         else:
-            r = (f"Build [#{buildNumber}]({url}) of `{builderName}` "
-                 f"{self.bot.format_build_status(build)}")
+            r = (
+                f"Build [#{buildNumber}]({url}) of `{builderName}` "
+                f"{self.bot.format_build_status(build)}"
+            )
         s = build.get('status_string')
         if build['results'] != SUCCESS and s is not None:
             r += ": " + s
@@ -316,39 +412,47 @@ class Channel(service.AsyncService):
         if self.notify_for(result_name):
             return True
 
-        if result in self.bot.results_severity and \
-                (self.notify_for('better', 'worse', 'problem', 'recovery') or
-                 any('To' in e for e in self.notify_events)):
-            prev_build = yield self.master.data.get(
-                ('builders', build['builderid'], 'builds', build['number'] - 1))
+        if result in self.bot.results_severity and (
+            self.notify_for('better', 'worse', 'problem', 'recovery')
+            or any('To' in e for e in self.notify_events)
+        ):
+            prev_build = yield self.master.data.get((
+                'builders',
+                build['builderid'],
+                'builds',
+                build['number'] - 1,
+            ))
             if prev_build:
                 prev_result = prev_build['results']
 
                 if prev_result in self.bot.results_severity:
                     result_severity = self.bot.results_severity.index(result)
                     prev_result_severity = self.bot.results_severity.index(prev_result)
-                    if self.notify_for('better') and \
-                            result_severity < prev_result_severity:
+                    if self.notify_for('better') and result_severity < prev_result_severity:
                         return True
-                    if self.notify_for('worse') and \
-                            result_severity > prev_result_severity:
+                    if self.notify_for('worse') and result_severity > prev_result_severity:
                         return True
 
-                    if self.notify_for('problem') \
-                            and prev_result in (SUCCESS, WARNINGS) \
-                            and result in (FAILURE, EXCEPTION):
+                    if (
+                        self.notify_for('problem')
+                        and prev_result in (SUCCESS, WARNINGS)
+                        and result in (FAILURE, EXCEPTION)
+                    ):
                         return True
 
-                    if self.notify_for('recovery') \
-                            and prev_result in (FAILURE, EXCEPTION) \
-                            and result in (SUCCESS, WARNINGS):
+                    if (
+                        self.notify_for('recovery')
+                        and prev_result in (FAILURE, EXCEPTION)
+                        and result in (SUCCESS, WARNINGS)
+                    ):
                         return True
 
                     # DEPRECATED
-                    required_notification_control_string = ''.join(
-                        (statusToString(prev_result).lower(),
-                         'To',
-                         result_name.capitalize()))
+                    required_notification_control_string = ''.join((
+                        statusToString(prev_result).lower(),
+                        'To',
+                        result_name.capitalize(),
+                    ))
                     if self.notify_for(required_notification_control_string):
                         return True
 
@@ -358,8 +462,10 @@ class Channel(service.AsyncService):
     def workerMissing(self, worker):
         self.missing_workers.add(worker['workerid'])
         if self.notify_for('worker'):
-            self.send(f"Worker `{worker['name']}` is missing. It was seen last on "
-                      f"{worker['last_connection']}.")
+            self.send(
+                f"Worker `{worker['name']}` is missing. It was seen last on "
+                f"{worker['last_connection']}."
+            )
         yield self.bot.saveMissingWorkers()
 
     @defer.inlineCallbacks
@@ -460,12 +566,12 @@ class Contact:
 
         cmd_suffix = self.bot.commandSuffix
         if cmd_suffix and cmd.endswith(cmd_suffix):
-            cmd = cmd[:-len(cmd_suffix)]
+            cmd = cmd[: -len(cmd_suffix)]
 
         self.bot.log(f"Received command `{cmd}` from {self.describeUser()}")
 
         if cmd.startswith(self.bot.commandPrefix):
-            meth = self.getCommandMethod(cmd[len(self.bot.commandPrefix):])
+            meth = self.getCommandMethod(cmd[len(self.bot.commandPrefix) :])
         else:
             meth = None
 
@@ -526,8 +632,9 @@ class Contact:
             pass
 
         if not args:
-            raise UsageError("Try "
-                             f"'{self.bot.commandPrefix}list [all|N] builders|workers|changes'.")
+            raise UsageError(
+                "Try " f"'{self.bot.commandPrefix}list [all|N] builders|workers|changes'."
+            )
 
         if args[0] == 'builders':
             bdicts = yield self.bot.getAllBuilders()
@@ -558,10 +665,12 @@ class Contact:
 
         elif args[0] == 'changes':
             if all:
-                self.send("Do you really want me to list all changes? It can be thousands!\n"
-                          "If you want to be flooded, specify the maximum number of changes "
-                          "to show.\n"
-                          "Right now, I will show up to 100 recent changes.")
+                self.send(
+                    "Do you really want me to list all changes? It can be thousands!\n"
+                    "If you want to be flooded, specify the maximum number of changes "
+                    "to show.\n"
+                    "Right now, I will show up to 100 recent changes."
+                )
                 num = 100
             changes = yield self.master.data.get(('changes',), order=['-changeid'], limit=num)
 
@@ -575,11 +684,14 @@ class Contact:
                     f"Date: {change['date']}\n"
                     f"Repository: {change['repository']}\n"
                     f"Branch: {change['branch']}\n"
-                    f"Revision: {change['revision']}\n")
+                    f"Revision: {change['revision']}\n"
+                )
             self.send('\n\n'.join(response))
 
-    command_LIST.usage = "list [all|N] builders|workers|changes - " \
-                         "list configured builders, workers, or N recent changes"
+    command_LIST.usage = (
+        "list [all|N] builders|workers|changes - "
+        "list configured builders, workers, or N recent changes"
+    )
 
     @defer.inlineCallbacks
     def command_STATUS(self, args, **kwargs):
@@ -609,6 +721,7 @@ class Contact:
             response.append(status)
         if response:
             self.send('\n'.join(response))
+
     command_STATUS.usage = "status [_which_] - list status of a builder (or all builders)"
 
     @defer.inlineCallbacks
@@ -646,9 +759,11 @@ class Contact:
         else:
             raise UsageError("Try '" + self.bot.commandPrefix + "notify on|off|list [_EVENT_]'.")
 
-    command_NOTIFY.usage = ("notify on|off|list [_EVENT_] ... - notify me about build events;"
-                            "  event should be one or more of: 'started', 'finished', 'failure',"
-                            " 'success', 'exception', 'problem', 'recovery', 'better', or 'worse'")
+    command_NOTIFY.usage = (
+        "notify on|off|list [_EVENT_] ... - notify me about build events;"
+        "  event should be one or more of: 'started', 'finished', 'failure',"
+        " 'success', 'exception', 'problem', 'recovery', 'better', or 'worse'"
+    )
 
     @defer.inlineCallbacks
     def command_WATCH(self, args, **kwargs):
@@ -674,20 +789,23 @@ class Contact:
         for build in builds:
             startConsuming = self.master.mq.startConsuming
             handle = yield startConsuming(
-                watchForCompleteEvent,
-                ('builds', str(build['buildid']), None))
+                watchForCompleteEvent, ('builds', str(build['buildid']), None)
+            )
             self.channel.build_subscriptions.append((build['buildid'], handle))
 
             url = utils.getURLForBuild(self.master, builder['builderid'], build['number'])
 
             if self.bot.useRevisions:
                 revisions = yield self.bot.getRevisionsForBuild(build)
-                r = (f"Watching build on `{which}` containing revision(s) "
-                     f"{','.join(revisions)} until it finishes...")
+                r = (
+                    f"Watching build on `{which}` containing revision(s) "
+                    f"{','.join(revisions)} until it finishes..."
+                )
             else:
                 r = f"Watching build [#{build['number']}]({url}) of `{which}` until it finishes..."
 
             self.send(r)
+
     command_WATCH.usage = "watch _which_ - announce the completion of an active build"
 
     @defer.inlineCallbacks
@@ -745,8 +863,7 @@ class Contact:
 
             # set properties
             for pname, pvalue in pdict.items():
-                if not pname_validate.match(pname) \
-                        or not pval_validate.match(pvalue):
+                if not pname_validate.match(pname) or not pval_validate.match(pvalue):
                     self.bot.log(f"Force: bad property name='{pname}', value='{pvalue}'")
                     self.send(f"Sorry, bad property name='{pname}', value='{pvalue}'")
                     return
@@ -757,25 +874,34 @@ class Contact:
 
         reason = f"forced: by {self.describeUser()}: {reason}"
         try:
-            yield self.master.data.updates.addBuildset(builderids=[builder['builderid']],
-                                                       # For now, we just use
-                                                       # this as the id.
-                                                       scheduler="status.words",
-                                                       sourcestamps=[{
-                                                           'codebase': codebase, 'branch': branch,
-                                                           'revision': revision, 'project': project,
-                                                           'repository': ""}],
-                                                       reason=reason,
-                                                       properties=properties.asDict(),
-                                                       waited_for=False)
+            yield self.master.data.updates.addBuildset(
+                builderids=[builder['builderid']],
+                # For now, we just use
+                # this as the id.
+                scheduler="status.words",
+                sourcestamps=[
+                    {
+                        'codebase': codebase,
+                        'branch': branch,
+                        'revision': revision,
+                        'project': project,
+                        'repository': "",
+                    }
+                ],
+                reason=reason,
+                properties=properties.asDict(),
+                waited_for=False,
+            )
         except AssertionError as e:
             self.send("I can't: " + str(e))
         else:
             self.send("Force build successfully requested.")
 
-    command_FORCE.usage = ("force build [--codebase=CODEBASE] [--branch=branch] "
-                           "[--revision=revision] [--props=prop1=val1,prop2=val2...] "
-                           "_which_ _reason_ - Force a build")
+    command_FORCE.usage = (
+        "force build [--codebase=CODEBASE] [--branch=branch] "
+        "[--revision=revision] [--props=prop1=val1,prop2=val2...] "
+        "_which_ _reason_ - Force a build"
+    )
 
     @defer.inlineCallbacks
     @dangerousCommand
@@ -801,8 +927,9 @@ class Contact:
         for bdict in builds:
             num = bdict['number']
 
-            yield self.master.data.control('stop', {'reason': r},
-                                           ('builders', builderid, 'builds', num))
+            yield self.master.data.control(
+                'stop', {'reason': r}, ('builders', builderid, 'builds', num)
+            )
             if self.bot.useRevisions:
                 revisions = yield self.bot.getRevisionsForBuild(bdict)
                 response = f"Build containing revision(s) {','.join(revisions)} interrupted"
@@ -845,8 +972,7 @@ class Contact:
                 complete_at = lastBuild['complete_at']
                 if complete_at:
                     complete_at = util.datetime2epoch(complete_at)
-                    ago = util.fuzzyInterval(int(reactor.seconds() -
-                                                 complete_at))
+                    ago = util.fuzzyInterval(int(reactor.seconds() - complete_at))
                 else:
                     ago = "??"
                 status = self.bot.format_build_status(lastBuild)
@@ -891,7 +1017,7 @@ class Contact:
             return
         command = args[0]
         if command.startswith(self.bot.commandPrefix):
-            command = command[len(self.bot.commandPrefix):]
+            command = command[len(self.bot.commandPrefix) :]
         meth = getattr(self, 'command_' + command.upper(), None)
         if not meth:
             raise UsageError(f"There is no such command '{args[0]}'.")
@@ -912,15 +1038,17 @@ class Contact:
         if doc:
             self.send(f"Usage: {self.bot.commandPrefix}{doc}")
         else:
-            self.send(
-                "No usage info for " + ' '.join([f"'{arg}'" for arg in args]))
-    command_HELP.usage = ("help [_command_ _arg_ [_subarg_ ...]] - "
-                          "Give help for _command_ or one of it's arguments")
+            self.send("No usage info for " + ' '.join([f"'{arg}'" for arg in args]))
+
+    command_HELP.usage = (
+        "help [_command_ _arg_ [_subarg_ ...]] - "
+        "Give help for _command_ or one of it's arguments"
+    )
 
     def command_SOURCE(self, args, **kwargs):
         "the source code for buildbot"
-        self.send("My source can be found at "
-                  "https://github.com/buildbot/buildbot")
+        self.send("My source can be found at https://github.com/buildbot/buildbot")
+
     command_SOURCE.usage = "source - the source code for Buildbot"
 
     def command_COMMANDS(self, args, **kwargs):
@@ -928,6 +1056,7 @@ class Contact:
         commands = self.build_commands()
         str = "Buildbot commands: " + ", ".join(self.bot.commandPrefix + c for c in commands)
         self.send(str)
+
     command_COMMANDS.usage = "commands - List available commands"
 
     @dangerousCommand
@@ -960,16 +1089,18 @@ class Contact:
         elif args == 'now':
             self.send("Stopping buildbot.")
             reactor.stop()
+
     command_SHUTDOWN.usage = {
         None: "shutdown check|start|stop|now - shutdown the buildbot master",
         "check": "shutdown check - check if the buildbot master is running or shutting down",
         "start": "shutdown start - start a clean shutdown",
         "stop": "shutdown cancel - stop the clean shutdown",
-        "now": "shutdown now - shutdown immediately without waiting for the builders to finish"}
+        "now": "shutdown now - shutdown immediately without waiting for the builders to finish",
+    }
 
 
 class StatusBot(service.AsyncMultiService):
-    """ Abstract status bot """
+    """Abstract status bot"""
 
     contactClass = Contact
     channelClass = Channel
@@ -981,8 +1112,9 @@ class StatusBot(service.AsyncMultiService):
     idle_string = "idle"
     running_string = "running:"
 
-    def __init__(self, authz=None, tags=None, notify_events=None,
-                 useRevisions=False, showBlameList=False):
+    def __init__(
+        self, authz=None, tags=None, notify_events=None, useRevisions=False, showBlameList=False
+    ):
         super().__init__()
         self.tags = tags
         if notify_events is None:
@@ -1008,21 +1140,18 @@ class StatusBot(service.AsyncMultiService):
 
     def isValidUser(self, user):
         for auth in self.authz.values():
-            if auth is True \
-                    or (isinstance(auth, (list, tuple)) and user in auth)\
-                    or user == auth:
+            if auth is True or (isinstance(auth, (list, tuple)) and user in auth) or user == auth:
                 return True
         # If user is in '', we have already returned; otherwise check if defaults apply
         return '' not in self.authz
 
     def getContact(self, user, channel):
-        """ get a Contact instance for ``user`` on ``channel`` """
+        """get a Contact instance for ``user`` on ``channel``"""
         try:
             return self.contacts[(channel, user)]
         except KeyError:
             valid = self.isValidUser(user)
-            new_contact = self.contactClass(user=user,
-                                            channel=self.getChannel(channel, valid))
+            new_contact = self.contactClass(user=user, channel=self.getChannel(channel, valid))
             if valid:
                 self.contacts[(channel, user)] = new_contact
             return new_contact
@@ -1039,14 +1168,21 @@ class StatusBot(service.AsyncMultiService):
 
     def _get_object_id(self):
         return self.master.db.state.getObjectId(
-            self.nickname, f'{self.__class__.__module__}.{self.__class__.__name__}')
+            self.nickname, f'{self.__class__.__module__}.{self.__class__.__name__}'
+        )
 
     @defer.inlineCallbacks
     def _save_channels_state(self, attr, json_type=None):
         if json_type is None:
             json_type = lambda x: x
-        data = [(k, v) for k, v in ((channel.id, json_type(getattr(channel, attr)))
-                                    for channel in self.channels.values()) if v]
+        data = [
+            (k, v)
+            for k, v in (
+                (channel.id, json_type(getattr(channel, attr)))
+                for channel in self.channels.values()
+            )
+            if v
+        ]
         try:
             objectid = yield self._get_object_id()
             yield self.master.db.state.setState(objectid, attr, data)
@@ -1104,17 +1240,25 @@ class StatusBot(service.AsyncMultiService):
         return any(tag for tag in builder_tags if tag in self.tags)
 
     def getRunningBuilds(self, builderid):
-        d = self.master.data.get(('builds',),
-                                 filters=[resultspec.Filter('builderid', 'eq', [builderid]),
-                                          resultspec.Filter('complete', 'eq', [False])])
+        d = self.master.data.get(
+            ('builds',),
+            filters=[
+                resultspec.Filter('builderid', 'eq', [builderid]),
+                resultspec.Filter('complete', 'eq', [False]),
+            ],
+        )
         return d
 
     def getLastCompletedBuild(self, builderid):
-        d = self.master.data.get(('builds',),
-                                 filters=[resultspec.Filter('builderid', 'eq', [builderid]),
-                                          resultspec.Filter('complete', 'eq', [True])],
-                                 order=['-number'],
-                                 limit=1)
+        d = self.master.data.get(
+            ('builds',),
+            filters=[
+                resultspec.Filter('builderid', 'eq', [builderid]),
+                resultspec.Filter('complete', 'eq', [True]),
+            ],
+            order=['-number'],
+            limit=1,
+        )
 
         @d.addCallback
         def listAsOneOrNone(res):
@@ -1125,11 +1269,12 @@ class StatusBot(service.AsyncMultiService):
         return d
 
     def getCurrentBuildstep(self, build):
-        d = self.master.data.get(('builds', build['buildid'], 'steps'),
-                                 filters=[
-                                     resultspec.Filter('complete', 'eq', [False])],
-                                 order=['number'],
-                                 limit=1)
+        d = self.master.data.get(
+            ('builds', build['buildid'], 'steps'),
+            filters=[resultspec.Filter('complete', 'eq', [False])],
+            order=['number'],
+            limit=1,
+        )
         return d
 
     @defer.inlineCallbacks
@@ -1150,8 +1295,7 @@ class StatusBot(service.AsyncMultiService):
                     complete_at = lastBuild['complete_at']
                     if complete_at:
                         complete_at = util.datetime2epoch(complete_at)
-                        ago = util.fuzzyInterval(int(reactor.seconds() -
-                                                     complete_at))
+                        ago = util.fuzzyInterval(int(reactor.seconds() - complete_at))
                     else:
                         ago = "??"
                     status = self.format_build_status(lastBuild, short=short)
@@ -1184,9 +1328,9 @@ class StatusBot(service.AsyncMultiService):
     @defer.inlineCallbacks
     def getBuilder(self, buildername=None, builderid=None):
         if buildername:
-            bdicts = yield self.master.data.get(('builders',),
-                                                filters=[resultspec.Filter('name', 'eq',
-                                                                           [buildername])])
+            bdicts = yield self.master.data.get(
+                ('builders',), filters=[resultspec.Filter('name', 'eq', [buildername])]
+            )
             if bdicts:
                 # Could there be more than one? One is enough.
                 bdict = bdicts[0]
@@ -1238,12 +1382,10 @@ class StatusBot(service.AsyncMultiService):
         CANCELLED: "was cancelled",
     }
 
-    results_severity = (
-        SKIPPED, SUCCESS, WARNINGS, FAILURE, CANCELLED, EXCEPTION
-    )
+    results_severity = (SKIPPED, SUCCESS, WARNINGS, FAILURE, CANCELLED, EXCEPTION)
 
     def format_build_status(self, build, short=False):
-        """ Optionally add color to the message """
+        """Optionally add color to the message"""
         return self.results_descriptions[build['results']]
 
 
