@@ -15,12 +15,12 @@
 
 
 from twisted.internet import defer
+from twisted.logger import Logger
 
 from buildbot import config
 from buildbot.reporters.base import ReporterBase
 from buildbot.reporters.generators.build import BuildStartEndStatusGenerator
 from buildbot.util import httpclientservice
-from buildbot.util.logger import Logger
 
 log = Logger()
 
@@ -43,8 +43,8 @@ class ZulipStatusPush(ReporterBase):
         self.verify = verify
         yield super().reconfigService(generators=[BuildStartEndStatusGenerator()])
         self._http = yield httpclientservice.HTTPClientService.getService(
-            self.master, endpoint,
-            debug=self.debug, verify=self.verify)
+            self.master, endpoint, debug=self.debug, verify=self.verify
+        )
         self.token = token
         self.stream = stream
 
@@ -52,8 +52,13 @@ class ZulipStatusPush(ReporterBase):
     def sendMessage(self, reports):
         build = reports[0]['builds'][0]
         event = ("new", "finished")[0 if build["complete"] is False else 1]
-        jsondata = dict(event=event, buildid=build["buildid"], buildername=build["builder"]["name"],
-                        url=build["url"], project=build["properties"]["project"][0])
+        jsondata = {
+            "event": event,
+            "buildid": build["buildid"],
+            "buildername": build["builder"]["name"],
+            "url": build["url"],
+            "project": build["properties"]["project"][0],
+        }
         if event == "new":
             jsondata["timestamp"] = int(build["started_at"].timestamp())
         elif event == "finished":
@@ -66,5 +71,8 @@ class ZulipStatusPush(ReporterBase):
         response = yield self._http.post(url, json=jsondata)
         if response.code != 200:
             content = yield response.content()
-            log.error("{code}: Error pushing build status to Zulip: {content}", code=response.code,
-                      content=content)
+            log.error(
+                "{code}: Error pushing build status to Zulip: {content}",
+                code=response.code,
+                content=content,
+            )
