@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-import copy
-
 from twisted.internet import defer
 from twisted.python import failure
 from twisted.python import log
@@ -26,19 +24,19 @@ from buildbot.changes import changes
 from buildbot.process.properties import Properties
 from buildbot.util.service import ClusteredBuildbotService
 from buildbot.util.state import StateMixin
-from buildbot.warnings import warn_deprecated
 
 
 @implementer(interfaces.IScheduler)
 class BaseScheduler(ClusteredBuildbotService, StateMixin):
-
     DEFAULT_CODEBASES = {'': {}}
 
-    compare_attrs = ClusteredBuildbotService.compare_attrs + \
-        ('builderNames', 'properties', 'codebases')
+    compare_attrs = ClusteredBuildbotService.compare_attrs + (
+        'builderNames',
+        'properties',
+        'codebases',
+    )
 
-    def __init__(self, name, builderNames, properties=None, codebases=None,
-                 priority=None):
+    def __init__(self, name, builderNames, properties=None, codebases=None, priority=None):
         super().__init__(name=name)
         if codebases is None:
             codebases = self.DEFAULT_CODEBASES.copy()
@@ -48,8 +46,7 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
             pass
         elif isinstance(builderNames, (list, tuple)):
             for b in builderNames:
-                if not isinstance(b, str) and \
-                        not interfaces.IRenderable.providedBy(b):
+                if not isinstance(b, str) and not interfaces.IRenderable.providedBy(b):
                     ok = False
         else:
             ok = False
@@ -57,7 +54,8 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
             config.error(
                 "The builderNames argument to a scheduler must be a list "
                 "of Builder names or an IRenderable object that will render"
-                "to a list of builder names.")
+                "to a list of builder names."
+            )
 
         self.builderNames = builderNames
 
@@ -77,8 +75,7 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
         elif isinstance(codebases, list):
             codebases = dict((codebase, {}) for codebase in codebases)
         elif not isinstance(codebases, dict):
-            config.error(
-                "Codebases must be a dict of dicts, or list of strings")
+            config.error("Codebases must be a dict of dicts, or list of strings")
         else:
             for codebase, attrs in codebases.items():
                 if not isinstance(attrs, dict):
@@ -86,8 +83,9 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
                 else:
                     unk = set(attrs) - known_keys
                     if unk:
-                        config.error(f"Unknown codebase keys {', '.join(unk)} "
-                                     f"for codebase {codebase}")
+                        config.error(
+                            f"Unknown codebase keys {', '.join(unk)} for codebase {codebase}"
+                        )
 
         self.codebases = codebases
 
@@ -98,8 +96,10 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
 
         self.enabled = True
         if priority and not isinstance(priority, int) and not callable(priority):
-            config.error(f"Invalid type for priority: {type(priority)}. "
-                         "It must either be an integer or a function")
+            config.error(
+                f"Invalid type for priority: {type(priority)}. "
+                "It must either be an integer or a function"
+            )
         self.priority = priority
 
     def __repr__(self):
@@ -163,12 +163,10 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
         return self.master.db.schedulers.getScheduler(sid)
 
     def _claimService(self):
-        return self.master.data.updates.trySetSchedulerMaster(self.serviceid,
-                                                              self.master.masterid)
+        return self.master.data.updates.trySetSchedulerMaster(self.serviceid, self.master.masterid)
 
     def _unclaimService(self):
-        return self.master.data.updates.trySetSchedulerMaster(self.serviceid,
-                                                              None)
+        return self.master.data.updates.trySetSchedulerMaster(self.serviceid, None)
 
     # status queries
 
@@ -180,28 +178,25 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
     # change handling
 
     @defer.inlineCallbacks
-    def startConsumingChanges(self, fileIsImportant=None, change_filter=None,
-                              onlyImportant=False):
+    def startConsumingChanges(self, fileIsImportant=None, change_filter=None, onlyImportant=False):
         assert fileIsImportant is None or callable(fileIsImportant)
 
         # register for changes with the data API
         assert not self._change_consumer
         self._change_consumer = yield self.master.mq.startConsuming(
-            lambda k, m: self._changeCallback(k, m, fileIsImportant,
-                                              change_filter, onlyImportant),
-            ('changes', None, 'new'))
+            lambda k, m: self._changeCallback(k, m, fileIsImportant, change_filter, onlyImportant),
+            ('changes', None, 'new'),
+        )
 
     @defer.inlineCallbacks
     def startConsumingEnableEvents(self):
         assert not self._enable_consumer
         self._enable_consumer = yield self.master.mq.startConsuming(
-            self._enabledCallback,
-            ('schedulers', str(self.serviceid), 'updated'))
+            self._enabledCallback, ('schedulers', str(self.serviceid), 'updated')
+        )
 
     @defer.inlineCallbacks
-    def _changeCallback(self, key, msg, fileIsImportant, change_filter,
-                        onlyImportant):
-
+    def _changeCallback(self, key, msg, fileIsImportant, change_filter, onlyImportant):
         # ignore changes delivered while we're not running
         if not self._change_consumer:
             return
@@ -211,46 +206,16 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
         change = yield changes.Change.fromChdict(self.master, chdict)
 
         # filter it
-        if change_filter:
-            # There has been a change in how Gerrit handles branches in Buildbot 3.5 - ref-updated
-            # events will now emit proper branch instead of refs/heads/<branch>. Below we detect
-            # whether this breaks change filters.
-            change_filter_may_be_broken = \
-                change.category == 'ref-updated' and not change.branch.startswith('refs/')
-
-            if change_filter_may_be_broken:
-                old_change = copy.deepcopy(change)
-                old_change.branch = f'refs/heads/{old_change.branch}'
-
-                old_filter_result = change_filter.filter_change(old_change)
-                new_filter_result = change_filter.filter_change(change)
-
-                def has_deprecated_ref_branch_filter():
-                    for filter in change_filter.filters:
-                        if filter.prop == 'branch':
-                            if 'refs/heads/' in filter.describe():
-                                return True
-
-                    return False
-
-                if old_filter_result != new_filter_result and has_deprecated_ref_branch_filter():
-                    warn_deprecated('3.5.0',
-                                    'Change filters must not expect ref-updated events from '
-                                    'Gerrit to include refs/heads prefix for the branch attr.')
-
-                    if not old_filter_result:
-                        return
-                else:
-                    if not new_filter_result:
-                        return
-            else:
-                if not change_filter.filter_change(change):
-                    return
+        if change_filter and not change_filter.filter_change(change):
+            return
 
         if change.codebase not in self.codebases:
-            log.msg(format='change contains codebase %(codebase)s that is '
-                    'not processed by scheduler %(name)s',
-                    codebase=change.codebase, name=self.name)
+            log.msg(
+                format='change contains codebase %(codebase)s that is '
+                'not processed by scheduler %(name)s',
+                codebase=change.codebase,
+                name=self.name,
+            )
             return
 
         if fileIsImportant:
@@ -266,8 +231,7 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
 
         # use change_consumption_lock to ensure the service does not stop
         # while this change is being processed
-        d = self._change_consumption_lock.run(
-            self.gotChange, change, important)
+        d = self._change_consumption_lock.run(self.gotChange, change, important)
         d.addErrback(log.err, 'while processing change')
 
     def _stopConsumingChanges(self):
@@ -279,6 +243,7 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
             if self._change_consumer:
                 self._change_consumer.stopConsuming()
                 self._change_consumer = None
+
         return self._change_consumption_lock.run(stop)
 
     def gotChange(self, change, important):
@@ -287,9 +252,16 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
     # starting builds
 
     @defer.inlineCallbacks
-    def addBuildsetForSourceStampsWithDefaults(self, reason, sourcestamps=None,
-                                               waited_for=False, properties=None, builderNames=None,
-                                               priority=None, **kw):
+    def addBuildsetForSourceStampsWithDefaults(
+        self,
+        reason,
+        sourcestamps=None,
+        waited_for=False,
+        properties=None,
+        builderNames=None,
+        priority=None,
+        **kw,
+    ):
         if sourcestamps is None:
             sourcestamps = []
 
@@ -332,9 +304,14 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
             stampsWithDefaults.append(ss)
 
         rv = yield self.addBuildsetForSourceStamps(
-            sourcestamps=stampsWithDefaults, reason=reason,
-            waited_for=waited_for, properties=properties,
-            builderNames=builderNames, priority=priority, **kw)
+            sourcestamps=stampsWithDefaults,
+            reason=reason,
+            waited_for=waited_for,
+            properties=properties,
+            builderNames=builderNames,
+            priority=priority,
+            **kw,
+        )
         return rv
 
     def getCodebaseDict(self, codebase):
@@ -346,10 +323,17 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
             return defer.fail()
 
     @defer.inlineCallbacks
-    def addBuildsetForChanges(self, waited_for=False, reason='',
-                              external_idstring=None, changeids=None, builderNames=None,
-                              properties=None, priority=None,
-                              **kw):
+    def addBuildsetForChanges(
+        self,
+        waited_for=False,
+        reason='',
+        external_idstring=None,
+        changeids=None,
+        builderNames=None,
+        properties=None,
+        priority=None,
+        **kw,
+    ):
         if changeids is None:
             changeids = []
         changesByCodebase = {}
@@ -391,16 +375,30 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
 
         # add one buildset, using the calculated sourcestamps
         bsid, brids = yield self.addBuildsetForSourceStamps(
-            waited_for, sourcestamps=sourcestamps, reason=reason,
-            external_idstring=external_idstring, builderNames=builderNames,
-            properties=properties, priority=priority, **kw)
+            waited_for,
+            sourcestamps=sourcestamps,
+            reason=reason,
+            external_idstring=external_idstring,
+            builderNames=builderNames,
+            properties=properties,
+            priority=priority,
+            **kw,
+        )
 
         return (bsid, brids)
 
     @defer.inlineCallbacks
-    def addBuildsetForSourceStamps(self, waited_for=False, sourcestamps=None,
-                                   reason='', external_idstring=None, properties=None,
-                                   builderNames=None, priority=None, **kw):
+    def addBuildsetForSourceStamps(
+        self,
+        waited_for=False,
+        sourcestamps=None,
+        reason='',
+        external_idstring=None,
+        properties=None,
+        builderNames=None,
+        priority=None,
+        **kw,
+    ):
         if sourcestamps is None:
             sourcestamps = []
         # combine properties
@@ -419,10 +417,10 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
         for ss in sourcestamps:
             if isinstance(ss, int):
                 # fetch actual sourcestamp and changes from data API
-                properties.sourcestamps.append(
-                    (yield self.master.data.get(('sourcestamps', ss))))
+                properties.sourcestamps.append((yield self.master.data.get(('sourcestamps', ss))))
                 properties.changes.extend(
-                    (yield self.master.data.get(('sourcestamps', ss, 'changes'))))
+                    (yield self.master.data.get(('sourcestamps', ss, 'changes')))
+                )
             else:
                 # sourcestamp with no change, see addBuildsetForChanges
                 properties.sourcestamps.append(ss)
@@ -443,7 +441,7 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
         # probably the multiple builder case will be severely impacted by the
         # several db requests needed.
         builderids = []
-        for bldr in (yield self.master.data.get(('builders', ))):
+        for bldr in (yield self.master.data.get(('builders',))):
             if bldr['name'] in builderNames:
                 builderids.append(bldr['builderid'])
 
@@ -455,7 +453,14 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
             priority = 0
 
         bsid, brids = yield self.master.data.updates.addBuildset(
-            scheduler=self.name, sourcestamps=sourcestamps, reason=reason,
-            waited_for=waited_for, properties=properties_dict, builderids=builderids,
-            external_idstring=external_idstring, priority=priority, **kw)
+            scheduler=self.name,
+            sourcestamps=sourcestamps,
+            reason=reason,
+            waited_for=waited_for,
+            properties=properties_dict,
+            builderids=builderids,
+            external_idstring=external_idstring,
+            priority=priority,
+            **kw,
+        )
         return (bsid, brids)
