@@ -16,7 +16,6 @@
 import os
 
 import jinja2
-
 from twisted.internet import defer
 from twisted.python import util
 
@@ -68,8 +67,7 @@ def makeSampleConfig(config):
     with open(source, "rt", encoding='utf-8') as f:
         config_sample = f.read()
     if config['db']:
-        config_sample = config_sample.replace('sqlite:///state.sqlite',
-                                              config['db'])
+        config_sample = config_sample.replace('sqlite:///state.sqlite', config['db'])
     with open(target, "wt", encoding='utf-8') as f:
         f.write(config_sample)
     os.chmod(target, 0o600)
