@@ -22,7 +22,6 @@ import traceback
 from twisted.internet import defer
 from twisted.python import util
 
-from buildbot import monkeypatches
 from buildbot.db import connector
 from buildbot.master import BuildMaster
 from buildbot.scripts import base
@@ -31,29 +30,29 @@ from buildbot.util import stripUrlPassword
 
 
 def installFile(config, target, source, overwrite=False):
-    with open(source, "rt") as f:
+    with open(source, "rt", encoding='utf-8') as f:
         new_contents = f.read()
     if os.path.exists(target):
-        with open(target, "rt") as f:
+        with open(target, "rt", encoding='utf-8') as f:
             old_contents = f.read()
         if old_contents != new_contents:
             if overwrite:
                 if not config['quiet']:
-                    print("{} has old/modified contents".format(target))
+                    print(f"{target} has old/modified contents")
                     print(" overwriting it with new contents")
-                with open(target, "wt") as f:
+                with open(target, "wt", encoding='utf-8') as f:
                     f.write(new_contents)
             else:
                 if not config['quiet']:
-                    print("{} has old/modified contents".format(target))
-                    print(" writing new contents to {}.new".format(target))
-                with open(target + ".new", "wt") as f:
+                    print(f"{target} has old/modified contents")
+                    print(f" writing new contents to {target}.new")
+                with open(target + ".new", "wt", encoding='utf-8') as f:
                     f.write(new_contents)
         # otherwise, it's up to date
     else:
         if not config['quiet']:
-            print("creating {}".format(target))
-        with open(target, "wt") as f:
+            print(f"creating {target}")
+        with open(target, "wt", encoding='utf-8') as f:
             f.write(new_contents)
 
 
@@ -64,31 +63,35 @@ def upgradeFiles(config):
     webdir = os.path.join(config['basedir'], "public_html")
     if os.path.exists(webdir):
         print("Notice: public_html is not used starting from Buildbot 0.9.0")
-        print("        consider using third party HTTP server for serving "
-              "static files")
+        print("        consider using third party HTTP server for serving static files")
 
-    installFile(config, os.path.join(config['basedir'], "master.cfg.sample"),
-                util.sibpath(__file__, "sample.cfg"), overwrite=True)
+    installFile(
+        config,
+        os.path.join(config['basedir'], "master.cfg.sample"),
+        util.sibpath(__file__, "sample.cfg"),
+        overwrite=True,
+    )
 
 
 @defer.inlineCallbacks
 def upgradeDatabase(config, master_cfg):
     if not config['quiet']:
-        print("upgrading database ({})".format(stripUrlPassword(master_cfg.db['db_url'])))
+        print(f"upgrading database ({stripUrlPassword(master_cfg.db['db_url'])})")
         print("Warning: Stopping this process might cause data loss")
 
     def sighandler(signum, frame):
-        msg = " ".join("""
+        msg = " ".join(
+            """
         WARNING: ignoring signal {}.
         This process should not be interrupted to avoid database corruption.
         If you really need to terminate it, use SIGKILL.
-        """.split())
+        """.split()
+        )
         print(msg.format(signum))
 
     prev_handlers = {}
     try:
-        for signame in ("SIGTERM", "SIGINT", "SIGQUIT", "SIGHUP",
-                        "SIGUSR1", "SIGUSR2", "SIGBREAK"):
+        for signame in ("SIGTERM", "SIGINT", "SIGQUIT", "SIGHUP", "SIGUSR1", "SIGUSR2", "SIGBREAK"):
             if hasattr(signal, signame):
                 signum = getattr(signal, signame)
                 prev_handlers[signum] = signal.signal(signum, sighandler)
@@ -109,10 +112,7 @@ def upgradeDatabase(config, master_cfg):
 
 
 @in_reactor
-def upgradeMaster(config, _noMonkey=False):
-    if not _noMonkey:  # pragma: no cover
-        monkeypatches.patch_all()
-
+def upgradeMaster(config):
     if not base.checkBasedir(config):
         return defer.succeed(1)
 
@@ -121,7 +121,7 @@ def upgradeMaster(config, _noMonkey=False):
     try:
         configFile = base.getConfigFileFromTac(config['basedir'])
     except (SyntaxError, ImportError):
-        print("Unable to load 'buildbot.tac' from '{}':".format(config['basedir'], file=sys.stderr))
+        print(f"Unable to load 'buildbot.tac' from '{config['basedir']}':", file=sys.stderr)
         e = traceback.format_exc()
         print(e, file=sys.stderr)
         return defer.succeed(1)
@@ -133,7 +133,6 @@ def upgradeMaster(config, _noMonkey=False):
 
 @defer.inlineCallbacks
 def _upgradeMaster(config, master_cfg):
-
     try:
         upgradeFiles(config)
         yield upgradeDatabase(config, master_cfg)
