@@ -13,35 +13,34 @@
 #
 # Portions Copyright Buildbot Team Members
 # Portions Copyright Marius Rieder <marius.rieder@durchmesser.ch>
-"""
-Steps and objects related to mock building.
-"""
 
 
 import re
 
+from twisted.internet import defer
+
 from buildbot import config
+from buildbot.process import buildstep
 from buildbot.process import logobserver
-from buildbot.process import remotecommand
-from buildbot.steps.shell import ShellCommand
 
 
 class MockStateObserver(logobserver.LogLineObserver):
-    _line_re = re.compile(r'^.*State Changed: (.*)$')
+    """Supports reading state changes from Mock state.log from mock version
+    1.1.23."""
+
+    _line_re = re.compile(r'^.*(Start|Finish): (.*)$')
 
     def outLineReceived(self, line):
         m = self._line_re.search(line.strip())
         if m:
-            state = m.group(1)
-            if not state == 'end':
-                self.step.descriptionSuffix = ["[{}]".format(m.group(1))]
+            if m.group(1) == "Start":
+                self.step.descriptionSuffix = [f"[{m.group(2)}]"]
             else:
                 self.step.descriptionSuffix = None
-            self.step.step_status.setText(self.step.describe(False))
+            self.step.updateSummary()
 
 
-class Mock(ShellCommand):
-
+class Mock(buildstep.ShellMixin, buildstep.CommandMixin, buildstep.BuildStep):
     """Add the mock logfiles and clean them if they already exist. Add support
     for the root and resultdir parameter of mock."""
 
@@ -57,20 +56,8 @@ class Mock(ShellCommand):
     root = None
     resultdir = None
 
-    def __init__(self,
-                 root=None,
-                 resultdir=None,
-                 **kwargs):
-        """
-        Creates the Mock object.
-
-        @type root: str
-        @param root: the name of the mock buildroot
-        @type resultdir: str
-        @param resultdir: the path of the result dir
-        @type kwargs: dict
-        @param kwargs: All further keyword arguments.
-        """
+    def __init__(self, root=None, resultdir=None, **kwargs):
+        kwargs = self.setupShellMixin(kwargs, prohibitArgs=['command'])
         super().__init__(**kwargs)
         if root:
             self.root = root
@@ -84,35 +71,32 @@ class Mock(ShellCommand):
         if self.resultdir:
             self.command += ['--resultdir', self.resultdir]
 
-    def start(self):
-        """
-        Try to remove the old mock logs first.
-        """
+    @defer.inlineCallbacks
+    def run(self):
+        # Try to remove the old mock logs first.
         if self.resultdir:
             for lname in self.mock_logfiles:
-                self.logfiles[lname] = self.build.path_module.join(self.resultdir,
-                                                                   lname)
+                self.logfiles[lname] = self.build.path_module.join(self.resultdir, lname)
         else:
             for lname in self.mock_logfiles:
                 self.logfiles[lname] = lname
         self.addLogObserver('state.log', MockStateObserver())
 
-        cmd = remotecommand.RemoteCommand('rmdir', {'dir':
-                                                    [self.build.path_module.join('build',
-                                                                                 self.logfiles[l])
-                                                     for l in self.mock_logfiles]})
-        d = self.runCommand(cmd)
-        # must resolve super() outside of the callback context.
-        super_ = super()
+        yield self.runRmdir([
+            self.build.path_module.join('build', self.logfiles[l]) for l in self.mock_logfiles
+        ])
 
-        @d.addCallback
-        def removeDone(cmd):
-            super_.start()
-        d.addErrback(self.failed)
+        cmd = yield self.makeRemoteShellCommand()
+        yield self.runCommand(cmd)
+
+        return cmd.results()
+
+    def getResultSummary(self):
+        self.descriptionSuffix = None
+        return super().getResultSummary()
 
 
 class MockBuildSRPM(Mock):
-
     """Build a srpm within a mock. Requires a spec file and a sources dir."""
 
     name = "mockbuildsrpm"
@@ -123,10 +107,7 @@ class MockBuildSRPM(Mock):
     spec = None
     sources = '.'
 
-    def __init__(self,
-                 spec=None,
-                 sources=None,
-                 **kwargs):
+    def __init__(self, spec=None, sources=None, **kwargs):
         """
         Creates the MockBuildSRPM object.
 
@@ -148,22 +129,19 @@ class MockBuildSRPM(Mock):
         if not self.sources:
             config.error("You must specify a sources dir")
 
-        self.command += ['--buildsrpm', '--spec', self.spec,
-                         '--sources', self.sources]
-        self.addLogObserver(
-            'stdio', logobserver.LineConsumerLogObserver(self.logConsumer))
+        self.command += ['--buildsrpm', '--spec', self.spec, '--sources', self.sources]
+        self.addLogObserver('stdio', logobserver.LineConsumerLogObserver(self.logConsumer))
 
     def logConsumer(self):
         r = re.compile(r"Wrote: .*/([^/]*.src.rpm)")
         while True:
-            stream, line = yield
+            _, line = yield
             m = r.search(line)
             if m:
                 self.setProperty("srpm", m.group(1), 'MockBuildSRPM')
 
 
 class MockRebuild(Mock):
-
     """Rebuild a srpm within a mock. Requires a srpm file."""
 
     name = "mock"
