@@ -56,8 +56,7 @@ git_describe_flags = [
     # string parameter
     ('match', lambda v: ['--match', v] if v else None),
     # numeric parameter
-    ('abbrev', lambda v: [f'--abbrev={v}']
-     if isTrueOrIsExactlyZero(v) else None),
+    ('abbrev', lambda v: [f'--abbrev={v}'] if isTrueOrIsExactlyZero(v) else None),
     ('candidates', lambda v: [f'--candidates={v}'] if isTrueOrIsExactlyZero(v) else None),
     # optional string parameter
     ('dirty', lambda v: ['--dirty'] if (v is True or v == '') else None),
@@ -66,17 +65,32 @@ git_describe_flags = [
 
 
 class Git(Source, GitStepMixin):
-
     name = 'git'
-    renderables = ["repourl", "reference", "branch",
-                   "codebase", "mode", "method", "origin"]
-
-    def __init__(self, repourl=None, branch='HEAD', mode='incremental', method=None,
-                 reference=None, submodules=False, remoteSubmodules=False, shallow=False,
-                 filters=None, progress=True, retryFetch=False, clobberOnFailure=False,
-                 getDescription=False, config=None, origin=None, sshPrivateKey=None,
-                 sshHostKey=None, sshKnownHosts=None, **kwargs):
+    renderables = ["repourl", "reference", "branch", "codebase", "mode", "method", "origin"]
 
+    def __init__(
+        self,
+        repourl=None,
+        branch='HEAD',
+        mode='incremental',
+        method=None,
+        reference=None,
+        submodules=False,
+        remoteSubmodules=False,
+        tags=False,
+        shallow=False,
+        filters=None,
+        progress=True,
+        retryFetch=False,
+        clobberOnFailure=False,
+        getDescription=False,
+        config=None,
+        origin=None,
+        sshPrivateKey=None,
+        sshHostKey=None,
+        sshKnownHosts=None,
+        **kwargs,
+    ):
         if not getDescription and not isinstance(getDescription, dict):
             getDescription = False
 
@@ -87,15 +101,13 @@ class Git(Source, GitStepMixin):
         self.retryFetch = retryFetch
         self.submodules = submodules
         self.remoteSubmodules = remoteSubmodules
+        self.tags = tags
         self.shallow = shallow
         self.filters = filters
         self.clobberOnFailure = clobberOnFailure
         self.mode = mode
         self.prog = progress
         self.getDescription = getDescription
-        self.sshPrivateKey = sshPrivateKey
-        self.sshHostKey = sshHostKey
-        self.sshKnownHosts = sshKnownHosts
         self.config = config
         self.srcdir = 'source'
         self.origin = origin
@@ -103,18 +115,26 @@ class Git(Source, GitStepMixin):
         super().__init__(**kwargs)
 
         self.setupGitStep()
+        self.setup_git_auth(sshPrivateKey, sshHostKey, sshKnownHosts)
 
         if isinstance(self.mode, str):
             if not self._hasAttrGroupMember('mode', self.mode):
                 bbconfig.error(
-                    f"Git: mode must be {' or '.join(self._listAttrGroupMembers('mode'))}")
+                    f"Git: mode must be {' or '.join(self._listAttrGroupMembers('mode'))}"
+                )
             if isinstance(self.method, str):
-                if self.mode == 'full' and \
-                        self.method not in ['clean', 'fresh', 'clobber', 'copy', None]:
+                if self.mode == 'full' and self.method not in [
+                    'clean',
+                    'fresh',
+                    'clobber',
+                    'copy',
+                    None,
+                ]:
                     bbconfig.error("Git: invalid method for mode 'full'.")
                 if self.shallow and (self.mode != 'full' or self.method != 'clobber'):
                     bbconfig.error(
-                        "Git: in mode 'full' shallow only possible with method 'clobber'.")
+                        "Git: in mode 'full' shallow only possible with method 'clobber'."
+                    )
         if not isinstance(self.getDescription, (bool, dict)):
             bbconfig.error("Git: getDescription must be a boolean or a dict.")
 
@@ -126,6 +146,8 @@ class Git(Source, GitStepMixin):
         self.method = self._getMethod()
         self.stdio_log = yield self.addLogForRemoteCommands("stdio")
 
+        auth_workdir = self._get_auth_data_workdir()
+
         try:
             gitInstalled = yield self.checkFeatureSupport()
 
@@ -137,17 +159,16 @@ class Git(Source, GitStepMixin):
             if patched:
                 yield self._dovccmd(['clean', '-f', '-f', '-d', '-x'])
 
-            yield self._downloadSshPrivateKeyIfNeeded()
+            yield self._git_auth.download_auth_files_if_needed(auth_workdir)
+
             yield self._getAttrGroupMember('mode', self.mode)()
             if patch:
                 yield self.patch(patch)
             yield self.parseGotRevision()
             res = yield self.parseCommitDescription()
-            yield self._removeSshPrivateKeyIfNeeded()
             return res
-        except Exception:
-            yield self._removeSshPrivateKeyIfNeeded()
-            raise
+        finally:
+            yield self._git_auth.remove_auth_files_if_needed(auth_workdir)
 
     @defer.inlineCallbacks
     def mode_full(self):
@@ -225,8 +246,7 @@ class Git(Source, GitStepMixin):
     @defer.inlineCallbacks
     def fresh(self):
         clean_command = ['clean', '-f', '-f', '-d', '-x']
-        res = yield self._dovccmd(clean_command,
-                                  abandonOnFailure=False)
+        res = yield self._dovccmd(clean_command, abandonOnFailure=False)
         if res == RC_SUCCESS:
             yield self._fetchOrFallback()
         else:
@@ -240,19 +260,22 @@ class Git(Source, GitStepMixin):
 
     @defer.inlineCallbacks
     def copy(self):
-        yield self.runRmdir(self.workdir, abandonOnFailure=False,
-                            timeout=self.timeout)
+        yield self.runRmdir(self.workdir, abandonOnFailure=False, timeout=self.timeout)
 
         old_workdir = self.workdir
         self.workdir = self.srcdir
 
         try:
             yield self.mode_incremental()
-            cmd = remotecommand.RemoteCommand('cpdir',
-                                              {'fromdir': self.srcdir,
-                                               'todir': old_workdir,
-                                               'logEnviron': self.logEnviron,
-                                               'timeout': self.timeout, })
+            cmd = remotecommand.RemoteCommand(
+                'cpdir',
+                {
+                    'fromdir': self.srcdir,
+                    'todir': old_workdir,
+                    'logEnviron': self.logEnviron,
+                    'timeout': self.timeout,
+                },
+            )
             cmd.useLog(self.stdio_log, False)
             yield self.runCommand(cmd)
             if cmd.didFail():
@@ -299,7 +322,7 @@ class Git(Source, GitStepMixin):
 
         return RC_SUCCESS
 
-    def _getSshDataWorkDir(self):
+    def _get_auth_data_workdir(self):
         if self.method == 'copy' and self.mode == 'full':
             return self.srcdir
         return self.workdir
@@ -308,15 +331,18 @@ class Git(Source, GitStepMixin):
     def _fetch(self, _, abandonOnFailure=True):
         fetch_required = True
 
-        # If the revision already exists in the repo, we don't need to fetch.
-        if self.revision:
-            rc = yield self._dovccmd(['cat-file', '-e', self.revision],
-                                     abandonOnFailure=False)
+        # If the revision already exists in the repo, we don't need to fetch. However, if tags
+        # were requested, then fetch still needs to be performed for the tags.
+        if not self.tags and self.revision:
+            rc = yield self._dovccmd(['cat-file', '-e', self.revision], abandonOnFailure=False)
             if rc == RC_SUCCESS:
                 fetch_required = False
 
         if fetch_required:
             command = ['fetch', '-f', '-t', self.repourl, self.branch]
+            if self.tags:
+                command.append("--tags")
+
             # If the 'progress' option is set, tell git fetch to output
             # progress information to the log. This can solve issues with
             # long fetches killed due to lack of output, but only works
@@ -426,7 +452,7 @@ class Git(Source, GitStepMixin):
     @defer.inlineCallbacks
     def _fullClone(self, shallowClone=False):
         """Perform full clone and checkout to the revision if specified
-           In the case of shallow clones if any of the step fail abort whole build step.
+        In the case of shallow clones if any of the step fail abort whole build step.
         """
         res = yield self._clone(shallowClone)
         if res != RC_SUCCESS:
@@ -451,7 +477,7 @@ class Git(Source, GitStepMixin):
     @defer.inlineCallbacks
     def _fullCloneOrFallback(self):
         """Wrapper for _fullClone(). In the case of failure, if clobberOnFailure
-           is set to True remove the build directory and try a full clone again.
+        is set to True remove the build directory and try a full clone again.
         """
 
         res = yield self._fullClone()
@@ -534,8 +560,7 @@ class Git(Source, GitStepMixin):
 
             return "clone"
 
-        cmd = remotecommand.RemoteCommand('listdir',
-                                          {'dir': self.workdir})
+        cmd = remotecommand.RemoteCommand('listdir', {'dir': self.workdir})
         cmd.useLog(self.stdio_log, False)
         yield self.runCommand(cmd)
 
@@ -552,7 +577,6 @@ class Git(Source, GitStepMixin):
 
 
 class GitPush(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
-
     description = None
     descriptionDone = None
     descriptionSuffix = None
@@ -560,11 +584,21 @@ class GitPush(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
     name = 'gitpush'
     renderables = ['repourl', 'branch']
 
-    def __init__(self, workdir=None, repourl=None, branch=None, force=False,
-                 env=None, timeout=20 * 60, logEnviron=True,
-                 sshPrivateKey=None, sshHostKey=None, sshKnownHosts=None,
-                 config=None, **kwargs):
-
+    def __init__(
+        self,
+        workdir=None,
+        repourl=None,
+        branch=None,
+        force=False,
+        env=None,
+        timeout=20 * 60,
+        logEnviron=True,
+        sshPrivateKey=None,
+        sshHostKey=None,
+        sshKnownHosts=None,
+        config=None,
+        **kwargs,
+    ):
         self.workdir = workdir
         self.repourl = repourl
         self.branch = branch
@@ -572,38 +606,36 @@ class GitPush(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
         self.env = env
         self.timeout = timeout
         self.logEnviron = logEnviron
-        self.sshPrivateKey = sshPrivateKey
-        self.sshHostKey = sshHostKey
-        self.sshKnownHosts = sshKnownHosts
         self.config = config
 
         super().__init__(**kwargs)
 
         self.setupGitStep()
+        self.setup_git_auth(sshPrivateKey, sshHostKey, sshKnownHosts)
 
         if not self.branch:
             bbconfig.error('GitPush: must provide branch')
 
-    def _getSshDataWorkDir(self):
+    def _get_auth_data_workdir(self):
         return self.workdir
 
     @defer.inlineCallbacks
     def run(self):
         self.stdio_log = yield self.addLog("stdio")
+
+        auth_workdir = self._get_auth_data_workdir()
+
         try:
             gitInstalled = yield self.checkFeatureSupport()
 
             if not gitInstalled:
                 raise WorkerSetupError("git is not installed on worker")
 
-            yield self._downloadSshPrivateKeyIfNeeded()
+            yield self._git_auth.download_auth_files_if_needed(auth_workdir)
             ret = yield self._doPush()
-            yield self._removeSshPrivateKeyIfNeeded()
             return ret
-
-        except Exception as e:
-            yield self._removeSshPrivateKeyIfNeeded()
-            raise e
+        finally:
+            yield self._git_auth.remove_auth_files_if_needed(auth_workdir)
 
     @defer.inlineCallbacks
     def _doPush(self):
@@ -616,7 +648,6 @@ class GitPush(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
 
 
 class GitTag(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
-
     description = None
     descriptionDone = None
     descriptionSuffix = None
@@ -624,10 +655,19 @@ class GitTag(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
     name = 'gittag'
     renderables = ['repourl', 'tagName', 'messages']
 
-    def __init__(self, workdir=None, tagName=None,
-                 annotated=False, messages=None, force=False, env=None,
-                 timeout=20 * 60, logEnviron=True, config=None, **kwargs):
-
+    def __init__(
+        self,
+        workdir=None,
+        tagName=None,
+        annotated=False,
+        messages=None,
+        force=False,
+        env=None,
+        timeout=20 * 60,
+        logEnviron=True,
+        config=None,
+        **kwargs,
+    ):
         self.workdir = workdir
         self.tagName = tagName
         self.annotated = annotated
@@ -640,9 +680,6 @@ class GitTag(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
 
         # These attributes are required for GitStepMixin but not useful to tag
         self.repourl = " "
-        self.sshHostKey = None
-        self.sshPrivateKey = None
-        self.sshKnownHosts = None
 
         super().__init__(**kwargs)
 
@@ -692,7 +729,6 @@ class GitTag(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
 
 
 class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
-
     description = None
     descriptionDone = None
     descriptionSuffix = None
@@ -700,10 +736,19 @@ class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
     name = 'gitcommit'
     renderables = ['paths', 'messages']
 
-    def __init__(self, workdir=None, paths=None, messages=None, env=None,
-                 timeout=20 * 60, logEnviron=True, emptyCommits='disallow',
-                 config=None, no_verify=False, **kwargs):
-
+    def __init__(
+        self,
+        workdir=None,
+        paths=None,
+        messages=None,
+        env=None,
+        timeout=20 * 60,
+        logEnviron=True,
+        emptyCommits='disallow',
+        config=None,
+        no_verify=False,
+        **kwargs,
+    ):
         self.workdir = workdir
         self.messages = messages
         self.paths = paths
@@ -713,12 +758,9 @@ class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
         self.config = config
         self.emptyCommits = emptyCommits
         self.no_verify = no_verify
-        # The repourl, sshPrivateKey and sshHostKey attributes are required by
-        # GitStepMixin, but aren't needed by git add and commit operations
+        # The repourl attribute is required by
+        # GitStepMixin, but isn't needed by git add and commit operations
         self.repourl = " "
-        self.sshPrivateKey = None
-        self.sshHostKey = None
-        self.sshKnownHosts = None
 
         super().__init__(**kwargs)
 
@@ -737,8 +779,10 @@ class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
             bbconfig.error('GitCommit: paths must be a list')
 
         if self.emptyCommits not in ('disallow', 'create-empty-commit', 'ignore'):
-            bbconfig.error('GitCommit: emptyCommits must be one of "disallow", '
-                           '"create-empty-commit" and "ignore"')
+            bbconfig.error(
+                'GitCommit: emptyCommits must be one of "disallow", '
+                '"create-empty-commit" and "ignore"'
+            )
 
     @defer.inlineCallbacks
     def run(self):
