@@ -13,6 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
 import json
 import os
@@ -22,7 +23,7 @@ from twisted.internet import defer
 from twisted.python import log
 
 from buildbot import config
-from buildbot.interfaces import WorkerTooOldError
+from buildbot.interfaces import WorkerSetupError
 from buildbot.process import remotecommand
 from buildbot.process import remotetransfer
 from buildbot.process.buildstep import FAILURE
@@ -31,18 +32,15 @@ from buildbot.process.buildstep import SUCCESS
 from buildbot.process.buildstep import BuildStep
 from buildbot.steps.worker import CompositeStepMixin
 from buildbot.util import flatten
-from buildbot.util.eventual import eventually
 
 
-def makeStatusRemoteCommand(step, remote_command, args):
-    self = remotecommand.RemoteCommand(
-        remote_command, args, decodeRC={None: SUCCESS, 0: SUCCESS})
+def makeStatusRemoteCommand(step, remote_command, args) -> remotecommand.RemoteCommand:
+    self = remotecommand.RemoteCommand(remote_command, args, decodeRC={None: SUCCESS, 0: SUCCESS})
     self.useLog(step.stdio_log)
     return self
 
 
 class _TransferBuildStep(BuildStep):
-
     """
     Base class for FileUpload and FileDownload to factor out common
     functionality.
@@ -57,36 +55,36 @@ class _TransferBuildStep(BuildStep):
         super().__init__(**buildstep_kwargs)
         self.workdir = workdir
 
-    def runTransferCommand(self, cmd, writer=None):
+    @defer.inlineCallbacks
+    def runTransferCommand(
+        self,
+        cmd: remotecommand.RemoteCommand,
+        writer: remotetransfer.FileWriter | None = None,
+    ):
         # Run a transfer step, add a callback to extract the command status,
         # add an error handler that cancels the writer.
         self.cmd = cmd
-        d = self.runCommand(cmd)
-
-        @d.addCallback
-        def checkResult(_):
-            if writer and cmd.didFail():
-                writer.cancel()
-            return FAILURE if cmd.didFail() else SUCCESS
-
-        @d.addErrback
-        def cancel(res):
+        try:
+            yield self.runCommand(cmd)
+        finally:
             if writer:
                 writer.cancel()
-            return res
 
-        return d
+        cmd_res = cmd.results()
+        if cmd_res >= FAILURE:
+            if writer:
+                writer.purge()
+        return cmd_res
 
+    @defer.inlineCallbacks
     def interrupt(self, reason):
-        self.addCompleteLog('interrupt', str(reason))
+        yield self.addCompleteLog('interrupt', str(reason))
         if self.cmd:
-            d = self.cmd.interrupt(reason)
-            return d
+            yield self.cmd.interrupt(reason)
         return None
 
 
 class FileUpload(_TransferBuildStep):
-
     name = 'upload'
 
     renderables = [
@@ -96,10 +94,19 @@ class FileUpload(_TransferBuildStep):
         'workersrc',
     ]
 
-    def __init__(self, workersrc=None, masterdest=None,
-                 workdir=None, maxsize=None, blocksize=256 * 1024, mode=None,
-                 keepstamp=False, url=None, urlText=None,
-                 **buildstep_kwargs):
+    def __init__(
+        self,
+        workersrc=None,
+        masterdest=None,
+        workdir=None,
+        maxsize=None,
+        blocksize=256 * 1024,
+        mode=None,
+        keepstamp=False,
+        url=None,
+        urlText=None,
+        **buildstep_kwargs,
+    ):
         # Emulate that first two arguments are positional.
         if workersrc is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -111,22 +118,16 @@ class FileUpload(_TransferBuildStep):
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
-            config.error(
-                'mode must be an integer or None')
+            config.error('mode must be an integer or None')
         self.mode = mode
         self.keepstamp = keepstamp
         self.url = url
         self.urlText = urlText
 
-    def finished(self, results):
-        log.msg("File '{}' upload finished with results {}".format(
-            os.path.basename(self.workersrc), str(results)))
-        self.step_status.setText(self.descriptionDone)
-        super().finished(results)
-
-    def start(self):
+    @defer.inlineCallbacks
+    def run(self):
         self.checkWorkerHasCommand("uploadFile")
-        self.stdio_log = self.addLog("stdio")
+        self.stdio_log = yield self.addLog("stdio")
 
         source = self.workersrc
         masterdest = self.masterdest
@@ -135,11 +136,10 @@ class FileUpload(_TransferBuildStep):
         # properly. TODO: maybe pass the master's basedir all the way down
         # into the BuildStep so we can do this better.
         masterdest = os.path.expanduser(masterdest)
-        log.msg("FileUpload started, from worker %r to master %r"
-                % (source, masterdest))
+        log.msg(f"FileUpload started, from worker {repr(source)} to master {repr(masterdest)}")
 
         if self.description is None:
-            self.description = ['uploading {}'.format(os.path.basename(source))]
+            self.description = [f'uploading {os.path.basename(source)}']
 
         if self.descriptionDone is None:
             self.descriptionDone = self.description
@@ -150,18 +150,17 @@ class FileUpload(_TransferBuildStep):
             if urlText is None:
                 urlText = os.path.basename(masterdest)
 
-            self.addURL(urlText, self.url)
-
-        self.step_status.setText(self.description)
+            yield self.addURL(urlText, self.url)
 
         # we use maxsize to limit the amount of data on both sides
-        fileWriter = remotetransfer.FileWriter(
-            masterdest, self.maxsize, self.mode)
+        fileWriter = remotetransfer.FileWriter(masterdest, self.maxsize, self.mode)
 
         if self.keepstamp and self.workerVersionIsOlderThan("uploadFile", "2.13"):
-            m = (("This worker ({}) does not support preserving timestamps. "
-                  "Please upgrade the worker.").format(self.build.workername))
-            raise WorkerTooOldError(m)
+            m = (
+                f"This worker ({self.build.workername}) does not support preserving timestamps. "
+                "Please upgrade the worker."
+            )
+            raise WorkerSetupError(m)
 
         # default arguments
         args = {
@@ -178,21 +177,32 @@ class FileUpload(_TransferBuildStep):
             args['workersrc'] = source
 
         cmd = makeStatusRemoteCommand(self, 'uploadFile', args)
-        d = self.runTransferCommand(cmd, fileWriter)
-        d.addCallback(self.finished).addErrback(self.failed)
+        res = yield self.runTransferCommand(cmd, fileWriter)
+
+        log.msg(
+            f"File '{os.path.basename(self.workersrc)}' upload finished with results {str(res)}"
+        )
+
+        return res
 
 
 class DirectoryUpload(_TransferBuildStep):
-
     name = 'upload'
 
-    renderables = ['workersrc', 'masterdest', 'url']
+    renderables = ['workersrc', 'masterdest', 'url', 'urlText']
 
-    def __init__(self, workersrc=None, masterdest=None,
-                 workdir=None, maxsize=None, blocksize=16 * 1024,
-                 compress=None, url=None, urlText=None,
-                 **buildstep_kwargs
-                 ):
+    def __init__(
+        self,
+        workersrc=None,
+        masterdest=None,
+        workdir=None,
+        maxsize=None,
+        blocksize=16 * 1024,
+        compress=None,
+        url=None,
+        urlText=None,
+        **buildstep_kwargs,
+    ):
         # Emulate that first two arguments are positional.
         if workersrc is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -204,15 +214,15 @@ class DirectoryUpload(_TransferBuildStep):
         self.maxsize = maxsize
         self.blocksize = blocksize
         if compress not in (None, 'gz', 'bz2'):
-            config.error(
-                "'compress' must be one of None, 'gz', or 'bz2'")
+            config.error("'compress' must be one of None, 'gz', or 'bz2'")
         self.compress = compress
         self.url = url
         self.urlText = urlText
 
-    def start(self):
+    @defer.inlineCallbacks
+    def run(self):
         self.checkWorkerHasCommand("uploadDirectory")
-        self.stdio_log = self.addLog("stdio")
+        self.stdio_log = yield self.addLog("stdio")
 
         source = self.workersrc
         masterdest = self.masterdest
@@ -221,21 +231,19 @@ class DirectoryUpload(_TransferBuildStep):
         # properly. TODO: maybe pass the master's basedir all the way down
         # into the BuildStep so we can do this better.
         masterdest = os.path.expanduser(masterdest)
-        log.msg("DirectoryUpload started, from worker {} to master {}".format(repr(source),
-                                                                              repr(masterdest)))
+        log.msg(f"DirectoryUpload started, from worker {repr(source)} to master {repr(masterdest)}")
 
-        self.descriptionDone = "uploading {}".format(os.path.basename(source))
+        self.descriptionDone = f"uploading {os.path.basename(source)}"
         if self.url is not None:
             urlText = self.urlText
 
             if urlText is None:
                 urlText = os.path.basename(os.path.normpath(masterdest))
 
-            self.addURL(urlText, self.url)
+            yield self.addURL(urlText, self.url)
 
         # we use maxsize to limit the amount of data on both sides
-        dirWriter = remotetransfer.DirectoryWriter(
-            masterdest, self.maxsize, self.compress, 0o600)
+        dirWriter = remotetransfer.DirectoryWriter(masterdest, self.maxsize, self.compress, 0o600)
 
         # default arguments
         args = {
@@ -243,7 +251,7 @@ class DirectoryUpload(_TransferBuildStep):
             'writer': dirWriter,
             'maxsize': self.maxsize,
             'blocksize': self.blocksize,
-            'compress': self.compress
+            'compress': self.compress,
         }
 
         if self.workerVersionIsOlderThan('uploadDirectory', '3.0'):
@@ -252,22 +260,31 @@ class DirectoryUpload(_TransferBuildStep):
             args['workersrc'] = source
 
         cmd = makeStatusRemoteCommand(self, 'uploadDirectory', args)
-        d = self.runTransferCommand(cmd, dirWriter)
-        d.addCallback(self.finished).addErrback(self.failed)
+        res = yield self.runTransferCommand(cmd, dirWriter)
+        return res
 
 
 class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
-
     name = 'upload'
     logEnviron = False
 
-    renderables = ['workersrcs', 'masterdest', 'url']
-
-    def __init__(self, workersrcs=None, masterdest=None,
-                 workdir=None, maxsize=None, blocksize=16 * 1024, glob=False,
-                 mode=None, compress=None, keepstamp=False, url=None,
-                 **buildstep_kwargs):
+    renderables = ['workersrcs', 'masterdest', 'url', 'urlText']
 
+    def __init__(
+        self,
+        workersrcs=None,
+        masterdest=None,
+        workdir=None,
+        maxsize=None,
+        blocksize=16 * 1024,
+        glob=False,
+        mode=None,
+        compress=None,
+        keepstamp=False,
+        url=None,
+        urlText=None,
+        **buildstep_kwargs,
+    ):
         # Emulate that first two arguments are positional.
         if workersrcs is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -279,20 +296,18 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
-            config.error(
-                'mode must be an integer or None')
+            config.error('mode must be an integer or None')
         self.mode = mode
         if compress not in (None, 'gz', 'bz2'):
-            config.error(
-                "'compress' must be one of None, 'gz', or 'bz2'")
+            config.error("'compress' must be one of None, 'gz', or 'bz2'")
         self.compress = compress
         self.glob = glob
         self.keepstamp = keepstamp
         self.url = url
+        self.urlText = urlText
 
     def uploadFile(self, source, masterdest):
-        fileWriter = remotetransfer.FileWriter(
-            masterdest, self.maxsize, self.mode)
+        fileWriter = remotetransfer.FileWriter(masterdest, self.maxsize, self.mode)
 
         args = {
             'workdir': self.workdir,
@@ -311,15 +326,14 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         return self.runTransferCommand(cmd, fileWriter)
 
     def uploadDirectory(self, source, masterdest):
-        dirWriter = remotetransfer.DirectoryWriter(
-            masterdest, self.maxsize, self.compress, 0o600)
+        dirWriter = remotetransfer.DirectoryWriter(masterdest, self.maxsize, self.compress, 0o600)
 
         args = {
             'workdir': self.workdir,
             'writer': dirWriter,
             'maxsize': self.maxsize,
             'blocksize': self.blocksize,
-            'compress': self.compress
+            'compress': self.compress,
         }
 
         if self.workerVersionIsOlderThan('uploadDirectory', '3.0'):
@@ -333,16 +347,13 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
     @defer.inlineCallbacks
     def startUpload(self, source, destdir):
         masterdest = os.path.join(destdir, os.path.basename(source))
-        args = {
-            'file': source,
-            'workdir': self.workdir
-        }
+        args = {'file': source, 'workdir': self.workdir}
 
         cmd = makeStatusRemoteCommand(self, 'stat', args)
         yield self.runCommand(cmd)
         if cmd.rc != 0:
-            self.addCompleteLog('stderr',
-                                'File {} not available at worker'.format(args))
+            msg = f'File {self.workdir}/{source} not available at worker'
+            yield self.addCompleteLog('stderr', msg)
             return FAILURE
         s = cmd.updates['stat'][-1]
         if stat.S_ISDIR(s[stat.ST_MODE]):
@@ -350,8 +361,8 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
         elif stat.S_ISREG(s[stat.ST_MODE]):
             result = yield self.uploadFile(source, masterdest)
         else:
-            self.addCompleteLog('stderr',
-                                '{} is neither a regular file, nor a directory'.format(source))
+            msg = f'{source} is neither a regular file, nor a directory'
+            yield self.addCompleteLog('stderr', msg)
             return FAILURE
 
         yield self.uploadDone(result, source, masterdest)
@@ -360,83 +371,81 @@ class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
     def uploadDone(self, result, source, masterdest):
         pass
 
+    @defer.inlineCallbacks
     def allUploadsDone(self, result, sources, masterdest):
         if self.url is not None:
-            self.addURL(
-                os.path.basename(os.path.normpath(masterdest)), self.url)
+            urlText = self.urlText
 
-    def start(self):
+            if urlText is None:
+                urlText = os.path.basename(os.path.normpath(masterdest))
+
+            yield self.addURL(urlText, self.url)
+
+    @defer.inlineCallbacks
+    def run(self):
         self.checkWorkerHasCommand("uploadDirectory")
         self.checkWorkerHasCommand("uploadFile")
         self.checkWorkerHasCommand("stat")
-        self.stdio_log = self.addLog("stdio")
+        self.stdio_log = yield self.addLog("stdio")
 
         masterdest = os.path.expanduser(self.masterdest)
         sources = self.workersrcs if isinstance(self.workersrcs, list) else [self.workersrcs]
 
         if self.keepstamp and self.workerVersionIsOlderThan("uploadFile", "2.13"):
-            m = (("This worker ({}) does not support preserving timestamps. "
-                  "Please upgrade the worker.").format(self.build.workername))
-            raise WorkerTooOldError(m)
+            m = (
+                f"This worker ({self.build.workername}) does not support preserving timestamps. "
+                "Please upgrade the worker."
+            )
+            raise WorkerSetupError(m)
 
         if not sources:
-            return self.finished(SKIPPED)
+            return SKIPPED
 
-        @defer.inlineCallbacks
-        def globSources(sources):
+        if self.glob:
             results = yield defer.gatherResults([
                 self.runGlob(os.path.join(self.workdir, source), abandonOnFailure=False)
                 for source in sources
             ])
-            results = [self.workerPathToMasterPath(p) for p in flatten(results)]
-            return results
+            sources = [self.workerPathToMasterPath(p) for p in flatten(results)]
 
-        @defer.inlineCallbacks
-        def uploadSources(sources):
-            if not sources:
-                return SKIPPED
-            else:
-                for source in sources:
-                    result = yield self.startUpload(source, masterdest)
-                    if result == FAILURE:
-                        return FAILURE
-                return SUCCESS
+        log.msg(f"MultipleFileUpload started, from worker {sources!r} to master {masterdest!r}")
 
-        def logUpload(sources):
-            log.msg("MultipleFileUpload started, from worker %r to master %r" %
-                    (sources, masterdest))
-            nsrcs = len(sources)
-            self.descriptionDone = 'uploading {} {}'.format(nsrcs,
-                                                            'file' if nsrcs == 1 else 'files')
-            return sources
+        self.descriptionDone = [
+            'uploading',
+            str(len(sources)),
+            'file' if len(sources) == 1 else 'files',
+        ]
 
-        if self.glob:
-            s = globSources(sources)
+        if not sources:
+            result = SKIPPED
         else:
-            s = defer.succeed(sources)
+            result = SUCCESS
+            for source in sources:
+                result_single = yield self.startUpload(source, masterdest)
+                if result_single == FAILURE:
+                    result = FAILURE
+                    break
 
-        s.addCallback(logUpload)
-        d = s.addCallback(uploadSources)
+        yield self.allUploadsDone(result, sources, masterdest)
 
-        @d.addCallback
-        def allUploadsDone(result):
-            d = defer.maybeDeferred(
-                self.allUploadsDone, result, sources, masterdest)
-            d.addCallback(lambda _: result)
-            return d
-
-        d.addCallback(self.finished).addErrback(self.failed)
+        return result
 
 
 class FileDownload(_TransferBuildStep):
-
     name = 'download'
 
     renderables = ['mastersrc', 'workerdest']
 
-    def __init__(self, mastersrc, workerdest=None,
-                 workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
-                 **buildstep_kwargs):
+    def __init__(
+        self,
+        mastersrc,
+        workerdest=None,
+        workdir=None,
+        maxsize=None,
+        blocksize=16 * 1024,
+        mode=None,
+        **buildstep_kwargs,
+    ):
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -448,34 +457,30 @@ class FileDownload(_TransferBuildStep):
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
-            config.error(
-                'mode must be an integer or None')
+            config.error('mode must be an integer or None')
         self.mode = mode
 
-    def start(self):
+    @defer.inlineCallbacks
+    def run(self):
         self.checkWorkerHasCommand("downloadFile")
-        self.stdio_log = self.addLog("stdio")
+        self.stdio_log = yield self.addLog("stdio")
 
         # we are currently in the buildmaster's basedir, so any non-absolute
         # paths will be interpreted relative to that
         source = os.path.expanduser(self.mastersrc)
         workerdest = self.workerdest
-        log.msg("FileDownload started, from master %r to worker %r" %
-                (source, workerdest))
+        log.msg(f"FileDownload started, from master {repr(source)} to worker {repr(workerdest)}")
 
-        self.descriptionDone = "downloading to {}".format(os.path.basename(workerdest))
+        self.descriptionDone = ["downloading to", os.path.basename(workerdest)]
 
         # setup structures for reading the file
         try:
-            fp = open(source, 'rb')
+            fp = open(source, 'rb')  # noqa pylint: disable=consider-using-with
         except IOError:
             # if file does not exist, bail out with an error
-            self.addCompleteLog('stderr',
-                                'File %r not available at master' % source)
-            # TODO: once BuildStep.start() gets rewritten to use
-            # maybeDeferred, just re-raise the exception here.
-            eventually(BuildStep.finished, self, FAILURE)
-            return
+            yield self.addCompleteLog('stderr', f'File {source!r} not available at master')
+            return FAILURE
+
         fileReader = remotetransfer.FileReader(fp)
 
         # default arguments
@@ -493,19 +498,25 @@ class FileDownload(_TransferBuildStep):
             args['workerdest'] = workerdest
 
         cmd = makeStatusRemoteCommand(self, 'downloadFile', args)
-        d = self.runTransferCommand(cmd)
-        d.addCallback(self.finished).addErrback(self.failed)
+        res = yield self.runTransferCommand(cmd)
+        return res
 
 
 class StringDownload(_TransferBuildStep):
-
     name = 'string_download'
 
     renderables = ['workerdest', 's']
 
-    def __init__(self, s, workerdest=None,
-                 workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
-                 **buildstep_kwargs):
+    def __init__(
+        self,
+        s,
+        workerdest=None,
+        workdir=None,
+        maxsize=None,
+        blocksize=16 * 1024,
+        mode=None,
+        **buildstep_kwargs,
+    ):
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -517,22 +528,21 @@ class StringDownload(_TransferBuildStep):
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
-            config.error("StringDownload step's mode must be an integer or None, got '{}'".format(
-                    mode))
+            config.error(f"StringDownload step's mode must be an integer or None, got '{mode}'")
         self.mode = mode
 
-    def start(self):
+    @defer.inlineCallbacks
+    def run(self):
         # we use 'downloadFile' remote command on the worker
         self.checkWorkerHasCommand("downloadFile")
-        self.stdio_log = self.addLog("stdio")
+        self.stdio_log = yield self.addLog("stdio")
 
         # we are currently in the buildmaster's basedir, so any non-absolute
         # paths will be interpreted relative to that
         workerdest = self.workerdest
-        log.msg("StringDownload started, from master to worker %r" %
-                workerdest)
+        log.msg(f"StringDownload started, from master to worker {repr(workerdest)}")
 
-        self.descriptionDone = "downloading to {}".format(os.path.basename(workerdest))
+        self.descriptionDone = ["downloading to", os.path.basename(workerdest)]
 
         # setup structures for reading the file
         fileReader = remotetransfer.StringFileReader(self.s)
@@ -552,51 +562,53 @@ class StringDownload(_TransferBuildStep):
             args['workerdest'] = workerdest
 
         cmd = makeStatusRemoteCommand(self, 'downloadFile', args)
-        d = self.runTransferCommand(cmd)
-        d.addCallback(self.finished).addErrback(self.failed)
+        res = yield self.runTransferCommand(cmd)
+        return res
 
 
 class JSONStringDownload(StringDownload):
-
     name = "json_download"
 
-    def __init__(self, o, workerdest=None,
-                 **buildstep_kwargs):
+    def __init__(self, o, workerdest=None, **buildstep_kwargs):
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
 
         if 's' in buildstep_kwargs:
             del buildstep_kwargs['s']
-        s = json.dumps(o)
-        super().__init__(s=s, workerdest=workerdest, **buildstep_kwargs)
+        super().__init__(s=o, workerdest=workerdest, **buildstep_kwargs)
+
+    @defer.inlineCallbacks
+    def run(self):
+        self.s = json.dumps(self.s)
+        res = yield super().run()
+        return res
 
 
 class JSONPropertiesDownload(StringDownload):
-
     name = "json_properties_download"
 
-    def __init__(self, workerdest=None,
-                 **buildstep_kwargs):
+    def __init__(self, workerdest=None, **buildstep_kwargs):
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 2 arguments")
 
-        self.super_class = StringDownload
         if 's' in buildstep_kwargs:
             del buildstep_kwargs['s']
         super().__init__(s=None, workerdest=workerdest, **buildstep_kwargs)
 
-    def start(self):
+    @defer.inlineCallbacks
+    def run(self):
         properties = self.build.getProperties()
         props = {}
-        for key, value, source in properties.asList():
+        for key, value, _ in properties.asList():
             props[key] = value
 
-        self.s = json.dumps(dict(
-            properties=props,
-            sourcestamps=[ss.asDict()
-                          for ss in self.build.getAllSourceStamps()],
-        ),
+        self.s = json.dumps(
+            {
+                "properties": props,
+                "sourcestamps": [ss.asDict() for ss in self.build.getAllSourceStamps()],
+            },
         )
-        return self.super_class.start(self)
+        res = yield super().run()
+        return res
