@@ -27,7 +27,6 @@ from buildbot.process.logobserver import LogLineObserver
 
 
 class MSLogLineObserver(LogLineObserver):
-
     stdoutDelimiter = "\r\n"
     stderrDelimiter = "\r\n"
 
@@ -75,8 +74,11 @@ class VisualStudio(buildstep.ShellMixin, buildstep.BuildStep):
     description = "compiling"
     descriptionDone = "compile"
 
-    progressMetrics = (buildstep.BuildStep.progressMetrics +
-                       ('projects', 'files', 'warnings',))
+    progressMetrics = buildstep.BuildStep.progressMetrics + (
+        'projects',
+        'files',
+        'warnings',
+    )
 
     logobserver = None
 
@@ -96,17 +98,19 @@ class VisualStudio(buildstep.ShellMixin, buildstep.BuildStep):
 
     renderables = ['projectfile', 'config', 'project', 'mode']
 
-    def __init__(self,
-                 installdir=None,
-                 mode="rebuild",
-                 projectfile=None,
-                 config='release',
-                 useenv=False,
-                 project=None,
-                 INCLUDE=None,
-                 LIB=None,
-                 PATH=None,
-                 **kwargs):
+    def __init__(
+        self,
+        installdir=None,
+        mode="rebuild",
+        projectfile=None,
+        config='release',
+        useenv=False,
+        project=None,
+        INCLUDE=None,
+        LIB=None,
+        PATH=None,
+        **kwargs,
+    ):
         if INCLUDE is None:
             INCLUDE = []
         if LIB is None:
@@ -132,7 +136,7 @@ class VisualStudio(buildstep.ShellMixin, buildstep.BuildStep):
         super().__init__(**kwargs)
 
     def add_env_path(self, name, value):
-        """ concat a path for this name """
+        """concat a path for this name"""
         try:
             oldval = self.env[name]
             if not oldval.endswith(';'):
@@ -196,8 +200,9 @@ class VisualStudio(buildstep.ShellMixin, buildstep.BuildStep):
             # step was skipped or log observer was not created due to another reason
             return {"step": results.statusToString(self.results)}
 
-        description = (f'compile {self.logobserver.nbProjects} projects {self.logobserver.nbFiles} '
-                       'files')
+        description = (
+            f'compile {self.logobserver.nbProjects} projects {self.logobserver.nbFiles} ' 'files'
+        )
 
         if self.logobserver.nbWarnings > 0:
             description += f' {self.logobserver.nbWarnings} warnings'
@@ -206,6 +211,8 @@ class VisualStudio(buildstep.ShellMixin, buildstep.BuildStep):
 
         if self.results != results.SUCCESS:
             description += f' ({results.statusToString(self.results)})'
+            if self.timed_out:
+                description += " (timed out)"
 
         return {'step': description}
 
@@ -218,7 +225,6 @@ class VisualStudio(buildstep.ShellMixin, buildstep.BuildStep):
 
 
 class VC6(VisualStudio):
-
     default_installdir = 'C:\\Program Files\\Microsoft Visual Studio'
 
     def setupEnvironment(self):
@@ -243,11 +249,7 @@ class VC6(VisualStudio):
 
     @defer.inlineCallbacks
     def run(self):
-        command = [
-            "msdev",
-            self.projectfile,
-            "/MAKE"
-        ]
+        command = ["msdev", self.projectfile, "/MAKE"]
         if self.project is not None:
             command.append(self.project + " - " + self.config)
         else:
@@ -293,10 +295,7 @@ class VC7(VisualStudio):
 
     @defer.inlineCallbacks
     def run(self):
-        command = [
-            "devenv.com",
-            self.projectfile
-        ]
+        command = ["devenv.com", self.projectfile]
         if self.mode == "rebuild":
             command.append("/Rebuild")
         elif self.mode == "clean":
@@ -320,7 +319,6 @@ VS2003 = VC7
 
 
 class VC8(VC7):
-
     # Our ones
     arch = None
     default_installdir = 'C:\\Program Files\\Microsoft Visual Studio 8'
@@ -369,13 +367,9 @@ VS2005 = VC8
 
 
 class VCExpress9(VC8):
-
     @defer.inlineCallbacks
     def run(self):
-        command = [
-            "vcexpress",
-            self.projectfile
-        ]
+        command = ["vcexpress", self.projectfile]
         if self.mode == "rebuild":
             command.append("/Rebuild")
         elif self.mode == "clean":
@@ -510,10 +504,12 @@ class MsBuild4(VisualStudio):
         if self.platform is None:
             config.error('platform is mandatory. Please specify a string such as "Win32"')
 
-        yield self.updateSummary()
+        self.updateSummary()
 
-        command = (f'"%VCENV_BAT%" x86 && msbuild "{self.projectfile}" '
-                   f'/p:Configuration="{self.config}" /p:Platform="{self.platform}" /maxcpucount')
+        command = (
+            f'"%VCENV_BAT%" x86 && msbuild "{self.projectfile}" '
+            f'/p:Configuration="{self.config}" /p:Platform="{self.platform}" /maxcpucount'
+        )
 
         command += _msbuild_format_target_parameter(self.mode, self.project)
         command += _msbuild_format_defines_parameter(self.defines)
@@ -550,10 +546,8 @@ class MsBuild141(VisualStudio):
     def setupEnvironment(self):
         super().setupEnvironment()
         self.env['VCENV_BAT'] = self.vcenv_bat
-        self.add_env_path("PATH",
-                   'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\')
-        self.add_env_path("PATH",
-                   'C:\\Program Files\\Microsoft Visual Studio\\Installer\\')
+        self.add_env_path("PATH", 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\')
+        self.add_env_path("PATH", 'C:\\Program Files\\Microsoft Visual Studio\\Installer\\')
         self.add_env_path("PATH", r'${PATH}')
 
     def describe_project(self, done=False):
@@ -565,18 +559,19 @@ class MsBuild141(VisualStudio):
     @defer.inlineCallbacks
     def run(self):
         if self.platform is None:
-            config.error(
-                'platform is mandatory. Please specify a string such as "Win32"')
+            config.error('platform is mandatory. Please specify a string such as "Win32"')
 
         self.description = 'building ' + self.describe_project()
         self.descriptionDone = 'built ' + self.describe_project()
-        yield self.updateSummary()
+        self.updateSummary()
 
-        command = ('FOR /F "tokens=*" %%I in '
-                   f'(\'vswhere.exe -version "{self.version_range}" -products * '
-                   '-property installationPath\') '
-                   f' do "%%I\\%VCENV_BAT%" x86 && msbuild "{self.projectfile}" '
-                   f'/p:Configuration="{self.config}" /p:Platform="{self.platform}" /maxcpucount')
+        command = (
+            'FOR /F "tokens=*" %%I in '
+            f'(\'vswhere.exe -version "{self.version_range}" -products * '
+            '-property installationPath\') '
+            f' do "%%I\\%VCENV_BAT%" x86 && msbuild "{self.projectfile}" '
+            f'/p:Configuration="{self.config}" /p:Platform="{self.platform}" /maxcpucount'
+        )
 
         command += _msbuild_format_target_parameter(self.mode, self.project)
         command += _msbuild_format_defines_parameter(self.defines)
