@@ -19,10 +19,15 @@ import warnings
 from unittest import mock
 
 import setuptools  # force import setuptools before any other distutils imports
+from sqlalchemy.exc import RemovedIn20Warning
 
 from buildbot import monkeypatches
-from buildbot.test.util.warnings import assertProducesWarning  # noqa pylint: disable=wrong-import-position
-from buildbot.test.util.warnings import assertProducesWarnings  # noqa pylint: disable=wrong-import-position
+from buildbot.test.util.warnings import (  # noqa pylint: disable=wrong-import-position
+    assertProducesWarning,
+)
+from buildbot.test.util.warnings import (  # noqa pylint: disable=wrong-import-position
+    assertProducesWarnings,
+)
 from buildbot.warnings import DeprecatedApiWarning  # noqa pylint: disable=wrong-import-position
 
 [mock]
@@ -53,8 +58,11 @@ warnings.filterwarnings('error')
 # if buildbot_worker is installed in pip install -e mode, then the docker directory will
 # match "import docker", and produce a warning.
 # We just suppress this warning instead of doing silly workaround.
-warnings.filterwarnings('ignore', "Not importing directory.*docker': missing __init__.py",
-                        category=ImportWarning)
+warnings.filterwarnings(
+    'ignore', "Not importing directory.*docker': missing __init__.py", category=ImportWarning
+)
+
+warnings.filterwarnings('ignore', "unclosed <socket.socket", category=Warning)
 
 # FIXME: needs to be sorted out (#3666)
 warnings.filterwarnings('ignore', "1300 Invalid utf8 character string")
@@ -64,9 +72,9 @@ warnings.filterwarnings('ignore', "'U' mode is deprecated", DeprecationWarning)
 
 # twisted.python.filepath and trial are using bytes file paths when
 # the "native" file path (Unicode) should be used on Windows.
-warnings.filterwarnings('ignore',
-                        "The Windows bytes API has been "
-                        "deprecated, use Unicode filenames instead")
+warnings.filterwarnings(
+    'ignore', "The Windows bytes API has been deprecated, use Unicode filenames instead"
+)
 # moto warning v1.0.0
 warnings.filterwarnings('ignore', "Flags not at the start of the expression")
 warnings.filterwarnings('ignore', r"object\(\) takes no parameters")
@@ -79,14 +87,17 @@ warnings.filterwarnings('ignore', ".*getClientIP was deprecated.*", DeprecationW
 
 # Python 3.7 adds a deprecation importing ABCs from collection.
 # Such imports are made in dependencies (e.g moto, werzeug, pyparsing)
-warnings.filterwarnings('ignore', ".*Using or importing the ABCs from 'collections'.*",
-                        DeprecationWarning)
+warnings.filterwarnings(
+    'ignore', ".*Using or importing the ABCs from 'collections'.*", DeprecationWarning
+)
 
 # more 3.7 warning from moto
-warnings.filterwarnings('ignore', r".*Use 'list\(elem\)' or iteration over elem instead.*",
-                        DeprecationWarning)
-warnings.filterwarnings('ignore', r".*distutils Version classes are deprecated.*",
-                        DeprecationWarning)
+warnings.filterwarnings(
+    'ignore', r".*Use 'list\(elem\)' or iteration over elem instead.*", DeprecationWarning
+)
+warnings.filterwarnings(
+    'ignore', r".*distutils Version classes are deprecated.*", DeprecationWarning
+)
 
 # ignore ResourceWarnings for unclosed sockets for the pg8000 driver on Python 3+ (tech debt: #4508)
 if sys.version_info[0] >= 3 and "pg8000" in os.getenv("BUILDBOT_TEST_DB_URL", ""):
@@ -102,48 +113,99 @@ warnings.filterwarnings('ignore', ".*the imp module is deprecated in favour of i
 warnings.filterwarnings('ignore', ".*time.clock has been deprecated in Python 3.3.*")
 
 # ignore an attrs API warning for APIs used in dependencies
-warnings.filterwarnings('ignore', ".*The usage of `cmp` is deprecated and will be removed "
-                                  "on or after.*", DeprecationWarning)
-
-# ignore a warning emitted by pkg_resources when importing certain namespace packages
-warnings.filterwarnings('ignore', ".*Not importing directory .*/zope: missing __init__",
-                        category=ImportWarning)
-warnings.filterwarnings('ignore', ".*Not importing directory .*/sphinxcontrib: missing __init__",
-                        category=ImportWarning)
+warnings.filterwarnings(
+    'ignore',
+    ".*The usage of `cmp` is deprecated and will be removed on or after.*",
+    DeprecationWarning,
+)
 
 # ignore warnings from importing lib2to3 via buildbot_pkg ->
 # setuptools.command.build_py -> setuptools.lib2to3_ex -> lib2to3
 # https://github.com/pypa/setuptools/issues/2086
-warnings.filterwarnings('ignore', ".*lib2to3 package is deprecated",
-                        category=PendingDeprecationWarning)
+warnings.filterwarnings(
+    'ignore', ".*lib2to3 package is deprecated", category=PendingDeprecationWarning
+)
 
 # on python 3.9, this warning is generated by the stdlib
-warnings.filterwarnings('ignore', ".*The loop argument is deprecated since Python",
-                        category=DeprecationWarning)
+warnings.filterwarnings(
+    'ignore', ".*The loop argument is deprecated since Python", category=DeprecationWarning
+)
 
 # This warning is generated by the EC2 latent
-warnings.filterwarnings('ignore', ".*stream argument is deprecated. Use stream parameter",
-                        category=DeprecationWarning)
+warnings.filterwarnings(
+    'ignore', ".*stream argument is deprecated. Use stream parameter", category=DeprecationWarning
+)
 
 # Botocore imports deprecated urllib3.contrib.pyopenssl for backwards compatibility that we don't
 # use. See https://github.com/boto/botocore/issues/2744
-warnings.filterwarnings('ignore', ".*'urllib3.contrib.pyopenssl' module is deprecated",
-                        category=DeprecationWarning)
+warnings.filterwarnings(
+    'ignore', ".*'urllib3.contrib.pyopenssl' module is deprecated", category=DeprecationWarning
+)
 
 # pipes is still used in astroid and buildbot_worker in default installation
-warnings.filterwarnings('ignore', "'pipes' is deprecated and slated for removal in Python 3.13",
-                        category=DeprecationWarning)
-
-# shown on Python 3.7 on Windows
-warnings.filterwarnings('ignore', "SelectableGroups dict interface is deprecated. Use select.",
-                        category=DeprecationWarning)
-
-# shown on Python 3.11
-warnings.filterwarnings('ignore', ".*pkg_resources is deprecated as an API.*",
-                        category=DeprecationWarning)
-warnings.filterwarnings('ignore', ".*Deprecated call to `pkg_resources.declare_namespace.*",
-                        category=DeprecationWarning)
+warnings.filterwarnings(
+    'ignore',
+    "'pipes' is deprecated and slated for removal in Python 3.13",
+    category=DeprecationWarning,
+)
 
 # boto3 shows this warning when on old Python
-warnings.filterwarnings('ignore', ".*Boto3 will no longer support Python .*",
-                        category=Warning)
+warnings.filterwarnings('ignore', ".*Boto3 will no longer support Python .*", category=Warning)
+
+# autobahn is not updated for Twisted 22.04 and newer
+warnings.filterwarnings(
+    "ignore", "twisted.web.resource.NoResource was deprecated in", category=DeprecationWarning
+)
+
+# Buildbot shows this warning after upgrading to Twisted 23.10
+warnings.filterwarnings('ignore', ".*unclosed event loop.*", category=Warning)
+
+# Ignore sqlalchemy 1.4 warning
+# sqlalchemy.exc.RemovedIn20Warning: Deprecated API features detected! These feature(s) are not
+# compatible with SQLAlchemy 2.0. To prevent incompatible upgrades prior to updating applications,
+# ensure requirements files are pinned to "sqlalchemy<2.0". Set environment variable
+# SQLALCHEMY_WARN_20=1 to show all deprecation warnings.  Set environment variable
+# SQLALCHEMY_SILENCE_UBER_WARNING=1 to silence this message. (Background on SQLAlchemy 2.0
+# at: https://sqlalche.me/e/b8d9) (Background on SQLAlchemy 2.0 at: https://sqlalche.me/e/b8d9)
+warnings.filterwarnings(
+    'ignore',
+    "The current statement is being autocommitted using implicit autocommit",
+    category=RemovedIn20Warning,
+)
+warnings.filterwarnings(
+    'ignore',
+    "Using non-integer/slice indices on Row is deprecated and will be removed in version 2.0",
+    category=RemovedIn20Warning,
+)
+warnings.filterwarnings(
+    'ignore',
+    "The ``bind`` argument for schema methods that invoke SQL against an engine or connection will be required in SQLAlchemy 2.0.",
+    category=RemovedIn20Warning,
+)
+
+# This warning is generated by graphql-core with Python 3.12.
+# See https://github.com/graphql-python/graphql-core/issues/211
+warnings.filterwarnings(
+    'ignore',
+    "'typing.ByteString' is deprecated and slated for removal in Python 3.14",
+    category=DeprecationWarning,
+)
+
+# When using Python 3.12, this generates some dependent package
+warnings.filterwarnings(
+    'ignore',
+    r"datetime.datetime.utcnow\(\) is deprecated and scheduled for "
+    r"removal in a future version. Use timezone-aware objects to represent "
+    r"datetimes in UTC: datetime.datetime.now\(datetime.UTC\).",
+    category=DeprecationWarning,
+)
+
+# Python3.12 generates deprecation warnings like:
+# "This process (pid=6558) is multi-threaded, use of fork() may lead to deadlocks in the child."
+# Tracked in https://github.com/buildbot/buildbot/issues/7276
+warnings.filterwarnings(
+    "ignore",
+    r"This process \(pid=\d+\) is multi-threaded, use of fork\(\) may lead "
+    r"to deadlocks in the child\.",
+    category=DeprecationWarning,
+)
