@@ -13,15 +13,12 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 from buildbot.process.properties import Properties
 from buildbot.test.fake.state import State
 
 
 class Change(State):
-
     project = ''
     repository = ''
     branch = ''
@@ -30,7 +27,7 @@ class Change(State):
     properties = {}
 
     def __init__(self, **kw):
-        State.__init__(self, **kw)
+        super().__init__(**kw)
         # change.properties is a IProperties
         props = Properties()
         props.update(self.properties, "test")
