@@ -14,7 +14,7 @@
 # Copyright Buildbot Team Members
 
 
-__version__ = "1.10.6"
+__version__ = "4.0"
 
 
 class Client:
@@ -23,13 +23,10 @@ class Client:
     start_exception = None
 
     def __init__(self, base_url):
-        Client.latest = self
         self.base_url = base_url
         self.call_args_create_container = []
         self.call_args_create_host_config = []
-        self.called_class_name = None
-        self._images = [
-            {'RepoTags': ['busybox:latest', 'worker:latest', 'tester:latest']}]
+        self._images = [{'RepoTags': ['busybox:latest', 'worker:latest', 'tester:latest']}]
         self._pullable = ['alpine:latest', 'tester:latest']
         self._pullCount = 0
         self._containers = {}
@@ -59,8 +56,7 @@ class Client:
             pass
         else:
             logs = []
-            for line in logs:
-                yield line
+            yield from logs
             self._images.append({'RepoTags': [tag + ':latest']})
 
     def pull(self, image, *args, **kwargs):
@@ -71,19 +67,10 @@ class Client:
     def containers(self, filters=None, *args, **kwargs):
         if filters is not None:
             if 'existing' in filters.get('name', ''):
-                self.create_container(
-                    image='busybox:latest',
-                    name="buildbot-existing-87de7e"
-                )
-                self.create_container(
-                    image='busybox:latest',
-                    name="buildbot-existing-87de7ef"
-                )
+                self.create_container(image='busybox:latest', name="buildbot-existing-87de7e")
+                self.create_container(image='busybox:latest', name="buildbot-existing-87de7ef")
 
-            return [
-                c for c in self._containers.values()
-                if c['name'].startswith(filters['name'])
-            ]
+            return [c for c in self._containers.values() if c['name'].startswith(filters['name'])]
         return self._containers.values()
 
     def create_host_config(self, *args, **kwargs):
@@ -91,7 +78,6 @@ class Client:
 
     def create_container(self, image, *args, **kwargs):
         self.call_args_create_container.append(kwargs)
-        self.called_class_name = self.__class__.__name__
         name = kwargs.get('name', None)
         if 'buggy' in image:
             raise RuntimeError('we could not create this container')
@@ -99,22 +85,25 @@ class Client:
             if c['name'] == name:
                 raise RuntimeError('cannot create with same name')
         ret = {
-            'Id':
-            '8a61192da2b3bb2d922875585e29b74ec0dc4e0117fcbf84c962204e97564cd7',
-            'Warnings': None
+            'Id': '8a61192da2b3bb2d922875585e29b74ec0dc4e0117fcbf84c962204e97564cd7',
+            'Warnings': None,
         }
         self._containers[ret['Id']] = {
             'started': False,
             'image': image,
             'Id': ret['Id'],
             'name': name,  # docker does not return this
-            'Names': [name]  # this what docker returns
+            'Names': ["/" + name],  # this what docker returns
+            "State": "running",
         }
         return ret
 
     def remove_container(self, id, **kwargs):
         del self._containers[id]
 
+    def logs(self, id, tail=None):
+        return f"log for {id}\n1\n2\n3\nend\n".encode("utf-8")
+
     def close(self):
         # dummy close, no connection to cleanup
         pass
