@@ -34,7 +34,7 @@ class Builder(Row):
         projectid=None,
         description=None,
         description_format=None,
-        description_html=None
+        description_html=None,
     ):
         super().__init__(
             id=id,
@@ -61,7 +61,10 @@ class BuildersTags(Row):
     table = "builders_tags"
 
     foreignKeys = ('builderid', 'tagid')
-    required_columns = ('builderid', 'tagid', )
+    required_columns = (
+        'builderid',
+        'tagid',
+    )
     id_column = 'id'
 
     def __init__(self, id=None, builderid=None, tagid=None):
@@ -69,7 +72,6 @@ class BuildersTags(Row):
 
 
 class FakeBuildersComponent(FakeDBComponent):
-
     def setUp(self):
         self.builders = {}
         self.builder_masters = {}
@@ -87,12 +89,10 @@ class FakeBuildersComponent(FakeDBComponent):
                     "description_html": row.description_html,
                 }
             if isinstance(row, BuilderMaster):
-                self.builder_masters[row.id] = \
-                    (row.builderid, row.masterid)
+                self.builder_masters[row.id] = (row.builderid, row.masterid)
             if isinstance(row, BuildersTags):
                 assert row.builderid in self.builders
-                self.builders_tags.setdefault(row.builderid,
-                                              []).append(row.tagid)
+                self.builders_tags.setdefault(row.builderid, []).append(row.tagid)
 
     def findBuilderId(self, name, autoCreate=True):
         for m in self.builders.values():
@@ -108,7 +108,7 @@ class FakeBuildersComponent(FakeDBComponent):
             "description_format": None,
             "description_html": None,
             "projectid": None,
-            "tags": []
+            "tags": [],
         }
         return defer.succeed(id)
 
@@ -128,8 +128,7 @@ class FakeBuildersComponent(FakeDBComponent):
 
     def getBuilder(self, builderid):
         if builderid in self.builders:
-            masterids = [bm[1] for bm in self.builder_masters.values()
-                         if bm[0] == builderid]
+            masterids = [bm[1] for bm in self.builder_masters.values() if bm[0] == builderid]
             bldr = self.builders[builderid].copy()
             bldr['masterids'] = sorted(masterids)
             return defer.succeed(self._row2dict(bldr))
@@ -138,14 +137,12 @@ class FakeBuildersComponent(FakeDBComponent):
     def getBuilders(self, masterid=None, projectid=None):
         rv = []
         for builderid, bldr in self.builders.items():
-            masterids = [bm[1] for bm in self.builder_masters.values()
-                         if bm[0] == builderid]
+            masterids = [bm[1] for bm in self.builder_masters.values() if bm[0] == builderid]
             bldr = bldr.copy()
             bldr['masterids'] = sorted(masterids)
             rv.append(self._row2dict(bldr))
         if masterid is not None:
-            rv = [bd for bd in rv
-                  if masterid in bd['masterids']]
+            rv = [bd for bd in rv if masterid in bd['masterids']]
         if projectid is not None:
             rv = [bd for bd in rv if bd['projectid'] == projectid]
         return defer.succeed(rv)
@@ -158,8 +155,9 @@ class FakeBuildersComponent(FakeDBComponent):
         ])
 
     @defer.inlineCallbacks
-    def updateBuilderInfo(self, builderid, description, description_format, description_html,
-                          projectid, tags):
+    def updateBuilderInfo(
+        self, builderid, description, description_format, description_html, projectid, tags
+    ):
         if builderid in self.builders:
             tags = tags if tags else []
             self.builders[builderid]['description'] = description
@@ -177,6 +175,7 @@ class FakeBuildersComponent(FakeDBComponent):
 
     def _row2dict(self, row):
         row = row.copy()
-        row['tags'] = [self.db.tags.tags[tagid]['name']
-                       for tagid in self.builders_tags.get(row['id'], [])]
+        row['tags'] = [
+            self.db.tags.tags[tagid]['name'] for tagid in self.builders_tags.get(row['id'], [])
+        ]
         return row
