@@ -16,8 +16,7 @@
 import stat
 import tarfile
 from io import BytesIO
-
-import mock
+from unittest import mock
 
 from twisted.internet import defer
 from twisted.python import log
@@ -47,49 +46,53 @@ def _dict_diff(d1, d2):
     d2_keys = set(d2.keys())
     both = d1_keys & d2_keys
 
-    missing_in_d1 = []
-    missing_in_d2 = []
+    missing_in_d1 = {}
+    missing_in_d2 = {}
     different = []
 
     for k in both:
         if isinstance(d1[k], dict) and isinstance(d2[k], dict):
-            missing_in_v1, missing_in_v2, different_in_v = _dict_diff(
-                d1[k], d2[k])
-            missing_in_d1.extend([f'{k}.{m}' for m in missing_in_v1])
-            missing_in_d2.extend([f'{k}.{m}' for m in missing_in_v2])
+            missing_in_v1, missing_in_v2, different_in_v = _dict_diff(d1[k], d2[k])
+
+            for sub_key in missing_in_v1:
+                missing_in_d1[f'{k}.{sub_key}'] = d2[k][sub_key]
+            for sub_key in missing_in_v2:
+                missing_in_d2[f'{k}.{sub_key}'] = d1[k][sub_key]
+
             for child_k, left, right in different_in_v:
                 different.append((f'{k}.{child_k}', left, right))
             continue
         if d1[k] != d2[k]:
             different.append((k, d1[k], d2[k]))
-    missing_in_d1.extend(d2_keys - both)
-    missing_in_d2.extend(d1_keys - both)
+
+    for k in d2_keys - both:
+        missing_in_d1[k] = d2[k]
+    for k in d1_keys - both:
+        missing_in_d2[k] = d1[k]
     return missing_in_d1, missing_in_d2, different
 
 
 def _describe_cmd_difference(exp_command, exp_args, got_command, got_args):
     if exp_command != got_command:
-        return (f'Expected command type {exp_command} got {got_command}. Expected args '
-                f'{exp_args!r}')
+        return f'Expected command type {exp_command} got {got_command}. Expected args {exp_args!r}'
     if exp_args == got_args:
         return ""
     text = ""
     missing_in_exp, missing_in_cmd, diff = _dict_diff(exp_args, got_args)
     if missing_in_exp:
-        missing_dict = {key: got_args[key] for key in missing_in_exp}
-        text += f'Keys in command missing from expectation: {missing_dict!r}\n'
+        text += f'Keys in command missing from expectation: {missing_in_exp!r}\n'
     if missing_in_cmd:
-        missing_dict = {key: exp_args[key] for key in missing_in_cmd}
-        text += f'Keys in expectation missing from command: {missing_dict!r}\n'
+        text += f'Keys in expectation missing from command: {missing_in_cmd!r}\n'
     if diff:
         formatted_diff = [f'"{d[0]}":\nexpected: {d[1]!r}\ngot:      {d[2]!r}\n' for d in diff]
-        text += ('Key differences between expectation and command: {0}\n'.format(
-            '\n'.join(formatted_diff)))
+        text += 'Key differences between expectation and command: {0}\n'.format(
+            '\n'.join(formatted_diff)
+        )
+
     return text
 
 
 class ExpectRemoteRef:
-
     """
     Define an expected RemoteReference in the args to an L{Expect} class
     """
@@ -102,7 +105,6 @@ class ExpectRemoteRef:
 
 
 class Expect:
-
     """
     Define an expected L{RemoteCommand}, with the same arguments
 
@@ -185,7 +187,7 @@ class Expect:
             name, streams = args
             for stream in streams:
                 if stream not in ['header', 'stdout', 'stderr']:
-                    raise Exception(f'Log stream {stream} is not recognized')
+                    raise RuntimeError(f'Log stream {stream} is not recognized')
 
             if name == command.stdioLogName:
                 if 'header' in streams:
@@ -196,10 +198,10 @@ class Expect:
                     command.remote_update([({"stderr": streams['stderr']}, 0)])
             else:
                 if 'header' in streams or 'stderr' in streams:
-                    raise Exception('Non stdio streams only support stdout')
+                    raise RuntimeError('Non stdio streams only support stdout')
                 yield command.addToLog(name, streams['stdout'])
                 if name not in command.logs:
-                    raise Exception(f"{command}.addToLog: no such log {name}")
+                    raise RuntimeError(f"{command}.addToLog: no such log {name}")
 
         elif behavior == 'callable':
             yield args[0](command)
@@ -232,14 +234,18 @@ class Expect:
     def _check(self, case, command):
         case.assertEqual(self.interrupted, command.interrupted)
 
-        if command.remote_command == self.remote_command and \
-                self._cleanup_args(command.args) == self._cleanup_args(self.args):
+        if command.remote_command == self.remote_command and self._cleanup_args(
+            command.args
+        ) == self._cleanup_args(self.args):
             return
 
-        cmd_dif = _describe_cmd_difference(self.remote_command, self.args,
-                                           command.remote_command, command.args)
-        msg = ("Command contents different from expected (command index: "
-               f"{case._expected_commands_popped}):\n{cmd_dif}")
+        cmd_dif = _describe_cmd_difference(
+            self.remote_command, self.args, command.remote_command, command.args
+        )
+        msg = (
+            "Command contents different from expected (command index: "
+            f"{case._expected_commands_popped}):\n{cmd_dif}"
+        )
         raise AssertionError(msg)
 
     def __repr__(self):
@@ -247,7 +253,6 @@ class Expect:
 
 
 class ExpectShell(Expect):
-
     """
     Define an expected L{RemoteShellCommand}, with the same arguments Any
     non-default arguments must be specified explicitly (e.g., usePTY).
@@ -256,10 +261,22 @@ class ExpectShell(Expect):
     class NotSet:
         pass
 
-    def __init__(self, workdir, command, env=NotSet,
-                 want_stdout=1, want_stderr=1, initial_stdin=None,
-                 timeout=20 * 60, max_time=None, sigterm_time=None, logfiles=None,
-                 use_pty=False, log_environ=True, interrupt_signal='KILL'):
+    def __init__(
+        self,
+        workdir,
+        command,
+        env=NotSet,
+        want_stdout=1,
+        want_stderr=1,
+        initial_stdin=None,
+        timeout=20 * 60,
+        max_time=None,
+        sigterm_time=None,
+        logfiles=None,
+        use_pty=False,
+        log_environ=True,
+        interrupt_signal='KILL',
+    ):
         if env is self.NotSet:
             env = {}
         if logfiles is None:
@@ -275,7 +292,7 @@ class ExpectShell(Expect):
             'maxTime': max_time,
             'logfiles': logfiles,
             'usePTY': use_pty,
-            'logEnviron': log_environ
+            'logEnviron': log_environ,
         }
 
         if sigterm_time is not self.NotSet:
@@ -289,7 +306,6 @@ class ExpectShell(Expect):
 
 
 class ExpectStat(Expect):
-
     def __init__(self, file, workdir=None, log_environ=None):
         args = {'file': file}
         if workdir is not None:
@@ -299,8 +315,9 @@ class ExpectStat(Expect):
 
         super().__init__('stat', args)
 
-    def stat(self, mode, inode=99, dev=99, nlink=1, uid=0, gid=0, size=99,
-             atime=0, mtime=0, ctime=0):
+    def stat(
+        self, mode, inode=99, dev=99, nlink=1, uid=0, gid=0, size=99, atime=0, mtime=0, ctime=0
+    ):
         self.update('stat', [mode, inode, dev, nlink, uid, gid, size, atime, mtime, ctime])
         return self
 
@@ -317,11 +334,18 @@ class ExpectStat(Expect):
 
 
 class ExpectUploadFile(Expect):
-
-    def __init__(self, blocksize=None, maxsize=None, workersrc=None, workdir=None,
-                 writer=None, keepstamp=None, slavesrc=None, interrupted=False):
-        args = {'workdir': workdir, 'writer': writer,
-                'blocksize': blocksize, 'maxsize': maxsize}
+    def __init__(
+        self,
+        blocksize=None,
+        maxsize=None,
+        workersrc=None,
+        workdir=None,
+        writer=None,
+        keepstamp=None,
+        slavesrc=None,
+        interrupted=False,
+    ):
+        args = {'workdir': workdir, 'writer': writer, 'blocksize': blocksize, 'maxsize': maxsize}
         if keepstamp is not None:
             args['keepstamp'] = keepstamp
         if slavesrc is not None:
@@ -354,11 +378,25 @@ class ExpectUploadFile(Expect):
 
 
 class ExpectUploadDirectory(Expect):
-
-    def __init__(self, compress=None, blocksize=None, maxsize=None, workersrc=None, workdir=None,
-                 writer=None, keepstamp=None, slavesrc=None, interrupted=False):
-        args = {'compress': compress, 'workdir': workdir, 'writer': writer,
-                'blocksize': blocksize, 'maxsize': maxsize}
+    def __init__(
+        self,
+        compress=None,
+        blocksize=None,
+        maxsize=None,
+        workersrc=None,
+        workdir=None,
+        writer=None,
+        keepstamp=None,
+        slavesrc=None,
+        interrupted=False,
+    ):
+        args = {
+            'compress': compress,
+            'workdir': workdir,
+            'writer': writer,
+            'blocksize': blocksize,
+            'maxsize': maxsize,
+        }
         if keepstamp is not None:
             args['keepstamp'] = keepstamp
         if slavesrc is not None:
@@ -391,16 +429,32 @@ class ExpectUploadDirectory(Expect):
         return self
 
     def __repr__(self):
-        return (f"ExpectUploadDirectory({repr(self.args['workdir'])}, "
-                f"{repr(self.args['workersrc'])})")
+        return (
+            f"ExpectUploadDirectory({repr(self.args['workdir'])}, "
+            f"{repr(self.args['workersrc'])})"
+        )
 
 
 class ExpectDownloadFile(Expect):
-
-    def __init__(self, blocksize=None, maxsize=None, workerdest=None, workdir=None,
-                reader=None, mode=None, interrupted=False, slavesrc=None, slavedest=None):
-        args = {'workdir': workdir, 'reader': reader, 'mode': mode,
-                'blocksize': blocksize, 'maxsize': maxsize}
+    def __init__(
+        self,
+        blocksize=None,
+        maxsize=None,
+        workerdest=None,
+        workdir=None,
+        reader=None,
+        mode=None,
+        interrupted=False,
+        slavesrc=None,
+        slavedest=None,
+    ):
+        args = {
+            'workdir': workdir,
+            'reader': reader,
+            'mode': mode,
+            'blocksize': blocksize,
+            'maxsize': maxsize,
+        }
         if slavesrc is not None:
             args['slavesrc'] = slavesrc
         if slavedest is not None:
@@ -426,12 +480,13 @@ class ExpectDownloadFile(Expect):
         return self
 
     def __repr__(self):
-        return (f"ExpectUploadDirectory({repr(self.args['workdir'])}, "
-                f"{repr(self.args['workerdest'])})")
+        return (
+            f"ExpectUploadDirectory({repr(self.args['workdir'])}, "
+            f"{repr(self.args['workerdest'])})"
+        )
 
 
 class ExpectMkdir(Expect):
-
     def __init__(self, dir=None, log_environ=None):
         args = {'dir': dir}
         if log_environ is not None:
@@ -444,7 +499,6 @@ class ExpectMkdir(Expect):
 
 
 class ExpectRmdir(Expect):
-
     def __init__(self, dir=None, log_environ=None, timeout=None, path=None):
         args = {'dir': dir}
         if log_environ is not None:
@@ -461,7 +515,6 @@ class ExpectRmdir(Expect):
 
 
 class ExpectCpdir(Expect):
-
     def __init__(self, fromdir=None, todir=None, log_environ=None, timeout=None, max_time=None):
         args = {'fromdir': fromdir, 'todir': todir}
         if log_environ is not None:
@@ -478,7 +531,6 @@ class ExpectCpdir(Expect):
 
 
 class ExpectGlob(Expect):
-
     def __init__(self, path=None, log_environ=None):
         args = {'path': path}
         if log_environ is not None:
@@ -497,7 +549,6 @@ class ExpectGlob(Expect):
 
 
 class ExpectListdir(Expect):
-
     def __init__(self, dir=None):
         args = {'dir': dir}
 
@@ -514,7 +565,6 @@ class ExpectListdir(Expect):
 
 
 class ExpectRmfile(Expect):
-
     def __init__(self, path=None, log_environ=None):
         args = {'path': path}
         if log_environ is not None:
@@ -532,8 +582,7 @@ def _check_env_is_expected(test, expected_env, env):
 
     env = env or {}
     for var, value in expected_env.items():
-        test.assertEqual(env.get(var), value,
-                         f'Expected environment to have {var} = {repr(value)}')
+        test.assertEqual(env.get(var), value, f'Expected environment to have {var} = {repr(value)}')
 
 
 class ExpectMasterShell:
@@ -569,9 +618,11 @@ class ExpectMasterShell:
         return self
 
     def _check(self, test, command, workdir, env):
-        test.assertDictEqual({'command': command, 'workdir': workdir},
-                             {'command': self._command, 'workdir': self._workdir},
-                             "unexpected command run")
+        test.assertDictEqual(
+            {'command': command, 'workdir': workdir},
+            {'command': self._command, 'workdir': self._workdir},
+            "unexpected command run",
+        )
 
         _check_env_is_expected(test, self._env, env)
         return (self._exit, self._stdout, self._stderr)
@@ -594,7 +645,6 @@ class FakeRunProcess:
 
 
 class TestBuildStepMixin:
-
     """
     @ivar build: the fake build containing the step
     @ivar progress: mock progress object
@@ -604,27 +654,29 @@ class TestBuildStepMixin:
 
     def setup_test_build_step(self, want_data=True, want_db=False, want_mq=False):
         if not hasattr(self, 'reactor'):
-            raise Exception('Reactor has not yet been setup for step')
+            raise RuntimeError('Reactor has not yet been setup for step')
 
         self._interrupt_remote_command_numbers = []
 
         self._expected_commands = []
         self._expected_commands_popped = 0
 
-        self.master = fakemaster.make_master(self, wantData=want_data, wantDb=want_db,
-                                             wantMq=want_mq)
+        self.master = fakemaster.make_master(
+            self, wantData=want_data, wantDb=want_db, wantMq=want_mq
+        )
 
         self.patch(runprocess, "create_process", self._patched_create_process)
         self._master_run_process_expect_env = {}
 
+        self.worker = worker.FakeWorker(self.master)
+        self.worker.attached(None)
+
     def tear_down_test_build_step(self):
         pass
 
     def _setup_fake_build(self, worker_version, worker_env, build_files):
         if worker_version is None:
-            worker_version = {
-                '*': '99.99'
-            }
+            worker_version = {'*': '99.99'}
 
         if worker_env is None:
             worker_env = {}
@@ -649,9 +701,14 @@ class TestBuildStepMixin:
 
         return build
 
-    def setup_step(self, step, worker_version=None, worker_env=None,
-                   build_files=None, want_default_work_dir=True):
-
+    def setup_step(
+        self,
+        step,
+        worker_version=None,
+        worker_env=None,
+        build_files=None,
+        want_default_work_dir=True,
+    ):
         self.step = buildstep.create_step_from_step_or_factory(step)
 
         # set defaults
@@ -660,18 +717,8 @@ class TestBuildStepMixin:
 
         self.build = self._setup_fake_build(worker_version, worker_env, build_files)
         self.step.setBuild(self.build)
-
-        # watch for properties being set
-        self.properties = self.build.getProperties()
-
-        # step.progress
-
         self.step.progress = mock.Mock(name="progress")
-
-        # step.worker
-
-        self.worker = self.step.worker = worker.FakeWorker(self.master)
-        self.worker.attached(None)
+        self.step.worker = self.worker
 
         # step overrides
 
@@ -680,6 +727,7 @@ class TestBuildStepMixin:
             self.step.logs[name] = _log
             self.step._connectPendingLogObservers()
             return defer.succeed(_log)
+
         self.step.addLog = addLog
 
         def addHTMLLog(name, html):
@@ -687,15 +735,17 @@ class TestBuildStepMixin:
             html = bytes2unicode(html)
             _log.addStdout(html)
             return defer.succeed(None)
+
         self.step.addHTMLLog = addHTMLLog
 
         def addCompleteLog(name, text):
             _log = logfile.FakeLogFile(name)
             if name in self.step.logs:
-                raise Exception(f'Attempt to add log {name} twice to the logs')
+                raise RuntimeError(f'Attempt to add log {name} twice to the logs')
             self.step.logs[name] = _log
             _log.addStdout(text)
             return defer.succeed(None)
+
         self.step.addCompleteLog = addCompleteLog
 
         self._got_test_result_sets = []
@@ -712,10 +762,18 @@ class TestBuildStepMixin:
 
         self._got_test_results = []
 
-        def add_test_result(setid, value, test_name=None, test_code_path=None, line=None,
-                            duration_ns=None):
-            self._got_test_results.append((setid, value, test_name, test_code_path, line,
-                                           duration_ns))
+        def add_test_result(
+            setid, value, test_name=None, test_code_path=None, line=None, duration_ns=None
+        ):
+            self._got_test_results.append((
+                setid,
+                value,
+                test_name,
+                test_code_path,
+                line,
+                duration_ns,
+            ))
+
         self.step.addTestResult = add_test_result
 
         self._got_build_data = {}
@@ -798,8 +856,9 @@ class TestBuildStepMixin:
 
         @returns: Deferred
         """
-        self.conn = connection.FakeConnection(self, "WorkerForBuilder(connection)", self.step,
-                                              self._interrupt_remote_command_numbers)
+        self.conn = connection.FakeConnection(
+            self, "WorkerForBuilder(connection)", self.step, self._interrupt_remote_command_numbers
+        )
         self.step.setupProgress()
         result = yield self.step.startStep(self.conn)
 
@@ -827,18 +886,23 @@ class TestBuildStepMixin:
                 self.exp_state_string,
                 stepStateString[stepids[0]],
                 f"expected state_string {self.exp_state_string!r}, got "
-                f"{stepStateString[stepids[0]]!r}")
+                f"{stepStateString[stepids[0]]!r}",
+            )
+
+        properties = self.build.getProperties()
+
         for pn, (pv, ps) in self.exp_properties.items():
-            self.assertTrue(self.properties.hasProperty(pn), f"missing property '{pn}'")
-            self.assertEqual(self.properties.getProperty(pn), pv, f"property '{pn}'")
+            self.assertTrue(properties.hasProperty(pn), f"missing property '{pn}'")
+            self.assertEqual(properties.getProperty(pn), pv, f"property '{pn}'")
             if ps is not None:
                 self.assertEqual(
-                    self.properties.getPropertySource(pn), ps,
-                    f"property {pn!r} source has source "
-                    f"{self.properties.getPropertySource(pn)!r}")
+                    properties.getPropertySource(pn),
+                    ps,
+                    f"property {pn!r} source has source {properties.getPropertySource(pn)!r}",
+                )
 
         for pn in self.exp_missing_properties:
-            self.assertFalse(self.properties.hasProperty(pn), f"unexpected property '{pn}'")
+            self.assertFalse(properties.hasProperty(pn), f"unexpected property '{pn}'")
 
         for l, exp in self.exp_logfiles.items():
             got = self.step.logs[l].stdout
@@ -849,8 +913,7 @@ class TestBuildStepMixin:
             self._match_log(exp, got, 'stderr')
 
         if self.exp_exception:
-            self.assertEqual(
-                len(self.flushLoggedErrors(self.exp_exception)), 1)
+            self.assertEqual(len(self.flushLoggedErrors(self.exp_exception)), 1)
 
         self.assertEqual(self._exp_test_result_sets, self._got_test_result_sets)
         self.assertEqual(self._exp_test_results, self._got_test_results)
@@ -881,12 +944,16 @@ class TestBuildStepMixin:
             exp = self._expected_commands.pop(0)
             self._expected_commands_popped += 1
         else:
-            self.fail(f"got remote command {command.remote_command} {command.args!r} when no "
-                      "further commands were expected")
+            self.fail(
+                f"got remote command {command.remote_command} {command.args!r} when no "
+                "further commands were expected"
+            )
 
         if not isinstance(exp, Expect):
-            self.fail(f"got command {command.remote_command} {command.args!r} but the "
-                      f"expectation is not instance of Expect: {exp!r}")
+            self.fail(
+                f"got command {command.remote_command} {command.args!r} but the "
+                f"expectation is not instance of Expect: {exp!r}"
+            )
 
         try:
             exp._check(self, command)
@@ -902,23 +969,37 @@ class TestBuildStepMixin:
         if not exp.connection_broken:
             command.remote_complete()
 
-    def _patched_create_process(self, reactor, command, workdir=None, env=None,
-                                collect_stdout=True, collect_stderr=True, stderr_is_error=False,
-                                io_timeout=300, runtime_timeout=3600, sigterm_timeout=5,
-                                initial_stdin=None, use_pty=False):
-
+    def _patched_create_process(
+        self,
+        reactor,
+        command,
+        workdir=None,
+        env=None,
+        collect_stdout=True,
+        collect_stderr=True,
+        stderr_is_error=False,
+        io_timeout=300,
+        runtime_timeout=3600,
+        sigterm_timeout=5,
+        initial_stdin=None,
+        use_pty=False,
+    ):
         _check_env_is_expected(self, self._master_run_process_expect_env, env)
 
         if self._expected_commands:
             exp = self._expected_commands.pop(0)
             self._expected_commands_popped += 1
         else:
-            self.fail(f"got master command {command!r} at {workdir} ({env!r}) when no "
-                      "further commands were expected")
+            self.fail(
+                f"got master command {command!r} at {workdir} ({env!r}) when no "
+                "further commands were expected"
+            )
 
         if not isinstance(exp, ExpectMasterShell):
-            self.fail(f"got command {command!r} at {workdir} ({env!r}) but the "
-                      f"expectation is not instance of ExpectMasterShell: {exp!r}")
+            self.fail(
+                f"got command {command!r} at {workdir} ({env!r}) but the "
+                f"expectation is not instance of ExpectMasterShell: {exp!r}"
+            )
 
         try:
             rc, stdout, stderr = exp._check(self, command, workdir, env)
