@@ -15,13 +15,11 @@
 
 
 from twisted.internet import defer
-from twisted.internet import task
 
 from buildbot.test.fake import fakemaster
 
 
 class ChangeSourceMixin:
-
     """
     This class is used for testing change sources, and handles a few things:
 
@@ -38,8 +36,7 @@ class ChangeSourceMixin:
 
     def setUpChangeSource(self):
         "Set up the mixin - returns a deferred."
-        self.master = fakemaster.make_master(wantDb=True, wantData=True,
-                                             testcase=self)
+        self.master = fakemaster.make_master(self, wantDb=True, wantData=True)
         assert not hasattr(self.master, 'addChange')  # just checking..
         return defer.succeed(None)
 
@@ -49,26 +46,16 @@ class ChangeSourceMixin:
         if not self.started:
             return
         if self.changesource.running:
-            yield defer.maybeDeferred(self.changesource.stopService)
+            yield self.changesource.stopService()
         yield self.changesource.disownServiceParent()
         return
 
+    @defer.inlineCallbacks
     def attachChangeSource(self, cs):
-        "Set up a change source for testing; sets its .master attribute"
         self.changesource = cs
-        # FIXME some changesource does not have master property yet but
-        # mailchangesource has :-/
-        try:
-            self.changesource.master = self.master
-        except AttributeError:
-            self.changesource.setServiceParent(self.master)
-
-        # configure the service to let secret manager render the secrets
-        d = self.changesource.configureService()
-        d.addErrback(lambda _: None)
-        # also, now that changesources are ClusteredServices, setting up
-        # the clock here helps in the unit tests that check that behavior
-        self.changesource.clock = task.Clock()
+        yield self.changesource.setServiceParent(self.master)
+        yield self.changesource.configureService()
+        return cs
 
     def startChangeSource(self):
         "start the change source as a service"
@@ -91,11 +78,8 @@ class ChangeSourceMixin:
         else:
             name = self.DEFAULT_NAME
 
-        self.master.data.updates.changesourceIds[
-            name] = self.DUMMY_CHANGESOURCE_ID
+        self.master.data.updates.changesourceIds[name] = self.DUMMY_CHANGESOURCE_ID
         if otherMaster:
-            self.master.data.updates.changesourceMasters[
-                self.DUMMY_CHANGESOURCE_ID] = otherMaster
+            self.master.data.updates.changesourceMasters[self.DUMMY_CHANGESOURCE_ID] = otherMaster
         else:
-            del self.master.data.updates.changesourceMasters[
-                self.DUMMY_CHANGESOURCE_ID]
+            del self.master.data.updates.changesourceMasters[self.DUMMY_CHANGESOURCE_ID]
