@@ -17,7 +17,6 @@
 import os
 
 from sqlalchemy.schema import MetaData
-
 from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.python import log
@@ -32,17 +31,54 @@ from buildbot.util.sautils import withoutSqliteForeignKeys
 
 def skip_for_dialect(dialect):
     """Decorator to skip a test for a particular SQLAlchemy dialect."""
+
     def dec(fn):
         def wrap(self, *args, **kwargs):
             if self.db_engine.dialect.name == dialect:
                 raise unittest.SkipTest(f"Not supported on dialect '{dialect}'")
             return fn(self, *args, **kwargs)
+
         return wrap
+
     return dec
 
 
-class RealDatabaseMixin:
+def get_trial_parallel_from_cwd(cwd):
+    cwd = cwd.rstrip("/")
+    last = os.path.basename(cwd)
+    prev = os.path.basename(os.path.dirname(cwd))
+    if last == "_trial_temp":
+        return False
+    if prev == "_trial_temp":
+        try:
+            return int(last)
+        except ValueError:
+            return None
+    return None
 
+
+def resolve_test_index_in_db_url(db_url):
+    test_id = get_trial_parallel_from_cwd(os.getcwd())
+
+    if "{TEST_ID}" in db_url:
+        return db_url.replace("{TEST_ID}", str(test_id or 0))
+
+    if db_url == 'sqlite://':
+        return db_url
+
+    if test_id is not None and test_id is not False:
+        if db_url.startswith('sqlite:///'):
+            # Relative DB URLs in the test directory are fine.
+            path = db_url[len('sqlite:///') :]
+            if not os.path.relpath(path).startswith(".."):
+                return db_url
+
+        raise RuntimeError("Database tests cannnot run in parallel")
+
+    return db_url
+
+
+class RealDatabaseMixin:
     """
     A class that sets up a real database for testing.  This sets self.db_url to
     the URL for the database.  By default, it specifies an in-memory SQLite
@@ -118,11 +154,11 @@ class RealDatabaseMixin:
         # pylint: disable=too-many-nested-blocks
 
         try:
-            meta = MetaData(bind=conn)
+            meta = MetaData()
 
             # Reflect database contents. May fail, e.g. if table references
             # non-existent table in SQLite.
-            meta.reflect()
+            meta.reflect(bind=conn)
 
             # Restore `use_alter` settings to break known reference cycles.
             # Main goal of this part is to remove SQLAlchemy warning
@@ -142,15 +178,14 @@ class RealDatabaseMixin:
             # SQLAlchemy wouldn't be able to break circular references.
             # Sqlalchemy fk support with sqlite is not yet perfect, so we must deactivate fk during
             # that operation, even though we made our possible to use use_alter
-            with withoutSqliteForeignKeys(conn.engine, conn):
-                meta.drop_all()
+            with withoutSqliteForeignKeys(conn):
+                meta.drop_all(bind=conn)
 
         except Exception:
             # sometimes this goes badly wrong; being able to see the schema
             # can be a big help
             if conn.engine.dialect.name == 'sqlite':
-                r = conn.execute("select sql from sqlite_master "
-                                 "where type='table'")
+                r = conn.execute("select sql from sqlite_master where type='table'")
                 log.msg("Current schema:")
                 for row in r.fetchall():
                     log.msg(row.sql)
@@ -158,17 +193,16 @@ class RealDatabaseMixin:
 
     def __thd_create_tables(self, conn, table_names):
         table_names_set = set(table_names)
-        tables = [t for t in model.Model.metadata.tables.values()
-                  if t.name in table_names_set]
+        tables = [t for t in model.Model.metadata.tables.values() if t.name in table_names_set]
         # Create tables using create_all() method. This way not only tables
         # and direct indices are created, but also deferred references
         # (that use use_alter=True in definition).
-        model.Model.metadata.create_all(
-            bind=conn, tables=tables, checkfirst=True)
+        model.Model.metadata.create_all(bind=conn, tables=tables, checkfirst=True)
 
     @defer.inlineCallbacks
-    def setUpRealDatabase(self, table_names=None, basedir='basedir',
-                          want_pool=True, sqlite_memory=True):
+    def setUpRealDatabase(
+        self, table_names=None, basedir='basedir', want_pool=True, sqlite_memory=True
+    ):
         """
 
         Set up a database.  Ordinarily sets up an engine and a pool and takes
@@ -191,12 +225,13 @@ class RealDatabaseMixin:
         if not sqlite_memory and self.db_url == default_sqlite:
             self.db_url = "sqlite:///tmp.sqlite"
 
+        self.db_url = resolve_test_index_in_db_url(self.db_url)
+
         if not os.path.exists(basedir):
             os.makedirs(basedir)
 
         self.basedir = basedir
-        self.db_engine = enginestrategy.create_engine(self.db_url,
-                                                      basedir=basedir)
+        self.db_engine = enginestrategy.create_engine(self.db_url, basedir=basedir)
         # if the caller does not want a pool, we're done.
         if not want_pool:
             return None
@@ -225,8 +260,9 @@ class RealDatabaseMixin:
         """
         # sort the tables by dependency
         all_table_names = {row.table for row in rows}
-        ordered_tables = [t for t in model.Model.metadata.sorted_tables
-                          if t.name in all_table_names]
+        ordered_tables = [
+            t for t in model.Model.metadata.sorted_tables if t.name in all_table_names
+        ]
 
         def thd(conn):
             # insert into tables -- in order
@@ -234,10 +270,11 @@ class RealDatabaseMixin:
                 for row in [r for r in rows if r.table == tbl.name]:
                     tbl = model.Model.metadata.tables[row.table]
                     try:
-                        tbl.insert(bind=conn).execute(row.values)
+                        conn.execute(tbl.insert().values(row.values))
                     except Exception:
                         log.msg(f"while inserting {row} - {row.values}")
                         raise
+
         yield self.db_pool.do(thd)
 
 
@@ -245,8 +282,9 @@ class RealDatabaseWithConnectorMixin(RealDatabaseMixin):
     # Same as RealDatabaseMixin, except that a real DBConnector is also setup in a correct way.
 
     @defer.inlineCallbacks
-    def setUpRealDatabaseWithConnector(self, master, table_names=None, basedir='basedir',
-                                       want_pool=True, sqlite_memory=True):
+    def setUpRealDatabaseWithConnector(
+        self, master, table_names=None, basedir='basedir', want_pool=True, sqlite_memory=True
+    ):
         yield self.setUpRealDatabase(table_names, basedir, want_pool, sqlite_memory)
         master.config.db['db_url'] = self.db_url
         master.db = DBConnector(self.basedir)
@@ -258,7 +296,6 @@ class RealDatabaseWithConnectorMixin(RealDatabaseMixin):
 
 
 class TestCase(unittest.TestCase):
-
     @defer.inlineCallbacks
     def assertFailure(self, d, excp):
         exception = None
