@@ -19,7 +19,6 @@ import os
 import sqlalchemy as sa
 from alembic.operations import Operations
 from alembic.runtime.migration import MigrationContext
-
 from twisted.internet import defer
 from twisted.python import log
 
@@ -39,7 +38,6 @@ from buildbot.util import sautils
 
 
 class MigrateTestMixin(TestReactorMixin, db.RealDatabaseMixin, dirs.DirsMixin):
-
     @defer.inlineCallbacks
     def setUpMigrateTest(self):
         self.setup_test_reactor()
@@ -58,26 +56,26 @@ class MigrateTestMixin(TestReactorMixin, db.RealDatabaseMixin, dirs.DirsMixin):
         return self.tearDownRealDatabase()
 
     @defer.inlineCallbacks
-    def do_test_migration(self, base_revision, target_revision,
-                          setup_thd_cb, verify_thd_cb):
-
+    def do_test_migration(self, base_revision, target_revision, setup_thd_cb, verify_thd_cb):
         def setup_thd(conn):
             metadata = sa.MetaData()
             table = sautils.Table(
-                'alembic_version', metadata,
+                'alembic_version',
+                metadata,
                 sa.Column("version_num", sa.String(32), nullable=False),
             )
             table.create(bind=conn)
-            conn.execute(table.insert(), version_num=base_revision)
+            conn.execute(table.insert().values(version_num=base_revision))
             setup_thd_cb(conn)
+
         yield self.db.pool.do(setup_thd)
 
         alembic_scripts = self.db.model.alembic_get_scripts()
 
         def upgrade_thd(engine):
             with querylog.log_queries():
-                with sautils.withoutSqliteForeignKeys(engine):
-                    with engine.connect() as conn:
+                with engine.connect() as conn:
+                    with sautils.withoutSqliteForeignKeys(conn):
 
                         def upgrade(rev, context):
                             log.msg(f'Upgrading from {rev} to {target_revision}')
@@ -95,16 +93,20 @@ class MigrateTestMixin(TestReactorMixin, db.RealDatabaseMixin, dirs.DirsMixin):
             # charsets are only a problem for MySQL
             if engine.dialect.name != 'mysql':
                 return
-            dbs = [r[0] for r in engine.execute("show tables")]
+            dbs = [r[0] for r in engine.exec_driver_sql("show tables")]
             for tbl in dbs:
-                r = engine.execute(f"show create table {tbl}")
+                r = engine.exec_driver_sql(f"show create table {tbl}")
                 create_table = r.fetchone()[1]
-                self.assertIn('DEFAULT CHARSET=utf8', create_table,
-                              f"table {tbl} does not have the utf8 charset")
+                self.assertIn(
+                    'DEFAULT CHARSET=utf8',
+                    create_table,
+                    f"table {tbl} does not have the utf8 charset",
+                )
+
         yield self.db.pool.do(check_table_charsets_thd)
 
-        def verify_thd(engine):
-            with sautils.withoutSqliteForeignKeys(engine):
-                verify_thd_cb(engine)
+        def verify_thd(conn):
+            with sautils.withoutSqliteForeignKeys(conn):
+                verify_thd_cb(conn)
 
         yield self.db.pool.do(verify_thd)
