@@ -28,7 +28,6 @@ validatorsByName = {}
 
 
 class Validator:
-
     name = None
     hasArgs = False
 
@@ -36,7 +35,6 @@ class Validator:
         raise NotImplementedError
 
     class __metaclass__(type):
-
         def __new__(mcs, name, bases, attrs):
             cls = type.__new__(mcs, name, bases, attrs)
             if 'name' in attrs and attrs['name']:
@@ -47,6 +45,7 @@ class Validator:
 
 # Basic types
 
+
 class InstanceValidator(Validator):
     types = ()
 
@@ -97,8 +96,9 @@ class IdentifierValidator(Validator):
     name = 'identifier'
     hasArgs = True
 
-    ident_re = re.compile('^[a-zA-Z\u00a0-\U0010ffff_-][a-zA-Z0-9\u00a0-\U0010ffff_-]*$',
-                          flags=re.UNICODE)
+    ident_re = re.compile(
+        '^[a-zA-Z\u00a0-\U0010ffff_-][a-zA-Z0-9\u00a0-\U0010ffff_-]*$', flags=re.UNICODE
+    )
 
     def __init__(self, len):
         self.len = len
@@ -113,11 +113,11 @@ class IdentifierValidator(Validator):
         elif len(object) > self.len:
             yield f"{name} - {object!r} - is longer than {self.len} characters"
 
+
 # Miscellaneous
 
 
 class NoneOk:
-
     def __init__(self, original):
         self.original = original
 
@@ -125,20 +125,18 @@ class NoneOk:
         if object is None:
             return
         else:
-            for msg in self.original.validate(name, object):
-                yield msg
+            yield from self.original.validate(name, object)
 
 
 class Any:
-
     def validate(self, name, object):
         return
 
+
 # Compound Types
 
 
 class DictValidator(Validator):
-
     name = 'dict'
 
     def __init__(self, optionalNames=None, **keys):
@@ -164,8 +162,7 @@ class DictValidator(Validator):
         if missing:
             yield f'{name} is missing keys {", ".join([repr(n) for n in missing])}'
         for k in gotNames & self.expectedNames:
-            for msg in self.keys[k].validate(f"{name}[{k!r}]", object[k]):
-                yield msg
+            yield from self.keys[k].validate(f"{name}[{k!r}]", object[k])
 
 
 class SequenceValidator(Validator):
@@ -180,9 +177,7 @@ class SequenceValidator(Validator):
             return
 
         for idx, elt in enumerate(object):
-            for msg in self.elementValidator.validate(f"{name}[{idx}]",
-                                                      elt):
-                yield msg
+            yield from self.elementValidator.validate(f"{name}[{idx}]", elt)
 
 
 class ListValidator(SequenceValidator):
@@ -203,7 +198,6 @@ class StringListValidator(ListValidator):
 
 
 class SourcedPropertiesValidator(Validator):
-
     name = 'sourced-properties'
 
     def validate(self, name, object):
@@ -226,7 +220,6 @@ class SourcedPropertiesValidator(Validator):
 
 
 class JsonValidator(Validator):
-
     name = 'json'
 
     def validate(self, name, object):
@@ -237,7 +230,6 @@ class JsonValidator(Validator):
 
 
 class PatchValidator(Validator):
-
     name = 'patch'
 
     validator = DictValidator(
@@ -249,12 +241,10 @@ class PatchValidator(Validator):
     )
 
     def validate(self, name, object):
-        for msg in self.validator.validate(name, object):
-            yield msg
+        yield from self.validator.validate(name, object)
 
 
 class MessageValidator(Validator):
-
     routingKeyValidator = TupleValidator(StrValidator())
 
     def __init__(self, events, messageValidator):
@@ -276,13 +266,10 @@ class MessageValidator(Validator):
             if event not in self.events:
                 yield f"routing key event {event!r} is not valid"
 
-        for msg in self.messageValidator.validate(f"{routingKey[0]} message",
-                                                  message):
-            yield msg
+        yield from self.messageValidator.validate(f"{routingKey[0]} message", message)
 
 
 class Selector(Validator):
-
     def __init__(self):
         self.selectors = []
 
@@ -296,8 +283,7 @@ class Selector(Validator):
             yield f"{arg_object!r}: not a not data options and data dict: {e}"
         for selector, validator in self.selectors:
             if selector is None or selector(arg):
-                for msg in validator.validate(name, object):
-                    yield msg
+                yield from validator.validate(name, object)
                 return
         yield f"no match for selector argument {arg!r}"
 
@@ -312,15 +298,18 @@ dbdict = {}
 # masters
 
 message['masters'] = Selector()
-message['masters'].add(None,
-                       MessageValidator(
-                           events=[b'started', b'stopped'],
-                           messageValidator=DictValidator(
-                               masterid=IntValidator(),
-                               name=StringValidator(),
-                               active=BooleanValidator(),
-                               # last_active is not included
-                           )))
+message['masters'].add(
+    None,
+    MessageValidator(
+        events=[b'started', b'stopped'],
+        messageValidator=DictValidator(
+            masterid=IntValidator(),
+            name=StringValidator(),
+            active=BooleanValidator(),
+            # last_active is not included
+        ),
+    ),
+)
 
 dbdict['masterdict'] = DictValidator(
     id=IntValidator(),
@@ -339,19 +328,19 @@ _sourcestamp = {
     "project": StringValidator(),
     "codebase": StringValidator(),
     "created_at": DateTimeValidator(),
-    "patch": NoneOk(DictValidator(
-        body=NoneOk(BinaryValidator()),
-        level=NoneOk(IntValidator()),
-        subdir=NoneOk(StringValidator()),
-        author=NoneOk(StringValidator()),
-        comment=NoneOk(StringValidator()))),
+    "patch": NoneOk(
+        DictValidator(
+            body=NoneOk(BinaryValidator()),
+            level=NoneOk(IntValidator()),
+            subdir=NoneOk(StringValidator()),
+            author=NoneOk(StringValidator()),
+            comment=NoneOk(StringValidator()),
+        )
+    ),
 }
 
 message['sourcestamps'] = Selector()
-message['sourcestamps'].add(None,
-                            DictValidator(
-                                **_sourcestamp
-                            ))
+message['sourcestamps'].add(None, DictValidator(**_sourcestamp))
 
 dbdict['ssdict'] = DictValidator(
     ssid=IntValidator(),
@@ -382,14 +371,17 @@ dbdict['projectdict'] = DictValidator(
 # builder
 
 message['builders'] = Selector()
-message['builders'].add(None,
-                        MessageValidator(
-                            events=[b'started', b'stopped'],
-                            messageValidator=DictValidator(
-                                builderid=IntValidator(),
-                                masterid=IntValidator(),
-                                name=StringValidator(),
-                            )))
+message['builders'].add(
+    None,
+    MessageValidator(
+        events=[b'started', b'stopped'],
+        messageValidator=DictValidator(
+            builderid=IntValidator(),
+            masterid=IntValidator(),
+            name=StringValidator(),
+        ),
+    ),
+)
 
 dbdict['builderdict'] = DictValidator(
     id=IntValidator(),
@@ -414,6 +406,7 @@ dbdict['workerdict'] = DictValidator(
         )
     ),
     paused=BooleanValidator(),
+    pause_reason=NoneOk(StringValidator()),
     graceful=BooleanValidator(),
     connected_to=ListValidator(IntValidator()),
     workerinfo=JsonValidator(),
@@ -435,27 +428,26 @@ _buildset = {
 _buildsetEvents = [b'new', b'complete']
 
 message['buildsets'] = Selector()
-message['buildsets'].add(lambda k: k[-1] == 'new',
-                         MessageValidator(
-                             events=_buildsetEvents,
-                             messageValidator=DictValidator(
-                                 scheduler=StringValidator(),  # only for 'new'
-                                 sourcestamps=ListValidator(
-                                     DictValidator(
-                                         **_sourcestamp
-                                     )),
-                                 **_buildset
-                             )))
-message['buildsets'].add(None,
-                         MessageValidator(
-                             events=_buildsetEvents,
-                             messageValidator=DictValidator(
-                                 sourcestamps=ListValidator(
-                                     DictValidator(
-                                         **_sourcestamp
-                                     )),
-                                 **_buildset
-                             )))
+message['buildsets'].add(
+    lambda k: k[-1] == 'new',
+    MessageValidator(
+        events=_buildsetEvents,
+        messageValidator=DictValidator(
+            scheduler=StringValidator(),  # only for 'new'
+            sourcestamps=ListValidator(DictValidator(**_sourcestamp)),
+            **_buildset,
+        ),
+    ),
+)
+message['buildsets'].add(
+    None,
+    MessageValidator(
+        events=_buildsetEvents,
+        messageValidator=DictValidator(
+            sourcestamps=ListValidator(DictValidator(**_sourcestamp)), **_buildset
+        ),
+    ),
+)
 
 dbdict['bsdict'] = DictValidator(
     bsid=IntValidator(),
@@ -466,6 +458,7 @@ dbdict['bsdict'] = DictValidator(
     complete=BooleanValidator(),
     complete_at=NoneOk(DateTimeValidator()),
     results=NoneOk(IntValidator()),
+    rebuilt_buildid=NoneOk(IntValidator()),
     parent_buildid=NoneOk(IntValidator()),
     parent_relationship=NoneOk(StringValidator()),
 )
@@ -473,43 +466,47 @@ dbdict['bsdict'] = DictValidator(
 # buildrequest
 
 message['buildrequests'] = Selector()
-message['buildrequests'].add(None,
-                             MessageValidator(
-                                 events=[b'new', b'claimed', b'unclaimed'],
-                                 messageValidator=DictValidator(
-                                     # TODO: probably wrong!
-                                     brid=IntValidator(),
-                                     builderid=IntValidator(),
-                                     bsid=IntValidator(),
-                                     buildername=StringValidator(),
-                                 )))
+message['buildrequests'].add(
+    None,
+    MessageValidator(
+        events=[b'new', b'claimed', b'unclaimed'],
+        messageValidator=DictValidator(
+            # TODO: probably wrong!
+            brid=IntValidator(),
+            builderid=IntValidator(),
+            bsid=IntValidator(),
+            buildername=StringValidator(),
+        ),
+    ),
+)
 
 # change
 
 message['changes'] = Selector()
-message['changes'].add(None,
-                       MessageValidator(
-                           events=[b'new'],
-                           messageValidator=DictValidator(
-                               changeid=IntValidator(),
-                               parent_changeids=ListValidator(IntValidator()),
-                               author=StringValidator(),
-                               committer=StringValidator(),
-                               files=ListValidator(StringValidator()),
-                               comments=StringValidator(),
-                               revision=NoneOk(StringValidator()),
-                               when_timestamp=IntValidator(),
-                               branch=NoneOk(StringValidator()),
-                               category=NoneOk(StringValidator()),
-                               revlink=NoneOk(StringValidator()),
-                               properties=SourcedPropertiesValidator(),
-                               repository=StringValidator(),
-                               project=StringValidator(),
-                               codebase=StringValidator(),
-                               sourcestamp=DictValidator(
-                                   **_sourcestamp
-                               ),
-                           )))
+message['changes'].add(
+    None,
+    MessageValidator(
+        events=[b'new'],
+        messageValidator=DictValidator(
+            changeid=IntValidator(),
+            parent_changeids=ListValidator(IntValidator()),
+            author=StringValidator(),
+            committer=StringValidator(),
+            files=ListValidator(StringValidator()),
+            comments=StringValidator(),
+            revision=NoneOk(StringValidator()),
+            when_timestamp=IntValidator(),
+            branch=NoneOk(StringValidator()),
+            category=NoneOk(StringValidator()),
+            revlink=NoneOk(StringValidator()),
+            properties=SourcedPropertiesValidator(),
+            repository=StringValidator(),
+            project=StringValidator(),
+            codebase=StringValidator(),
+            sourcestamp=DictValidator(**_sourcestamp),
+        ),
+    ),
+)
 
 dbdict['chdict'] = DictValidator(
     changeid=IntValidator(),
@@ -565,12 +562,9 @@ _build = {
 _buildEvents = [b'new', b'complete']
 
 message['builds'] = Selector()
-message['builds'].add(None,
-                      MessageValidator(
-                          events=_buildEvents,
-                          messageValidator=DictValidator(
-                              **_build
-                          )))
+message['builds'].add(
+    None, MessageValidator(events=_buildEvents, messageValidator=DictValidator(**_build))
+)
 
 # As build's properties are fetched at DATA API level,
 # a distinction shall be made as both are not equal.
@@ -584,13 +578,15 @@ dbdict['dbbuilddict'] = buildbase = DictValidator(
     masterid=IntValidator(),
     started_at=DateTimeValidator(),
     complete_at=NoneOk(DateTimeValidator()),
+    locks_duration_s=IntValidator(),
     state_string=StringValidator(),
     results=NoneOk(IntValidator()),
 )
 
 # Validates DATA API layer
 dbdict['builddict'] = DictValidator(
-    properties=NoneOk(SourcedPropertiesValidator()), **buildbase.keys)
+    properties=NoneOk(SourcedPropertiesValidator()), **buildbase.keys
+)
 
 # build data
 
@@ -603,9 +599,7 @@ _build_data_msgdict = DictValidator(
 )
 
 message['build_data'] = Selector()
-message['build_data'].add(None,
-                          MessageValidator(events=[],
-                                           messageValidator=_build_data_msgdict))
+message['build_data'].add(None, MessageValidator(events=[], messageValidator=_build_data_msgdict))
 
 dbdict['build_datadict'] = DictValidator(
     buildid=IntValidator(),
@@ -633,12 +627,9 @@ _step = {
 _stepEvents = [b'new', b'complete']
 
 message['steps'] = Selector()
-message['steps'].add(None,
-                     MessageValidator(
-                         events=_stepEvents,
-                         messageValidator=DictValidator(
-                             **_step
-                         )))
+message['steps'].add(
+    None, MessageValidator(events=_stepEvents, messageValidator=DictValidator(**_step))
+)
 
 dbdict['stepdict'] = DictValidator(
     id=IntValidator(),
@@ -646,6 +637,7 @@ dbdict['stepdict'] = DictValidator(
     name=IdentifierValidator(50),
     buildid=IntValidator(),
     started_at=DateTimeValidator(),
+    locks_acquired_at=NoneOk(DateTimeValidator()),
     complete_at=NoneOk(DateTimeValidator()),
     state_string=StringValidator(),
     results=NoneOk(IntValidator()),
@@ -661,7 +653,7 @@ _log = {
     "stepid": IntValidator(),
     "complete": BooleanValidator(),
     "num_lines": IntValidator(),
-    "type": IdentifierValidator(1)
+    "type": IdentifierValidator(1),
 }
 _logEvents = ['new', 'complete', 'appended']
 
@@ -674,7 +666,8 @@ dbdict['logdict'] = DictValidator(
     slug=IdentifierValidator(50),
     complete=BooleanValidator(),
     num_lines=IntValidator(),
-    type=IdentifierValidator(1))
+    type=IdentifierValidator(1),
+)
 
 # test results sets
 
@@ -687,13 +680,13 @@ _test_result_set_msgdict = DictValidator(
     value_unit=StringValidator(),
     tests_passed=NoneOk(IntValidator()),
     tests_failed=NoneOk(IntValidator()),
-    complete=BooleanValidator()
+    complete=BooleanValidator(),
 )
 
 message['test_result_sets'] = Selector()
-message['test_result_sets'].add(None,
-                                MessageValidator(events=[b'new', b'completed'],
-                                                 messageValidator=_test_result_set_msgdict))
+message['test_result_sets'].add(
+    None, MessageValidator(events=[b'new', b'completed'], messageValidator=_test_result_set_msgdict)
+)
 
 dbdict['test_result_setdict'] = DictValidator(
     id=IntValidator(),
@@ -705,7 +698,7 @@ dbdict['test_result_setdict'] = DictValidator(
     value_unit=StringValidator(),
     tests_passed=NoneOk(IntValidator()),
     tests_failed=NoneOk(IntValidator()),
-    complete=BooleanValidator()
+    complete=BooleanValidator(),
 )
 
 # test results
@@ -721,9 +714,9 @@ _test_results_msgdict = DictValidator(
 )
 
 message['test_results'] = Selector()
-message['test_results'].add(None,
-                            MessageValidator(events=[b'new'],
-                                             messageValidator=_test_results_msgdict))
+message['test_results'].add(
+    None, MessageValidator(events=[b'new'], messageValidator=_test_results_msgdict)
+)
 
 dbdict['test_resultdict'] = DictValidator(
     id=IntValidator(),
@@ -739,6 +732,7 @@ dbdict['test_resultdict'] = DictValidator(
 
 # external functions
 
+
 def _verify(testcase, validator, name, object):
     msgs = list(validator.validate(name, object))
     if msgs:
@@ -756,8 +750,7 @@ def verifyMessage(testcase, routingKey, message_):
     # -1 being the event, and -2 the id.
 
     validator = message[bytes2unicode(routingKey[-3])]
-    _verify(testcase, validator, '',
-            (routingKey, (routingKey, message_)))
+    _verify(testcase, validator, '', (routingKey, (routingKey, message_)))
 
 
 def verifyDbDict(testcase, type, value):
