@@ -43,7 +43,6 @@ log = Logger()
 
 @implementer(IHttpResponse)
 class TxRequestsResponseWrapper:
-
     def __init__(self, res):
         self._res = res
 
@@ -64,7 +63,6 @@ class TxRequestsResponseWrapper:
 
 @implementer(IHttpResponse)
 class TreqResponseWrapper:
-
     def __init__(self, res):
         self._res = res
 
@@ -91,6 +89,7 @@ class HTTPClientService(service.SharedService):
     I provide minimal get/post/put/delete API with automatic baseurl joining, and json data encoding
     that is suitable for use from buildbot services.
     """
+
     TREQ_PROS_AND_CONS = textwrap.dedent("""
        txrequests is based on requests and is probably a bit more mature, but it requires threads
        to run, so has more overhead.
@@ -109,10 +108,10 @@ class HTTPClientService(service.SharedService):
     PREFER_TREQ = False
     MAX_THREADS = 5
 
-    def __init__(self, base_url, auth=None, headers=None, verify=None, debug=False,
-                 skipEncoding=False):
-        assert not base_url.endswith(
-            "/"), "baseurl should not end with /: " + base_url
+    def __init__(
+        self, base_url, auth=None, headers=None, verify=None, debug=False, skipEncoding=False
+    ):
+        assert not base_url.endswith("/"), "baseurl should not end with /: " + base_url
         super().__init__()
         self._base_url = base_url
         self._auth = auth
@@ -131,11 +130,13 @@ class HTTPClientService(service.SharedService):
     @staticmethod
     def checkAvailable(from_module):
         """Call me at checkConfig time to properly report config error
-           if neither txrequests or treq is installed
+        if neither txrequests or treq is installed
         """
         if txrequests is None and treq is None:
-            config.error(f"neither txrequests nor treq is installed, but {from_module} is "
-                         f"requiring it\n\n{HTTPClientService.TREQ_PROS_AND_CONS}")
+            config.error(
+                f"neither txrequests nor treq is installed, but {from_module} is "
+                f"requiring it\n\n{HTTPClientService.TREQ_PROS_AND_CONS}"
+            )
 
     def startService(self):
         # treq only supports basicauth, so we force txrequests if the auth is
@@ -146,10 +147,11 @@ class HTTPClientService(service.SharedService):
             self._session = txrequests.Session(maxthreads=self.MAX_THREADS)
             self._doRequest = self._doTxRequest
         elif treq is None:
-            raise ImportError("{classname} requires either txrequest or treq install."
-                              " Users should call {classname}.checkAvailable() during checkConfig()"
-                              " to properly alert the user.".format(
-                                  classname=self.__class__.__name__))
+            raise ImportError(
+                "{classname} requires either txrequest or treq install."
+                " Users should call {classname}.checkAvailable() during checkConfig()"
+                " to properly alert the user.".format(classname=self.__class__.__name__)
+            )
         else:
             self._doRequest = self._doTReq
             self._pool = HTTPConnectionPool(self.master.reactor)
@@ -216,8 +218,8 @@ class HTTPClientService(service.SharedService):
     def _doTReq(self, method, ep, **kwargs):
         url, kwargs = yield self._prepareRequest(ep, kwargs)
         # treq requires header values to be an array
-        kwargs['headers'] = {k: [v]
-                             for k, v in kwargs['headers'].items()}
+        if "headers" in kwargs:
+            kwargs['headers'] = {k: [v] for k, v in kwargs["headers"].items()}
         kwargs['agent'] = self._agent
 
         res = yield getattr(treq, method)(url, **kwargs)
