@@ -49,34 +49,47 @@ PRICE_TOO_LOW = 'price-too-low'
 
 
 class EC2LatentWorker(AbstractLatentWorker):
-
     instance = image = None
     _poll_resolution = 5  # hook point for tests
 
-    def __init__(self, name, password, instance_type, ami=None,
-                 valid_ami_owners=None, valid_ami_location_regex=None,
-                 elastic_ip=None, identifier=None, secret_identifier=None,
-                 aws_id_file_path=None, user_data=None, region=None,
-                 keypair_name=None,
-                 security_name=None,
-                 spot_instance=False, max_spot_price=1.6, volumes=None,
-                 placement=None, price_multiplier=1.2, tags=None,
-                 product_description='Linux/UNIX',
-                 subnet_id=None, security_group_ids=None, instance_profile_name=None,
-                 block_device_map=None, session=None,
-                 **kwargs):
-
+    def __init__(
+        self,
+        name,
+        password,
+        instance_type,
+        ami=None,
+        valid_ami_owners=None,
+        valid_ami_location_regex=None,
+        elastic_ip=None,
+        identifier=None,
+        secret_identifier=None,
+        aws_id_file_path=None,
+        user_data=None,
+        region=None,
+        keypair_name=None,
+        security_name=None,
+        spot_instance=False,
+        max_spot_price=1.6,
+        volumes=None,
+        placement=None,
+        price_multiplier=1.2,
+        tags=None,
+        product_description='Linux/UNIX',
+        subnet_id=None,
+        security_group_ids=None,
+        instance_profile_name=None,
+        block_device_map=None,
+        session=None,
+        **kwargs,
+    ):
         if not boto3:
-            config.error("The python module 'boto3' is needed to use a "
-                         "EC2LatentWorker")
+            config.error("The python module 'boto3' is needed to use a EC2LatentWorker")
 
         if keypair_name is None:
-            config.error("EC2LatentWorker: 'keypair_name' parameter must be "
-                         "specified")
+            config.error("EC2LatentWorker: 'keypair_name' parameter must be specified")
 
         if security_name is None and not subnet_id:
-            config.error("EC2LatentWorker: 'security_name' parameter must be "
-                         "specified")
+            config.error("EC2LatentWorker: 'security_name' parameter must be specified")
 
         if volumes is None:
             volumes = []
@@ -89,13 +102,16 @@ class EC2LatentWorker(AbstractLatentWorker):
         if security_name and subnet_id:
             raise ValueError(
                 'security_name (EC2 classic security groups) is not supported '
-                'in a VPC.  Use security_group_ids instead.')
-        if not ((ami is not None) ^
-                (valid_ami_owners is not None or
-                 valid_ami_location_regex is not None)):
+                'in a VPC.  Use security_group_ids instead.'
+            )
+        if not (
+            (ami is not None)
+            ^ (valid_ami_owners is not None or valid_ami_location_regex is not None)
+        ):
             raise ValueError(
                 'You must provide either a specific ami, or one or both of '
-                'valid_ami_location_regex and valid_ami_owners')
+                'valid_ami_location_regex and valid_ami_owners'
+            )
         self.ami = ami
         if valid_ami_owners is not None:
             if isinstance(valid_ami_owners, int):
@@ -104,17 +120,17 @@ class EC2LatentWorker(AbstractLatentWorker):
                 for element in valid_ami_owners:
                     if not isinstance(element, int):
                         raise ValueError(
-                            'valid_ami_owners should be int or iterable '
-                            'of ints', element)
+                            'valid_ami_owners should be int or iterable of ints', element
+                        )
         if valid_ami_location_regex is not None:
             if not isinstance(valid_ami_location_regex, str):
-                raise ValueError(
-                    'valid_ami_location_regex should be a string')
+                raise ValueError('valid_ami_location_regex should be a string')
             # pre-compile the regex
             valid_ami_location_regex = re.compile(valid_ami_location_regex)
         if spot_instance and price_multiplier is None and max_spot_price is None:
-            raise ValueError('You must provide either one, or both, of '
-                             'price_multiplier or max_spot_price')
+            raise ValueError(
+                'You must provide either one, or both, of price_multiplier or max_spot_price'
+            )
         self.valid_ami_owners = None
         if valid_ami_owners:
             self.valid_ami_owners = [str(o) for o in valid_ami_owners]
@@ -134,25 +150,27 @@ class EC2LatentWorker(AbstractLatentWorker):
         else:
             self.placement = None
         if identifier is None:
-            assert secret_identifier is None, (
-                'supply both or neither of identifier, secret_identifier')
+            assert (
+                secret_identifier is None
+            ), 'supply both or neither of identifier, secret_identifier'
             if aws_id_file_path is None:
                 home = os.environ['HOME']
                 default_path = os.path.join(home, '.ec2', 'aws_id')
                 if os.path.exists(default_path):
                     aws_id_file_path = default_path
             if aws_id_file_path:
-                log.msg('WARNING: EC2LatentWorker is using deprecated '
-                        'aws_id file')
+                log.msg('WARNING: EC2LatentWorker is using deprecated aws_id file')
                 with open(aws_id_file_path, 'r', encoding='utf-8') as aws_file:
                     identifier = aws_file.readline().strip()
                     secret_identifier = aws_file.readline().strip()
         else:
-            assert aws_id_file_path is None, \
-                'if you supply the identifier and secret_identifier, ' \
+            assert aws_id_file_path is None, (
+                'if you supply the identifier and secret_identifier, '
                 'do not specify the aws_id_file_path'
-            assert secret_identifier is not None, \
-                'supply both or neither of identifier, secret_identifier'
+            )
+            assert (
+                secret_identifier is not None
+            ), 'supply both or neither of identifier, secret_identifier'
 
         region_found = None
 
@@ -161,9 +179,8 @@ class EC2LatentWorker(AbstractLatentWorker):
         if self.session is None:
             if region is not None:
                 for r in boto3.Session(
-                        aws_access_key_id=identifier,
-                        aws_secret_access_key=secret_identifier).get_available_regions('ec2'):
-
+                    aws_access_key_id=identifier, aws_secret_access_key=secret_identifier
+                ).get_available_regions('ec2'):
                     if r == region:
                         region_found = r
 
@@ -171,10 +188,10 @@ class EC2LatentWorker(AbstractLatentWorker):
                     self.session = boto3.Session(
                         region_name=region,
                         aws_access_key_id=identifier,
-                        aws_secret_access_key=secret_identifier)
+                        aws_secret_access_key=secret_identifier,
+                    )
                 else:
-                    raise ValueError(
-                        'The specified region does not exist: ' + region)
+                    raise ValueError('The specified region does not exist: ' + region)
 
             else:
                 # boto2 defaulted to us-east-1 when region was unset, we
@@ -185,7 +202,7 @@ class EC2LatentWorker(AbstractLatentWorker):
                 self.session = boto3.Session(
                     aws_access_key_id=identifier,
                     aws_secret_access_key=secret_identifier,
-                    region_name=region
+                    region_name=region,
                 )
 
         self.ec2 = self.session.resource('ec2')
@@ -205,12 +222,14 @@ class EC2LatentWorker(AbstractLatentWorker):
         except ClientError as e:
             if 'InvalidKeyPair.NotFound' not in str(e):
                 if 'AuthFailure' in str(e):
-                    log.msg('POSSIBLE CAUSES OF ERROR:\n'
-                            '  Did you supply your AWS credentials?\n'
-                            '  Did you sign up for EC2?\n'
-                            '  Did you put a credit card number in your AWS '
-                            'account?\n'
-                            'Please doublecheck before reporting a problem.\n')
+                    log.msg(
+                        'POSSIBLE CAUSES OF ERROR:\n'
+                        '  Did you supply your AWS credentials?\n'
+                        '  Did you sign up for EC2?\n'
+                        '  Did you put a credit card number in your AWS '
+                        'account?\n'
+                        'Please doublecheck before reporting a problem.\n'
+                    )
                 raise
             # make one; we would always do this, and stash the result, if we
             # needed the key (for instance, to SSH to the box).  We'd then
@@ -225,7 +244,8 @@ class EC2LatentWorker(AbstractLatentWorker):
                 if 'InvalidGroup.NotFound' in str(e):
                     self.security_group = self.ec2.create_security_group(
                         GroupName=security_name,
-                        Description='Authorization to access the buildbot instance.')
+                        Description='Authorization to access the buildbot instance.',
+                    )
                     # Authorize the master as necessary
                     # TODO this is where we'd open the hole to do the reverse pb
                     # connect to the buildbot
@@ -249,22 +269,20 @@ class EC2LatentWorker(AbstractLatentWorker):
             # Using ec2.vpc_addresses.filter(PublicIps=[elastic_ip]) throws a
             # NotImplementedError("Filtering not supported in describe_address.") in moto
             # https://github.com/spulec/moto/blob/100ec4e7c8aa3fde87ff6981e2139768816992e4/moto/ec2/responses/elastic_ip_addresses.py#L52
-            addresses = self.ec2.meta.client.describe_addresses(
-                PublicIps=[elastic_ip])['Addresses']
+            addresses = self.ec2.meta.client.describe_addresses(PublicIps=[elastic_ip])['Addresses']
             if not addresses:
-                raise ValueError(
-                    'Could not find EIP for IP: ' + elastic_ip)
+                raise ValueError('Could not find EIP for IP: ' + elastic_ip)
             allocation_id = addresses[0]['AllocationId']
             elastic_ip = self.ec2.VpcAddress(allocation_id)
         self.elastic_ip = elastic_ip
         self.subnet_id = subnet_id
         self.security_group_ids = security_group_ids
-        self.classic_security_groups = [
-            self.security_name] if self.security_name else None
+        self.classic_security_groups = [self.security_name] if self.security_name else None
         self.instance_profile_name = instance_profile_name
         self.tags = tags
-        self.block_device_map = self.create_block_device_mapping(
-            block_device_map) if block_device_map else None
+        self.block_device_map = (
+            self.create_block_device_mapping(block_device_map) if block_device_map else None
+        )
 
     def create_block_device_mapping(self, mapping_definitions):
         if not isinstance(mapping_definitions, list):
@@ -309,14 +327,12 @@ class EC2LatentWorker(AbstractLatentWorker):
                                 int_sort = int(alpha_sort)
                             except ValueError:
                                 level = 1
-                options.append([int_sort, alpha_sort,
-                                image.image_location, image.id, image])
+                options.append([int_sort, alpha_sort, image.image_location, image.id, image])
             if level:
                 log.msg(f'sorting images at level {level}')
                 options = [candidate[level:] for candidate in options]
         else:
-            options = [(image.image_location, image.id, image) for image
-                       in images]
+            options = [(image.image_location, image.id, image) for image in images]
         options.sort()
         images = [f'{candidate[-1].id} ({candidate[-1].image_location})' for candidate in options]
         log.msg(f"sorted images (last is chosen): {', '.join(images)}")
@@ -328,6 +344,7 @@ class EC2LatentWorker(AbstractLatentWorker):
         if self.instance is None:
             return None
         return self.instance.public_dns_name
+
     dns = property(dns)
 
     def start_instance(self, build):
@@ -350,18 +367,20 @@ class EC2LatentWorker(AbstractLatentWorker):
             "SecurityGroups": self.classic_security_groups,
             "InstanceType": self.instance_type,
             "UserData": self.user_data,
-            "Placement": self._remove_none_opts(AvailabilityZone=self.placement,),
+            "Placement": self._remove_none_opts(
+                AvailabilityZone=self.placement,
+            ),
             "MinCount": 1,
             "MaxCount": 1,
             "SubnetId": self.subnet_id,
             "SecurityGroupIds": self.security_group_ids,
-            "IamInstanceProfile": self._remove_none_opts(Name=self.instance_profile_name,),
-            "BlockDeviceMappings": self.block_device_map
+            "IamInstanceProfile": self._remove_none_opts(
+                Name=self.instance_profile_name,
+            ),
+            "BlockDeviceMappings": self.block_device_map,
         }
         launch_opts = self._remove_none_opts(launch_opts)
-        reservations = self.ec2.create_instances(
-            **launch_opts
-        )
+        reservations = self.ec2.create_instances(**launch_opts)
 
         self.instance = reservations[0]
         instance_id, start_time = self._wait_for_instance()
@@ -372,7 +391,6 @@ class EC2LatentWorker(AbstractLatentWorker):
         return None
 
     def stop_instance(self, fast=False):
-
         if self.instance is None:
             # be gentle.  Something may just be trying to alert us that an
             # instance never attached, and it's because, somehow, we never
@@ -380,14 +398,12 @@ class EC2LatentWorker(AbstractLatentWorker):
             return defer.succeed(None)
         instance = self.instance
         self.output = self.instance = None
-        return threads.deferToThread(
-            self._stop_instance, instance, fast)
+        return threads.deferToThread(self._stop_instance, instance, fast)
 
     def _attach_volumes(self):
         for volume_id, device_node in self.volumes:
             vol = self.ec2.Volume(volume_id)
-            vol.attach_to_instance(
-                InstanceId=self.instance.id, Device=device_node)
+            vol.attach_to_instance(InstanceId=self.instance.id, Device=device_node)
             log.msg(f'Attaching EBS volume {volume_id} to {device_node}.')
 
     def _stop_instance(self, instance, fast):
@@ -396,8 +412,10 @@ class EC2LatentWorker(AbstractLatentWorker):
         instance.reload()
         if instance.state['Name'] not in (SHUTTINGDOWN, TERMINATED):
             instance.terminate()
-            log.msg(f'{self.__class__.__name__} {self.workername} terminating instance '
-                    f'{instance.id}')
+            log.msg(
+                f'{self.__class__.__name__} {self.workername} terminating instance '
+                f'{instance.id}'
+            )
         duration = 0
         interval = self._poll_resolution
         if fast:
@@ -409,20 +427,24 @@ class EC2LatentWorker(AbstractLatentWorker):
             time.sleep(interval)
             duration += interval
             if duration % 60 == 0:
-                log.msg(f'{self.__class__.__name__} {self.workername} has waited {duration // 60} '
-                        f'minutes for instance {instance.id} to end')
+                log.msg(
+                    f'{self.__class__.__name__} {self.workername} has waited {duration // 60} '
+                    f'minutes for instance {instance.id} to end'
+                )
             instance.reload()
-        log.msg(f'{self.__class__.__name__} {self.workername} instance {instance.id} {goal} after '
-                f'about {duration // 60} minutes {duration % 60} seconds')
+        log.msg(
+            f'{self.__class__.__name__} {self.workername} instance {instance.id} {goal} after '
+            f'about {duration // 60} minutes {duration % 60} seconds'
+        )
 
     def _bid_price_from_spot_price_history(self):
         timestamp_yesterday = time.gmtime(int(time.time() - 86400))
-        spot_history_starttime = time.strftime(
-            '%Y-%m-%dT%H:%M:%SZ', timestamp_yesterday)
+        spot_history_starttime = time.strftime('%Y-%m-%dT%H:%M:%SZ', timestamp_yesterday)
         spot_prices = self.ec2.meta.client.describe_spot_price_history(
             StartTime=spot_history_starttime,
             ProductDescriptions=[self.product_description],
-            AvailabilityZone=self.placement)
+            AvailabilityZone=self.placement,
+        )
         price_sum = 0.0
         price_count = 0
         for price in spot_prices['SpotPriceHistory']:
@@ -440,11 +462,12 @@ class EC2LatentWorker(AbstractLatentWorker):
             bid_price = self.max_spot_price
         else:
             bid_price = self._bid_price_from_spot_price_history()
-            if self.max_spot_price is not None \
-               and bid_price > self.max_spot_price:
+            if self.max_spot_price is not None and bid_price > self.max_spot_price:
                 bid_price = self.max_spot_price
-        log.msg(f'{self.__class__.__name__} {self.workername} requesting spot instance with '
-                f'price {bid_price:0.4f}')
+        log.msg(
+            f'{self.__class__.__name__} {self.workername} requesting spot instance with '
+            f'price {bid_price:0.4f}'
+        )
 
         image = self.get_image()
         reservations = self.ec2.meta.client.request_spot_instances(
@@ -463,11 +486,10 @@ class EC2LatentWorker(AbstractLatentWorker):
                 BlockDeviceMappings=self.block_device_map,
                 IamInstanceProfile=self._remove_none_opts(
                     Name=self.instance_profile_name,
-                )
-            )
+                ),
+            ),
         )
-        request, success = self._thd_wait_for_request(
-            reservations['SpotInstanceRequests'][0])
+        request, success = self._thd_wait_for_request(reservations['SpotInstanceRequests'][0])
         if not success:
             raise LatentWorkerFailedToSubstantiate()
         instance_id = request['InstanceId']
@@ -476,16 +498,20 @@ class EC2LatentWorker(AbstractLatentWorker):
         return instance_id, image.id, start_time
 
     def _wait_for_instance(self):
-        log.msg(f'{self.__class__.__name__} {self.workername} waiting for instance '
-                f'{self.instance.id} to start')
+        log.msg(
+            f'{self.__class__.__name__} {self.workername} waiting for instance '
+            f'{self.instance.id} to start'
+        )
         duration = 0
         interval = self._poll_resolution
         while self.instance.state['Name'] == PENDING:
             time.sleep(interval)
             duration += interval
             if duration % 60 == 0:
-                log.msg(f'{self.__class__.__name__} {self.workername} has waited {duration // 60} '
-                        f'minutes for instance {self.instance.id}')
+                log.msg(
+                    f'{self.__class__.__name__} {self.workername} has waited {duration // 60} '
+                    f'minutes for instance {self.instance.id}'
+                )
             self.instance.reload()
 
         if self.instance.state['Name'] == RUNNING:
@@ -493,17 +519,20 @@ class EC2LatentWorker(AbstractLatentWorker):
             self.output = self.instance.console_output().get('Output')
             minutes = duration // 60
             seconds = duration % 60
-            log.msg(f'{self.__class__.__name__} {self.workername} instance {self.instance.id} '
-                    f'started on {self.dns} in about {minutes} minutes {seconds} seconds '
-                    f'({self.output})')
+            log.msg(
+                f'{self.__class__.__name__} {self.workername} instance {self.instance.id} '
+                f'started on {self.dns} in about {minutes} minutes {seconds} seconds '
+                f'({self.output})'
+            )
             if self.elastic_ip is not None:
                 self.elastic_ip.associate(InstanceId=self.instance.id)
             start_time = f'{minutes // 60:02d}:{minutes % 60:02d}:{seconds:02d}'
             if self.volumes:
                 self._attach_volumes()
             if self.tags:
-                self.instance.create_tags(Tags=[{"Key": k, "Value": v}
-                                                for k, v in self.tags.items()])
+                self.instance.create_tags(
+                    Tags=[{"Key": k, "Value": v} for k, v in self.tags.items()]
+                )
             return self.instance.id, start_time
         else:
             self.failed_to_start(self.instance.id, self.instance.state['Name'])
@@ -519,7 +548,8 @@ class EC2LatentWorker(AbstractLatentWorker):
             # ID 'sir-abcd1234' does not exist" exception.
             try:
                 requests = self.ec2.meta.client.describe_spot_instance_requests(
-                    SpotInstanceRequestIds=[reservation['SpotInstanceRequestId']])
+                    SpotInstanceRequestIds=[reservation['SpotInstanceRequestId']]
+                )
             except ClientError as e:
                 if 'InvalidSpotInstanceRequestID.NotFound' in str(e):
                     requests = None
@@ -535,28 +565,36 @@ class EC2LatentWorker(AbstractLatentWorker):
             time.sleep(interval)
             duration += interval
             if duration % 10 == 0:
-                log.msg(f"{self.__class__.__name__} {self.workername} has waited {duration} "
-                        f"seconds for spot request {reservation['SpotInstanceRequestId']}")
+                log.msg(
+                    f"{self.__class__.__name__} {self.workername} has waited {duration} "
+                    f"seconds for spot request {reservation['SpotInstanceRequestId']}"
+                )
 
         if request_status == FULFILLED:
             minutes = duration // 60
             seconds = duration % 60
-            log.msg(f"{self.__class__.__name__} {self.workername} spot request "
-                    f"{request['SpotInstanceRequestId']} fulfilled in about {minutes} minutes "
-                    f"{seconds} seconds")
+            log.msg(
+                f"{self.__class__.__name__} {self.workername} spot request "
+                f"{request['SpotInstanceRequestId']} fulfilled in about {minutes} minutes "
+                f"{seconds} seconds"
+            )
             return request, True
         elif request_status == PRICE_TOO_LOW:
             self.ec2.meta.client.cancel_spot_instance_requests(
-                SpotInstanceRequestIds=[request['SpotInstanceRequestId']])
-            log.msg(f'{self.__class__.__name__} {self.workername} spot request rejected, spot '
-                    'price too low')
-            raise LatentWorkerFailedToSubstantiate(
-                request['SpotInstanceRequestId'], request_status)
+                SpotInstanceRequestIds=[request['SpotInstanceRequestId']]
+            )
+            log.msg(
+                f'{self.__class__.__name__} {self.workername} spot request rejected, spot '
+                'price too low'
+            )
+            raise LatentWorkerFailedToSubstantiate(request['SpotInstanceRequestId'], request_status)
         else:
-            log.msg(f"{self.__class__.__name__} {self.workername} failed to fulfill spot request "
-                    f"{request['SpotInstanceRequestId']} with status {request_status}")
+            log.msg(
+                f"{self.__class__.__name__} {self.workername} failed to fulfill spot request "
+                f"{request['SpotInstanceRequestId']} with status {request_status}"
+            )
             # try to cancel, just for good measure
             self.ec2.meta.client.cancel_spot_instance_requests(
-                SpotInstanceRequestIds=[request['SpotInstanceRequestId']])
-            raise LatentWorkerFailedToSubstantiate(
-                request['SpotInstanceRequestId'], request_status)
+                SpotInstanceRequestIds=[request['SpotInstanceRequestId']]
+            )
+            raise LatentWorkerFailedToSubstantiate(request['SpotInstanceRequestId'], request_status)
