@@ -44,7 +44,6 @@ class Listener(base.UpdateRegistrationListener):
 
 
 class ReferenceableProxy(pb.Referenceable):
-
     def __init__(self, impl):
         assert isinstance(impl, self.ImplClass)
         self.impl = impl
@@ -75,15 +74,16 @@ def _wrapRemoteException():
     try:
         yield
     except pb.RemoteError as e:
-        if e.remoteType in (b'twisted.spread.flavors.NoSuchMethod',
-                            'twisted.spread.flavors.NoSuchMethod'):
+        if e.remoteType in (
+            b'twisted.spread.flavors.NoSuchMethod',
+            'twisted.spread.flavors.NoSuchMethod',
+        ):
             raise _NoSuchMethod(e) from e
         raise
 
 
 class Connection(base.Connection, pb.Avatar):
-    proxies = {base.FileWriterImpl: FileWriterProxy,
-               base.FileReaderImpl: FileReaderProxy}
+    proxies = {base.FileWriterImpl: FileWriterProxy, base.FileReaderImpl: FileReaderProxy}
     # TODO: configure keepalive_interval in
     # c['protocols']['pb']['keepalive_interval']
     keepalive_timer = None
@@ -96,9 +96,9 @@ class Connection(base.Connection, pb.Avatar):
         self.worker = worker
         self.mind = mind
         self._keepalive_waiter = deferwaiter.DeferWaiter()
-        self._keepalive_action_handler = \
-            deferwaiter.RepeatedActionHandler(master.reactor, self._keepalive_waiter,
-                                              self.keepalive_interval, self._do_keepalive)
+        self._keepalive_action_handler = deferwaiter.RepeatedActionHandler(
+            master.reactor, self._keepalive_waiter, self.keepalive_interval, self._do_keepalive
+        )
 
     # methods called by the PBManager
 
@@ -170,12 +170,14 @@ class Connection(base.Connection, pb.Avatar):
         except _NoSuchMethod:
             yield self.remotePrint(
                 "buildbot-slave detected, failing back to deprecated buildslave API. "
-                "(Ignoring missing getWorkerInfo method.)")
+                "(Ignoring missing getWorkerInfo method.)"
+            )
             info = {}
 
             # Probably this is deprecated buildslave.
-            log.msg("Worker.getWorkerInfo is unavailable - falling back to "
-                    "deprecated buildslave API")
+            log.msg(
+                "Worker.getWorkerInfo is unavailable - falling back to deprecated buildslave API"
+            )
 
             try:
                 with _wrapRemoteException():
@@ -193,8 +195,7 @@ class Connection(base.Connection, pb.Avatar):
             # commands and version using separate requests.
             try:
                 with _wrapRemoteException():
-                    info["worker_commands"] = yield self.mind.callRemote(
-                        'getCommands')
+                    info["worker_commands"] = yield self.mind.callRemote('getCommands')
             except _NoSuchMethod:
                 log.msg("Worker.getCommands is unavailable - ignoring")
 
@@ -216,8 +217,9 @@ class Connection(base.Connection, pb.Avatar):
         workerforbuilder = self.builders.get(builderName)
         remoteCommand = RemoteCommand(remoteCommand)
         args = self.createArgsProxies(args)
-        return workerforbuilder.callRemote('startCommand',
-                                           remoteCommand, commandId, commandName, args)
+        return workerforbuilder.callRemote(
+            'startCommand', remoteCommand, commandId, commandName, args
+        )
 
     @defer.inlineCallbacks
     def remoteShutdown(self):
@@ -268,9 +270,11 @@ class Connection(base.Connection, pb.Avatar):
                         log.msg(f"Lost connection to {name}")
                     else:
                         log.err(f"Unexpected error when trying to shutdown {name}")
+
                 return d
             log.err("Couldn't find remote builder to shut down worker")
             return defer.succeed(None)
+
         yield old_way()
 
     def remoteStartBuild(self, builderName):
@@ -279,8 +283,7 @@ class Connection(base.Connection, pb.Avatar):
 
     def remoteInterruptCommand(self, builderName, commandId, why):
         workerforbuilder = self.builders.get(builderName)
-        return defer.maybeDeferred(workerforbuilder.callRemote, "interruptCommand",
-                                   commandId, why)
+        return defer.maybeDeferred(workerforbuilder.callRemote, "interruptCommand", commandId, why)
 
     # perspective methods called by the worker
 
