@@ -42,13 +42,15 @@ class AvatarGitHub(AvatarBase):
 
     DEFAULT_GITHUB_API_URL = 'https://api.github.com'
 
-    def __init__(self,
-                 github_api_endpoint=None,
-                 token=None,
-                 client_id=None,
-                 client_secret=None,
-                 debug=False,
-                 verify=False):
+    def __init__(
+        self,
+        github_api_endpoint=None,
+        token=None,
+        client_id=None,
+        client_secret=None,
+        debug=False,
+        verify=False,
+    ):
         httpclientservice.HTTPClientService.checkAvailable(self.__class__.__name__)
 
         self.github_api_endpoint = github_api_endpoint
@@ -61,9 +63,9 @@ class AvatarGitHub(AvatarBase):
         if client_id:
             if token:
                 config.error('client_id and client_secret must not be provided when token is')
-            self.client_creds = base64.b64encode(b':'.join(
-                cred.encode('utf-8') for cred in (client_id, client_secret)
-            )).decode('ascii')
+            self.client_creds = base64.b64encode(
+                b':'.join(cred.encode('utf-8') for cred in (client_id, client_secret))
+            ).decode('ascii')
         self.debug = debug
         self.verify = verify
 
@@ -83,9 +85,13 @@ class AvatarGitHub(AvatarBase):
         elif self.client_creds:
             headers['Authorization'] = 'basic ' + self.client_creds
 
-        self.client = yield httpclientservice.HTTPClientService.getService(self.master,
-            self.github_api_endpoint, headers=headers,
-            debug=self.debug, verify=self.verify)
+        self.client = yield httpclientservice.HTTPClientService.getService(
+            self.master,
+            self.github_api_endpoint,
+            headers=headers,
+            debug=self.debug,
+            verify=self.verify,
+        )
 
         return self.client
 
@@ -95,7 +101,7 @@ class AvatarGitHub(AvatarBase):
             'Accept': 'application/vnd.github.v3+json',
         }
 
-        url = '/users/{}'.format(username)
+        url = f'/users/{username}'
         http = yield self._get_http_client()
         res = yield http.get(url, headers=headers)
         if res.code == 404:
@@ -105,7 +111,7 @@ class AvatarGitHub(AvatarBase):
             data = yield res.json()
             return data['avatar_url']
 
-        log.msg('Failed looking up user: response code {}'.format(res.code))
+        log.msg(f'Failed looking up user: response code {res.code}')
         return None
 
     @defer.inlineCallbacks
@@ -114,10 +120,8 @@ class AvatarGitHub(AvatarBase):
             'Accept': 'application/vnd.github.v3+json',
         }
 
-        query = '{} in:email'.format(email)
-        url = '/search/users?{}'.format(urlencode({
-            'q': query,
-        }))
+        query = f'{email} in:email'
+        url = f"/search/users?{urlencode({'q': query})}"
         http = yield self._get_http_client()
         res = yield http.get(url, headers=headers)
         if 200 <= res.code < 300:
@@ -127,7 +131,7 @@ class AvatarGitHub(AvatarBase):
                 return None
             return data['items'][0]['avatar_url']
 
-        log.msg('Failed searching user by email: response code {}'.format(res.code))
+        log.msg(f'Failed searching user by email: response code {res.code}')
         return None
 
     @defer.inlineCallbacks
@@ -137,12 +141,12 @@ class AvatarGitHub(AvatarBase):
         }
 
         query = {
-            'q': 'author-email:{}'.format(email),
+            'q': f'author-email:{email}',
             'sort': 'committer-date',
             'per_page': '1',
         }
         sorted_query = sorted(query.items(), key=lambda x: x[0])
-        url = '/search/commits?{}'.format(urlencode(sorted_query))
+        url = f'/search/commits?{urlencode(sorted_query)}'
         http = yield self._get_http_client()
         res = yield http.get(url, headers=headers)
         if 200 <= res.code < 300:
@@ -156,7 +160,7 @@ class AvatarGitHub(AvatarBase):
                 return None
             return author['avatar_url']
 
-        log.msg('Failed searching user by commit: response code {}'.format(res.code))
+        log.msg(f'Failed searching user by commit: response code {res.code}')
         return None
 
     def _add_size_to_url(self, avatar, size):
@@ -164,10 +168,15 @@ class AvatarGitHub(AvatarBase):
         query = parts.query
         if query:
             query += '&'
-        query += 's={0}'.format(size)
-        return urlunparse((parts.scheme,
-            parts.netloc, parts.path, parts.params,
-            query, parts.fragment))
+        query += f's={size}'
+        return urlunparse((
+            parts.scheme,
+            parts.netloc,
+            parts.path,
+            parts.params,
+            query,
+            parts.fragment,
+        ))
 
     @defer.inlineCallbacks
     def getUserAvatar(self, email, username, size, defaultAvatarUrl):
@@ -224,11 +233,12 @@ class AvatarResource(resource.Resource):
     def reconfigResource(self, new_config):
         self.avatarMethods = new_config.www.get('avatar_methods', [])
         self.defaultAvatarFullUrl = urljoin(
-            unicode2bytes(new_config.buildbotURL), unicode2bytes(self.defaultAvatarUrl))
+            unicode2bytes(new_config.buildbotURL), unicode2bytes(self.defaultAvatarUrl)
+        )
         self.cache = {}
         # ensure the avatarMethods is a iterable
         if isinstance(self.avatarMethods, AvatarBase):
-            self.avatarMethods = (self.avatarMethods, )
+            self.avatarMethods = (self.avatarMethods,)
 
         for method in self.avatarMethods:
             method.master = self.master
