@@ -26,6 +26,7 @@ from twisted.python import log
 from twisted.web.error import Error
 
 from buildbot.data import exceptions
+from buildbot.data.base import EndpointKind
 from buildbot.util import bytes2unicode
 from buildbot.util import toJson
 from buildbot.util import unicode2bytes
@@ -34,20 +35,17 @@ from buildbot.www.authz import Forbidden
 
 
 class BadJsonRpc2(Exception):
-
     def __init__(self, message, jsonrpccode):
         self.message = message
         self.jsonrpccode = jsonrpccode
 
 
 class ContentTypeParser:
-
     def __init__(self, contenttype):
         self.typeheader = contenttype
 
     def gettype(self):
-        mimetype, _ = cgi.parse_header(
-            bytes2unicode(self.typeheader))
+        mimetype, _ = cgi.parse_header(bytes2unicode(self.typeheader))
         return mimetype
 
 
@@ -81,9 +79,9 @@ class RestRootResource(resource.Resource):
     def render(self, request):
         request.setHeader(b"content-type", JSON_ENCODED)
         min_vers = self.master.config.www.get('rest_minimum_version', 0)
-        api_versions = dict((f'v{v}', f'{self.base_url}api/v{v}')
-                            for v in self.version_classes
-                            if v > min_vers)
+        api_versions = dict(
+            (f'v{v}', f'{self.base_url}api/v{v}') for v in self.version_classes if v > min_vers
+        )
         data = json.dumps({"api_versions": api_versions})
         return unicode2bytes(data)
 
@@ -93,12 +91,11 @@ JSONRPC_CODES = {
     "invalid_request": -32600,
     "method_not_found": -32601,
     "invalid_params": -32602,
-    "internal_error": -32603
+    "internal_error": -32603,
 }
 
 
 class V2RootResource(resource.Resource):
-
     # For GETs, this API follows http://jsonapi.org.  The getter API does not
     # permit create, update, or delete, so this is limited to reading.
     #
@@ -121,8 +118,7 @@ class V2RootResource(resource.Resource):
     def getEndpoint(self, request, method, params):
         # note that trailing slashes are not allowed
         request_postpath = tuple(bytes2unicode(p) for p in request.postpath)
-        yield self.master.www.assertUserAllowed(request, request_postpath,
-                                                method, params)
+        yield self.master.www.assertUserAllowed(request, request_postpath, method, params)
         ret = yield self.master.data.getEndpoint(request_postpath)
         return ret
 
@@ -132,18 +128,25 @@ class V2RootResource(resource.Resource):
             yield
         except exceptions.InvalidPathError as e:
             msg = unicode2bytes(e.args[0])
-            writeError(msg or b"invalid path", errcode=404,
-                       jsonrpccode=JSONRPC_CODES['invalid_request'])
+            writeError(
+                msg or b"invalid path", errcode=404, jsonrpccode=JSONRPC_CODES['invalid_request']
+            )
             return
         except exceptions.InvalidControlException as e:
             msg = unicode2bytes(str(e))
-            writeError(msg or b"invalid control action", errcode=501,
-                       jsonrpccode=JSONRPC_CODES["method_not_found"])
+            writeError(
+                msg or b"invalid control action",
+                errcode=501,
+                jsonrpccode=JSONRPC_CODES["method_not_found"],
+            )
             return
         except exceptions.InvalidQueryParameter as e:
             msg = unicode2bytes(e.args[0])
-            writeError(msg or b"invalid request", errcode=400,
-                       jsonrpccode=JSONRPC_CODES["method_not_found"])
+            writeError(
+                msg or b"invalid request",
+                errcode=400,
+                jsonrpccode=JSONRPC_CODES["method_not_found"],
+            )
             return
         except BadJsonRpc2 as e:
             msg = unicode2bytes(e.message)
@@ -153,14 +156,12 @@ class V2RootResource(resource.Resource):
             # There is nothing in jsonrc spec about forbidden error, so pick
             # invalid request
             msg = unicode2bytes(e.message)
-            writeError(
-                msg, errcode=403, jsonrpccode=JSONRPC_CODES["invalid_request"])
+            writeError(msg, errcode=403, jsonrpccode=JSONRPC_CODES["invalid_request"])
             return
         except Exception as e:
             log.err(_why='while handling API request')
             msg = unicode2bytes(repr(e))
-            writeError(repr(e), errcode=500,
-                       jsonrpccode=JSONRPC_CODES["internal_error"])
+            writeError(repr(e), errcode=500, jsonrpccode=JSONRPC_CODES["internal_error"])
             return
 
     # JSONRPC2 support
@@ -170,8 +171,9 @@ class V2RootResource(resource.Resource):
         # POST data to arbitrary URLs via 'form' elements, but they won't
         # use the application/json content-type.
         if ContentTypeParser(request.getHeader(b'content-type')).gettype() != "application/json":
-            raise BadJsonRpc2('Invalid content-type (use application/json)',
-                              JSONRPC_CODES["invalid_request"])
+            raise BadJsonRpc2(
+                'Invalid content-type (use application/json)', JSONRPC_CODES["invalid_request"]
+            )
 
         try:
             data = json.loads(bytes2unicode(request.content.read()))
@@ -179,33 +181,33 @@ class V2RootResource(resource.Resource):
             raise BadJsonRpc2(f"JSON parse error: {str(e)}", JSONRPC_CODES["parse_error"]) from e
 
         if isinstance(data, list):
-            raise BadJsonRpc2("JSONRPC batch requests are not supported",
-                              JSONRPC_CODES["invalid_request"])
+            raise BadJsonRpc2(
+                "JSONRPC batch requests are not supported", JSONRPC_CODES["invalid_request"]
+            )
         if not isinstance(data, dict):
-            raise BadJsonRpc2("JSONRPC root object must be an object",
-                              JSONRPC_CODES["invalid_request"])
+            raise BadJsonRpc2(
+                "JSONRPC root object must be an object", JSONRPC_CODES["invalid_request"]
+            )
 
         def check(name, types, typename):
             if name not in data:
                 raise BadJsonRpc2(f"missing key '{name}'", JSONRPC_CODES["invalid_request"])
             if not isinstance(data[name], types):
                 raise BadJsonRpc2(f"'{name}' must be {typename}", JSONRPC_CODES["invalid_request"])
+
         check("jsonrpc", (str,), "a string")
         check("method", (str,), "a string")
-        check("id", (str, int, type(None)),
-              "a string, number, or null")
+        check("id", (str, int, type(None)), "a string, number, or null")
         check("params", (dict,), "an object")
         if data['jsonrpc'] != '2.0':
-            raise BadJsonRpc2("only JSONRPC 2.0 is supported",
-                              JSONRPC_CODES['invalid_request'])
+            raise BadJsonRpc2("only JSONRPC 2.0 is supported", JSONRPC_CODES['invalid_request'])
         return data["method"], data["id"], data['params']
 
     @defer.inlineCallbacks
     def renderJsonRpc(self, request):
         jsonRpcReply = {'jsonrpc': "2.0"}
 
-        def writeError(msg, errcode=399,
-                       jsonrpccode=JSONRPC_CODES["internal_error"]):
+        def writeError(msg, errcode=399, jsonrpccode=JSONRPC_CODES["internal_error"]):
             if isinstance(msg, bytes):
                 msg = bytes2unicode(msg)
             if self.debug:
@@ -235,8 +237,7 @@ class V2RootResource(resource.Resource):
             result = yield ep.control(method, params, kwargs)
             jsonRpcReply['result'] = result
 
-            data = json.dumps(jsonRpcReply, default=toJson,
-                              sort_keys=True, separators=(',', ':'))
+            data = json.dumps(jsonRpcReply, default=toJson, sort_keys=True, separators=(',', ':'))
 
             request.setHeader(b'content-type', JSON_ENCODED)
             if request.method == b"HEAD":
@@ -249,13 +250,16 @@ class V2RootResource(resource.Resource):
     def decodeResultSpec(self, request, endpoint):
         args = request.args
         entityType = endpoint.rtype.entityType
-        return self.master.data.resultspec_from_jsonapi(args, entityType, endpoint.isCollection)
+        return self.master.data.resultspec_from_jsonapi(
+            args, entityType, endpoint.kind == EndpointKind.COLLECTION
+        )
 
-    def encodeRaw(self, data, request):
-        request.setHeader(b"content-type",
-                          unicode2bytes(data['mime-type']) + b'; charset=utf-8')
-        request.setHeader(b"content-disposition",
-                          b'attachment; filename=' + unicode2bytes(data['filename']))
+    def encodeRaw(self, data, request, is_inline):
+        request.setHeader(b"content-type", unicode2bytes(data['mime-type']) + b'; charset=utf-8')
+        if not is_inline:
+            request.setHeader(
+                b"content-disposition", b'attachment; filename=' + unicode2bytes(data['filename'])
+            )
         request.write(unicode2bytes(data['raw']))
         return
 
@@ -277,14 +281,20 @@ class V2RootResource(resource.Resource):
             rspec = self.decodeResultSpec(request, ep)
             data = yield ep.get(rspec, kwargs)
             if data is None:
-                msg = (f"not found while getting from {repr(ep)} with "
-                       f"arguments {repr(rspec)} and {str(kwargs)}")
+                msg = (
+                    f"not found while getting from {repr(ep)} with "
+                    f"arguments {repr(rspec)} and {str(kwargs)}"
+                )
                 msg = unicode2bytes(msg)
                 writeError(msg, errcode=404)
                 return
 
-            if ep.isRaw:
-                self.encodeRaw(data, request)
+            if ep.kind == EndpointKind.RAW:
+                self.encodeRaw(data, request, False)
+                return
+
+            if ep.kind == EndpointKind.RAW_INLINE:
+                self.encodeRaw(data, request, True)
                 return
 
             # post-process any remaining parts of the resultspec
@@ -292,7 +302,7 @@ class V2RootResource(resource.Resource):
 
             # annotate the result with some metadata
             meta = {}
-            if ep.isCollection:
+            if ep.kind == EndpointKind.COLLECTION:
                 offset, total = data.offset, data.total
                 if offset is None:
                     offset = 0
@@ -307,10 +317,7 @@ class V2RootResource(resource.Resource):
                 data = [data]
 
             typeName = ep.rtype.plural
-            data = {
-                typeName: data,
-                'meta': meta
-            }
+            data = {typeName: data, 'meta': meta}
 
             # set up the content type and formatting options; if the request
             # accepts text/html or text/plain, the JSON will be rendered in a
@@ -318,29 +325,24 @@ class V2RootResource(resource.Resource):
 
             if b'application/json' in (request.getHeader(b'accept') or b''):
                 compact = True
-                request.setHeader(b"content-type",
-                                  b'application/json; charset=utf-8')
+                request.setHeader(b"content-type", b'application/json; charset=utf-8')
             else:
                 compact = False
-                request.setHeader(b"content-type",
-                                  b'text/plain; charset=utf-8')
+                request.setHeader(b"content-type", b'text/plain; charset=utf-8')
 
             # set up caching
             if self.cache_seconds:
-                now = datetime.datetime.utcnow()
+                now = datetime.datetime.now(datetime.timezone.utc)
                 expires = now + datetime.timedelta(seconds=self.cache_seconds)
-                expiresBytes = unicode2bytes(
-                    expires.strftime("%a, %d %b %Y %H:%M:%S GMT"))
+                expiresBytes = unicode2bytes(expires.strftime("%a, %d %b %Y %H:%M:%S GMT"))
                 request.setHeader(b"Expires", expiresBytes)
                 request.setHeader(b"Pragma", b"no-cache")
 
             # filter out blanks if necessary and render the data
             if compact:
-                data = json.dumps(data, default=toJson,
-                                  sort_keys=True, separators=(',', ':'))
+                data = json.dumps(data, default=toJson, sort_keys=True, separators=(',', ':'))
             else:
-                data = json.dumps(data, default=toJson,
-                                  sort_keys=True, indent=2)
+                data = json.dumps(data, default=toJson, sort_keys=True, indent=2)
 
             if request.method == b"HEAD":
                 request.setHeader(b"content-length", unicode2bytes(str(len(data))))
@@ -380,11 +382,11 @@ class V2RootResource(resource.Resource):
                 data = unicode2bytes(data)
                 request.write(data)
             request.finish()
+
         return self.asyncRenderHelper(request, self.asyncRender, writeError)
 
     @defer.inlineCallbacks
     def asyncRender(self, request):
-
         # Handle CORS, if necessary.
         origins = self.origins
         if origins is not None:
@@ -396,8 +398,7 @@ class V2RootResource(resource.Resource):
                 if not any(o.match(bytes2unicode(reqOrigin)) for o in self.origins):
                     err = b"invalid origin"
                 elif request.method == b'OPTIONS':
-                    preflightMethod = request.getHeader(
-                        b'access-control-request-method')
+                    preflightMethod = request.getHeader(b'access-control-request-method')
                     if preflightMethod not in (b'GET', b'POST', b'HEAD'):
                         err = b'invalid method'
                     isPreflight = True
@@ -409,8 +410,7 @@ class V2RootResource(resource.Resource):
                 # content types other than form data and text/plain to not be
                 # simple.
                 request.setHeader(b"access-control-allow-origin", reqOrigin)
-                request.setHeader(b"access-control-allow-headers",
-                                  b"Content-Type")
+                request.setHeader(b"access-control-allow-headers", b"Content-Type")
                 request.setHeader(b"access-control-max-age", b'3600')
 
                 # if this was a preflight request, we're done
